<?php
/**
 * Common utility functions used in the plugin
 *
 */
if ( ! function_exists( 'landkit_elementor_get_theme_typography' ) ) {
    function landkit_elementor_get_theme_typography() {
        $typo_name   = 'typography';
        $typo_prefix = $typo_name . '_';

        $typography_key     = $typo_prefix . 'typography';
        $font_family_key    = $typo_prefix . 'font_family';
        $font_weight_key    = $typo_prefix . 'font_weight';
        $font_size_key      = $typo_prefix . 'font_size';
        $line_height_key    = $typo_prefix . 'line_height';
        $letter_spacing_key = $typo_prefix . 'letter_spacing';

        $landkit_fonts = [
            [
                '_id'               => 'display-3',
                'title'             => esc_html__( 'Display 3', 'landkit-elementor' ),
                $typography_key     => 'custom',
                $line_height_key    => '1.2',
                $font_size_key   => array(
                    'unit'  => 'rem',
                    'size'  => '3'
                ),
                $font_weight_key => '400',
                $letter_spacing_key => array(
                    'unit' => 'em',
                    'size' => '-.02'
                )
            ],
            [
                '_id'            => 'lead',
                'title'          => esc_html__( 'Lead', 'landkit-elementor' ),
                $typography_key  => 'custom',
                $font_family_key => 'default',
                $font_weight_key => '400',
                $font_size_key   => array(
                    'unit'  => 'rem',
                    'size'  => '1.325'
                )
            ],
            [
                '_id'            => 'font-size-lg',
                'title'          => esc_html__( 'Font Size - Lg', 'landkit-elementor' ),
                $font_size_key   => array(
                    'unit'  => 'rem',
                    'size'  => '1.875'
                )
            ],
            [
                '_id'            => 'font-weight-bold',
                'title'          => esc_html__( 'Font Weight - Bold', 'landkit-elementor' ),
                $font_weight_key => '600',
            ]
        ];

        return $landkit_fonts;
    }
}

if ( ! function_exists( 'landkit_elementor_get_theme_colors' ) ) {
    function landkit_elementor_get_theme_colors() {
        $landkit_colors = [
            [
                '_id' => 'primary',
                'title' => esc_html__( 'Primary', 'landkit-elementor' ),
                'color' => '#335EEA',
            ],
            [
                '_id' => 'secondary',
                'title' => esc_html__( 'Secondary', 'landkit-elementor' ),
                'color' => '#506690',
            ],
            [
                '_id' => 'primary-desat',
                'title' => esc_html__( 'Primary Desat', 'landkit-elementor' ),
                'color' => '#6C8AEC',
            ],
            [
                '_id' => 'success',
                'title' => esc_html__( 'Success', 'landkit-elementor' ),
                'color' => '#42BA96',
            ],
            [
                '_id' => 'info',
                'title' => esc_html__( 'Info', 'landkit-elementor' ),
                'color' => '#7C69EF',
            ],
            [
                '_id' => 'warning',
                'title' => esc_html__( 'Warning', 'landkit-elementor' ),
                'color' => '#FAD776',
            ],
            [
                '_id' => 'danger',
                'title' => esc_html__( 'Danger', 'landkit-elementor' ),
                'color' => '#DF4759',
            ],
            [
                '_id' => 'light',
                'title' => esc_html__( 'Light', 'landkit-elementor' ),
                'color' => '#F9FBFD',
            ],
            [
                '_id' => 'dark',
                'title' => esc_html__( 'Dark', 'landkit-elementor' ),
                'color' => '#1B2A4E',
            ],
            [
                '_id' => 'white',
                'title' => esc_html__( 'White', 'landkit-elementor' ),
                'color' => '#FFFFFF',
            ],
            [
                '_id' => 'black',
                'title' => esc_html__( 'Black', 'landkit-elementor' ),
                'color' => '#161C2D',
            ],
            [
                '_id' => 'text',
                'title' => esc_html__( 'Text', 'landkit-elementor' ),
                'color' => '#161C2D',
            ],
            [
                '_id' => 'text-muted',
                'title' => esc_html__( 'Text Muted', 'landkit-elementor' ),
                'color' => '#869ab8',
            ],
            [
                '_id' => 'gray-100',
                'title' => esc_html__( 'Gray 100', 'landkit-elementor' ),
                'color' => '#F9FBFD',
            ],
            [
                '_id' => 'gray-200',
                'title' => esc_html__( 'Gray 200', 'landkit-elementor' ),
                'color' => '#F1F4F8',
            ],
            [
                '_id' => 'gray-300',
                'title' => esc_html__( 'Gray 300', 'landkit-elementor' ),
                'color' => '#D9E2EF',
            ],
            [
                '_id' => 'gray-400',
                'title' => esc_html__( 'Gray 400', 'landkit-elementor' ),
                'color' => '#C6D3E6',
            ],
            [
                '_id' => 'gray-500',
                'title' => esc_html__( 'Gray 500', 'landkit-elementor' ),
                'color' => '#ABBCD5',
            ],
            [
                '_id' => 'gray-600',
                'title' => esc_html__( 'Gray 600', 'landkit-elementor' ),
                'color' => '#869AB8',
            ],
            [
                '_id' => 'gray-700',
                'title' => esc_html__( 'Gray 700', 'landkit-elementor' ),
                'color' => '#506690',
            ],
            [
                '_id' => 'gray-800',
                'title' => esc_html__( 'Gray 800', 'landkit-elementor' ),
                'color' => '#384C74',
            ],
            [
                '_id' => 'gray-900',
                'title' => esc_html__( 'Gray 900', 'landkit-elementor' ),
                'color' => '#1B2A4E',
            ],
            [
                '_id' => 'accent',
                'title' => __( 'Accent', 'landkit-elementor' ),
                'color' => '#335EEA',
            ],
        ];

        return $landkit_colors;
    }
}