<?php
/**
 * Plugin Name: Landkit Elementor
 * Description: Elementor Extensions built for Landkit Multipurpose Business WordPress Theme
 * Plugin URI:  https://themeforest.net/user/madrasthemes/portfolio
 * Version:     1.0.16
 * Author:      MadrasThemes
 * Author URI:  https://madrasthemes.com/
 * Elementor tested up to: 3.6.0
 * Text Domain: landkit-elementor
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

define( 'LANDKIT_ELEMENTOR_VERSION', '1.0.4' );
define( 'LANDKIT_ELEMENTOR_PREVIOUS_STABLE_VERSION', '1.0.4' );

define( 'LANDKIT_ELEMENTOR__FILE__', __FILE__ );
define( 'LANDKIT_ELEMENTOR_PLUGIN_BASE', plugin_basename( LANDKIT_ELEMENTOR__FILE__ ) );
define( 'LANDKIT_ELEMENTOR_PATH', plugin_dir_path( LANDKIT_ELEMENTOR__FILE__ ) );
define( 'LANDKIT_ELEMENTOR_ASSETS_PATH', LANDKIT_ELEMENTOR_PATH . 'assets/' );
define( 'LANDKIT_ELEMENTOR_MODULES_PATH', LANDKIT_ELEMENTOR_PATH . 'modules/' );
define( 'LANDKIT_ELEMENTOR_INCLUDES_PATH', LANDKIT_ELEMENTOR_PATH . 'includes/' );
define( 'LANDKIT_ELEMENTOR_TEMPLATES_PATH', LANDKIT_ELEMENTOR_PATH . 'templates/' );
define( 'LANDKIT_ELEMENTOR_URL', plugins_url( '/', LANDKIT_ELEMENTOR__FILE__ ) );
define( 'LANDKIT_ELEMENTOR_ASSETS_URL', LANDKIT_ELEMENTOR_URL . 'assets/' );
define( 'LANDKIT_ELEMENTOR_MODULES_URL', LANDKIT_ELEMENTOR_URL . 'modules/' );
define( 'LANDKIT_ELEMENTOR_INCLUDES_URL', LANDKIT_ELEMENTOR_URL . 'includes/' );

/**
 * Load gettext translate for our text domain.
 *
 * @since 1.0.0
 *
 * @return void
 */
function landkit_elementor_load_plugin() {
	load_plugin_textdomain( 'landkit-elementor' );

	if ( ! did_action( 'elementor/loaded' ) ) {
		add_action( 'admin_notices', 'landkit_elementor_fail_load' );

		return;
	}

	$elementor_version_required = '3.0.0';
	if ( ! version_compare( ELEMENTOR_VERSION, $elementor_version_required, '>=' ) ) {
		add_action( 'admin_notices', 'landkit_elementor_fail_load_out_of_date' );

		return;
	}

	$elementor_version_recommendation = '3.0.0';
	if ( ! version_compare( ELEMENTOR_VERSION, $elementor_version_recommendation, '>=' ) ) {
		add_action( 'admin_notices', 'landkit_elementor_admin_notice_upgrade_recommendation' );
	}

	require LANDKIT_ELEMENTOR_PATH . 'plugin.php';
}

add_action( 'plugins_loaded', 'landkit_elementor_load_plugin' );

/**
 * Show in WP Dashboard notice about the plugin is not activated.
 *
 * @since 1.0.0
 *
 * @return void
 */
function landkit_elementor_fail_load() {
	$screen = get_current_screen();
	if ( isset( $screen->parent_file ) && 'plugins.php' === $screen->parent_file && 'update' === $screen->id ) {
		return;
	}

	$plugin = 'elementor/elementor.php';

	if ( _is_elementor_installed() ) {
		if ( ! current_user_can( 'activate_plugins' ) ) {
			return;
		}

		$activation_url = wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $plugin . '&amp;plugin_status=all&amp;paged=1&amp;s', 'activate-plugin_' . $plugin );

		$message = '<p>' . esc_html__( 'Landkit Elementor is not working because you need to activate the Elementor plugin.', 'landkit-elementor' ) . '</p>';
		$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $activation_url, esc_html__( 'Activate Elementor Now', 'landkit-elementor' ) ) . '</p>';
	} else {
		if ( ! current_user_can( 'install_plugins' ) ) {
			return;
		}

		$install_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=elementor' ), 'install-plugin_elementor' );

		$message = '<p>' . esc_html__( 'Landkit Elementor is not working because you need to install the Elementor plugin.', 'landkit-elementor' ) . '</p>';
		$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $install_url, esc_html__( 'Install Elementor Now', 'landkit-elementor' ) ) . '</p>';
	}

	echo '<div class="error"><p>' . wp_kses_post( $message ) . '</p></div>';
}

/**
 * Display error message for using out of date Elementor.
 */
function landkit_elementor_fail_load_out_of_date() {
	if ( ! current_user_can( 'update_plugins' ) ) {
		return;
	}

	$file_path = 'elementor/elementor.php';

	$upgrade_link = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' ) . $file_path, 'upgrade-plugin_' . $file_path );
	$message = '<p>' . esc_html__( 'Landkit Elementor is not working because you are using an old version of Elementor.', 'landkit-elementor' ) . '</p>';
	$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $upgrade_link, esc_html__( 'Update Elementor Now', 'landkit-elementor' ) ) . '</p>';

	echo '<div class="error">' . wp_kses_post( $message ) . '</div>';
}

/**
 * Display upgrade recommendation notice.
 */
function landkit_elementor_admin_notice_upgrade_recommendation() {
	if ( ! current_user_can( 'update_plugins' ) ) {
		return;
	}

	$file_path = 'elementor/elementor.php';

	$upgrade_link = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' ) . $file_path, 'upgrade-plugin_' . $file_path );
	$message = '<p>' . esc_html__( 'A new version of Elementor is available. For better performance and compatibility of Landkit Elementor, we recommend updating to the latest version.', 'landkit-elementor' ) . '</p>';
	$message .= '<p>' . sprintf( '<a href="%s" class="button-primary">%s</a>', $upgrade_link, esc_html__( 'Update Elementor Now', 'landkit-elementor' ) ) . '</p>';

	echo '<div class="error">' . wp_kses_post( $message ) . '</div>';
}

if ( ! function_exists( '_is_elementor_installed' ) ) {
	/**
	 * Check if elementor is installed.
	 *
	 * @return bool
	 */
	function _is_elementor_installed() {
		$file_path = 'elementor/elementor.php';
		$installed_plugins = get_plugins();

		return isset( $installed_plugins[ $file_path ] );
	}
}
