<?php
namespace LandkitElementor\Modules\Accordion\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Skin_Base;
use Elementor\Icons_Manager;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use LandkitElementor\Plugin as LKPlugin;
use Elementor\Plugin;

use LandkitElementor\Core\Utils as LKUtils;

class Skin_Accordion_Card extends Skin_Base {
    
    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
        add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
        add_action( 'elementor/element/accordion/section_title/before_section_end', [ $this, 'section_title_controls' ], 10 );
        add_action( 'elementor/element/accordion/section_toggle_style_content/after_section_end', [ $this, 'style_controls' ] , 10 );
    }

    public function get_id() {
        return 'accordion-card';
    }

    public function get_title() {
        return esc_html__( 'Card', 'landkit-elementor' );
    }

    public function section_title_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;

        $this->parent->update_control(
            'tabs', [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );
        
        $this->parent->update_control(
            'selected_icon', [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );

        $this->parent->update_control(
            'selected_active_icon', [
                'condition' => [
                    'selected_icon[value]!' => '',
                    '_skin' => '',
                ],
            ]
        );

        $this->parent->update_control(
            'title_html_tag', [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );

        $this->add_control( 'id', [
            'label'       => esc_html__( 'ID', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'description' => esc_html__( 'Give the accordion a unique ID', 'landkit-elementor' ),
            'default'     => 'accordion-' . uniqid()
        ] );

        $repeater = new Repeater();

        $repeater->add_control(
            'title', [
                'label'       => esc_html__( 'Title', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => esc_html__( 'Accordion Title', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Accordion Title', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'subtitle', [
                'label'       => esc_html__( 'Subtitle', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => esc_html__( 'Accordion Subtitle', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Accordion Subtitle', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'content', [
                'label'       => esc_html__( 'Content', 'landkit-elementor' ),
                'type'        => Controls_Manager::WYSIWYG,
                'label_block' => true,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Sunt rerum minima a possimus, amet perferendis, temporibus.', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Accordion Content', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'link_enable', [
                'label'     => esc_html__( 'Enable Link', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'link_text', [
                'label'       => esc_html__( 'Link Text', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic'     => [
                    'active' => true,
                ],
                'condition' => [
                    'link_enable' => 'yes',
                ],
                'default'     => esc_html__( 'Check Out', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Check Out', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'link', [
                'label'       => esc_html__( 'Link', 'landkit-elementor' ),
                'type'        => Controls_Manager::URL,
                'dynamic'     => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'landkit-elementor' ),
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'link_enable' => 'yes',
                ],
            ]
        );

        $repeater->add_control(
            'link_icon', [
                'label'            => esc_html__( 'Icon', 'landkit-elementor' ),
                'type'             => Controls_Manager::ICONS,
                'condition'        => [
                    'link_enable' => 'yes',
                ],
            ]
        );

        $repeater->add_control(
            'badge', [
                'label'     => esc_html__( 'Enable Badge', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'no',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'badge_text', [
                'label'     => esc_html__( 'Badge Text', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'Text',
                'condition' => [
                    'badge' => 'yes',
                ],

            ]
        );

        $repeater->add_control(
            'badge_color', [
                'label'     => esc_html__( 'Badge Background', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'primary'   => 'Primary',
                    'secondary' => 'Secondary',
                    'success'   => 'Success',
                    'danger'    => 'Danger',
                    'warning'   => 'Warning',
                    'info'      => 'Info',
                    'light'     => 'Light',
                    'dark'      => 'Dark',
                ],
                'condition' => [
                    'badge' => 'yes',
                ],
                'default'   => 'success',
            ]
        );


        $this->add_control(
            'content_settings', [
                'type'      => Controls_Manager::REPEATER,
                'fields'    => $repeater->get_controls(),
                'default'   => [
                    [
                        'title'    => esc_html__( 'Flexible access to facilities.', 'landkit-elementor' ),
                        'subtitle' => esc_html__( 'Our new key fobs make it so easy!', 'landkit-elementor' ),
                    ],
                    [
                        'title'    => esc_html__( 'Snacks, drinks, coffee, and more.', 'landkit-elementor' ),
                        'subtitle' => esc_html__( 'Keep your engine going with free food and drinks.', 'landkit-elementor' ),

                    ],
                    [
                        'title'    => esc_html__( 'On site tech support', 'landkit-elementor' ),
                        'subtitle' => esc_html__( 'Connectivity, power, and IT issues solved in no time.', 'landkit-elementor' ),
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
    }

    public function style_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;

        $this->parent->update_control( 
            'section_toggle_style_content', 
            [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );

        $this->parent->update_control( 
            'section_title_style', 
            [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );

        $this->parent->update_control( 
            'section_toggle_style_title', 
            [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );

        $this->parent->update_control( 
            'section_toggle_style_icon', 
            [
                'condition' => [
                    '_skin' => '',
                ],
            ]
        );

        $this->start_controls_section(
            'title_section', [
                'label' => esc_html__( 'Title', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label'     => esc_html__( 'Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .accordion__title' => 'color: {{VALUE}};',
                ],
                'global'    => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .accordion .accordion__title',
                'global'   => [
                    'default' => Global_Typography::TYPOGRAPHY_TEXT,
                ],
            ]
        );

        $this->add_control(
            'title_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'font-weight-bold'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'subtitle_section', [
                'label' => esc_html__( 'Subtitle', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label'     => esc_html__( 'Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .accordion__subtitle' => 'color: {{VALUE}};',
                ],
                'global'    => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'sub_title_typography',
                'selector' => '{{WRAPPER}} .accordion .accordion__subtitle',
                'global'   => [
                    'default' => Global_Typography::TYPOGRAPHY_TEXT,
                ],
            ]
        );

        $this->add_control(
            'subtitle_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'font-size-sm text-muted'
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_section', [
                'label' => esc_html__( 'Content', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_color', [
                'label'     => esc_html__( 'Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .accordion__content' => 'color: {{VALUE}};',
                ],
                'global'    => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .accordion__content',
                'global'   => [
                    'default' => Global_Typography::TYPOGRAPHY_TEXT,
                ],
            ]
        );

        $this->add_control(
            'content_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );

        $this->end_controls_section();
    }

    public function render() {     
        $widget   = $this->parent;
        $settings = $widget->get_settings();

        $id       = ! empty( $settings[ $this->get_control_id( 'id') ] ) ? $settings[ $this->get_control_id( 'id') ] : 'featuresAccordion';

        $title_css = $settings[ $this->get_control_id( 'title_css' ) ];
        $widget->add_render_attribute( 'title', 'class', [
            'accordion__title', 'mb-0'
        ] );
        if ( ! empty( $title_css ) ) {
            $widget->add_render_attribute( 'title', 'class', $title_css );
        }

        $subtitle_css = $settings[ $this->get_control_id( 'subtitle_css' ) ];
        $widget->add_render_attribute( 'subtitle', 'class', [
            'accordion__subtitle', 'mb-0'
        ] );
        if ( ! empty( $subtitle_css ) ) {
            $widget->add_render_attribute( 'subtitle', 'class', $subtitle_css );
        }

        $content_css = $settings[ $this->get_control_id( 'content_css' ) ];
        $widget->add_render_attribute( 'content', 'class', [
            'accordion__content', 'py-5', 'py-mb-6'
        ] );
        if ( ! empty( $content_css ) ) {
            $widget->add_render_attribute( 'content', 'class', $content_css );
        }

        $items = $settings[ $this->get_control_id( 'content_settings' ) ];

        ?>
        <div class="card accordion" id="<?php echo esc_attr( $id ); ?>">
            <div class="card-body">
                <div class="list-group list-group-flush">
                <?php foreach( $items as $index => $item ) :
                    
                    $count             = $index + 1;
                    $link_setting_key  = LKPlugin::instance()->modules_manager->get_repeater_setting_key( 'link', 'content_settings', $index );

                    $widget->add_link_attributes( $link_setting_key, $item['link'] );
                ?>
                <div class="list-group-item">
                    <a class="d-flex align-items-center text-reset text-decoration-none" data-toggle="collapse" href="#features<?php echo $count; ?>" role="button" <?php if ( $count === 1 ): ?>aria-expanded="true"<?php else: ?>aria-expanded="false"<?php endif; ?> aria-controls="features<?php echo $count?>">
                        <div class="mr-auto">
                            <p <?php echo $widget->get_render_attribute_string( 'title' );?>>
                                <?php echo $item['title']; ?>
                            </p>
                            <p <?php echo $widget->get_render_attribute_string( 'subtitle' ); ?>>
                                <?php echo $item['subtitle']; ?>
                            </p>
                        </div>
                        <?php
                            if ( $item['badge'] == 'yes' ) {
                                ?><span class="badge badge-pill badge-<?php echo esc_attr( $item[ 'badge_color' ] ); ?>-soft ml-4">
                                    <span class="h6 text-uppercase"><?php echo $item['badge_text']; ?></span>
                                </span>
                                <?php
                            }
                        ?>
                        <span class="collapse-chevron text-muted ml-4">
                            <i class="fe fe-lg fe-chevron-down"></i>
                        </span>
                    </a>
                    <div class="collapse<?php if ( $count === 1 ): ?> show<?php endif;?>" id="features<?php echo $count; ?>" data-parent="#<?php echo $id; ?>">
                        <div <?php echo $widget->get_render_attribute_string( 'content' ); ?>>
                            <?php echo LKUtils::parse_text_editor( $item['content'], $settings ); ?>
                            <?php
                                if ( $item['link_enable'] == 'yes' ) {                                
                                    ?><a <?php echo $widget->get_render_attribute_string( $link_setting_key ); ?> class="font-weight-bold text-decoration-none d-block mt-4">
                                        <?php echo $item['link_text']; ?>
                                        <?php 
                                            if ( ! empty( $item['link_icon'] ) || ! empty( $item['link_icon']['value'] ) ) :
                                                Icons_Manager::render_icon( $item['link_icon'], [ 
                                                    'aria-hidden' => 'true', 
                                                    'class'       => 'ml-3' 
                                                ] );
                                            endif;
                                        ?>
                                    </a>
                                    <?php
                                }
                            ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
            </div>
        </div>
        <?php
    }

    public function skin_print_template( $content, $widget ) {
        if( 'accordion' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }
}