<?php

namespace LandkitElementor\Modules\AosAnimation;

use LandkitElementor\Base\Module_Base;
use Elementor\Controls_Manager;
use LandkitElementor\Plugin;
use LandkitElementor\Core\Controls_Manager as LE_Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Module extends Module_Base {

    public function get_name() {
        return 'override-motion-effects';
    }

    public function __construct() {
        parent::__construct();

        $this->add_actions();
    }

    public function add_actions() {
        add_action( 'elementor/element/before_section_end', [ $this, 'set_default_effects' ], 10, 3 );
        add_action( 'elementor/element/after_add_attributes', [ $this, 'modify_attributes' ], 10 );
    }

    public function set_default_effects( $widget, $section_id, $args ) {
        if( $section_id == 'section_effects' ) {
            
            $widget->remove_responsive_control( '_animation' );
            $widget->remove_responsive_control( 'animation' );
            $widget->remove_responsive_control( 'animation_duration' );
            $widget->remove_responsive_control( 'animation_delay' );
            $widget->remove_responsive_control( '_animation_delay' );

            $widget->add_control(
                '_enable_aos_animation',
                [
                    'label'        => esc_html__( 'Enable AOS Animation', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'separator'    => 'after',
                    'description'  => esc_html__( 'Enable AOS amination or Elementor\'s defult animation.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
                    'return_value' => 'yes',
                    'default'      => 'no',
                ]
            );

            $widget->add_control(
                '_aos_animation',
                [
                    'label'              => esc_html__( 'Entrance Animation', 'landkit-elementor' ),
                    'type'               => LE_Controls_Manager::AOS_ANIMATION,
                    'condition'          => [
                        '_enable_aos_animation' => 'yes',
                    ],
                    'render_type'        => 'none',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                '_aos_animation_delay',
                [
                    'label'      => esc_html__( 'Animation Delay', 'landkit-elementor' ) . ' (ms)',
                    'type'       => Controls_Manager::NUMBER,
                    'default'    => '',
                    'min'        => 0,
                    'step'       => 100,
                    'condition'  => [
                        '_enable_aos_animation' => 'yes',
                        '_aos_animation!'       => '',
                    ],
                    'render_type' => 'none',
                    'frontend_available' => true,
                ]
            );

            $widget->add_responsive_control(
                '_animation',
                [
                    'label'              => esc_html__( 'Entrance Animation', 'landkit-elementor' ),
                    'type'               => Controls_Manager::ANIMATION,
                    'frontend_available' => true,
                    'condition'          => [
                        '_enable_aos_animation!' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'animation_duration',
                [
                    'label'   => esc_html__( 'Animation Duration', 'landkit-elementor' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => '',
                    'options' => [
                        'slow'  =>    esc_html__( 'Slow', 'landkit-elementor' ),
                        ''      =>    esc_html__( 'Normal', 'landkit-elementor' ),
                        'fast'  =>    esc_html__( 'Fast', 'landkit-elementor' ),
                    ],
                    'prefix_class' => 'animated-',
                    'condition'    => [
                        '_enable_aos_animation!' => 'yes',
                        '_animation!'            => '',
                    ],
                ]
            );

            $widget->add_control(
                '_animation_delay',
                [
                    'label'         => esc_html__( 'Animation Delay', 'landkit-elementor' ) . ' (ms)',
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => '',
                    'min'           => 0,
                    'step'          => 100,
                    'condition'     => [
                        '_enable_aos_animation!' => 'yes',
                        '_animation!'            => '',
                    ],
                    'render_type'   => 'none',
                    'frontend_available' => true,
                ]
            );
        }
    }

    public function modify_attributes( $element ) {

        $settings = $element->get_settings_for_display();

        if( isset( $settings['_enable_aos_animation'] ) && $settings['_enable_aos_animation'] == 'yes' && isset( $settings['_aos_animation'] ) ) {
            $element->set_render_attribute( '_wrapper', 'data-aos', $settings['_aos_animation'] );
            
            if( isset( $settings['_aos_animation_delay'] ) ) {
                $element->set_render_attribute( '_wrapper', 'data-aos-delay', $settings['_aos_animation_delay'] );
            }
        }
    }
}