<?php

namespace LandkitElementor\Modules\Background;

use LandkitElementor\Base\Module_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Module extends Module_Base {

	public function __construct() {
		parent::__construct();

		$this->add_actions();
	}

	public function get_name() {
		return 'override-background';
	}

	public function add_actions() {
		// Section
		add_action( 'elementor/frontend/section/before_render', [ $this, 'background_attributes' ], 10 );
		add_action( 'elementor/element/section/section_background/before_section_end', [ $this, 'add_background_controls' ], 10, 2 );
		add_action( 'elementor/element/section/section_background/after_section_end', [ $this, 'update_background_controls' ], 10, 2 );
	}

	public function add_background_controls( $element, $args ) {
		$element->start_injection( [
			'of' => 'background_color',
		] );

		$element->add_control(
			'double_image_1',
			[
				'label'   	 => _x( 'Image 1', 'Background Control', 'landkit-elementor' ),
				'type'    	 => Controls_Manager::MEDIA,
				'dynamic' 	 => [
					'active' => true,
				],
				'title'   	  => _x( 'Background Image', 'Background Control', 'landkit-elementor' ),
				'render_type' => 'template',
				'condition'   => [
					'background_background' => [ 'between' ],
				],
			]
		);

		$element->add_control(
			'double_image_2',
			[
				'label' 	 => _x( 'Image 2', 'Background Control', 'landkit-elementor' ),
				'type' 		 => Controls_Manager::MEDIA,
				'dynamic'    => [
					'active' => true,
				],
				'title' 	  => _x( 'Background Image', 'Background Control', 'landkit-elementor' ),
				'render_type' => 'template',
				'condition'   => [
					'background_background' => [ 'between' ],
				],
			]
		);

		$element->end_injection();
	}

	public function update_background_controls( $element, $args ) {
		// get section args
		$section_background = \Elementor\Plugin::instance()->controls_manager->get_control_from_stack( $element->get_unique_name(), 'background_background' );

		// pass custom option
		$section_background['options']['between']['title'] = _x( 'Between', 'Background Control', 'landkit-elementor' );
		$section_background['options']['between']['icon'] = 'eicon-column';

		// update control
		$element->update_control( 'background_background', $section_background );

		// update control
		$element->update_control(
			'background_color',
			[
				'condition' => [
					'background_background' => [ 'classic', 'gradient', 'between' ],
				],
			]
		);
	}

	public function background_attributes( $element ) {
		$settings = $element->get_settings_for_display();

		if ( $element->get_settings( 'background_background' ) == 'between' ) {
			$has_image_one = $element->get_settings( 'double_image_1' );
			$has_image_two = $element->get_settings( 'double_image_2' );

			if ( ! empty( $has_image_one[ 'url' ] ) || ! empty( $has_image_two[ 'url' ] ) ) {
				$image_one = ! empty( $has_image_one[ 'url' ] ) ? 'url( ' . $settings[ 'double_image_1' ][ 'url' ] . ' )' : '';
				$seperator = ( ! empty( $has_image_one[ 'url' ] ) && ! empty( $has_image_two[ 'url' ] ) ) ? ', ' : '';
				$image_two = ! empty( $has_image_two[ 'url' ] ) ? 'url( ' . $settings[ 'double_image_2' ][ 'url' ] . ' )' : '';

				$element->add_render_attribute( '_wrapper', 'class', 'bg-between' );
				$element->set_render_attribute( 
					'_wrapper', 
					'style',
					'background-image: ' . $image_one . $seperator . $image_two
				);
			}
		}
	}
}