<?php
namespace LandkitElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use LandkitElementor\Base\Base_Widget;
use Elementor\Core\Files\Assets\Files_Upload_Handler;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

abstract class Base extends Base_Widget {

	private $slide_prints_count = 0;

	public function get_script_depends() {
		return [ 'imagesloaded', 'jquery', 'flickity', 'flickity-fade' ];
	}

	abstract protected function add_repeater_controls( Repeater $repeater );

	abstract protected function get_repeater_defaults();

	abstract protected function print_slide( array $slide, array $settings, $element_key );

	protected function register_controls() {
		$this->start_controls_section(
			'section_slides',
			[
				'label' => __( 'Slides', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$this->add_repeater_controls( $repeater );

		$this->add_control(
			'slides',
			[
				'label' => __( 'Slides', 'landkit-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => $this->get_repeater_defaults(),
				'separator' => 'after',
			]
		);

		$this->add_responsive_control(
			'slides_per_view',
			[
				'type' => Controls_Manager::SELECT,
				'label' => __( 'Slides Per View', 'landkit-elementor' ),
				'options' => [
					'' => __( 'Default', 'landkit-elementor' ),
					'1' => __( '1', 'landkit-elementor' ),
					'2' => __( '2', 'landkit-elementor' ),
					'3' => __( '3', 'landkit-elementor' ),
					'4' => __( '4', 'landkit-elementor' ),
					'6' => __( '6', 'landkit-elementor' ),
				],
				'frontend_available' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => __( 'Additional Options', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'show_arrows',
			[
				'type' => Controls_Manager::SWITCHER,
				'label' => __( 'Arrows', 'landkit-elementor' ),
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'prefix_class' => 'elementor-arrows-',
				'render_type' => 'template',
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'pagination',
			[
				'type' => Controls_Manager::SWITCHER,
				'label' => __( 'Dots', 'landkit-elementor' ),
				'default' => 'no',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'prefix_class' => 'elementor-pagination-',
				'render_type' => 'template',
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'loop',
			[
				'label' => __( 'Infinite Loop', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => __( 'Autoplay', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'separator' => 'before',
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'autoplay_speed',
			[
				'label' => __( 'Autoplay Speed', 'landkit-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 1500,
				'condition' => [
					'autoplay' => 'yes',
				],
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label' => __( 'Pause on Hover', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'condition' => [
					'autoplay' => 'yes',
				],
				'frontend_available' => true,
			]
		);

		$this->add_control(
            'image_class',
            [
               'label'        => esc_html__( 'Image Class', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'title'       => esc_html__( 'Add your custom class for <img> tag  without the dot. e.g: my-class', 'landkit-elementor' ),
                'default'     => 'img-fluid',
                'label_block' => true,
                'description' => esc_html__( 'Additional CSS class that you want to apply to the img tag', 'landkit-elementor' ),
            ]
        );

		$this->end_controls_section();
	}
}
