<?php
namespace LandkitElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;

use LandkitElementor\Modules\QueryControl\Module as Module_Query;
use LandkitElementor\Modules\QueryControl\Controls\Group_Control_Related;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Posts_Carousel extends Base {

    /**
	 * @var string Save current permalink to avoid conflict with plugins the filters the permalink during the post render.
	 */
	protected $current_permalink;

    /**
     * @var \WP_Query
     */
    protected $query = null;

    public function get_name() {
        return 'lk-posts-carousel';
    }

    public function get_title() {
        return esc_html__( 'Posts Carousel', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-posts-carousel';
    }

    public function get_keywords() {
        return [ 'posts-carousel', 'posts', 'carousel', 'image' ];
    }

    public function get_query() {
        return $this->query;
    }

    public function on_import( $element ) {
        if ( ! get_post_type_object( $element['settings']['posts_post_type'] ) ) {
            $element['settings']['posts_post_type'] = 'post';
        }

        return $element;
    }

    protected function add_repeater_controls( Repeater $repeater ) {}

    protected function get_repeater_defaults() {}

    protected function print_slide( array $slide, array $settings, $element_key ) {}

    protected function register_controls() {
        $this->register_query_section_controls();

        parent::register_controls();

        $this->register_slides_style_section_controls();

        $this->remove_control( 'section_slides' );
        
        $this->remove_control( 'image_class' );
        $this->remove_control( 'pagination' );
        $this->remove_control( 'speed' );
    }

    protected function register_query_section_controls() {
        $this->start_controls_section(
            'section_query', [
                'label'     => esc_html__( 'Query', 'landkit-elementor' ),
                'tab'       => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_group_control(
            Group_Control_Related::get_type(), [
                'name'      => 'posts', //$this->get_name(),
                'presets'   => [ 'full' ],
            ]
        );

        $this->remove_control( 'posts_post_type' );

        $this->end_controls_section();
    }

    protected function register_slides_style_section_controls() {
        $this->start_controls_section(
            'section_style_slides', [
                'label'     => esc_html__( 'Post', 'landkit-elementor' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'open_new_tab', [
                'label'     => esc_html__( 'Open in new window', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Yes', 'landkit-elementor' ),
                'label_off' => esc_html__( 'No', 'landkit-elementor' ),
                'default'   => 'no',
                'render_type'   => 'none',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Title Options', 'landkit-elementor' ),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title_color', [
                'label'     => esc_html__( 'Title Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-post__title'   => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'      => 'title_typography',
                'selector'  => '{{WRAPPER}} .lk-post__title',
            ]
        );

        $this->add_control(
            'excerpt_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Excerpt Options', 'landkit-elementor' ),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_excerpt', [
                'label'     => esc_html__( 'Show Excerpt ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'excerpt_length', [
                'label'     => esc_html__( 'Excerpt Length', 'landkit-elementor' ),
                'type'      => Controls_Manager::NUMBER,
                /** This filter is documented in wp-includes/formatting.php */
                'default'   => 30,
                'min'       => 3,
                'max'       => 120,
                'condition' => [
                    'show_excerpt'  => 'yes',
                ],
            ]
        );

        $this->add_control(
            'excerpt_color', [
                'label'     => esc_html__( 'Excerpt Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-post__excerpt > p' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'show_excerpt'  => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'      => 'excerpt_typography',
                'selector'  => '{{WRAPPER}} .lk-post__excerpt > p',
                'condition' => [
                    'show_excerpt'  => 'yes',
                ],
            ]
        );

        $this->add_control(
            'meta_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Meta Options', 'landkit-elementor' ),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_meta', [
                'label'     => esc_html__( 'Show Meta ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'show_avatar', [
                'label'     => esc_html__( 'Show Avatar ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'default'   => 'yes',
                'condition' => [
                    'show_meta' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'show_author', [
                'label'     => esc_html__( 'Show Author ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'default'   => 'yes',
                'condition' => [
                    'show_meta' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'show_date', [
                'label'     => esc_html__( 'Show Date ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'default'   => 'yes',
                'condition' => [
                    'show_meta' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'meta_author_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Author Text Options', 'landkit-elementor' ),
                'separator' => 'before',
                'condition' => [
                    'show_meta'     => 'yes',
                    'show_author'   => 'yes',
                ],
            ]
        );

        $this->add_control(
            'meta_author_color', [
                'label'     => esc_html__( 'Meta Author Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-post__meta--author'    => 'color: {{VALUE}} !important',
                ],
                'condition' => [
                    'show_meta'     => 'yes',
                    'show_author'   => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'      => 'meta_author_typography',
                'selector'  => '{{WRAPPER}} .lk-post__meta--author',
                'condition' => [
                    'show_meta'     => 'yes',
                    'show_author'   => 'yes',
                ],
            ]
        );

        $this->add_control(
            'meta_date_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Date Text Options', 'landkit-elementor' ),
                'separator' => 'before',
                'condition' => [
                    'show_meta' => 'yes',
                    'show_date' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'meta_date_color', [
                'label'     => esc_html__( 'Meta Date Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-post__meta--date'  => 'color: {{VALUE}} !important',
                ],
                'condition' => [
                    'show_meta' => 'yes',
                    'show_date' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'      => 'meta_date_typography',
                'selector'  => '{{WRAPPER}} .lk-post__meta--date',
                'condition' => [
                    'show_meta' => 'yes',
                    'show_date' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }

    public function query_posts( $settings ) {
        $query_args = [
            'posts_per_page' => $settings[ 'posts_posts_per_page' ],
        ];

        /** @var Module_Query $elementor_query */
        $elementor_query = Module_Query::instance();
        $this->query = $elementor_query->get_query( $this, 'posts', $query_args, [] );
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $this->query_posts( $settings );

        /** @var \WP_Query $query */
        $query = $this->get_query();

        if ( ! $query->found_posts ) {
            return;
        }

        $post_html = [
            'image'     => '',
            'content'   => '',
        ];

        // It's the global `wp_query` it self. and the loop was started from the theme.
        if ( $query->in_the_loop ) {
            $post_html['image']     .= $this->render_image_html( $settings );
            $post_html['content']   .= $this->render_content_html( $settings );
        } else {
            while ( $query->have_posts() ) {
                $query->the_post();

                $this->current_permalink = get_permalink();
                $post_html['image']     .= $this->render_image_html( $settings );
                $post_html['content']   .= $this->render_content_html( $settings );
            }
        }

        wp_reset_postdata();

        $uniqId = 'posts-slider-' . $this->get_id();

        $default_settings = [];

        $settings = array_merge( $default_settings, $settings );

        $image_carousel_settings = [
            'fade'              => true,
            'imagesLoaded'      => true,
            'adaptiveHeight'    => true,
            'pageDots'          => false,
            'prevNextButtons'   => false,
            'asNavFor'          => '#' . $uniqId,
            'draggable'         => false,
        ];

        $content_carousel_settings = [
            'pageDots'          => false,
            'adaptiveHeight'    => true,
            'wrapAround'        => isset( $settings['loop'] ) && $settings['loop'] === 'yes' ? true : false,
            'prevNextButtons'   => isset( $settings['show_arrows'] ) && $settings['show_arrows'] === 'yes' ? true : false,
        ];

        if( isset( $settings['autoplay'] ) && $settings['autoplay'] === 'yes' ) {
            $content_carousel_settings['autoPlay'] = $settings['autoplay_speed'] ? $settings['autoplay_speed'] : 1500;
            $content_carousel_settings['pauseAutoPlayOnHover'] = isset( $settings['pause_on_hover'] ) && $settings['pause_on_hover'] === 'yes' ? true : false;
        }

        $this->render_loop_header();

        ?>
        <div class="col-12 col-md-6">
            <div class="card-img-slider" data-flickity='<?php echo htmlspecialchars( json_encode( $image_carousel_settings ), ENT_QUOTES, 'UTF-8' ); ?>' data-aos-id="flickity:in" data-aos="1">
                <?php echo wp_kses_post( $post_html['image'] ); ?>
            </div>
            <div class="shape shape-right shape-fluid-y svg-shim text-white d-none d-md-block">
                <svg viewBox="0 0 112 690" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M116 0H51v172C76 384 0 517 0 517v173h116V0z" fill="currentColor"></path></svg>
            </div>
        </div>
        <div class="col-12 col-md-6 position-md-static">
            <div class="position-md-static" data-flickity='<?php echo htmlspecialchars( json_encode( $content_carousel_settings ), ENT_QUOTES, 'UTF-8' ); ?>' id="<?php echo esc_attr( $uniqId ); ?>" data-aos-id="flickity:in" data-aos="1">
                <?php echo wp_kses_post( $post_html['content'] ); ?>
            </div>
        </div>
        <?php

        $this->render_loop_footer();
    }

    protected function render_loop_header() {
        ?>
        <div class="row">
            <div class="col-12">
                <div class="card card-row shadow-light-lg mb-6">
                    <div class="row no-gutters">
        <?php
    }

    protected function render_loop_footer() {
        ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    protected function render_image_html( $settings ) {
        $post_id = get_the_ID();
        $post_thumbnail_id = get_post_thumbnail_id();

        $this->add_render_attribute( $post_id . '-card-img', [
            'class' => [ 'img-fluid', 'd-md-none', 'invisible' ],
        ] );

        if ( empty( $post_thumbnail_id ) || $post_thumbnail_id < 1 ) {
            $post_thumbnail_url = Utils::get_placeholder_image_src();
            $post_thumbnail_bg_url = 'background-image: url(' . $post_thumbnail_url . ');';
            $this->add_render_attribute( $post_id . '-card-img', [
                'src' => $post_thumbnail_url,
            ] );
        } else {
            $attachment_image = wp_get_attachment_image_src( $post_thumbnail_id, 'medium' );
            $post_thumbnail_bg_url = 'background-image: url(' . get_the_post_thumbnail_url() . ');';
            $this->add_render_attribute( $post_id . '-card-img', [
                'src' => $attachment_image[0],
            ] );
        }

        ob_start();
        ?>
        <a class="card-img-left w-100 bg-cover" style="<?php echo esc_attr( $post_thumbnail_bg_url ); ?>" href="<?php echo get_permalink(); ?>"<?php if( isset( $settings['open_new_tab'] ) && $settings['open_new_tab'] === 'yes' ) { echo esc_attr( ' target="_blank ' ); } ?>>
            <img <?php echo $this->get_render_attribute_string( $post_id . '-card-img' ); ?> alt="">
        </a>
        <?php
        return ob_get_clean();
    }

    protected function render_content_html( $settings ) {
        ob_start();
        ?><div class="w-100"><?php
            ?><a class="card-body" href="<?php echo get_permalink(); ?>"<?php if( isset( $settings['open_new_tab'] ) && $settings['open_new_tab'] === 'yes' ) { echo esc_attr( ' target="_blank ' ); } ?>><?php
                $this->render_loop_title( $settings );
                if( isset( $settings['show_excerpt'] ) && $settings['show_excerpt'] === 'yes' ) {
                    $this->render_loop_excerpt( $settings );
                }
            ?></a><?php
            if( ( isset( $settings['show_meta'] ) && $settings['show_meta'] === 'yes' ) && ( ( isset( $settings['show_avatar'] ) && $settings['show_avatar'] === 'yes' ) || ( isset( $settings['show_author'] ) && $settings['show_author'] === 'yes' ) || ( isset( $settings['show_date'] ) && $settings['show_date'] === 'yes' ) ) ) {
                $this->render_loop_meta( $settings );
            }
        ?></div><?php
        return ob_get_clean();
    }

    protected function render_loop_title() {
        echo '<h3 class="lk-post__title">' . get_the_title() . '</h3>';
    }

    protected function render_loop_excerpt() {
        add_filter( 'excerpt_more', [ $this, 'filter_post_carousel_excerpt_more' ], 20 );
        add_filter( 'excerpt_length', [ $this, 'filter_post_carousel_excerpt_length' ], 20 );

        ?>
        <div class="lk-post__excerpt">
            <?php the_excerpt(); ?>
        </div>
        <?php

        remove_filter( 'excerpt_more', [ $this, 'filter_post_carousel_excerpt_more' ], 20 );
        remove_filter( 'excerpt_length', [ $this, 'filter_post_carousel_excerpt_length' ], 20 );
    }

    protected function render_loop_meta( $settings ) {
        ?>
        <a class="card-meta mt-auto" href="<?php echo get_permalink(); ?>"<?php if( isset( $settings['open_new_tab'] ) && $settings['open_new_tab'] === 'yes' ) { echo esc_attr( ' target="_blank ' ); } ?>>
            <hr class="card-meta-divider mb-5">
            <?php if( isset( $settings['show_avatar'] ) && $settings['show_avatar'] === 'yes' ) { ?>
                <div class="avatar avatar-sm mr-2">
                    <?php echo get_avatar( get_the_author_meta( 'ID' ), 24, '', get_the_author_meta( 'display_name' ), [ 'class' => 'avatar-img rounded-circle' ] ); ?>
                </div>
            <?php } ?>
            <?php if( isset( $settings['show_author'] ) && $settings['show_author'] === 'yes' ) { ?>
                <h6 class="lk-post__meta--author text-uppercase text-muted mr-2 mb-0"><?php the_author(); ?></h6>
            <?php } ?>
            <?php if( isset( $settings['show_date'] ) && $settings['show_date'] === 'yes' ) { ?>
                <p class="lk-post__meta--date h6 text-uppercase text-muted mb-0 ml-auto"><time datetime="<?php echo get_the_date('Y-m-d'); ?>"><?php echo get_the_date(); ?></time></p>
            <?php } ?>
        </a>
        <?php
    }

    public function filter_post_carousel_excerpt_more( $more ) {
        return '';
    }

    public function filter_post_carousel_excerpt_length( $length ) {
        $settings = $this->get_settings_for_display();
        return  isset( $settings['excerpt_length'] ) && intval( $settings['excerpt_length'] ) >= 3 &&  intval( $settings['excerpt_length'] ) <= 120 ? $settings['excerpt_length'] : $length;
    }
}
