<?php
namespace LandkitElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Testimonial_Carousel extends Base {

    private $files_upload_handler = false;

    public function get_name() {
        return 'lk-testimonial-carousel';
    }

    public function get_title() {
        return esc_html__( 'Testimonial Carousel', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-testimonial-carousel';
    }

    public function get_keywords() {
        return [ 'testimonial-carousel', 'testimonial', 'carousel', 'image' ];
    }

    protected function register_controls() {
        parent::register_controls();

        $this->remove_responsive_control( 'slides_per_view' );

        $this->remove_control( 'pagination' );
        $this->remove_control( 'speed' );
        $this->remove_control( 'image_class' );
        
        $this->start_controls_section(
            'section_style_text', [
                'label' => esc_html__( 'Slides', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_typo_style', [
                'type'  => Controls_Manager::HEADING,
                'label' => esc_html__( 'Content Text Styles', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'content_color', [
                'label'     => esc_html__( 'Content Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-testimonial-slide-content' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .lk-testimonial-slide-content',
            ]
        );

        $this->add_control(
            'author_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Author Text Styles', 'landkit-elementor' ),
                'separator' => 'before',
            ]
        );


        $this->add_control(
            'author_color', [
                'label'     => esc_html__( 'Author Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-testimonial-slide-author' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'author_typography',
                'selector' => '{{WRAPPER}} .lk-testimonial-slide-author',
            ]
        );

        $this->end_controls_section();
    }

    protected function add_repeater_controls( Repeater $repeater ) {
        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        $repeater->add_control(
            'content', [
                'label' => esc_html__( 'Content', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXTAREA,
            ]
        );

        $repeater->add_control(
            'name', [
                'label' => esc_html__( 'Author', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'image', [
                'label' => esc_html__( 'Image', 'landkit-elementor' ),
                'type'  => Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
            ]
        );

        $repeater->add_control(
            'logo', [
                'label' => esc_html__( 'Logo', 'landkit-elementor' ),
                'type'  => Controls_Manager::MEDIA,
            ]
        );

        if ( $enabled ) {
            $repeater->add_control(
                'logo_inline_svg', [
                   'label'         => esc_html__( 'Logo Inline SVG', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'title'        => esc_html__( 'If you are uploading SVG file, it might be useful to inline the SVG files. Do not inline, if your SVG file is from unknown sources.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ), 
                    'return_value' => 'yes',
                    'default'      => 'no',
                ]
            );

            $repeater->add_control(
                'logo_svg_color', [
                    'label'        => esc_html__( 'Logo SVG Color', 'landkit-elementor' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}}.slider-logo path' => 'fill: {{VALUE}}; color: {{VALUE}};',
                    ],
                    'condition' => [
                        'logo_inline_svg' => 'yes',
                    ],
                ]
            );
        }

        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'logo', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
                'condition' => [
                    'logo_inline_svg!' => 'yes',
                ],
            ]
        );
    }

    protected function get_repeater_defaults() {
        $placeholder_image_src = Utils::get_placeholder_image_src();

        $defaults = [];
        $names    = [ 'Dave Gamache', 'Russ D\'Sa' ];
        $content  = [
            esc_html__( '"Landkit is hands down the most useful front end Bootstrap theme I\'ve ever used. I can\'t wait to use it again for my next project."', 'landkit-elementor' ),
            esc_html__( '"I\'ve never used a theme as versatile and flexible as Landkit. It\'s my go to for building landing sites on almost any project."', 'landkit-elementor' )
        ];

        foreach( $names as $key => $name ) {
            $defaults[] = [
                'content' => $content[ $key ],
                'name'    => $name,
                'image'   => [ 'url' => $placeholder_image_src ],
                'logo'    => [ 'url' => $placeholder_image_src ]
            ];
        }

        return $defaults;
    }

    protected function print_slide( array $slide, array $settings, $element_key ) {
        if ( substr( $element_key, 0, 6 ) === "image-" ) {
            if( empty( $slide['image']['url'] ) ) {
                $slide['image']['url'] = Utils::get_placeholder_image_src();
            }

            $this->add_render_attribute( $element_key . '-card-img', [
                'href'  => '#!',
                'class' => 'card-img-left bg-cover w-100',
                'style' => 'background-image: url( ' . $slide['image']['url'] . ' );',
            ] );

            $image_classes = 'slider-image img-fluid d-md-none invisible elementor-repeater-item-' . $slide['_id'];

            ?><a <?php echo $this->get_render_attribute_string( $element_key . '-card-img' ); ?>><?php
                $image_html = Group_Control_Image_Size::get_attachment_image_html( $slide, 'image' );
                if ( false === strpos( $image_html, 'class="' ) ) {
                    $image_html = str_replace( '<img', '<img class="' . esc_attr( $image_classes ) . '"', $image_html );
                } else {
                    $image_html = str_replace( 'class="', 'class="' . esc_attr( $image_classes ) .' ' , $image_html );
                }
                echo $image_html;
            ?></a><?php
        } else {
            if ( ! empty( $slide['logo']['url'] ) ) {
                $file_ext = pathinfo( $slide['logo']['url'], PATHINFO_EXTENSION );
                $is_svg_logo = $file_ext === 'svg' ? true : false;
                $load_svg_logo = $this->files_upload_handler && isset( $slide['logo_inline_svg'] ) && $slide['logo_inline_svg'] === 'yes' && $is_svg_logo;

                $logo_classes = 'slider-logo img-fluid elementor-repeater-item-' . $slide['_id'];

                $this->add_render_attribute( $element_key . '-logo', [
                    'class' => $logo_classes,
                ] );
            }

            ?><div class="w-100">
                <div class="card-body">
                    <blockquote class="blockquote text-center mb-0">
                        <div class="row justify-content-center mb-5 mb-md-7">
                            <div class="col-6 col-sm-4 col-md-7 col-lg-5">
                                <?php if ( ! empty( $slide['logo']['url'] ) ) :
                                    if( $load_svg_logo ) :
                                        $this->add_render_attribute( $element_key . '-logo', [
                                            'class' => 'logo-svg',
                                        ] );
                                        $content = wp_remote_get( $slide['logo']['url'] );
                                        ?><div <?php echo $this->get_render_attribute_string( $element_key . '-logo' ); ?>><?php
                                            print_r( wp_remote_retrieve_body( $content ) );
                                        ?></div><?php
                                    else :
                                        if ( ! empty( $slide['logo']['url'] ) ) {
                                            if( $is_svg_logo ) {
                                                $this->add_render_attribute( $element_key . '-logo', [
                                                    'src'   => $slide['logo']['url'],
                                                    'alt'   => ! empty( $slide['name'] ) ? $slide['name'] : '',
                                                ] );
                                                ?><img <?php echo $this->get_render_attribute_string( $element_key . '-logo' ); ?>><?php
                                            } else {
                                                $logo_html = Group_Control_Image_Size::get_attachment_image_html( $slide, 'logo' );
                                                if ( false === strpos( $logo_html, 'class="' ) ) {
                                                    $logo_html = str_replace( '<img', '<img class="' . esc_attr( $logo_classes ) . '"', $logo_html );
                                                } else {
                                                    $logo_html = str_replace( 'class="', 'class="' . esc_attr( $logo_classes ) .' ' , $logo_html );
                                                }
                                                echo $logo_html;
                                            }
                                        }
                                    endif;
                                endif; ?>
                            </div>
                        </div>
                        <p class="lk-testimonial-slide-content mb-5 mb-md-7"><?php echo $slide['content']; ?></p>
                        <?php if ( ! empty( $slide['name'] ) ) : ?>
                            <footer class="blockquote-footer">
                                <span class="lk-testimonial-slide-author h6 text-uppercase"><?php echo $slide['name']; ?></span>
                            </footer>
                        <?php endif; ?>
                    </blockquote>
                </div>
            </div><?php
        }
    }

    protected function render() {
        $uniqId   = 'testimoial-slider-' . $this->get_id();
        $settings = $this->get_settings_for_display();
        $this->files_upload_handler = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        $image_carousel_args = [
            'fade'            => true,
            'imagesLoaded'    => true,
            'pageDots'        => false,
            'prevNextButtons' => false,
            'asNavFor'        => '#' . $uniqId,
            'draggable'       => false,
        ];

        $content_carousel_args = [
            'pageDots'        => false,
            'adaptiveHeight'  => true,
            'wrapAround'      => isset( $settings['loop'] ) && $settings['loop'] === 'yes' ? true : false,
            'prevNextButtons' => isset( $settings['show_arrows'] ) && $settings['show_arrows'] === 'yes' ? true : false,
        ];

        if( isset( $settings['autoplay'] ) && $settings['autoplay'] === 'yes' ) {
            $content_carousel_args['autoPlay']             = $settings['autoplay_speed'] ? $settings['autoplay_speed'] : 1500;
            $content_carousel_args['pauseAutoPlayOnHover'] = isset( $settings['pause_on_hover'] ) && $settings['pause_on_hover'] === 'yes' ? true : false;
        }
        ?>
        <div class="row">
            <div class="col-12">
                <div class="card card-row shadow-light-lg mb-6">
                    <div class="row no-gutters">
                        <div class="col-12 col-md-6">
                            <div class="card-img-slider" data-flickity='<?php echo htmlspecialchars( json_encode( $image_carousel_args ), ENT_QUOTES, 'UTF-8' ); ?>' data-aos-id="flickity:in" data-aos="1">
                                <?php foreach ( $settings['slides'] as $slide ) :
                                    $this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'] );
                                endforeach; ?>
                            </div>
                            <div class="shape shape-right shape-fluid-y svg-shim text-white d-none d-md-block">
                                <svg viewBox="0 0 112 690" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M116 0H51v172C76 384 0 517 0 517v173h116V0z" fill="currentColor"/></svg>
                            </div>
                        </div>
                        <div class="col-12 col-md-6 position-md-static">
                            <div class="position-md-static" data-flickity='<?php echo htmlspecialchars( json_encode( $content_carousel_args ), ENT_QUOTES, 'UTF-8' ); ?>' id="<?php echo esc_attr( $uniqId ); ?>" data-aos-id="flickity:in" data-aos="1">
                                <?php foreach ( $settings['slides'] as $slide ) :
                                    $this->print_slide( $slide, $settings, 'content-slide-' . $slide['_id'] );
                                endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}
