<?php

namespace LandkitElementor\Modules\Column;

use LandkitElementor\Base\Module_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Module extends Module_Base {

    public function __construct() {
        parent::__construct();

        $this->add_actions();
    }

    public function get_name() {
        return 'override-column';
    }

    public function add_actions() {
        add_action( 'elementor/element/column/layout/before_section_start', [ $this, 'add_column_controls' ], 10 );
        add_action( 'elementor/element/column/section_advanced/before_section_end', [ $this, 'add_widget_wrap_class' ] );
        add_action( 'elementor/element/after_add_attributes', [ $this, 'modify_attributes' ], 20 );
    }

    public function add_widget_wrap_class( $element ) {
        $element->add_control( 'widget_wrapper_css', [
            'label'        => esc_html__( 'Widget Wrapper CSS Classes', 'landkit-elementor' ),
            'label_block'  => true,
            'type'         => Controls_Manager::TEXT,
            'description'  => esc_html__( 'Applied to elementor-widget-wrap element.', 'landkit-elementor' ),
        ] );
    }

    public function add_column_controls( $element ) {
        
        $element->start_controls_section( 'section_landkit', [
            'label' => esc_html__( 'Landkit Options', 'landkit-elementor' )
        ] );
        
        $element->add_control( 'remove_column_width_class', [
            'label'        => esc_html__( 'Remove Column Width Class?', 'landkit-elementor' ),
            'type'         => Controls_Manager::SWITCHER,
            'description'  => esc_html__( 'If you\'ve added custom column classes from Bootstrap, you can use turn this ON to remove Elementor\'s column classes. Especially useful when using auto class from Bootstrap.', 'landkit-elementor' ),
            'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
            'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
            'return_value' => 'yes',
            'default'      => '',
        ] );

        $element->add_control( 'enable_card', [
            'label'        => esc_html__( 'Enable Card?', 'landkit-elementor' ),
            'type'         => Controls_Manager::SWITCHER,
            'description'  => esc_html__( 'Card Design for your column. Make sure to add card-body class to one of the widget to wrap them inside a body.', 'landkit-elementor' ),
            'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
            'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
            'return_value' => 'yes',
            'default'      => '',
        ] );

        $element->add_control( 'enable_card_body', [
            'label'        => esc_html__( 'Enable Card Body?', 'landkit-elementor' ),
            'type'         => Controls_Manager::SWITCHER,
            'description'  => esc_html__( 'Adds card-body class to the widget wrapper.', 'landkit-elementor' ),
            'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
            'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
            'return_value' => 'yes',
            'default'      => '',
        ] );

        $element->add_control( 'enable_card_shadow', [
            'label'        => esc_html__( 'Enable Card Shadow?', 'landkit-elementor' ),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
            'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
            'return_value' => 'yes',
            'default'      => '',
            'condition'    => [ 'enable_card' => 'yes' ]
        ] );

        $element->add_control( 'enable_lift', [
            'label'        => esc_html__( 'Apply Lift on hover?', 'landkit-elementor' ),
            'type'         => Controls_Manager::SWITCHER,
            'description'  => esc_html__( 'Card Design for your column. Make sure to add card-body class to one of the widget to wrap them inside a body.', 'landkit-elementor' ),
            'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
            'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
            'return_value' => 'yes',
            'default'      => '',
            'condition'    => [ 'enable_card' => 'yes' ]
        ] );

        $element->end_controls_section();
    }

    public function modify_attributes( $element ) {
        if ( $element->get_name() == 'column' ) {
            $settings = $element->get_settings_for_display();
            if ( 'yes' === $settings['remove_column_width_class'] ) {
                $element->remove_render_attribute( '_wrapper', 'class', 'elementor-col-' . $settings['_column_size'] );
            }

            $is_card_enabled       = 'yes' === $settings[ 'enable_card' ];
            $is_card_body_enabled  = 'yes' === $settings[ 'enable_card_body' ];
            $card_attribute_string = '';

            if ( $is_card_enabled && $is_card_body_enabled ) {
                $card_attribute_string = '_wrapper';
            } elseif ( $is_card_enabled ) {
                $card_attribute_string = '_widget_wrapper';
            }

            if ( $is_card_enabled ) {
                $element->add_render_attribute( $card_attribute_string, 'class', 'card' );

                if ( '_widget_wrapper' === $card_attribute_string ) {
                    $element->add_render_attribute( '_wrapper', 'class', 'd-block' );
                }
            }

            if ( $is_card_body_enabled && $card_attribute_string !== '_widget_wrapper' ) {
                $element->add_render_attribute( '_widget_wrapper', 'class', 'card-body' );
            }

            if ( $is_card_enabled && 'yes' === $settings[ 'enable_card_shadow'] ) {
                $element->add_render_attribute( $card_attribute_string, 'class', 'shadow-light-lg' );
            }

            if ( $is_card_enabled && 'yes' === $settings[ 'enable_lift'] ) {
                $element->add_render_attribute( $card_attribute_string, 'class', [ 'lift', 'lift-lg' ] );
            }

            if ( ! empty( $settings[ 'widget_wrapper_css' ] ) ) {
                $element->add_render_attribute( '_widget_wrapper', 'class', $settings[ 'widget_wrapper_css' ] );
            }
        }
    }
}