<?php
namespace LandkitElementor\Modules\Counters\Skins;

use Elementor\Skin_Base;
use Elementor\Repeater;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Skin_Display extends Skin_Base {

    public function get_id() {
        return 'display';
    }

    public function get_title() {
        return esc_html__( 'Display', 'landkit-elementor' );
    }

    public function render_counter( $item, $key ) {
        if ( ! empty( $item['prefix'] ) ): ?><span class="landkit-elementor-counter__number--prefix"><?php echo $item['prefix'];?></span><?php endif; ?><span <?php echo $this->parent->get_render_attribute_string( $key ); ?>></span><?php if ( ! empty( $item['suffix'] ) ): ?><span class="landkit-elementor-counter__number--suffix"><?php echo $item['suffix'];?></span><?php endif;
    }

    public function render() {
        $settings = $this->parent->get_settings_for_display();
        $count = count( $settings['counter_settings'] );
        ?>
        <div class="row row-cols-1 row-cols-md-<?php echo $count?>">
           <?php foreach( $settings['counter_settings'] as $index => $item ) :

                $counter   = $this->parent->get_repeater_setting_key( 'starting_number', 'counter_settings', $index );
                $counter_2 = $this->parent->get_repeater_setting_key( 'starting_number_2', 'counter_settings', $index );
                $title_key = $this->parent->get_repeater_setting_key( 'title', 'counter_settings', $index );
                $heading_key = $this->parent->get_repeater_setting_key( 'heading', 'counter_settings', $index );

                $this->parent->add_render_attribute( $counter, [
                    'class'         => 'landkit-elementor-counter__number',
                    'data-toggle'   => 'countup',
                    'data-to'       => $item['ending_number'],
                    'data-from'     => $item['starting_number'],
                    'data-duration' => $item['duration'],
                    'data-aos-id'   => 'countup:in',
                    'data-aos'      => true,
                    'data-decimals'=> $item['decimal_places']
                ] );

                if ( 'no' !== $item['enable_double_counter'] ) {
                    $this->parent->add_render_attribute( $counter_2, [
                        'class'         => 'landkit-elementor-counter__number--2',
                        'data-toggle'   => 'countup',
                        'data-to'       => $item['ending_number_2'],
                        'data-from'     => $item['starting_number_2'],
                        'data-duration' => $item['duration'],
                        'data-aos-id'   => 'countup:in',
                        'data-aos'      => true,
                        'data-decimals'=> $item['decimal_places_2']
                    ] );
                }

                $this->parent->add_render_attribute( $heading_key, 'class', [
                    'landkit-elementor-counter__number-wrapper',
                    'font-weight-bold',
                    $settings['font-class'],
                    $settings['heading_css_class'], 
                ] );

                $this->parent->add_render_attribute( $title_key, 'class', [
                    'landkit-elementor-counter__title',
                    'text-muted',
                    'mb-6',
                    'mb-md-0',
                    $settings['text_css_class'],
                ] );

                $this->parent->add_inline_editing_attributes( $title_key );?>
                    <div class="landkit-elementor-column-wrapper col">
                        <<?php echo $settings['number_html_tag']; ?> <?php echo $this->parent->get_render_attribute_string( $heading_key ) ?>>
                            <?php 
                                $this->render_counter( $item, $counter );
                                
                                if ( 'yes' == $item['enable_double_counter'] ) {
                                    echo $item['double_counter_separator'];
                                    $this->render_counter( $item, $counter_2 );
                                }
                            ?>
                        </<?php echo $settings['number_html_tag']; ?>>
                        <p <?php echo $this->parent->get_render_attribute_string( $title_key ); ?>><?php echo $item['title']; ?></p>
                    </div>
            <?php endforeach; ?>
        </div>
        <?php
    }
}

