<?php
namespace LandkitElementor\Modules\Counters\Widgets;

use LandkitElementor\Base\Base_Widget;
use LandkitElementor\Modules\Counters\Skins;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use Elementor\Controls_Manager;
// use Elementor\Core\Schemes;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Class Counters
 */
class Counters extends Base_Widget {

    public function get_name() {
        return 'lk-counters';
    }

    public function get_title() {
        return esc_html__( 'Counters', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-counter';
    }

    protected $_has_template_content = false;

    protected function register_skins() {
        $this->add_skin( new Skins\Skin_Flex( $this ) );
        $this->add_skin( new Skins\Skin_Display( $this ) );
        $this->add_skin( new Skins\Skin_Card( $this ) );
    }

    /**
     * Register button widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_counter',
            [
                'label' => esc_html__( 'Counters', 'landkit-elementor' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'enable_double_counter',
            [
                'label'     => esc_html__( 'Double Counter', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'no',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'starting_number',
            [
                'label'   => esc_html__( 'Starting Number', 'landkit-elementor' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 0,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'starting_number_2',
            [
                'label'     => esc_html__( 'Starting Number 2', 'landkit-elementor' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 0,
                'dynamic'   => [
                    'active' => true,
                ],
                'condition' => [
                    'enable_double_counter' => 'yes',
                ],
            ]
        );

        $repeater->add_control(
            'ending_number',
            [
                'label'   => esc_html__( 'Ending Number', 'landkit-elementor' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 100,
                'dynamic' => [
                    'active' => true,
                ],

            ]
        );

        $repeater->add_control(
            'ending_number_2',
            [
                'label'     => esc_html__( 'Ending Number 2', 'landkit-elementor' ),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 100,
                'dynamic'   => [
                    'active' => true,
                ],
                'condition' => [
                    'enable_double_counter' => 'yes',
                ],

            ]
        );

        $repeater->add_control(
            'double_counter_separator',
            [
                'label'     => esc_html__( 'Double Counter Separator', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => '/',
                'condition' => [
                    'enable_double_counter' => 'yes',
                ],

            ]
        );

        $repeater->add_control(
            'prefix',
            [
                'label'      => esc_html__( 'Number Prefix', 'landkit-elementor' ),
                'type'       => Controls_Manager::TEXT,
                'dynamic'    => [
                    'active' => true,
                ],
                'default'     => '',
                'placeholder' => 1,

            ]
        );

        $repeater->add_control(
            'suffix',
            [
                'label'      => esc_html__( 'Number Suffix', 'landkit-elementor' ),
                'type'       => Controls_Manager::TEXT,
                'dynamic'    => [
                    'active' => true,
                ],
                'default'     => '',
                'placeholder' => esc_html__( 'Plus', 'landkit-elementor' ),
            ]
        );

        $repeater->add_control(
            'duration',
            [
                'label'   => esc_html__( 'Animation Duration', 'landkit-elementor' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 2,
                'min'     => 1,
                'step'    => 1,
            ]
        );

        $repeater->add_control(
            'decimal_places',
            [
                'label' => __( 'Decimal Places', 'landkit-elementor' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 0,
                'min' => 0,
                'step' => 1,
            ]
        );

        $repeater->add_control(
            'decimal_places_2',
            [
                'label' => __( 'Decimal Places', 'landkit-elementor' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 0,
                'min' => 0,
                'step' => 1,
                'condition' => [
                    'enable_double_counter' => 'yes',
                ],
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label'       => esc_html__( 'Title', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => esc_html__( 'Number', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Number', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'counter_settings',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'starting_number' => '0',
                        'ending_number'   => '100',
                        'suffix'          => '%',
                        'title'           => esc_html__( 'Satisfaction', 'landkit-elementor' )
                    ],
                    [
                        'starting_number'          => '0',
                        'ending_number'            => '24',
                        'enable_double_counter'    => 'yes',
                        'double_counter_separator' => '/',
                        'starting_number_2'        => '0',
                        'ending_number_2'          => '7',
                        'title'                    => esc_html__( 'Support', 'landkit-elementor' )

                    ],
                    [
                        'starting_number' => '0',
                        'ending_number'   => '100',
                        'suffix'          => 'k+',
                        'title'           => esc_html__( 'Sales', 'landkit-elementor' )
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->add_control(
            'show_border',
            [
                'label'     => esc_html__( 'Border', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'condition' => [
                    '_skin' => 'flex',
                ],
            ]
        );

        $this->add_control(
            'font-class',
            [
                'label' => __( 'Display', 'landkit-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'display-1' => 'Display 1',
                    'display-2' => 'Display 2',
                    'display-3' => 'Display 3',
                    'display-4' => 'Display 4',
                    'display-5' => 'Display 5',
                    'display-6' => 'Display 6',
                    'display-7' => 'Display 7',
                ],
                'default' => 'display-2',
                'condition' => [
                    '_skin' => 'display',
                ],
            ]
        );

        $this->add_control(
            'number_html_tag',
            [
                'label'     => esc_html__( 'Number Tag', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                ],
                'default'   => 'h3',
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => __( 'Alignment', 'landkit-elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'landkit-elementor' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'landkit-elementor' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'landkit-elementor' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'landkit-elementor' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-column-wrapper'=> 'text-align: {{VALUE}};',
                ],
                'condition' => [
                    '_skin!' => 'flex',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_number',
            [
                'label' => esc_html__( 'Number', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'heading_css_class',
            [
                'label' => esc_html__( 'Heading CSS Class', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'title' => esc_html__( 'Add your custom class for Heading title without the dot. e.g: my-class', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'number_color',
            [
                'label'     => esc_html__( 'Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-counter__number-wrapper' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'typography_number',
                'selector' => '{{WRAPPER}} .landkit-elementor-counter__number-wrapper',
                // 'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'Title', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_css_class',
            [
                'label' => esc_html__( 'Text CSS Class', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'title' => esc_html__( 'Add your custom class for text title without the dot. e.g: my-class', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__( 'Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-counter__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'typography_title',               
                'selector' => '{{WRAPPER}} .landkit-elementor-counter__title',
                // 'scheme'   => Schemes\Typography::TYPOGRAPHY_2,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_border',
            [
                'label' => esc_html__( 'Border', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    '_skin' => 'card',
                ],
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label' => __( 'Border Color', 'landkit-elementor' ),
                'type' => Controls_Manager::COLOR,
                // 'scheme' => [
                //     'type' => Schemes\Color::get_type(),
                //     'value' => Schemes\Color::COLOR_2,
                // ],
                'default' => '#335eea',
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-counter__border' => 'border-color: {{VALUE}}',

                ],
                'separator' => 'before',
            ]
        );

        $this->end_controls_section();
    }

    public function render() {}
}