<?php
namespace LandkitElementor\Modules\Docs\Widgets;

use LandkitElementor\Base\Base_Widget;
use LandkitElementor\Modules\QueryControl\Module as Module_Query;
use LandkitElementor\Modules\QueryControl\Controls\Group_Control_Related;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
exit; // Exit if accessed directly
}

class Docs extends Base_Widget {

    public function get_name() {
        return 'lk-docs';
    }

    public function get_title() {
        return __( 'Docs', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-document-file';
    }

    protected function register_controls() {
        $this->register_query_section_controls();
    }

    public function register_query_section_controls() {
        $this->start_controls_section(
            'section_layout',
            [
                'label' => __( 'Layout', 'landkit-elementor' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'posts_per_page',
            [
                'label' => __( 'Posts Per Page', 'landkit-elementor' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'default' => 3,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_query',
            [
                'label' => __( 'Query', 'landkit-elementor' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_group_control(
            Group_Control_Related::get_type(),
            [
                'name' => 'posts',
                'presets' => [ 'full' ],
                'exclude' => [
            'posts_per_page', //use the one from Layout section
            ],
            ]
            );

        $this->end_controls_section();
    }

    protected function render_loop_header() {?>
        <div class="row">
        <?php }

        protected function render_loop_footer() {?>
        </div>
    <?php }

    public function query_posts() {
        $query_args = [
            'posts_per_page' => $this->get_settings( 'posts_per_page' ),
            'post_parent' => 0,
        ];

        /** @var Module_Query $elementor_query */
        $elementor_query = Module_Query::instance();
        $this->_query = $elementor_query->get_query( $this, 'posts', $query_args, [] );
    }

    public function get_query() {
        return $this->_query;
    }

    public function render() { 
        if ( landkit_is_wedocs_activated() ) { 
            $settings = $this->get_settings_for_display();
            $this->query_posts();

            /** @var \WP_Query $query */
            $query = $this->get_query();

            if ( ! $query->found_posts ) {
                return;
            }

            $this->render_loop_header(); 

            while ( $query->have_posts() ) {

                $query->the_post();

                $this->render_post();
            }
            
            $this->render_loop_footer();
            
            wp_reset_postdata();

        } else {
            echo "Please Install Wedoc and Activate It";
        }
    }

    public function render_post(){ 
        global $post;
        $thepostid = isset( $thepostid )? $thepostid : $post->ID;
        if ( function_exists( 'lk_get_post_featured_icon_bg' ) ) { 
            $docs_border_top_color = lk_get_post_featured_icon_bg( $post->ID);  
        }
        if ( $docs_border_top_color ) {
            $border_color = $docs_border_top_color;
        } else {
            $border_color = 'primary';
        } 
        ?>

        <div class="col-12 col-md-6 col-lg-4">

            <!-- Card -->
            <a class="card card-border border-<?php echo esc_attr(  $border_color  );?> shadow-lg mb-6 mb-md-8 lift lift-lg" href="<?php echo esc_url( get_permalink( $post->ID ) ); ?>">

                <div class="card-body text-center">

                    <!-- Icon -->
                    <?php if ( function_exists( 'lk_wedocs_featured_icon' ) ) {
                        lk_wedocs_featured_icon( $thepostid, 'mb-5' ); 
                    } ?>
                    <!-- Heading -->
                    <h4 class="font-weight-bold">
                        <?php echo esc_html( $post->post_title ); ?>
                    </h4>

                    <!-- Text -->
                    <?php if ( ! empty( $post->post_excerpt ) ) : ?>
                        <p class="text-gray-700 mb-5"><?php echo esc_html( $post->post_excerpt ); ?></p>
                    <?php endif; ?>

                    <!-- Badge -->
                    <?php $pages = get_pages( array( 'child_of' => $post->ID, 'post_type' => 'docs'));
                    $count = count($pages); ?>                    
                        <span class="badge badge-pill badge-dark-soft"><span class="h6 text-uppercase">
                            <?php if( $count != 0 ){ 
                             echo esc_html( sprintf( _nx( '%d entry', '%d entries',  $count, 'front-end', 'landkit-elementor' ),  $count ) ); 
                            } else {
                            echo "No entries"; } ?>
                        </span>                    
                </div>
            </a>
        </div>

    <?php }
}
