<?php

namespace LandkitElementor\Modules\IconList\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Icons_Manager;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use LandkitElementor\Plugin;
use Elementor\Skin_Base;

class Skin_Icon_List_Card extends Skin_Base {

    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
    }

    public function get_id() {
        return 'icon-list-card';
    }

    public function get_title() {
        return esc_html__( 'Card', 'landkit-elementor' );
    }

    protected function _register_controls_actions() {
        add_action( 'elementor/element/icon-list/section_icon/before_section_end', [ $this, 'register_section_icon_controls' ] );
        add_action( 'elementor/element/icon-list/section_icon_list/before_section_end', [ $this, 'register_icon_list_controls' ] );
        add_action( 'elementor/element/icon-list/section_icon_style/before_section_end', [ $this, 'register_icon_style_controls' ] );
        add_action( 'elementor/element/icon-list/section_text_style/before_section_end', [ $this, 'register_text_style_controls' ] );
        add_filter( 'landkit-elementor/widget/icon-list/print_template', [ $this, 'print_template' ], 10 );
    }

    public function register_section_icon_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;

        $this->parent->update_control(
            'view', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->parent->update_control(
            'link_click', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'text',
            [
                'label'       => esc_html__( 'Text', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => esc_html__( 'List Item', 'landkit-elementor' ),
                'default'     => esc_html__( 'List Item', 'landkit-elementor' ),
                'dynamic'     => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'subtext',
            [
                'label'       => esc_html__( 'Subtext', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'description' => esc_html__( 'Used in Cards Skin.', 'landkit-elementor' ),
                'label_block' => true,
                'dynamic'     => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'selected_icon',
            [
                'label'            => esc_html__( 'Icon', 'landkit-elementor' ),
                'type'             => Controls_Manager::ICONS,
                'default'          => [
                    'value'   => 'fas fa-check',
                    'library' => 'fa-solid',
                ],
                'fa4compatibility' => 'icon',
            ]
        );

        $this->parent->update_control( 'icon_list', [
            'fields' => $repeater->get_controls(),
        ] );
    }

    public function register_icon_list_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;

        $this->parent->update_control(
            'space_between', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->parent->update_control(
            'icon_align', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->parent->update_control(
            'divider', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->add_control(
            'card_css', [
                'label'        => esc_html__( 'CSS Classes', 'landkit-elementor' ),
                'type'         => Controls_Manager::TEXT,
                'dynamic'      => [
                    'active' => true,
                ],
                'title'        => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description'  => esc_html__( 'CSS classes applied to card wrapper.', 'landkit-elementor' )
            ]
        );

        $this->add_control(
            'border_color', [
                'label'        => esc_html__( 'Border Color', 'landkit-elementor' ),
                'type'         => Controls_Manager::COLOR,
                'default'      => '',
                'selectors'    => [
                    '{{WRAPPER}} .card' => 'border-color: {{VALUE}}'
                ]
            ]
        );
    }

    public function register_icon_style_controls( Elementor\Widget_Base $widget ) {
        
        $this->parent = $widget;

        $this->parent->update_control(
            'icon_color', [
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-list-icon i'            => 'color: {{VALUE}};',
                    '{{WRAPPER}} .elementor-icon-list-icon svg'          => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .landkit-elementor-icon-list__icon'     => 'color: {{VALUE}};',
                    '{{WRAPPER}} .landkit-elementor-icon-list__icon svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->parent->update_control(
            'icon_color_hover', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->add_control(
            'icon_bg', [
                'label' => __( 'Background', 'landkit-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-icon-list__icon'     => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->parent->update_control(
            'icon_size', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->parent->update_control(
            'icon_self_align', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->add_control(
            'icon_css', [
                'label'        => esc_html__( 'Icon CSS Classes', 'landkit-elementor' ),
                'type'         => Controls_Manager::TEXT,
                'dynamic'      => [
                    'active' => true,
                ],
                'title'        => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description'  => esc_html__( 'CSS classes applied to the icon wrapper.', 'landkit-elementor' )
            ]
        );
    }

    public function register_text_style_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;
        
        // $this->parent->remove_control( 'icon_typography_typography' );

        $this->parent->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .landkit-elementor-icon-list__heading, {{WRAPPER}} .elementor-icon-list-item, {{WRAPPER}} .elementor-icon-list-item a'
            ]
        );

        $this->add_control(
            'title_css', [
                'label'        => esc_html__( 'Title CSS Classes', 'landkit-elementor' ),
                'type'         => Controls_Manager::TEXT,
                'dynamic'      => [
                    'active' => true,
                ],
                'title'        => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description'  => esc_html__( 'CSS classes applied to icon list title.', 'landkit-elementor' )
            ]
        );
        
        $this->parent->update_control(
            'text_color', [
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-list-text' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .landkit-elementor-icon-list__heading' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->parent->update_control(
            'text_color_hover', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->parent->update_control(
            'text_indent', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label'     => esc_html__( 'Subtitle Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-icon-list__subtitle' => 'color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'subtitle_typography',
                'selector' => '{{WRAPPER}} .landkit-elementor-icon-list__subtitle',
            ]
        );

        $this->add_control(
            'subtitle_css', [
                'label'        => esc_html__( 'Subtitle CSS Classes', 'landkit-elementor' ),
                'type'         => Controls_Manager::TEXT,
                'dynamic'      => [
                    'active' => true,
                ],
                'title'        => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description'  => esc_html__( 'CSS classes applied to icon list subtitle.', 'landkit-elementor' )
            ]
        );
    }

    public function render() {
        $widget   = $this->parent;
        $settings = $widget->get_settings_for_display();

        $widget->add_render_attribute( 'icon_card', 'class', [
            'card', 'card-border', 'shadow-lg'
        ] );

        $card_css = $settings[ $this->get_control_id( 'card_css' ) ];

        if ( ! empty( $card_css ) ) {
            $widget->add_render_attribute( 'icon_card', 'class', $card_css );
        }

        $widget->add_render_attribute( 'icon_list', 'class', [
            'list-group', 'list-group-flush'
        ] );

        $widget->add_render_attribute( 'list_item', 'class', [
            'list-group-item', 'd-flex', 'align-items-center'
        ] );

        $widget->add_render_attribute( 'icon_badge', 'class', [
            'landkit-elementor-icon-list__icon', 'badge', 'badge-rounded-circle', 'ml-4'
        ] );

        $icon_css = $settings[ $this->get_control_id( 'icon_css' ) ];
        if ( ! empty( $icon_css ) ) {
            $widget->add_render_attribute( 'icon_badge', 'class', $icon_css );
        }

        ?>
        <div <?php echo $widget->get_render_attribute_string( 'icon_card' ); ?>>
            <div class="card-body">
                <div <?php echo $widget->get_render_attribute_string( 'icon_list' );?>>
                <?php 
                    foreach ( $settings['icon_list'] as $index => $item ) :
                    
                        $repeater_setting_key = Plugin::instance()->modules_manager->get_repeater_setting_key( 'text', 'icon_list', $index );
                        $widget->add_render_attribute( $repeater_setting_key, 'class', [
                            'landkit-elementor-icon-list__heading', 'mb-1'
                        ] );

                        $title_css = $settings[ $this->get_control_id( 'title_css' ) ];

                        if ( ! empty( $title_css ) ) {
                            $widget->add_render_attribute( $repeater_setting_key, 'class', $title_css );
                        }
                        
                        Plugin::instance()->modules_manager->add_inline_editing_attributes( $widget, $repeater_setting_key );

                        $subtext_repeater_key = Plugin::instance()->modules_manager->get_repeater_setting_key( 'subtext', 'icon_list', $index );

                        $widget->add_render_attribute( $subtext_repeater_key, 'class', [
                            'landkit-elementor-icon-list__subtitle', 'mb-0'
                        ] );

                        $subtitle_css = $settings[ $this->get_control_id( 'subtitle_css' ) ];

                        if ( ! empty( $subtitle_css ) ) {
                            $widget->add_render_attribute( $subtext_repeater_key, 'class', $subtitle_css );
                        }

                        ?>
                        <div <?php echo $widget->get_render_attribute_string( 'list_item' ); ?>>
                            <div class="mr-auto">
                                <p <?php echo $widget->get_render_attribute_string( $repeater_setting_key ); ?>><?php echo $item['text']; ?></p>
                                <p <?php echo $widget->get_render_attribute_string( $subtext_repeater_key ); ?>><?php echo $item['subtext']; ?></p>

                            </div>
                            <?php if ( ! empty( $item['icon'] ) || ( ! empty( $item['selected_icon']['value'] ) ) ): ?>
                            <div <?php echo $widget->get_render_attribute_string( 'icon_badge' ); ?>>
                                <?php Icons_Manager::render_icon( $item['selected_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                            </div>
                            <?php endif; ?>
                        </div>
                        <?php
                    endforeach;
                ?>        
                </div>
            </div>
        </div>
        <?php
    }

    public function print_template( $content ) {
        ob_start();
        $this->content_template( $content );
        return ob_get_clean();
    }

    public function content_template( $content ) {
        ?>
        <# if ( '' === settings._skin ) { #>
            <?php echo $content; ?>
        <# } else if ( 'icon-list-card' === settings._skin ) { #>
            <#
                view.addRenderAttribute( 'icon_card', 'class', [
                    'card', 'card-border', 'shadow-lg'
                ] );

                if ( '' != settings.icon_list_card_card_css ) {
                    view.addRenderAttribute( 'icon_card', 'class', settings.icon_list_card_card_css );
                }

                view.addRenderAttribute( 'icon_list', 'class', [
                    'list-group', 'list-group-flush'
                ]);

                view.addRenderAttribute( 'list_item', 'class', [
                    'list-group-item', 'd-flex', 'align-items-center'
                ] );

                view.addRenderAttribute( 'icon_badge', 'class', [
                    'landkit-elementor-icon-list__icon', 'badge', 'badge-rounded-circle', 'ml-4'
                ] );

                if ( '' != settings.icon_list_card_icon_css ) {
                    view.addRenderAttribute( 'icon_badge', 'class', settings.icon_list_card_icon_css );
                }

                var iconsHTML = {};
            #>
            <# if ( settings.icon_list ) { #>
            <div {{{ view.getRenderAttributeString( 'icon_card' ) }}}>
                <div class="card-body">
                    <div {{{ view.getRenderAttributeString( 'icon_list' ) }}}>
                        <# _.each( settings.icon_list, function( item, index ) {

                            var iconTextKey = view.getRepeaterSettingKey( 'text', 'icon_list', index );

                            view.addRenderAttribute( iconTextKey, 'class', [
                                'landkit-elementor-icon-list__heading', 'mb-1'
                            ] ); 

                            if ( '' != settings.icon_list_card_title_css ) {
                                view.addRenderAttribute( iconTextKey, 'class', settings.icon_list_card_title_css );
                            }

                            var iconSubtextKey = view.getRepeaterSettingKey( 'subtext', 'icon_list', index );

                            view.addRenderAttribute( iconSubtextKey, 'class', [
                                'landkit-elementor-icon-list__subtitle', 'mb-0'
                            ] );

                            if ( '' != settings.icon_list_card_subtitle_css ) {
                                view.addRenderAttribute( iconSubtextKey, 'class', settings.icon_list_card_subtitle_css );
                            }

                            #>
                        <div {{{ view.getRenderAttributeString( 'list_item' ) }}}>
                            <div class="mr-auto">
                                <p {{{ view.getRenderAttributeString( iconTextKey ) }}}>{{{ item.text }}}</p>
                                <p {{{ view.getRenderAttributeString( iconSubtextKey ) }}}>{{{ item.subtext }}}</p>

                            </div>
                            <# if ( item.icon || item.selected_icon.value ) { #>
                            <div {{{ view.getRenderAttributeString( 'icon_badge' ) }}}>
                                <#
                                    iconsHTML[ index ] = elementor.helpers.renderIcon( view, item.selected_icon, { 'aria-hidden': true }, 'i', 'object' );
                                #>
                                {{{ iconsHTML[ index ].value }}}
                            </div>
                            <# } #>
                        </div>
                        <#
                        } ); #>
                    </div>
                </div>
            </div>
            <#  } #>
        <# } #>
        <?php
    }
}