<?php

namespace LandkitElementor\Modules\IconList\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Skin_Base;
use Elementor\Group_Control_Typography;

class Skin_Icon_List_Flex extends Skin_Base {

    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
    }

    public function get_id() {
        return 'icon-list-flex';
    }

    public function get_title() {
        return esc_html__( 'Flex', 'landkit-elementor' );
    }

    protected function _register_controls_actions() {
        add_action( 'elementor/element/icon-list/section_icon_list/before_section_end', [ $this, 'register_icon_list_controls' ] );
        add_action( 'elementor/element/icon-list/section_icon_style/before_section_end', [ $this, 'register_icon_style_controls' ], 20 );
        add_action( 'elementor/element/icon-list/section_text_style/before_section_end', [ $this, 'register_text_style_controls' ] );
        add_filter( 'landkit-elementor/widget/icon-list/print_template', [ $this, 'print_template' ], 20 );
    }

    public function register_icon_list_controls( Elementor\Widget_Base $widget ) {
        $this->parent = $widget;

        $this->parent->update_control(
            'space_between', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->parent->update_control(
            'icon_align', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->parent->update_control(
            'divider', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->add_control( 'disable_column', [
            'label'        => esc_html__( 'Disable Column?', 'landkit-elementor' ),
            'type'         => Controls_Manager::SWITCHER,
            'description'  => esc_html__( 'Card Design for your column. Make sure to add card-body class to one of the widget to wrap them inside a body.', 'landkit-elementor' ),
            'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
            'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
            'return_value' => 'yes',
            'default'      => '',
        ] );

        $this->add_responsive_control(
            'column',
            [
                'label'          => esc_html__( 'Columns', 'landkit-elementor' ),
                'type'           => Controls_Manager::SELECT,
                'default'        => '2',
                'tablet_default' => '2',
                'mobile_default' => '1',
                'options' => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ],
                'frontend_available' => true,
                'condition'          => [ $this->get_control_id( 'disable_column' ) . '!' => 'yes' ]
            ]
        );
    }

    public function register_icon_style_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;

        $this->parent = $widget;

        $this->parent->update_control(
            'icon_color', [
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-list-icon i'            => 'color: {{VALUE}};',
                    '{{WRAPPER}} .elementor-icon-list-icon svg'          => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .landkit-elementor-icon-list__icon'     => 'color: {{VALUE}};',
                    '{{WRAPPER}} .landkit-elementor-icon-list__icon svg' => 'fill: {{VALUE}};',
                ],
            ]
        );

        $this->parent->update_control(
            'icon_color_hover', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->add_control(
            'icon_bg', [
                'label' => __( 'Background', 'landkit-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .landkit-elementor-icon-list__icon'     => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->parent->update_control(
            'icon_size', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->parent->update_control(
            'icon_self_align', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $this->add_control(
            'icon_css', [
                'label'        => esc_html__( 'Icon CSS Classes', 'landkit-elementor' ),
                'type'         => Controls_Manager::TEXT,
                'dynamic'      => [
                    'active' => true,
                ],
                'title'        => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description'  => esc_html__( 'CSS classes applied to the icon wrapper.', 'landkit-elementor' )
            ]
        );
        
    }

    public function register_text_style_controls( Elementor\Widget_Base $widget ) {

        $this->parent = $widget;

        $this->add_control(
            'title_css', [
                'label'        => esc_html__( 'Title CSS Classes', 'landkit-elementor' ),
                'type'         => Controls_Manager::TEXT,
                'dynamic'      => [
                    'active' => true,
                ],
                'title'        => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description'  => esc_html__( 'CSS classes applied to icon list title.', 'landkit-elementor' )
            ]
        );
        
        $this->parent->update_control(
            'text_color', [
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-list-text' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .landkit-elementor-icon-list__heading' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->parent->update_control(
            'text_color_hover', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
        $this->parent->update_control(
            'text_indent', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );
    }

    public function render() {
        $widget      = $this->parent;
        $settings    = $this->parent->get_settings();
        $disable_col = $settings[ $this->get_control_id( 'disable_column' ) ];

        $widget->add_render_attribute( 'icon_badge', 'class', [
            'landkit-elementor-icon-list__icon', 'badge', 'badge-rounded-circle', 'mt-1','mr-4'
        ] );

        $icon_css = $settings[ $this->get_control_id( 'icon_css' ) ];
        if ( ! empty( $icon_css ) ) {
            $widget->add_render_attribute( 'icon_badge', 'class', $icon_css );
        }

        if ( 'yes' !== $disable_col ) {
            $widget->add_render_attribute( 'row', 'class', [
                'row' , 'row-cols-' . $settings[ 'icon_list_flex_column_mobile' ] ,'row-cols-md-' . $settings[ 'icon_list_flex_column_tablet' ] ,'row-cols-lg-' . $settings[ 'icon_list_flex_column' ]
            ] );
            $widget->add_render_attribute( 'col', 'class', 'col' );
        }

        $widget->add_render_attribute( 'icon_text', 'class', [
            'landkit-elementor-icon-list__heading'
        ] );

        $title_css = $settings[ $this->get_control_id( 'title_css' ) ];
        if ( ! empty( $title_css ) ) {
            $widget->add_render_attribute( 'icon_text', 'class', $title_css );
        }

        ?>
        <div <?php echo $widget->get_render_attribute_string( 'row' );?> >
            <?php foreach ( $settings['icon_list'] as $index => $item ) : ?>
                <div <?php echo $widget->get_render_attribute_string( 'col' ); ?>>
                    <div class="d-flex">
                        <!-- Check -->
                        <?php if ( ! empty( $item['icon'] ) || ( ! empty( $item['selected_icon']['value'] ) ) ): ?>
                            <div <?php echo $widget->get_render_attribute_string( 'icon_badge' ); ?>>
                                <?php Icons_Manager::render_icon( $item['selected_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                            </div>
                        <?php endif; ?>

                        <!-- Text -->
                        <p <?php echo $widget->get_render_attribute_string( 'icon_text' );?>>
                            <?php echo $item['text']; ?>
                        </p>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    <?php
    }

    public function print_template( $content ) {
        ob_start();
        $this->content_template( $content );
        return ob_get_clean();
    }

    public function content_template( $content ) {
        echo $content; ?>
        <# if ( 'icon-list-flex' === settings._skin ) { #>
            <# if ( settings.icon_list ) { #>
            <#
                view.addRenderAttribute( 'icon_badge', 'class', [
                    'landkit-elementor-icon-list__icon', 'badge', 'badge-rounded-circle', 'mt-1','mr-4'
                ] );

                if ( '' != settings.icon_list_flex_icon_css ) {
                    view.addRenderAttribute( 'icon_badge', 'class', settings.icon_list_flex_icon_css );
                }

                if ( 'yes' != settings.disable_column ) {
                    view.addRenderAttribute( 'row', 'class', [
                        'row' , 'row-cols-' + settings.icon_list_flex_column_mobile , 
                        'row-cols-md-' + settings.icon_list_flex_column_tablet ,
                        'row-cols-lg-' + settings.icon_list_flex_column
                    ] );

                    view.addRenderAttribute( 'col', 'class', 'col' );
                }

                

                view.addRenderAttribute( 'icon_text', 'class', [
                    'landkit-elementor-icon-list__heading'
                ] );

                if ( '' != settings.icon_list_flex_title_css ) {
                    view.addRenderAttribute( 'icon_text', 'class', settings.icon_list_flex_title_css );
                }
                
                var iconsHTML = {};
            #>
            
            <div {{{ view.getRenderAttributeString( 'row' ) }}}>
                <# _.each( settings.icon_list, function( item, index ) { #>
                    <div {{{ view.getRenderAttributeString( 'col' ) }}}>
                        <div class="d-flex">
                            <# if ( item.icon || item.selected_icon.value ) { #>
                                <div {{{ view.getRenderAttributeString( 'icon_badge' ) }}}>
                                    <#
                                        iconsHTML[ index ] = elementor.helpers.renderIcon( view, item.selected_icon, { 'aria-hidden': true }, 'i', 'object' );
                                    #>
                                    {{{ iconsHTML[ index ].value }}}
                                </div>
                            <# } #>

                            <# if ( 'yes' !== settings.disable_column && index == 2 ) {
                                    view.addRenderAttribute( 'icon_text', 'class', 'mb-0' );
                                }
                            #>

                            <p {{{ view.getRenderAttributeString( 'icon_text' ) }}}>
                                {{{ item.text }}}
                            </p>
                        </div>
                    </div>
                <# } ); #>
            </div>
            <# } #>
        <# } #>
        <?php
    }
}