<?php
namespace LandkitElementor\Modules\ImageBox\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use LandkitElementor\Core\Utils as LE_Utils;

class Skin_Image_Box_Card extends Skin_Base {

    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
        add_filter( 'elementor/widget/print_template', [ $this, 'skin_print_template' ], 10, 2 );
        add_action( 'elementor/element/image-box/section_image/before_section_end', [ $this, 'section_image_controls' ], 10, 2 );
        add_action( 'elementor/element/image-box/section_style_image/before_section_end', [ $this, 'style_image_controls' ] );
        add_action( 'elementor/element/image-box/section_style_content/before_section_end', [ $this, 'style_content_controls' ] );
    }

    public function get_id() {
        return 'image-box-card';
    }

    public function get_title() {
        return esc_html__( 'Card', 'landkit-elementor' );
    }

    public function style_image_controls( $widget ) {
        $this->parent = $widget;

        $this->add_control( 'img_css', [
            'label' => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'  => Controls_Manager::TEXT,
            'title' => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
        ] );
    }

    public function style_content_controls( $widget ) {
        $this->parent = $widget;

        $this->add_control( 'title_css', [
            'label'    => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'     => Controls_Manager::TEXT,
            'title'    => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
        ], [
            'position' => [
                'at' => 'before',
                'of' => 'heading_description'
            ]
        ] );

        $this->add_control( 'desc_css', [
            'label' => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'  => Controls_Manager::TEXT,
            'title' => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
        ] );
    }

    public function section_image_controls( $widget, $args ) {
        $this->parent = $widget;

        $widget->update_control( 'position', [
            'condition' => [ '_skin' => '' ]
        ] );

        $this->add_control(
            'position', [
                'label'   => esc_html__( 'Image Position', 'landkit-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'default' => 'top',
                'options' => [
                    'left'  => [
                        'title' => esc_html__( 'Left', 'landkit-elementor' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'landkit-elementor' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
            ]
        );
    }

    public function skin_print_template( $content, $widget ) {
        if ( 'image-box' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }

    private function render_image( $settings ) {
        $widget = $this->parent;

        if ( empty( $settings['image']['url'] ) ) {
            return;
        }

        $img_pos     = $settings[ 'image_box_card_position' ];
        $img_classes = [ 'h-75', 'position-absolute', 'w-auto', 'mw-none' ];
        $img_css     = $settings[ $this->get_control_id( 'img_css' ) ];

        $widget->add_render_attribute( 'img_wrapper', 'class', [
            'elementor-image-box-img', 'col-md-4', 'position-relative'
        ] );

        if ( 'right' === $img_pos ) {
            $img_classes[] = 'left-0';
            $widget->add_render_attribute( 'img_wrapper', 'class', 'order-2' );
        } else {
            $img_classes[] = 'right-0';
        }

        if ( ! empty( $img_css ) ) {
            $img_classes = array_merge( $img_classes, explode( ' ', $img_css ) );
        }

        $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
        $image_html = LE_Utils::add_class_to_image_html( $image_html, $img_classes ); 

        if ( ! empty( $settings['link']['url'] ) ) {
            $image_html = '<a ' . $widget->get_render_attribute_string( 'link' ) . '>' . $image_html . '</a>';
        }

        ?>

        <div <?php echo $widget->get_render_attribute_string( 'img_wrapper' );?>>
            <!-- Image -->
            <?php print( $image_html ); ?>
        </div><?php
    }

    private function render_title( $settings ) {
        $widget     = $this->parent;
        $title      = $settings['title_text'];
        $has_title  = ! Utils::is_empty( $title );
        $title_css  = $settings[ $this->get_control_id( 'title_css' ) ];
        $title_html = $title;

        if ( ! $has_title ) {
            return;
        }

        $widget->add_render_attribute( 'title', 'class', 'elementor-image-box-title' );

        if ( ! empty( $settings['link']['url'] ) ) {
            $title_html = '<a ' . $widget->get_render_attribute_string( 'link' ) . '>' . $title_html . '</a>';
        }

        if ( ! empty( $title_css ) ) {
            $widget->add_render_attribute( 'title', 'class', $title_css );
        }

        printf( '<%1$s %2$s>%3$s</%1$s>', $settings['title_size'], $widget->get_render_attribute_string( 'title' ), $title_html );
    }

    private function render_description( $settings ) {
        $widget   = $this->parent;
        $desc     = $settings[ 'description_text' ];
        $has_desc = ! Utils::is_empty( $desc );
        $desc_css = $settings [ $this->get_control_id( 'desc_css' ) ];

        if ( ! $has_desc ) {
            return;
        }

        $widget->add_render_attribute( 'description_text', 'class', [ 'elementor-image-box-description', 'mb-0' ] );

        if ( ! empty( $desc_css ) ) {
            $widget->add_render_attribute( 'description_text', 'class', $desc_css );
        }

        printf( '<p %1$s>%2$s</p>', $widget->get_render_attribute_string( 'description_text' ), $settings['description_text'] );
    }

    private function render_content( $settings ) {
        $widget      = $this->parent;
        $has_content = ! Utils::is_empty( $settings['title_text'] ) || ! Utils::is_empty( $settings['description_text'] );

        if ( ! $has_content ) {
            return;
        }

        $widget->add_render_attribute( 'content', 'class', [
            'elementor-image-box-content', 'col-md-8'
        ] );
        ?><div <?php echo $widget->get_render_attribute_string( 'content' );?>>
            <div class="card-body py-7 py-md-9">
                <?php 
                    $this->render_title( $settings );
                    $this->render_description( $settings );
                ?>
            </div>
        </div><?php
    }

    public function render() {
        $widget   = $this->parent;
        $settings = $widget->get_settings_for_display();

        if ( ! empty( $settings['link']['url'] ) ) {
            $widget->add_link_attributes( 'link', $settings['link'] );
        }

        ?><div class="elementor-image-box-wrapper card shadow-light-lg overflow-hidden">
            <div class="row"><?php
                $this->render_image( $settings );
                $this->render_content( $settings ); ?>
            </div>
        </div><?php
    }

}