<?php
namespace LandkitElementor\Modules\ImageBox\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;

class Skin_Image_Box_Flex extends Skin_Base {

    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
        add_filter( 'elementor/widget/print_template', [ $this, 'skin_print_template' ], 10, 2 );
        add_action( 'elementor/element/image-box/section_image/before_section_end', [ $this, 'section_image_controls' ], 10, 2 );
        add_action( 'elementor/element/image-box/section_style_content/before_section_end', [ $this, 'style_controls' ], 10, 2 );
    }

    public function get_id() {
        return 'image-box-flex';
    }

    public function get_title() {
        return esc_html__( 'Flex', 'landkit-elementor' );
    }

    public function section_image_controls( $element, $args ) {
        $this->parent = $element;

        $element->update_control( 'position', [
            'condition' => [ '_skin' => '' ]
        ] );

        $this->add_control(
            'position', [
                'label'   => esc_html__( 'Image Position', 'landkit-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'default' => 'top',
                'options' => [
                    'left'  => [
                        'title' => esc_html__( 'Left', 'landkit-elementor' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'landkit-elementor' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
            ]
        );
    }

    public function style_controls( $element, $args ) {
        $this->parent = $element;

        $default_only_controls = [
            'content_vertical_alignment', 'title_bottom_space'
        ];

        foreach( $default_only_controls as $control ) {
            $this->parent->update_control( $control, [
                'condition' => [
                    '_skin' => ''
                ]
            ] );
        }

        $this->add_control( 'img_css', [
            'label'    => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'     => Controls_Manager::TEXT,
            'title'    => esc_html__( 'Add your custom class for image without the dot. e.g: my-class', 'landkit-elementor' ),
            'default'  => 'img-fluid',
        ], [
            'position' => [
                'type' => 'section',
                'at'   => 'end',
                'of'   => 'section_style_image',
            ]
        ] );

        $this->add_control( 'title_css', [
            'label'    => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'     => Controls_Manager::TEXT,
            'title'    => esc_html__( 'Add your custom class for title without the dot. e.g: my-class', 'landkit-elementor' ),
            'default'  => 'font-weight-bold'
        ], [
            'position' =>  [
                'at'   => 'before',
                'of'   => 'heading_description'
            ]
        ] );

        $this->add_control( 'description_css', [
            'label'   => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'    => Controls_Manager::TEXT,
            'title'   => esc_html__( 'Add your custom class for description without the dot. e.g: my-class', 'landkit-elementor' ),
            'default' => 'text-gray-700'
        ] );
    }

    public function skin_print_template( $content, $widget ) {
        if( 'image-box' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }

    public function render() {
        $widget    = $this->parent;
        $settings  = $widget->get_settings_for_display();
        $image_pos = $settings[ $this->get_control_id( 'position' ) ];

        $has_content = ! Utils::is_empty( $settings['title_text'] ) || ! Utils::is_empty( $settings['description_text'] );

        $html = '<div class="elementor-image-box-wrapper">';
        $html .= '<div class="row align-items-center mb-8">';

        if ( ! empty( $settings['link']['url'] ) ) {
            //$widget->add_link_attributes( 'link', $settings['link'] );
        }

        if ( ! empty( $settings['image']['url'] ) ) {
            $widget->add_render_attribute( 'image', 'src', $settings['image']['url'] );
            $widget->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
            $widget->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );

            if ( $settings['hover_animation'] ) {
                $widget->add_render_attribute( 'image', 'class', 'elementor-animation-' . $settings['hover_animation'] );
            }

            $image_html    = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
            $image_classes = $settings[ $this->get_control_id( 'img_css' ) ];

            $image_box_classes = 'elementor-image-box-img col-4 col-lg-5';

            if ( ! empty( $image_pos ) && 'right' === $image_pos ) {
                $image_box_classes .= ' order-2';
            }

            if ( false === strpos( $image_html, 'class="' ) ) {
                $image_html = str_replace( '<img', '<img class="' . esc_attr( $image_classes ) . '"', $image_html );
            } else {
                $image_html = str_replace( 'class="', 'class="' . esc_attr( $image_classes ) .' ' , $image_html );
            }

            if ( ! empty( $settings['link']['url'] ) ) {
                $image_html = '<a ' . $widget->get_render_attribute_string( 'link' ) . '>' . $image_html . '</a>';
            }

            $html .= '<div class="' . esc_attr( $image_box_classes ) . '">' . $image_html . '</div>';
        }

        if ( $has_content ) {
            $html .= '<div class="elementor-image-box-content col-8 col-lg-7">';

            if ( ! Utils::is_empty( $settings['title_text'] ) ) {
                $widget->add_render_attribute( 'title_text', 'class', [
                    'elementor-image-box-title', 'mb-2' 
                ] );

                $title_css = $settings[ $this->get_control_id( 'title_css' ) ];
                if ( ! empty( $title_css ) ) {
                    $widget->add_render_attribute( 'title_text', 'class', $title_css );
                }

                $title_html = $settings['title_text'];

                if ( ! empty( $settings['link']['url'] ) ) {
                    $title_html = '<a ' . $widget->get_render_attribute_string( 'link' ) . '>' . $title_html . '</a>';
                }

                $html .= sprintf( '<%1$s %2$s>%3$s</%1$s>', $settings['title_size'], $widget->get_render_attribute_string( 'title_text' ), $title_html );
            }

            if ( ! Utils::is_empty( $settings['description_text'] ) ) {
                $widget->add_render_attribute( 'description_text', 'class', [ 'elementor-image-box-description', 'mb-0' ] );

                $description_css = $settings[ $this->get_control_id( 'description_css' ) ];
                if ( ! empty( $description_css ) ) {
                    $widget->add_render_attribute( 'description_text', 'class', $description_css );
                }

                $html .= sprintf( '<p %1$s>%2$s</p>', $widget->get_render_attribute_string( 'description_text' ), $settings['description_text'] );
            }

            $html .= '</div>';
        }

        $html .= '</div>';
        $html .= '</div>';

        echo $html;
    }

}