<?php
namespace LandkitElementor\Modules\ImageCarousel\Skins;

use Elementor\Skin_Base;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use LandkitElementor\Includes\Controls\Groups\Group_Control_Shape_Divider;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Skin_Slider extends Skin_Base {

    public function __construct( Widget_Base $parent ) {
        parent::__construct( $parent );

        $this->add_actions();

        add_filter( 'elementor/widget/print_template', [ $this, 'skin_print_template' ], 10, 2 );
    }

    public function get_id() {
        return 'slider';
    }

    public function get_title() {
        return esc_html__( 'Slider', 'landkit-elementor' );
    }

    public function skin_print_template( $content, $widget ) {
        if( 'image-carousel' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }

    public function add_actions() {
        add_action( 'elementor/element/image-carousel/section_image_carousel/after_section_end', [ $this, 'add_section_shapes_controls' ], 10, 2  );
        add_action( 'elementor/element/image-carousel/section_image_carousel/before_section_end', [ $this, 'modify_section_image_carousel_controls' ], 10, 2  );
        add_action( 'elementor/element/image-carousel/section_additional_options/before_section_end', [ $this, 'modify_section_additional_options_controls' ], 10, 2  );
        add_action( 'elementor/element/image-carousel/section_style_navigation/before_section_end', [ $this, 'modify_section_style_navigation_controls' ], 10, 2  );
        add_action( 'elementor/element/image-carousel/section_style_image/before_section_end', [ $this, 'modify_section_style_image_controls' ], 10, 2  );
        add_action( 'elementor/element/image-carousel/section_caption/before_section_end', [ $this, 'modify_section_caption_controls' ], 10, 2  );
    }

    public function add_section_shapes_controls( $element, $args ) {
        $element->start_controls_section(
            'section_shapes_controls', [
                'label'     => esc_html__( 'Shapes', 'landkit-elementor' ),
                'condition' => [ '_skin' => 'slider' ],
            ]
        );

        $element->add_group_control(
            Group_Control_Shape_Divider::get_type(), [
                'name'      => 'slider_divider'
            ]
        );

        $element->end_controls_section();
    }

    public function modify_section_image_carousel_controls( $element, $args ) {
        $this->parent = $element;
        $element->update_control(
            'thumbnail_size', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->update_control(
            'thumbnail_custom_dimension', [
                'condition' => [
                    'thumbnail_size'    => 'custom',
                    '_skin!'            => 'slider',
                ],
            ]
        );

        $element->update_responsive_control( 
            'slides_to_show', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->update_responsive_control(
            'slides_to_scroll', [
                'condition' => [
                    'slides_to_show!'   => '1',
                    '_skin!'            => 'slider',
                ],
            ]
        );

        $element->update_control(
            'image_stretch', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->update_control(
            'link_to', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->update_control(
            'link', [
                'condition' => [
                    'link_to'   => 'custom',
                    '_skin!'    => 'slider',
                ],
            ]
        );

        $element->update_control(
            'open_lightbox', [
                'condition' => [
                    'link_to'   => 'file',
                    '_skin!'    => 'slider',
                ],
            ]
        );

        $element->update_control(
            'caption_type', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->update_control(
            'view', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->start_injection( [
            'of'    => '_skin',
        ] );

        $element->add_control(
            'slider_style', [
                'label'         => esc_html__( 'Slider Style', 'landkit-elementor' ),
                'description'   => esc_html__( 'Backgroud Cover style dependent on column or parent elelment height', 'landkit-elementor' ),
                'type'          => Controls_Manager::SELECT,
                'options'       => [
                    ''          => esc_html__( 'Default', 'landkit-elementor' ),
                    'bg-cover'  => esc_html__( 'Backgroud Cover', 'landkit-elementor' ),
                ],
                'condition'     => [ '_skin' => 'slider' ],
                'frontend_available' => true,
            ]
        );

        $element->add_control(
            'enable_rounded_image', [
                'label'     => esc_html__( 'Rounded Edge Image ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'no',
                'label_on'  => esc_html__( 'Eanble', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    '_skin'         => 'slider',
                    'slider_style!' => 'bg-cover'
                ],
            ]
        );

        $element->add_control(
            'enable_carousel_caption', [
                'label'     => esc_html__( 'Carousel Caption ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'no',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'condition' => [
                    '_skin'         => 'slider',
                    'slider_style!' => 'bg-cover'
                ],
            ]
        );

        $element->add_control(
            'carousel_caption_text', [
                'label'     => esc_html__( 'Carousel Caption Text', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXTAREA,
                'default'   => esc_html__( 'This is a caption on this photo for reference', 'landkit-elementor' ),
                'condition' => [
                    '_skin'                     => 'slider',
                    'enable_carousel_caption'   => 'yes',
                    'slider_style!'             => 'bg-cover',
                ],
            ]
        );

        $element->add_control(
            'image_additional_classes', [
                'label'     => esc_html__( 'Image Additional Classes', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'w-100',
                'condition' => [
                    '_skin'         => 'slider',
                    'slider_style!' => 'bg-cover',
                ],
            ]
        );

        $element->add_control(
            'display_mobile', [
                'label'     => esc_html__( 'Enable in Mobile', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'condition' => [
                    '_skin'         => 'slider',
                    'slider_style'  => 'bg-cover'
                ],
            ]
        );

        $element->add_control(
            'enable_half_view_width', [
                'label'     => esc_html__( 'Enable Half Screen View Width', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'condition' => [
                    '_skin'         => 'slider',
                    'slider_style'  => 'bg-cover'
                ],
            ]
        );

        $element->end_injection();
    }

    public function modify_section_additional_options_controls( $element, $args ) {
        $element->update_control(
            'pause_on_interaction', [
                'condition' => [
                    'autoplay'  => 'yes',
                    '_skin!'    => 'slider',
                ],
            ]
        );

        $element->update_control(
            'effect', [
                'condition' => [
                    'slides_to_show'    => '1',
                    '_skin!'            => 'slider',
                ],
            ]
        );

        $element->update_control(
            'speed', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );

        $element->update_control(
            'direction', [
                'condition' => [ '_skin!' => 'slider' ],
            ]
        );
    }

    public function modify_section_style_navigation_controls( $element, $args ) {
        $element->update_control(
            'arrows_position', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'arrows', 'both' ],
                ],
            ]
        );

        $element->update_control(
            'arrows_size', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'arrows', 'both' ],
                ],
            ]
        );

        $element->update_control(
            'arrows_color', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'arrows', 'both' ],
                ],
            ]
        );

        $element->update_control(
            'heading_style_dots', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'dots', 'both' ],
                ],
            ]
        );

        $element->update_control(
            'dots_position', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'dots', 'both' ],
                ],
            ]
        );

        $element->update_control(
            'dots_size', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'dots', 'both' ],
                ],
            ]
        );

        $element->update_control(
            'dots_color', [
                'condition' => [
                    '_skin!'        => 'slider',
                    'navigation'    => [ 'dots', 'both' ],
                ],
            ]
        );

        $element->start_injection( [
            'of' => 'heading_style_arrows',
        ] );

        $element->add_control(
            'flkty_arrows_position', [
                'label'     => esc_html__( 'Arrow Position', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'flickity-button-inset',
                'options'   => [
                    ''                          => esc_html__( 'Outside', 'landkit-elementor' ),
                    'flickity-button-inset'     => esc_html__( 'Inside', 'landkit-elementor' ),
                    'flickity-button-bottom'    => esc_html__( 'Inside Bottom', 'landkit-elementor' )
                ],
                'condition' => [
                    '_skin'         => 'slider',
                    'navigation'    => [ 'arrows', 'both' ],
                ],
                'frontend_available'    => true,
            ]
        );

        $element->add_control(
            'flkty_arrows_color', [
                'label'     => esc_html__( 'Arrow Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'flickity-button-white',
                'options'   => [
                    ''                      => esc_html__( 'Default', 'landkit-elementor' ),
                    'flickity-button-white' => esc_html__( 'White', 'landkit-elementor' ),
                ],
                'condition' => [
                    '_skin'         => 'slider',
                    'navigation'    => [ 'arrows', 'both' ],
                ],
                'frontend_available'    => true,
            ]
        );

        $element->end_injection();
    }

    public function modify_section_style_image_controls( $element, $args ) {
        $element->update_control( 'section_style_image', [
            'condition' => [
                '_skin!' => 'slider',
            ],
        ] );
    }

    public function modify_section_caption_controls( $element, $args ) {
        $element->update_control( 'section_caption', [
            'condition' => [
                '_skin!'        => 'slider',
                'caption_type!' => '',
            ],
        ] );
    }

    public function render() {
        $settings = $this->parent->get_settings_for_display();

        if( ! ( isset( $settings['carousel'] ) && count( $settings['carousel'] ) > 0 && isset( $settings['carousel'][0]['url'] ) ) ) {
            return '';
        }

        $default_carousel_settings = apply_filters( 'landkit_image_carousel_slider_default_carousel_args', [
            'pageDots'        => false,
            'imagesLoaded'    => true,
            'wrapAround'      => true,
            'prevNextButtons' => false,
        ] );

        $show_dots = isset( $settings['navigation'] ) && in_array( $settings['navigation'], [ 'dots', 'both' ] ) ? true : false;
        $show_arrows = isset( $settings['navigation'] ) && in_array( $settings['navigation'], [ 'arrows', 'both' ] ) ? true : false;

        $carousel_settings = [
            'wrapAround'        => isset( $settings['infinite'] ) && $settings['infinite'] === 'yes' ? true : false,
            'pageDots'          => $show_dots,
            'prevNextButtons'   => $show_arrows,
        ];

        if( isset( $settings['slider_style'] ) && $settings['slider_style'] === 'bg-cover' ) {
            $carousel_settings["setGallerySize"] = false;
        } else {
            $carousel_settings["adaptiveHeight"] = true;
        }

        $carousel_settings = array_merge( $default_carousel_settings, $carousel_settings );

        $carousel_settings = apply_filters( 'landkit_image_carousel_slider_carousel_args', $carousel_settings );

        if( isset( $settings['autoplay'] ) && $settings['autoplay'] === 'yes' ) {
            $carousel_settings['autoPlay'] = $settings['autoplay_speed'] ? intval( $settings['autoplay_speed'] ) : 1500;
            $carousel_settings['pauseAutoPlayOnHover'] = isset( $settings['pause_on_hover'] ) && $settings['pause_on_hover'] === 'yes' ? true : false;
        }

        $this->parent->add_render_attribute( 'slider-wrap', [
            'class'         => 'flickity-init-wrap',
            'data-flickity' => htmlspecialchars( json_encode( $carousel_settings ), ENT_QUOTES, 'UTF-8' ),
            'data-aos-id'   => 'flickity:in',
            'data-aos'      => "1"
        ] );

        if( $show_arrows ) {
            if( isset( $settings['flkty_arrows_color'] ) && $settings['flkty_arrows_color'] !== '' ) {
                $this->parent->add_render_attribute( 'slider-wrap', 'class', $settings['flkty_arrows_color'] );
            }

            if( isset( $settings['flkty_arrows_position'] ) && $settings['flkty_arrows_position'] !== '' ) {
                $this->parent->add_render_attribute( 'slider-wrap', 'class', $settings['flkty_arrows_position'] );
            }
        }

        if( isset( $settings['slider_style'] ) && $settings['slider_style'] === 'bg-cover' ) {
            $this->parent->add_render_attribute( '_wrapper', 'class', [ 'h-md-100', 'elementor-widget-container-h-100' ] );

            $this->parent->add_render_attribute( 'slider-wrap-outter', [
                'class' => [ 'position-relative', 'h-100', 'd-none', 'd-md-block' ],
            ] );

            if( isset( $settings['enable_half_view_width'] ) && $settings['enable_half_view_width'] === 'yes' ) {
                $this->parent->add_render_attribute( 'slider-wrap-outter', 'class', 'vw-50' );
            }

            $this->parent->add_render_attribute( 'slider-wrap', [
                'class' => [ 'h-100', 'w-100' ],
            ] );

            $this->parent->add_render_attribute( 'mobile-slider-wrap', [
                'class'         => [ 'flickity-mobile-init-wrap', 'd-md-none', 'img-cover' ],
                'data-flickity' => htmlspecialchars( json_encode( $default_carousel_settings ), ENT_QUOTES, 'UTF-8' ),
                'data-aos-id'   => 'flickity:in',
                'data-aos'      => "1"
            ] );

            if( isset( $settings['display_mobile'] ) && $settings['display_mobile'] === 'yes' ) : ?>
                <!-- Mobile Slider -->
                <div <?php echo $this->parent->get_render_attribute_string( 'mobile-slider-wrap' ); ?>>
                    <?php foreach( $settings['carousel'] as $key => $slide_image ) {
                        $this->parent->add_render_attribute( "slide-image-{$key}", [
                            'class' => [ 'img-fluid', 'w-100' ],
                            'src'   => esc_url( $slide_image['url'] ),
                            'alt'   => esc_attr( isset( $slide_image['id'] ) ? $slide_image['id'] : $key ),
                        ], true );

                        ?><div class="w-100"><img <?php echo $this->parent->get_render_attribute_string( "slide-image-{$key}" ); ?>></div><?php
                    } ?>
                </div>
                <!-- Mobile Slider End -->
            <?php endif; ?>

            <!-- Slider -->
            <div <?php echo $this->parent->get_render_attribute_string( 'slider-wrap-outter' ); ?>>
                <div <?php echo $this->parent->get_render_attribute_string( 'slider-wrap' ); ?>>
                    <?php foreach( $settings['carousel'] as $key => $slide_image ) {
                        ?><div class="w-100 h-100 bg-cover" style="background-image: url(<?php echo esc_url( $slide_image['url'] ); ?>);" aria-hidden="true"></div><?php
                    } ?>
                </div>
                <?php echo Group_Control_Shape_Divider::get_shape_divider( $settings, 'slider_divider' ); ?>
            </div>
            <!-- Slider End -->
            <?php
        } else {
            if( isset( $settings['enable_carousel_caption'] ) && $settings['enable_carousel_caption'] === 'yes' && isset( $settings['carousel_caption_text'] ) && ! empty( $settings['carousel_caption_text'] ) ) {
                ?><figure class="figure mb-0"><?php

                $this->parent->add_render_attribute( 'slider-wrap', 'class', 'figure-img' );
            }
            ?>
            <div <?php echo $this->parent->get_render_attribute_string( 'slider-wrap' ); ?>>
                <?php foreach( $settings['carousel'] as $key => $slide_image ) {
                    $this->parent->add_render_attribute( "slide-image-{$key}", [
                        'class' => [ 'img-fluid' ],
                        'src' => esc_url( $slide_image['url'] ),
                        'alt' => esc_attr( isset( $slide_image['id'] ) ? $slide_image['id'] : $key ),
                    ], true );

                    if( isset( $settings['enable_rounded_image'] ) && $settings['enable_rounded_image'] === 'yes' ) {
                        $this->parent->add_render_attribute( "slide-image-{$key}", 'class', 'rounded' );
                    }

                    if( isset( $settings['image_additional_classes'] ) && ! empty( $settings['image_additional_classes'] ) ) {
                        $this->parent->add_render_attribute( "slide-image-{$key}", 'class', $settings['image_additional_classes'] );
                    }

                    ?><div class="w-100">
                        <img <?php echo $this->parent->get_render_attribute_string( "slide-image-{$key}" ); ?>>
                        <?php echo Group_Control_Shape_Divider::get_shape_divider( $settings, 'slider_divider' ); ?>
                    </div><?php
                } ?>
            </div>
            <?php

            if( isset( $settings['enable_carousel_caption'] ) && $settings['enable_carousel_caption'] === 'yes' && isset( $settings['carousel_caption_text'] ) && ! empty( $settings['carousel_caption_text'] ) ) {
                ?><figcaption class="figure-caption text-center"><?php echo wp_kses_post( $settings['carousel_caption_text'] ); ?></figcaption><?php
                ?></figure><?php
            }
        }
    }
}
