<?php
namespace LandkitElementor\Modules\ImageGrid\Skins;

use Elementor\Widget_Base;
use Elementor\Skin_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Skin_Grid_2 extends Skin_Base {

    public function __construct( Widget_Base $parent ) {
        $this->parent = $parent;

        add_action( 'elementor/element/lk-image-grid/section_grid/after_section_end', [ $this, 'update_controls' ] );
    }

    public function get_id() {
        return 'grid-style-2';
    }

    public function get_title() {
        return esc_html__( 'Style 2', 'landkit-elementor' );
    }


    public function update_controls() {
        $this->parent->update_control(
            'image-4', [
                'condition' => [
                    '_skin' => [ 'grid-style-2', 'grid-style-4' ],
                ],
            ]
        );
        $this->parent->update_control(
            'data_animation_1', [
                'condition' => [
                    '_skin!' => [ '', 'grid-style-4' ]
                ],
            ]
        );
        $this->parent->update_control(
            'data_animation_2', [
                'condition' => [
                    '_skin!' => '',
                    '_skin!' => [ '', 'grid-style-4' ]
                ],
            ]
        );
    }

    protected function add_inline_editing_attributes( $key, $toolbar = 'basic' ) {
        if ( ! Plugin::$instance->editor->is_edit_mode() ) {
            return;
        }

        $this->parent->add_render_attribute( $key, [
            'class' => 'elementor-inline-editing',
            'data-elementor-setting-key' => $key,
        ] );

        if ( 'basic' !== $toolbar ) {
            $this->parent->add_render_attribute( $key, [
                'data-elementor-inline-editing-toolbar' => $toolbar,
            ] );
        }
    }

    public function render() {
        $settings = $this->parent->get_settings(); 
        $apply_mrg_top = $settings['apply_mrg_top'];
        $left  = '';
        $right = '';
        
        if ('right' ===  $apply_mrg_top){
            $right = 'mt-8';
        } else {
            $left  = 'mt-8';
        }
        ?>
        <div class="row">
            <div class="col-6 mr-n5 <?php echo esc_attr( $left ); ?>" data-aos=<?php echo esc_attr( $settings[ 'data_animation_1'] ); ?>>
                <img class="img-fluid mb-4 rounded"  alt="..." src=<?php echo esc_url( $settings['image-1']['url'] ); ?>>
                <img class="img-fluid rounded" alt="..." src=<?php echo esc_url( $settings['image-2']['url'] ); ?>>
            </div>
            <div class="col-6 <?php echo esc_attr( $right ); ?>" data-aos-delay="100" data-aos-delay="100" data-aos=<?php echo esc_attr( $settings[ 'data_animation_2'] );?>>
                <img class="img-fluid mb-4 rounded" alt="..." src=<?php echo esc_url( $settings['image-3']['url'] ); ?>>
                <img class="img-fluid rounded" alt="..." src=<?php echo esc_url( $settings['image-4']['url'] ); ?>>
            </div>
        </div><?php
    }
}
