<?php
namespace LandkitElementor\Modules\ImageGrid\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use LandkitElementor\Base\Base_Widget;
use LandkitElementor\Modules\ImageGrid\Skins;
use Elementor\Icons_Manager;
use Elementor\Plugin;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes;
use Elementor\Utils;



class Image_Grid extends Base_Widget {

	public function get_name() {
        return 'lk-image-grid';
    }

    public function get_title() {
        return esc_html__( 'Image Grid', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-gallery-justified';
    }

    protected $_has_template_content = false;

	protected function register_skins() {
		$this->add_skin( new Skins\Skin_Grid_1( $this ) );
        $this->add_skin( new Skins\Skin_Grid_2( $this ) );
        $this->add_skin( new Skins\Skin_Grid_3( $this ) );
        $this->add_skin( new Skins\Skin_Grid_4( $this ) );
    }


	protected function register_controls() {
		$this->start_controls_section( 'section_grid', [ 'label' => __( 'Grid Settings', 'landkit-elementor' ) ] );

		$this->add_control(
			'apply_mrg_top',
			[
				'label' => __( 'Apply Margin Top', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'left' => 'Left',
					'right' => 'Right',
				],
				'default' => 'right',
			]
		);

		$this->add_control(
			'image-1',
			[
				'label' => __( 'Choose Image 1', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'image-2',
			[
				'label' => __( 'Choose Image 2', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'image-3',
			[
				'label' => __( 'Choose Image 3', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'image-4',
			[
				'label' => __( 'Choose Image 4', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'image-5',
			[
				'label' => __( 'Choose Image 5', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'image-6',
			[
				'label' => __( 'Choose Image 6', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'data_animation_1',
			[
				'label' => __( 'Data Animation 1', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'fade-up' => 'fade-up',
					'fade-down' => 'fade-down',
					'fade-left' => 'fade-left',
					'fade-right' => 'fade-right',
					'fade-up-right' => 'fade-up-right',
					'fade-up-left' => 'fade-up-left',
					'fade-down-right' => 'fade-down-right',
					'fade-down-left' => 'fade-down-left',
					'none' => ''

				],
				'default' => 'fade-up',
			]
		);
		$this->add_control(
			'data_animation_2',
			[
				'label' => __( 'Data Animation 2', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'fade-up' => 'fade-up',
					'fade-down' => 'fade-down',
					'fade-left' => 'fade-left',
					'fade-right' => 'fade-right',
					'fade-up-right' => 'fade-up-right',
					'fade-up-left' => 'fade-up-left',
					'fade-down-right' => 'fade-down-right',
					'fade-down-left' => 'fade-down-left',
					'none' => ''
				],
				'default' => 'fade-up',
			]
		);
		$this->add_control(
			'data_animation_3',
			[
				'label' => __( 'Data Animation 3', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'fade-up' => 'fade-up',
					'fade-down' => 'fade-down',
					'fade-left' => 'fade-left',
					'fade-right' => 'fade-right',
					'fade-up-right' => 'fade-up-right',
					'fade-up-left' => 'fade-up-left',
					'fade-down-right' => 'fade-down-right',
					'fade-down-left' => 'fade-down-left',
					'none' => ''
				],
				'default' => 'fade-up',
			]
		);
		$this->end_controls_section();
	}
}

