<?php

namespace LandkitElementor\Modules\Image;

use LandkitElementor\Base\Module_Base;
use Elementor\Controls_Manager;
use LandkitElementor\Modules\Image\Skins;
use Elementor\Core\Schemes;
use Elementor\Plugin;


if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Module extends Module_Base {

    public function __construct() {
        parent::__construct();

        $this->add_actions();
    }

    public function add_actions() {
        add_action( 'elementor/widget/image/skins_init', [ $this, 'init_skins' ], 10 );
        add_action( 'elementor/element/image/section_image/before_section_end', [ $this, 'add_css_classes_controls' ], 10 );
        add_action( 'elementor/element/image/section_style_image/before_section_end', [ $this, 'update_style_image' ], 10 );
        add_filter( 'elementor/image_size/get_attachment_image_html', [ $this, 'image_html' ], 10, 4 ); 
        add_filter( 'wp_kses_allowed_html', [ $this, 'remove_svg_kses' ],  10, 2);
    }

    public function remove_svg_kses( $tags ) {

        $tags['svg'] = array(
            'xmlns' => array(),
            'fill' => array(),
            'viewbox' => array(),
            'role' => array(),
            'aria-hidden' => array(),
            'focusable' => array(),
        );
        $tags['path'] = array(
            'd' => array(),
            'fill' => array(),
        );
        return $tags;
    }

    public function init_skins( $widget ) { 
        $widget->add_skin( new Skins\Skewed_Image( $widget ) );
        $widget->add_skin( new Skins\Card( $widget ) );
    }

    public function get_name() {
        return 'override-image';
    }

    public function add_css_classes_controls( $element ) {
        $element->add_control(
            'image_class',
            [
               'label'        => esc_html__( 'Image Class', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'title'       => esc_html__( 'Add your custom class for <img> tag  without the dot. e.g: my-class', 'landkit-elementor' ),
                'default'     => 'img-fluid',
                'label_block' => true,
                'description' => esc_html__( 'Additional CSS class that you want to apply to the img tag', 'landkit-elementor' ),
            ]
        );

        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        if ( $enabled ) {
            $element->add_control(
                'inline_svg',
                [
                   'label'         => esc_html__( 'Inline SVG', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'title'        => esc_html__( 'If you are uploading SVG file, it might be useful to inline the SVG files. Do not inline, if your SVG file is from unknown sources.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
                    'return_value' => 'yes',
                    'default'      => 'no',
                ]
            );

            $element->add_control(
                'color',
                [
                    'label'        => esc_html__( 'Color', 'landkit-elementor' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .landkit-elementor-svg-wrapper' => 'color: {{VALUE}};',
                    ],
                ]
            );
        }

        $element->add_control(
            'aos',
            [
                'label'     => esc_html__( 'Image Direction', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'label_on'  => esc_html__( 'Right', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Left', 'landkit-elementor' ),
                'condition' => [
                    '_skin!' => [ '', 'card-image' ]
                ],
            ]
        );
    }

    public function update_style_image( $widget ) {
        $widget->add_responsive_control( 'space', [
            'selectors' => [
                '{{WRAPPER}} .elementor-image img' => 'max-width: {{SIZE}}{{UNIT}};',
                '{{WRAPPER}} .elementor-image .landkit-elementor-svg-wrapper' => 'max-width: {{SIZE}}{{UNIT}};',
            ]
        ], [
            'overwrite' => true 
        ] );
    }

    public function image_html( $html, $settings, $image_size_key, $image_key  ) {

        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        if ( $enabled && isset( $settings['inline_svg'] ) && 'yes' === $settings['inline_svg'] && isset( $settings['image']['url'] ) ) {

            if ( isset( $settings['image_class'] ) && ! empty( $settings['image_class'] ) ) {
                $html = '<div class="landkit-elementor-svg-wrapper ' . esc_attr( $settings['image_class'] ) . '">';
            } else {
                $html = '<div class="landkit-elementor-svg-wrapper">';
            }
            
            $html .= file_get_contents( $settings['image']['url'] );
            $html .= '</div>';

        } else {

            if ( isset( $settings['image_class'] ) && ! empty( $settings['image_class'] ) ) {
            
                if ( strpos( $html, 'class="') !== false ) {
                    $html = str_replace( 'class="', 'class="' . esc_attr( $settings['image_class'] ) . ' ', $html );
                } else {
                    $html = str_replace( '<img', '<img class="' . esc_attr( $settings['image_class'] ) . '"', $html );
                }                
            }
        }

        if( isset( $settings['aos'] ) ) {
            $aos_animation = $settings['aos'] == 'yes' ? 'img-skewed-item-right' : 'img-skewed-item-left';
            $html = str_replace( '<img ', '<img data-aos="' . $aos_animation . '" ', $html);
        }

        return $html;
    }
}

