<?php
namespace LandkitElementor\Modules\Image\Skins;

use Elementor;
use Elementor\Widget_Base;
use Elementor\Skin_Base;
use Elementor\Plugin;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Card extends Skin_Base {

    public function get_id() {
        return 'card-image';
    }

    public function get_title() {
        return esc_html__( 'Card', 'landkit-elementor' );
    }

    /*public function __construct( Elementor\Widget_Base $parent ) {
        //parent::__construct( $parent );
    }*/

    /**
     * Check if the current widget has caption
     *
     * @access private
     * @since 2.3.0
     *
     * @param array $settings
     *
     * @return boolean
     */
    private function has_caption( $settings ) {
        return ( ! empty( $settings['caption_source'] ) && 'none' !== $settings['caption_source'] );
    }

    /**
     * Get the caption for current widget.
     *
     * @access private
     * @since 2.3.0
     * @param $settings
     *
     * @return string
     */
    private function get_caption( $settings ) {
        $caption = '';
        if ( ! empty( $settings['caption_source'] ) ) {
            switch ( $settings['caption_source'] ) {
                case 'attachment':
                    $caption = wp_get_attachment_caption( $settings['image']['id'] );
                    break;
                case 'custom':
                    $caption = ! Utils::is_empty( $settings['caption'] ) ? $settings['caption'] : '';
            }
        }
        return $caption;
    }

    /**
     * Retrieve image widget link URL.
     *
     * @since 1.0.0
     * @access private
     *
     * @param array $settings
     *
     * @return array|string|false An array/string containing the link URL, or false if no link.
     */
    private function get_link_url( $settings ) {
        if ( 'none' === $settings['link_to'] ) {
            return false;
        }

        if ( 'custom' === $settings['link_to'] ) {
            if ( empty( $settings['link']['url'] ) ) {
                return false;
            }

            return $settings['link'];
        }

        return [
            'url' => $settings['image']['url'],
        ];
    }

    public function render() {
        $widget   = $this->parent;
        $settings = $widget->get_settings_for_display();
        $wrap_tag = 'div';

        if ( empty( $settings['image']['url'] ) ) {
            return;
        }

        $has_caption = $this->has_caption( $settings );

        $link = $this->get_link_url( $settings );


        if ( $link ) {
            $widget->add_link_attributes( 'card', $link );

            if ( Plugin::$instance->editor->is_edit_mode() ) {
                $widget->add_render_attribute( 'card', [
                    'class' => [ 'elementor-clickable', 'text-reset', 'text-decoration-none' ]
                ] );
            }

            if ( 'custom' !== $settings['link_to'] ) {
                $widget->add_lightbox_data_attributes( 'card', $settings['image']['id'], $settings['open_lightbox'] );
            }

            $wrap_tag = 'a';
        }

        $widget->add_render_attribute( 'card', 'class', [ 'card', 'lift', 'lift-lg', 'shadow-light-lg' ] );

        ?>

        <<?php echo implode( ' ', [ $wrap_tag, $widget->get_render_attribute_string( 'card' ) ] ); ?>>

            <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings ); ?>
        
            <?php if ( $has_caption ) : ?>
            
            <div class="card-body d-flex align-items-center">

                <!-- Heading -->
                <h5 class="mb-0 mr-auto widget-image-caption"><?php echo $this->get_caption( $settings ); ?></h5>

                <!-- Chevron -->
                <span class="collapse-chevron text-gray-400">
                    <i class="fe fe-lg fe-chevron-right"></i>
                </span>

            </div><?php

            endif;

        ?></<?php echo $wrap_tag; ?>><?php
    }


}