<?php
namespace LandkitElementor\Modules\Image\Skins;
use Elementor;
use Elementor\Widget_Base;
use Elementor\Skin_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Image_Size;
// use Elementor\Core\Schemes;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Skewed_Image extends Skin_Base {

    public function get_id() {
        return 'skewed-image';
    }

    public function get_title() {
        return __( 'Skewed Image', 'landkit-elementor' );
    }

    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
        add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
        add_action( 'elementor/element/image/section_image/before_section_end', [ $this, 'register_icon_list_controls' ], 20 );
    }

    public function register_icon_list_controls( Elementor\Widget_Base $widget ) {
        $this->parent = $widget;

        $this->add_control(
            'img_wrapper_class',
            [
                'label' => esc_html__( 'Image Wrapper Class', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'title' => esc_html__( 'Add your custom class without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'img-skewed',
                'condition' => [ 
                   'inline_svg!' => 'yes' 
                ],
            ]
        );

        $this->add_control(
            'enable_shape',
            [
                'label'     => esc_html__( 'Enable Shape', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'no',
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'Shape_wrapper_class',
            [
               'label'        => esc_html__( 'Shape Wrapper Class', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'title'       => esc_html__( 'Add your custom class for without the dot. e.g: my-class', 'landkit-elementor' ),
                'default'     => 'w-md-150 w-lg-130 position-relative',
                'condition' => [ 
                    $this->get_control_id('enable_shape') => 'yes' 
                ],
            ]
        );

        $this->add_control(
            'shapes',
            [
                'label' => __( 'Shapes', 'landkit-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'curves'   => 'Curves',
                    'angles'   => 'Angles',
                    'blurs'    => 'Blurs',
                    'wave' => 'Wave',
                ],
                'default'   => 'blurs',
                'separator' => 'before',
                'condition' => [ 
                    $this->get_control_id('enable_shape') => 'yes' 
                ],
            ]
        );

        $this->add_control(
            'curves_styles',
            [
                'label'   => __( 'Curve Styles', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'curve-1',
                'condition' => [ 
                    $this->get_control_id('shapes') => 'curves' 
                ],
                'options' => [
                    'curve-1'   => 'Curve-1',
                    'curve-2'   => 'Curve-2',
                    'curve-3'   => 'Curve-3',
                    'curve-4'   => 'Curve-4',
                    'curve-5'   => 'Curve-5',
                    'curve-6'   => 'Curve-6',
                ],
            ]
        );

        $this->add_control(
            'angles_styles',
            [
                'label'   => __( 'Angles Styles', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'angle-1',
                'condition' => [ 
                    $this->get_control_id('shapes') => 'angles' 
                ],
                'options' => [
                    'angle-1'   => 'Angle-1',
                    'angle-2'   => 'Angle-2',
                    'angle-3'   => 'Angle-3',
                    'angle-4'   => 'Angle-4',
                ],
            ]
        );

        $this->add_control(
            'blur_styles',
            [
                'label'   => __( 'Blur Styles', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'blur-1',
                'condition' => [ 
                    $this->get_control_id('shapes') => 'blurs',
                    $this->get_control_id('enable_shape') => 'yes' 
                ],
                'options' => [
                    'blur-1'   => 'Blur-1',
                    'blur-2'   => 'Blur-2',
                    'blur-3'   => 'Blur-3',
                    'blur-4'   => 'Blur-4',
                ],
            ]
        );

        $this->add_control(
            'shape_color',
            [
                'label' => __( 'Shape Color', 'landkit-elementor' ),
                'type' => Controls_Manager::COLOR,
                // 'scheme' => [
                //     'type' => Schemes\Color::get_type(),
                //     'value' => Schemes\Color::COLOR_2,
                // ],
                'selectors' => [
                    '{{WRAPPER}} .lk-elementor-shape' => 'color: {{VALUE}}',

                ],
                'default' => '#f1f4f8',
                'separator' => 'before',
                'condition' => [ 
                    $this->get_control_id('enable_shape') => 'yes' 
                ],
            ]
        );

       

        $this->parent->update_control(
            'align',
            [
                'condition' => [
                    '_skin!' => 'skewed-image',
                ],
            ]
        );
        $this->parent->update_control(
            'caption_source',
            [
                'condition' => [
                    '_skin!' => 'skewed-image',
                ],
            ]
        );
        $this->parent->update_control(
            'caption',
            [
                'condition' => [
                    '_skin!' => 'skewed-image',
                ],
            ]
        );
        $this->parent->update_control(
            'link_to',
            [
                'condition' => [
                    '_skin!' => 'skewed-image',
                ],
            ]
        );
    }

    public function render() {
        $widget   = $this->parent;
        $settings = $widget->get_settings_for_display();
        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        $widget->add_render_attribute( 'image_wrapper_class', 'class', [
            'img-skewed',
            $settings[ $this->get_control_id('img_wrapper_class') ]
        ] );

        if ( isset( $settings['aos'] ) ) {
            if ( $settings['aos'] === 'yes' ) {
                $skewed_class = 'img-skewed-right';
            } else {
                $skewed_class = 'img-skewed-left';
            }
            $widget->add_render_attribute( 'image_wrapper_class', 'class', $skewed_class );
        } 

        $widget->add_render_attribute( 'Shape_wrapper_class', 'class', [
            'skewed-item-wrapper',
            $settings[ $this->get_control_id('Shape_wrapper_class')],
        ] );
            if ( 'yes' == $settings[ $this->get_control_id('enable_shape') ] ) {
                ?><div <?php echo $widget->get_render_attribute_string( 'Shape_wrapper_class' ); ?>><?php
            }
            
                if ( 'yes' == $settings[ $this->get_control_id('enable_shape') ] ) { 
                    switch ( $settings[$this->get_control_id('shapes')] ) {
                        case 'curves':
                            switch ( $settings[$this->get_control_id('curves_styles')] ) {
                                case 'curve-1':
                                    ?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-1.svg' ); ?>
                                    </div><?php
                                break;
                                case 'curve-2':
                                    ?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-2.svg' ); ?>
                                    </div><?php
                                break;
                                case 'curve-3':
                                    ?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-3.svg' ); ?>
                                    </div><?php
                                break;
                                case 'curve-4':
                                    ?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-4.svg' ); ?>
                                    </div><?php
                                break;
                                case 'curve-5':
                                    ?><div class="shape shape-right shape-fluid-y svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-5.svg' ); ?>
                                    </div><?php
                                break;
                                case 'curve-6':
                                    ?><div class="shape shape-left shape-fluid-y svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-6.svg' ); ?>
                                    </div><?php
                                break;
                            } // End switch().
                        break;
                        case 'wave':
                            ?><div class="shape shape-top shape-fluid-x svg-shim lk-elementor-shape">
                                    <?php require get_theme_file_path( 'assets/img/shapes/waves/wave-1.svg' ); ?>
                                </div>
                            <?php
                        break;
                        case 'angles':
                            switch ( $settings[$this->get_control_id('angles_styles')] ) {
                                case 'angle-1':
                                    ?><div class="shape shape-top shape-fluid-x svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/angles/angle-top.svg' ); ?>
                                    </div><?php
                                break;
                                case 'angle-2':
                                ?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/angles/angle-bottom.svg' ); ?>
                                    </div><?php
                                break;
                                case 'angle-3':
                                ?><div class="shape shape-right shape-fluid-y svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/angles/angle-right.svg' ); ?>
                                    </div><?php
                                break;
                                case 'angle-4':
                                ?><div class="shape shape-left shape-fluid-y svg-shim lk-elementor-shape">
                                        <?php require get_theme_file_path( 'assets/img/shapes/angles/angle-left.svg' ); ?>
                                    </div><?php
                                break;
                            } // End switch().
                        break;
                        case 'blurs':
                            ?>
                                <div class="shape shape-fluid-y shape-blur-4 svg-shim lk-elementor-shape">
                                    <?php
                                    switch ( $settings[ $this->get_control_id ('blur_styles') ] ) {
                                        case 'blur-1':
                                        require get_theme_file_path( 'assets/img/shapes/blurs/blur-1.svg' );
                                        break;
                                        case 'blur-2':
                                        require get_theme_file_path( 'assets/img/shapes/blurs/blur-2.svg' );
                                        break;
                                        case 'blur-3':
                                        require get_theme_file_path( 'assets/img/shapes/blurs/blur-3.svg' );
                                        break;
                                        case 'blur-4':
                                        require get_theme_file_path( 'assets/img/shapes/blurs/blur-4.svg' );
                                        break;
                                    } // End switch().
                                    ?>
                                </div>
                            <?php
                        break;
                    }
                }
                if ( isset( $settings['inline_svg'] ) && 'yes' === $settings['inline_svg'] ) :
                ?><?php echo Group_Control_Image_Size::get_attachment_image_html( $settings ); ?><?php
                else :
                    ?><div <?php echo $widget->get_render_attribute_string( 'image_wrapper_class' ); ?>>
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings ); ?>
                    </div>
                <?php endif; ?><?php
            if ( 'yes' == $settings[ $this->get_control_id('enable_shape') ] ) {
                ?></div><?php
            }?>
        <?php
    }

    public function skin_print_template( $content, $widget ) {
        if( 'image' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }
}
