<?php
namespace LandkitElementor\Modules\LinkList\Widgets;

use LandkitElementor\Base\Base_Widget;
use Elementor\Controls_Manager;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Class Link_List
 */
class Link_List extends Base_Widget {

    public function get_name() {
        return 'link-list';
    }

    public function get_title() {
        return esc_html__( 'Link List', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-nav-menu';
    }

    public function get_categories() {
        return [ 'landkit' ];
    }

    protected function register_controls() {
        $this->start_controls_section(
            'section_link_list', [
                'label' => esc_html__( 'Link List', 'landkit-elementor' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control( 'text', [
            'label'       => esc_html__( 'Text', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'dynamic'     => [
                'active' => true,
            ],
            'placeholder' => esc_html__( 'Link', 'landkit-elementor' ),
        ] );

        $repeater->add_control( 'link', [
            'label'       => esc_html__( 'Link', 'landkit-elementor' ),
            'type'        => Controls_Manager::URL,
            'dynamic'     => [
                'active' => true,
            ],
            'placeholder' => esc_html__( 'https://your-link.com', 'landkit-elementor' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control( 'link_list', [
            'label'  => esc_html__( 'Links', 'landkit-elementor' ),
            'type'   => Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => '{{ text }}'
        ] );
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        foreach( $settings['link_list'] as $index => $item ) {
            if ( ! empty( $item['link']['url'] ) ) {
                $link_key = 'link_' . $index;
                $this->add_link_attributes( $link_key, $item['link'] );
                $this->add_render_attribute( $link_key, 'class', 'dropdown-item' );
                $before = '<a ' . $this->get_render_attribute_string( $link_key ) . '>';
                $after  = '</a>';
            } else {
                $before = ''; 
                $after  = '';
            }
            print( $before . $item['text'] . $after );
        }
    }
}