<?php
namespace LandkitElementor\Modules\Login\Widgets;


if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

use LandkitElementor\Base\Base_Widget;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Plugin;

/**
 * Landkit Elementor login widget.
 *
 * Landkit Elementor widget that displays a login with the ability to control every
 * aspect of the login design.
 *
 * @since 1.0.0
 */

class Login extends Base_Widget {

    public function get_name() {
        return 'lk-login';
    }

    public function get_title() {
        return esc_html__( 'User Account Forms', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-lock-user';
    }

    public function get_keywords() {
        return [ 'login', 'user', 'form', 'signin', 'signup', 'register' ];
    }

    protected function register_controls() {

        $can_register = get_option( 'users_can_register' );

        $this->start_controls_section( 'section_general', [
            'label' => esc_html__( 'General', 'landkit-elementor' ),
        ] );

        $this->add_control( 'display', [
            'label'       => esc_html__( 'Display', 'landkit-elementor' ),
            'description' => esc_html__( 'Choose which forms you want to display. Please note that the register form is available only if registration is enabled from Settings > General > Membership.', 'landkit-elementor' ),
            'type'        => Controls_Manager::SELECT,
            'options'     => [
                'all'      => esc_html__( 'All', 'landkit-elementor' ),
                'login'    => esc_html__( 'Login', 'landkit-elementor' ),
                'register' => esc_html__( 'Register', 'landkit-elementor' ),
                'forgot'   => esc_html__( 'Password Reset', 'landkit-elementor' )
            ],
            'default'     => 'all'
        ] );

        $this->end_controls_section();

        $this->add_form_option_controls();

        $this->add_login_form_controls();

        $this->add_register_form_controls();

        $this->add_password_reset_form_controls();

        $this->add_additional_options_controls();

        $this->start_controls_section( 'section_heading_style', [
            'label' => esc_html__( 'Form', 'landkit-elementor' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'form_title_heading', [
            'label'     => __( 'Form Title', 'landkit-elementor' ),
            'type'      => Controls_Manager::HEADING,
            'condition' => [ 'show_form_title' => 'yes'],
        ] );


        $this->add_control( 'form_title_color', [
            'label'     => esc_html__( 'Color', 'landkit-elementor' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .form-header__title' => 'color: {{VALUE}};'
            ],
            'condition' => [ 'show_form_title' => 'yes'],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'      => 'form_title_typography',
            'selector'  => '{{WRAPPER}} .form-header__title',
            'condition' => [ 'show_form_title' => 'yes'],
        ] );

        $this->add_control( 'form_title_alignment', [
            'label'          => esc_html__( 'Alignment', 'landkit-elementor' ),
            'type'           => Controls_Manager::CHOOSE,
            'options'        => [
                'left'       => [
                    'title'     => esc_html__( 'Left', 'landkit-elementor' ),
                    'icon'      => 'eicon-text-align-left',
                ],
                'center'     => [
                    'title'     => esc_html__( 'Center', 'landkit-elementor' ),
                    'icon'      => 'eicon-text-align-center',
                ],
                'right'      => [
                    'title'     => esc_html__( 'Right', 'landkit-elementor' ),
                    'icon'      => 'eicon-text-align-right',
                ],
            ],
            'selectors'      => [
                '{{WRAPPER}} .form-header__title' => 'text-align: {{VALUE}}',
            ],
            'default'        => 'left',
            'condition'      => [ 'show_form_title'   => 'yes' ],
        ] );

        $this->add_control( 'title_css', [
            'label'     => esc_html__( 'CSS Classes', 'landkit-elementor' ),
            'type'      => Controls_Manager::TEXT,
            'title'     => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
            'default'   => 'mb-0 font-weight-bold',
            'condition' => [ 'show_form_title' => 'yes'],
        ] );

        $this->add_control( 'form_description_heading', [
            'label'     => __( 'Form Description', 'landkit-elementor' ),
            'type'      => Controls_Manager::HEADING,
            'separator' => 'before',
            'condition' => [ 'show_form_description' => 'yes' ],
        ] );


        $this->add_control( 'form_description_color', [
            'label'     => esc_html__( 'Color', 'landkit-elementor' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .form-header__desc' => 'color: {{VALUE}};',
            ],
            'condition' => [ 'show_form_description' => 'yes' ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'      => 'form_description_typography',
            'selector'  => '{{WRAPPER}} .form-header__desc',
            'condition' => [ 'show_form_description' => 'yes' ],
        ] );

        $this->add_control(
            'description_alignment',
            [
                'label'          => esc_html__( 'Description Alignment', 'landkit-elementor' ),
                'type'           => Controls_Manager::CHOOSE,
                'options'        => [
                    'left'       => [
                        'title'     => esc_html__( 'Left', 'landkit-elementor' ),
                        'icon'      => 'eicon-text-align-left',
                    ],
                    'center'     => [
                        'title'     => esc_html__( 'Center', 'landkit-elementor' ),
                        'icon'      => 'eicon-text-align-center',
                    ],
                    'right'      => [
                        'title'     => esc_html__( 'Right', 'landkit-elementor' ),
                        'icon'      => 'eicon-text-align-right',
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}} .form-header__desc' => 'text-align: {{VALUE}}',
                ],
                'default'        => 'left',
                'condition'      => [ 'show_form_description' => 'yes' ],
            ]
        );

        $this->add_control(
            'description_css', [
                'label'   => esc_html__( 'CSS Classes', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'mb-6 text-muted',
                'condition'   => [
                    'show_form_description'   => 'yes',
                ],
            ]
        );

        $this->add_control( 'form_footer_alignment', [
            'label'   => esc_html__( 'Form Footer Alignment', 'landkit-elementor' ),
            'type'    => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => esc_html__( 'Left', 'landkit-elementor' ),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => esc_html__( 'Center', 'landkit-elementor' ),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => esc_html__( 'Right', 'landkit-elementor' ),
                    'icon' => 'eicon-text-align-right',
                ],
            ],
            'separator' => 'before',
            'default'   => 'left',
            'selectors' => [
                '{{WRAPPER}} .form__footer' => 'text-align: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section();
    }

    private function add_form_option_controls() {
        $this->start_controls_section( 'section_form_controls', [
            'label'     => esc_html__( 'Form Controls', 'landkit-elementor' ),
        ] );

        $this->add_control( 'show_form_title', [
            'label'     => esc_html__( 'Title', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => 'yes',
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
        ] );

        $this->add_control( 'title_tag', [
            'label'    => esc_html__( 'Title HTML Tag', 'landkit-elementor' ),
            'type'     => Controls_Manager::SELECT,
            'options'  => [
                'h1'   => 'H1',
                'h2'   => 'H2',
                'h3'   => 'H3',
                'h4'   => 'H4',
                'h5'   => 'H5',
                'h6'   => 'H6',
                'div'  => 'div',
                'span' => 'span',
                'p'    => 'p',
            ],
            'default'  => 'h1',
            'condition'   => [
                'show_form_title' => 'yes',
            ],
        ] );

        $this->add_control( 'show_form_description', [
            'label'     => esc_html__( 'Description', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => 'yes',
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
        ] );

        $this->add_control( 'show_labels', [
            'label'     => esc_html__( 'Labels', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => 'yes',
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
        ] );

        $this->add_control( 'button_heading', [
            'label'     => esc_html__( 'Submit Button', 'landkit-elementor' ),
            'type'      => Controls_Manager::HEADING,
            'separator' => 'before',
        ] );

        $this->add_control( 'button_type', [
            'label'   => esc_html__( 'Type', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'primary',
            'options' => [
                'primary'           => esc_html__( 'Primary', 'landkit-elementor' ),
                'secondary'         => esc_html__( 'Secondary', 'landkit-elementor' ),
                'success'           => esc_html__( 'Success', 'landkit-elementor' ),
                'danger'            => esc_html__( 'Danger', 'landkit-elementor' ),
                'warning'           => esc_html__( 'Warning', 'landkit-elementor' ),
                'info'              => esc_html__( 'Info', 'landkit-elementor' ),
                'light'             => esc_html__( 'Light', 'landkit-elementor' ),
                'dark'              => esc_html__( 'Dark', 'landkit-elementor' ),
                'link'              => esc_html__( 'Link', 'landkit-elementor' ),
                'outline-primary'   => esc_html__( 'Primary outline', 'landkit-elementor' ),
                'outline-secondary' => esc_html__( 'Secondary outline', 'landkit-elementor' ),
                'outline-success'   => esc_html__( 'Success outline', 'landkit-elementor' ),
                'outline-danger'    => esc_html__( 'Danger outline', 'landkit-elementor' ),
                'outline-warning'   => esc_html__( 'Warning outline', 'landkit-elementor' ),
                'outline-info'      => esc_html__( 'Info outline', 'landkit-elementor' ),
                'outline-light'     => esc_html__( 'Light outline', 'landkit-elementor' ),
                'outline-dark'      => esc_html__( 'Dark outline', 'landkit-elementor' ),
                'primary-soft'      => esc_html__( 'Primary soft', 'landkit-elementor' ),
                'secondary-soft'    => esc_html__( 'Secondary soft', 'landkit-elementor' ),
                'success-soft'      => esc_html__( 'Success soft', 'landkit-elementor' ),
                'danger-soft'       => esc_html__( 'Danger soft', 'landkit-elementor' ),
                'warning-soft'      => esc_html__( 'Warning soft', 'landkit-elementor' ),
                'info-soft'         => esc_html__( 'Info soft', 'landkit-elementor' ),
            ],
        ] );

        $this->add_control( 'button_size', [
            'label'          => esc_html__( 'Size', 'landkit-elementor' ),
            'type'           => Controls_Manager::SELECT,
            'options'        => [
                'xs' => esc_html__( 'Extra Small', 'landkit-elementor' ),
                'sm' => esc_html__( 'Small', 'landkit-elementor' ),
                ''   => esc_html__( 'Base', 'landkit-elementor' ),
                'lg' => esc_html__( 'Large', 'landkit-elementor' ),
            ],
            'style_transfer' => true,
            'default'        => '',
        ] );

        $this->add_control( 'button_radius', [
            'label'          => esc_html__( 'Border Radius', 'landkit-elementor' ),
            'type'           => Controls_Manager::SELECT,
            'options'        => [
                ''          => esc_html__( 'Normal', 'landkit-elementor' ),
                'pill'      => esc_html__( 'Pill', 'landkit-elementor' ),
                'rounded-0' => esc_html__( 'Rounded 0', 'landkit-elementor' ),
                'card-btn'  => esc_html__( 'Card Btn', 'landkit-elementor' ),
            ],
            'default'        => '',
            'style_transfer' => true,
        ] );

        $this->add_control( 'button_css_id', [
            'label'       => esc_html__( 'Button ID', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'dynamic'     => [
                'active' => true,
            ],
            'default'     => '',
            'title'       => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'landkit-elementor' ),
            'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'landkit-elementor' ),
            'separator'   => 'before',

        ] );

        $this->end_controls_section();
    }

    private function form_fields_render_attributes() {
        $settings = $this->get_settings();
        $unique_id = uniqid();

        $this->add_render_attribute( 'button_text', 'class', [
            'elementor-login__button',
            'btn',
            'btn-block',
        ] );

    
        $this->add_render_attribute( 'register_button_text', 'class', [
            'lk-register__button',
            'btn',
            'btn-block',
        ] );

        
        if ( ! empty( $settings['button_type'] ) ) {
            $this->add_render_attribute( 'button_text', 'class', 'btn-' . $settings['button_type'] );
        }

        if ( ! empty( $settings['button_radius'] ) ) {
            if ( $settings['button_radius'] == 'rounded-0' ) {
                $this->add_render_attribute( 'button_text', 'class', $settings['button_radius'] );
            } else if ( $settings['button_radius'] == 'card-btn' ) {
                $this->add_render_attribute( 'button_text', 'class', $settings['button_radius'] );
            } else {
                $this->add_render_attribute( 'button_text', 'class', 'btn-' . $settings['button_radius'] );
            }
        }

        if ( ! empty( $settings['button_size'] ) ) {
            $this->add_render_attribute( 'button_text', 'class', 'btn-' . $settings['button_size'] );
        }

        if ( ! empty( $settings[ 'button_classes' ] ) ) {
            $this->add_render_attribute( 'button_text', 'class', $settings['button_classes'] );
        }

        $this->add_render_attribute(
            [
                'wrapper' => [
                    'class' => [
                        'lk-form-fields-wrapper',
                        'mb-6',
                    ],
                ],
                'field-group' => [
                    'class' => [
                        'elementor-field-type-text',
                        'elementor-field-group',
                        'elementor-column',
                        'elementor-col-100',
                        'form-group',
                        'p-0',
                    ],
                ],
                'submit-group' => [
                    'class' => [
                        'mb-0',
                        'p-0',
                        'mt-2',
                    ],
                ],

                'button' => [
                    'class' => [
                        'lk-button',
                    ],
                    'name' => 'login',
                ],
                'user_label' => [
                    'for' => 'user-' . $unique_id,
                ],
                'user_input' => [
                    'type' => 'text',
                    'name' => 'username',
                    'id'   => 'user-' . $unique_id,
                    'placeholder' => $settings['user_placeholder'],
                    'class' => [
                        'form-control',
                    ],
                    'value' => (! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''
                ],
                'password_label' => [
                    'for' => 'password-' . $unique_id,
                ],
                'password_input' => [
                    'type' => 'password',
                    'name' => 'password',
                    'id'   => 'password-' . $unique_id,
                    'placeholder' => $settings['password_placeholder'],
                    'class' => [
                        'form-control',

                    ],
                ],
                'user_forget_password_label' => [
                    'for' => 'recoverSrEmail-' . $unique_id,
                    
                ],
                
                'user_forget_password_input' => [
                    'type' => 'text',
                    'name' => 'user_login',
                    'id'   => 'recoverSrEmail-' . $unique_id,
                    'placeholder' => $settings['user_placeholder'],
                    'class' => [
                        'form-control',
                    ],
                ],

                'user_register_label' => [
                    'for' => 'reg_username-' . $unique_id,
                ],
                
                'user_register_input' => [
                    'type' => 'text',
                    'name' => 'username',
                    'id'   => 'reg_username-' . $unique_id,
                    'placeholder' => $settings['register_email_placeholder'],
                    'class' => [
                        'form-control',
                    ],
                ],

                'register_password_label' => [
                    'for' => 'signupSrPassword-' . $unique_id,
                ],
                
                'register_password_input' => [
                    'type' => 'password',
                    'name' => 'password',
                    'id'   => 'signupSrPassword-' . $unique_id,
                    'placeholder' => $settings['register_password_placeholder'],
                    'class' => [
                        'form-control',
                    ],
                ],
                'email_register_label' => [
                    'for' => 'reg_email-' . $unique_id,
                ],
                
                'email_register_input' => [
                    'type' => 'email',
                    'name' => 'email',
                    'id'   => 'reg_email-' . $unique_id,
                    'placeholder' => $settings['register_email_placeholder'],
                    'class' => [
                        'form-control',
                    ],
                ],
                'register_confirm_password_label' => [
                    'for'   => 'signupSrConfirmPassword-' . $unique_id,
                    'class' => 'sr-only'
                ],
                'register_confirm_password_input' => [
                    'type' => 'password',
                    'name' => 'confirmPassword',
                    'id'   => 'signupSrConfirmPassword-' . $unique_id,
                    'placeholder' => $settings['register_confirm_password_placeholder'],
                    'class' => [
                        'form-control',
                    ],
                ],

                
                
                //TODO: add unique ID
                'label_user' => [
                    'for' => 'user',
                    'class' => 'elementor-field-label',
                ],

                'label_password' => [
                    'for' => 'password',
                    'class' => 'elementor-field-label',
                ],
            ]
        );

        if ( ! $settings['show_labels'] ) {
            $this->add_render_attribute( 'label', 'class', 'elementor-screen-only' );
        }

        $this->add_render_attribute( 'field-group', 'class', 'elementor-field-required' )
             ->add_render_attribute( 'input', 'required', true )
             ->add_render_attribute( 'input', 'aria-required', 'true' );
    }

    private function add_login_form_controls() {

        $can_register = get_option( 'users_can_register' );

        $this->start_controls_section( 'section_login', [
            'label' => esc_html__( 'Login Form', 'landkit-elementor' ),
            'condition' => [
                'display' => [ 'all', 'login' ]
            ]
        ] );

        $this->add_control(
            'login_title', [
                'label'       => esc_html__( 'Form Title', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Sign in', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Title', 'landkit-elementor' ),
                'condition'   => [
                    'show_form_title' => 'yes',
                ],
            ]
        );
       
        $this->add_control(
            'login_description', [
                'label'       => esc_html__( 'Form Description', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'Simplify your workflow in minutes.', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Description', 'landkit-elementor' ),
                'condition'   => [
                    'show_form_description' => 'yes',
                ],
            ]
        );

        $this->add_control( 'user_label', [
            'label'       => esc_html__( 'Username Label', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'separator'   => 'before',
            'default'     => esc_html__( 'Email Address', 'landkit-elementor' ),
            'condition'   => [
                'show_labels' => 'yes',
            ],
        ] );

        $this->add_control( 'user_placeholder', [
            'label'       => esc_html__( 'Username Placeholder', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( 'name@address.com', 'landkit-elementor' ),
        ] );

        $this->add_control( 'password_label', [
            'label'       => esc_html__( 'Password Label', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'separator'   => 'before',
            'default'     => esc_html__( 'Password', 'landkit-elementor' ),
            'condition'   => [
                'show_labels' => 'yes',
            ],
        ] );

        $this->add_control( 'password_placeholder', [
            'label'       => esc_html__( 'Password Placeholder', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( 'Enter your password', 'landkit-elementor' ),
        ] );

        $this->add_control( 'show_lost_password', [
            'label'     => esc_html__( 'Password Reset Link', 'landkit-elementor' ),
            'separator' => 'before',
            'type'      => Controls_Manager::SWITCHER,
            'default'   => 'yes',
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
        ] );

        $this->add_control( 'password_reset_text', [
            'label'       => esc_html__( 'Password Reset Text', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( 'Lost your password?', 'landkit-elementor' ),
            'label_off'   => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'    => esc_html__( 'Show', 'landkit-elementor' ),
            'condition'   => [ 'show_lost_password' => 'yes' ]
        ] );

        $this->add_control( 'password_reset_link', [
            'label'     => esc_html__( 'Password Reset Page', 'landkit-elementor' ),
            'type'      => Controls_Manager::URL,
            'default'   => [ 'url' => '#' ],
            'dynamic'   => [ 'active'   => true ],
            'condition' => [ 'display!' => 'all', 'show_lost_password' => 'yes' ],
        ] );

        $this->add_control( 'show_remember_me', [
            'label'     => esc_html__( 'Remember Me', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => 'no',
            'separator' => 'before',
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
        ] );

        $this->add_control( 'button_text', [
            'label'       => esc_html__( 'Login Button Text', 'landkit-elementor' ),
            'label_block' => true,
            'separator'   => 'before',
            'type'        => Controls_Manager::TEXT,
            'default'     => esc_html__( 'Sign in', 'landkit-elementor' ),
        ] );

        if ( $can_register ) :

            $this->add_control( 'show_register', [
                'label'     => esc_html__( 'Registration Link', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'separator' => 'before',
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
            ] );

            $this->add_control( 'register_link_intro', [
                'label'       => esc_html__( 'Registration Page Intro', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Don\'t have an account yet?', 'landkit-elementor' ),
                'condition'   => [ 'show_register' => 'yes' ],
            ] );

            $this->add_control( 'register_link_text', [
                'label'       => esc_html__( 'Registration Link Text', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Sign up', 'landkit-elementor' ),
                'condition'   => [ 'show_register' => 'yes' ],
            ] );

            $this->add_control( 'register_link', [
                'label'     => esc_html__( 'Registration Page Link', 'landkit-elementor' ),
                'type'      => Controls_Manager::URL,
                'default'   => [ 'url' => '#' ],
                'dynamic'   => [ 'active'   => true ],
                'condition' => [ 'display!' => 'all', 'show_register' => 'yes' ],
            ] );

        endif;

        $this->end_controls_section();
    }

    private function add_register_form_controls() {
        $can_register = get_option( 'users_can_register' );

        if ( $can_register ) :

            $this->start_controls_section( 'section_register', [
                'label'     => esc_html__( 'Register Form', 'landkit-elementor' ),
                'condition' => [ 'display' => [ 'all', 'register' ] ]
            ] );

            $this->add_control( 'register_title', [
                'label'       => esc_html__( 'Form Title', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Sign up', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Title', 'landkit-elementor' ),
                'condition'   => [ 'show_form_title' => 'yes' ],
            ] );

           
            $this->add_control( 'register_description', [
                'label'       => esc_html__( 'Form Description', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => esc_html__( 'Simplify your workflow in minutes.', 'landkit-elementor' ),
                'placeholder' => esc_html__( 'Description', 'landkit-elementor' ),
                'condition'   => [ 'show_form_description' => 'yes' ],
                'separator'   => 'after',
            ] );

            $this->add_control( 'register_email_label', [
                'label'       => esc_html__( 'Email Label', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Email Address', 'landkit-elementor' ),
                'condition'   => [ 'show_labels' => 'yes' ]
            ] );

            $this->add_control( 'register_email_placeholder', [
                'label'       => esc_html__( 'Email Placeholder', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'name@address.com', 'landkit-elementor' ),
                'separator'   => 'after',
            ] );

            $this->add_control( 'register_password_label', [
                'label'       => esc_html__( 'Pasword Label', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Password', 'landkit-elementor' ),
                'condition'   => [ 'show_labels' => 'yes' ]
            ] );

            $this->add_control( 'register_password_placeholder', [
                'label'       => esc_html__( 'Password Placeholder', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Enter your password', 'landkit-elementor' ),
            ] );

            $this->add_control( 'register_confirm_password_placeholder', [
                'label'       => esc_html__( 'Confirm Password Label', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Confirm Password', 'landkit-elementor' ),
                'separator'   => 'after',
            ] );

            $this->add_control( 'register_button_text', [
                'label'       => esc_html__( 'Register Button Text', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Sign up', 'landkit-elementor' ),
            ] );

            $this->add_control( 'show_login', [
                'label'     => esc_html__( 'Login Link', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'separator' => 'before',
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
            ] );

            $this->add_control( 'login_link_intro', [
                'label'       => esc_html__( 'Login Page Intro', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Already have an account?', 'landkit-elementor' ),
                'condition'   => [ 'show_login' => 'yes' ],
            ] );

            $this->add_control( 'login_link_text', [
                'label'       => esc_html__( 'Login Link Text', 'landkit-elementor' ),
                'label_block' => true,
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Login', 'landkit-elementor' ),
                'condition'   => [ 'show_login' => 'yes' ],
            ] );

            $this->add_control( 'login_link', [
                'label'     => esc_html__( 'Login Page Link', 'landkit-elementor' ),
                'type'      => Controls_Manager::URL,
                'default'   => [ 'url' => '#' ],
                'dynamic'   => [ 'active'   => true ],
                'condition' => [ 'display!' => 'all', 'show_login' => 'yes' ],
            ] );

            $this->end_controls_section();

        endif;
    }

    private function add_password_reset_form_controls() {

        $this->start_controls_section( 'section_password_reset', [
            'label'     => esc_html__( 'Password Reset Form', 'landkit-elementor' ),
            'condition' => [ 'display' => [ 'all', 'forgot' ] ]
        ] );
        
        $this->add_control( 'password_title', [
            'label'       => esc_html__( 'Form Title', 'landkit-elementor' ),
            'label_block' => true,
            'type'        => Controls_Manager::TEXT,
            'default'     => esc_html__( 'Password Reset', 'landkit-elementor' ),
            'placeholder' => esc_html__( 'Title', 'landkit-elementor' ),
            'condition'   => [ 'show_form_title' => 'yes' ],
        ] );

       
        $this->add_control( 'password_description', [
            'label'       => esc_html__( 'Form Description', 'landkit-elementor' ),
            'label_block' => true,
            'type'        => Controls_Manager::TEXTAREA,
            'default'     => esc_html__( 'Enter your email to reset your password.', 'landkit-elementor' ),
            'placeholder' => esc_html__( 'Description', 'landkit-elementor' ),
            'condition'   => [ 'show_form_description' => 'yes' ],
        ] );

        $this->add_control( 'reset_pasword_button_text', [
            'label'       => esc_html__( 'Button Text', 'landkit-elementor' ),
            'label_block' => true,
            'type'        => Controls_Manager::TEXT,
            'default'     => esc_html__( 'Reset Password', 'landkit-elementor' ),
        ] );

        $this->add_control( 'rp_show_login', [
            'label'     => esc_html__( 'Login Link', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => 'yes',
            'separator' => 'before',
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
        ] );

        $this->add_control( 'rp_login_link_intro', [
            'label'       => esc_html__( 'Login Page Intro', 'landkit-elementor' ),
            'label_block' => true,
            'type'        => Controls_Manager::TEXT,
            'default'     => esc_html__( 'Remember your password?', 'landkit-elementor' ),
            'condition'   => [ 'rp_show_login' => 'yes' ],
        ] );

        $this->add_control( 'rp_login_link_text', [
            'label'       => esc_html__( 'Login Link Text', 'landkit-elementor' ),
            'label_block' => true,
            'type'        => Controls_Manager::TEXT,
            'default'     => esc_html__( 'Log in', 'landkit-elementor' ),
            'condition'   => [ 'rp_show_login' => 'yes' ],
        ] );

        $this->add_control( 'rp_login_link', [
            'label'     => esc_html__( 'Login Page Link', 'landkit-elementor' ),
            'type'      => Controls_Manager::URL,
            'default'   => [ 'url' => '#' ],
            'dynamic'   => [ 'active'   => true ],
            'condition' => [ 'display!' => 'all', 'rp_show_login' => 'yes' ],
        ] );

        $this->end_controls_section();
    }

    private function add_additional_options_controls() {
        $this->start_controls_section( 'section_login_content', [
            'label' => esc_html__( 'Additional Options', 'landkit-elementor' ),
        ] );

        $this->add_control( 'redirect_after_login', [
            'label'     => esc_html__( 'Redirect After Login', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => '',
            'label_off' => esc_html__( 'Off', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'On', 'landkit-elementor' ),
        ] );

        $this->add_control( 'redirect_url', [
            'type'        => Controls_Manager::URL,
            'show_label'  => false,
            'options'     => false,
            'separator'   => false,
            'placeholder' => esc_html__( 'https://your-link.com', 'landkit-elementor' ),
            'description' => esc_html__( 'Note: Because of security reasons, you can ONLY use your current domain here.', 'landkit-elementor' ),
            'condition'   => [ 'redirect_after_login' => 'yes' ],
            'default'     => [ 'url' => '#' ],
        ] );

        $this->add_control( 'redirect_after_logout', [
            'label'     => esc_html__( 'Redirect After Logout', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'default'   => '',
            'label_off' => esc_html__( 'Off', 'landkit-elementor' ),
            'label_on'  => esc_html__( 'On', 'landkit-elementor' ),
        ] );

        $this->add_control( 'redirect_logout_url', [
            'type'        => Controls_Manager::URL,
            'show_label'  => false,
            'options'     => false,
            'separator'   => false,
            'placeholder' => esc_html__( 'https://your-link.com', 'landkit-elementor' ),
            'description' => esc_html__( 'Note: Because of security reasons, you can ONLY use your current domain here.', 'landkit-elementor' ),
            'condition'   => [ 'redirect_after_logout' => 'yes' ],
        ] );

        $this->end_controls_section();
    }

    protected function render() {
        $settings          = $this->get_settings();
        $current_url       = remove_query_arg( 'fake_arg' );
        $logout_redirect   = $current_url;
        $show_title        = $settings['show_form_title'];
        $show_description  = $settings['show_form_description'];
        $title_tag         = $settings['title_tag'];
        $display           = $settings['display'];
        $unique_id         = uniqid();
        $login_form_id     = 'login-form-' . $unique_id;
        $register_form_id  = 'register-form-' . $unique_id;
        $lost_pwd_form_id  = 'lost-password-' . $unique_id;

        /**
         * Add Form IDs to settings data
         */
        $settings['login_form_id']    = $login_form_id;
        $settings['register_form_id'] = $register_form_id;
        $settings['lost_pwd_form_id'] = $lost_pwd_form_id;

        
        if ( isset( $_POST['recoverPassword'] ) ) {
            $login_tab_pane    = '';
            $register_tab_pane = '';
            $forget_password_tab_pane = ' active';
        } elseif ( isset( $_POST['register'] ) ) {
            $login_tab_pane    = '';
            $forget_password_tab_pane ='';
            $register_tab_pane = ' active';
        } else {
            $login_tab_pane    = ' active';
            $forget_password_tab_pane = '';
            $register_tab_pane = '';
        }

        if ( 'yes' === $settings['redirect_after_logout'] && ! empty( $settings['redirect_logout_url']['url'] ) ) {
            $logout_redirect = $settings['redirect_logout_url']['url'];
        }

        if ( is_user_logged_in() && ! Plugin::$instance->editor->is_edit_mode() ) {
            $current_user = wp_get_current_user();

            echo '<div class="elementor-login elementor-login__logged-in-message">' .
                sprintf( __( 'You are Logged in as %1$s (<a href="%2$s">Logout</a>)', 'landkit-elementor' ), $current_user->display_name, wp_logout_url( $logout_redirect ) ) .
                '</div>';

            return;
        }

        $this->form_fields_render_attributes();

        if ( 'register' === $display ) {
            $this->render_register_form( $settings );
            return;
        } elseif ( 'login' === $display ) {
            $this->render_login_form( $settings );
            return;
        } elseif ( 'forgot' === $display ) {
            $this->render_password_reset_form( $settings );
            return;
        }

        ?><div class="lk-tab-content tab-content">
            <div class="tab-pane<?php echo esc_attr( $login_tab_pane ); ?>" id="<?php echo esc_attr( $login_form_id ); ?>" aria-labelledby="login-tab">
                <?php $this->render_login_form( $settings ); ?>
            </div>

            <div class="tab-pane<?php echo esc_attr( $forget_password_tab_pane ); ?>" id="<?php echo esc_attr( $lost_pwd_form_id ); ?>" aria-labelledby="forget-password-tab">
                <?php $this->render_password_reset_form( $settings ); ?>
            </div>

            <?php if ( get_option( 'users_can_register' ) ): ?>
            <div class="tab-pane<?php echo esc_attr( $register_tab_pane ); ?>" id="<?php echo esc_attr( $register_form_id ); ?>" aria-labelledby="register-tab">
                <?php $this->render_register_form( $settings ); ?>
            </div>
            <?php endif; ?>
        
        </div><?php
    }

    private function render_form_header( $title, $desc, $settings ) {
        $show_title = ( 'yes' === $settings['show_form_title'] );
        $show_desc  = ( 'yes' === $settings['show_form_description'] );
        $title_tag  = $settings['title_tag'];

        $this->add_render_attribute( 'form_title', 'class', 'form-header__title' );

        if ( ! empty( $settings['title_css'] ) ) {
            $this->add_render_attribute( 'form_title', 'class', $settings['title_css'] );
        }

        $this->add_render_attribute( 'form_desc', 'class', 'form-header__desc' );

        if ( ! empty( $settings['description_css'] ) ) {
            $this->add_render_attribute( 'form_desc', 'class', $settings['description_css'] );
        }

        ?><?php if (  $show_title && ! empty( $title ) ): ?>
            <<?php echo $title_tag . ' ' . $this->get_render_attribute_string( 'form_title' ); ?>><?php echo esc_html( $title ); ?></<?php echo $title_tag; ?>>
        <?php endif; ?>

        <?php if (  $show_desc && ! empty( $desc ) ): ?>
            <p <?php echo $this->get_render_attribute_string( 'form_desc' ); ?>><?php echo esc_html( $desc ); ?></p>
        <?php endif;
    }

    private function render_label( $render_key, $settings, $label_key = '' ) {
        
        $show_label = ( 'yes' === $settings['show_labels'] );

        if ( ! $show_label ) {
            $this->add_render_attribute( $render_key, 'class', 'sr-only' );
        }

        if ( empty( $label_key ) ) {
            $label_key = $render_key;
        }

        ?><label <?php echo $this->get_render_attribute_string( $render_key );?>>
            <?php print( $settings[ $label_key ] ); ?>
        </label><?php
    }

    private function render_lost_password_form_link( $settings ) {
        $show      = ( 'yes' === $settings['show_lost_password'] );
        $form_id   = $settings['lost_pwd_form_id'];
        $link_text = $settings['password_reset_text'];

        if ( ! $show ) {
            return;
        }

        $this->add_render_attribute( 'lost_password_form_link', [
            'id'    => 'forgot-password-tab',
            'class' => [ 'elementor-lost-password', 'font-size-sm' ]
        ] );

        if ( 'all' === $settings['display'] ) {
            $this->add_render_attribute( 'lost_password_form_link', 'href', '#' . $form_id );
            $this->add_render_attribute( 'lost_password_form_link', 'class', 'login-register-tab-switcher' );
        } else {
            $this->add_link_attributes( 'lost_password_form_link', $settings['password_reset_link'] );
        }

        printf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'lost_password_form_link' ), $link_text );
    }

    private function render_register_form_link( $settings ) {
        $show       = ( get_option( 'users_can_register' ) && 'yes' === $settings['show_register'] );
        $form_id    = $settings['register_form_id'];
        $link_intro = $settings['register_link_intro'];
        $link_text  = $settings['register_link_text'];

        if ( ! $show ) {
            return;
        }

        $this->add_render_attribute( 'register_form_link', [ 
            'class' => [ 'd-inline-block', 'login' ]
        ] );

        if ( 'all' === $settings['display'] ) {
            $this->add_render_attribute( 'register_form_link', 'id', 'register-tab' );
            $this->add_render_attribute( 'register_form_link', 'href', '#' . $form_id );
            $this->add_render_attribute( 'register_form_link', 'class', 'login-register-tab-switcher' );
        } else {
            $this->add_link_attributes( 'register_form_link', $settings['register_link'] );
        }

        $link_html = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'register_form_link' ), $link_text );
        
        ?><p class="mb-0 font-size-sm text-muted form__footer">
            <?php printf( '%s %s.', $link_intro, $link_html ); ?>
        </p><?php
    }

    private function render_login_form_link( $settings ) {
        $show       = ( 'yes' === $settings['show_login'] );
        $form_id    = $settings['login_form_id'];
        $link_intro = $settings['login_link_intro'];
        $link_text  = $settings['login_link_text'];

        if ( ! $show ) {
            return;
        }

        $this->add_render_attribute( 'login_form_link', [
            'class'         => [ 'login' ]
        ] );

        if ( 'all' === $settings['display'] ) {
            $this->add_render_attribute( 'login_form_link', 'id', 'login-tab' );
            $this->add_render_attribute( 'login_form_link', 'href', '#' . $form_id );
            $this->add_render_attribute( 'login_form_link', 'class', 'login-register-tab-switcher' );
        } else {
            $this->add_link_attributes( 'login_form_link', $settings['login_link'] );
        }

        $link_html = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'login_form_link' ), $link_text );

        ?><p class="mb-0 font-size-sm text-muted form__footer">
            <?php printf( '%s %s.', $link_intro, $link_html ); ?>
        </p><?php
    }

    private function render_rp_login_form_link( $settings ) {
        $show       = ( 'yes' === $settings['rp_show_login'] );
        $form_id    = $settings['login_form_id'];
        $link_intro = $settings['rp_login_link_intro'];
        $link_text  = $settings['rp_login_link_text'];

        if ( ! $show ) {
            return;
        }

        $this->add_render_attribute( 'rp_login_form_link', [
            'class'         => [ 'login' ],
            'id'            => 'login-tab'
        ] );

        if ( 'all' === $settings['display'] ) {
            $this->add_render_attribute( 'rp_login_form_link', 'href', '#' . $form_id );
            $this->add_render_attribute( 'rp_login_form_link', 'class', 'login-register-tab-switcher' );
        } else {
            $this->add_link_attributes( 'rp_login_form_link', $settings['rp_login_link'] );
        }

        $link_html = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'rp_login_form_link' ), $link_text );

        ?><p class="mb-0 font-size-sm text-muted form__footer">
            <?php printf( '%s %s.', $link_intro, $link_html ); ?>
        </p><?php
    }

    private function render_login_form( $settings ) {

        $current_url = remove_query_arg( 'fake_arg' );

        if ( 'yes' === $settings['redirect_after_login'] && ! empty( $settings['redirect_url']['url'] ) ) {
            $redirect_url = $settings['redirect_url']['url'];   
        } else {
            $redirect_url = $current_url;
        }

        $this->render_form_header( $settings['login_title'], $settings['login_description'], $settings );

        ?>
        <form class="elementor-form lk-login-form login" method="post">
            <?php
            if ( isset( $_POST['login'] ) ) {
                    // show any error messages after form submission
                    ?><div class="mb-3"><?php landkit_show_error_messages(); ?></div><?php
                }
            ?>

            <input type="hidden" name="redirect_to" value="<?php echo esc_attr( $redirect_url ); ?>">
            
            <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
                
                <div class="mb-5">
                    
                    <div <?php echo $this->get_render_attribute_string( 'field-group' ); ?>>
                        <?php $this->render_label( 'user_label', $settings ); ?>
                        <input <?php echo $this->get_render_attribute_string( 'user_input' );?>>
                    </div>
                    
                    <div <?php echo $this->get_render_attribute_string( 'field-group' ); ?>>
                        <div class="w-100 d-flex justify-content-between align-items-center">
                            <?php  
                                $this->render_label( 'password_label', $settings );
                                $this->render_lost_password_form_link( $settings );
                            ?>
                        </div>
                        <input <?php echo $this->get_render_attribute_string( 'password_input' ); ?>>
                    </div>

                    <?php if ( 'yes' === $settings['show_remember_me'] ) : ?>
                        <div class="elementor-field-type-checkbox elementor-field-group elementor-column elementor-col-100 elementor-remember-me mb-0 p-0">
                            <label for="elementor-login-remember-me">
                                <input type="checkbox" name="rememberme" value="forever">
                                <?php echo esc_html__( 'Remember Me', 'landkit-elementor' ); ?>
                            </label>
                        </div>
                    <?php endif; ?>
                </div>


                <div <?php echo $this->get_render_attribute_string( 'submit-group' ); ?>>
                    <?php if ( ! empty( $settings['button_text'] ) ) : ?>
                        <input type="hidden" name="landkit_login_nonce" value="<?php echo wp_create_nonce('landkit-login-nonce'); ?>"/>
                        <input type="hidden" name="landkit_login_check" value="1"/>

                        <button type="submit" name="login" <?php echo $this->get_render_attribute_string( 'button_text' ); ?>><?php echo $settings['button_text']; ?></button>
                    <?php endif; ?>
                </div>
                
            </div>

            <?php $this->render_register_form_link( $settings ); ?>
                
        </form><?php
    }

    private function render_register_form( $settings ) {

        $can_register = get_option( 'users_can_register' );

        if ( ! $can_register ) {
            return;
        }
        
        $this->render_form_header( $settings['register_title'], $settings['register_description'], $settings );
        
        ?>
        <form class="lk-register elementor-form register" method="post">
            
            <?php
                if ( isset( $_POST['register'] ) ) {
                    ?><div class="mb-3"><?php landkit_show_error_messages(); ?></div><?php
                }
            ?>

            <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
                <div class="mb-5">
                    <div <?php echo $this->get_render_attribute_string( 'field-group' ); ?>>
                        <?php $this->render_label( 'email_register_label', $settings, 'register_email_label' ); ?>
                        <input <?php echo $this->get_render_attribute_string( 'email_register_input' );?>>
                    </div>

                    <?php if ( apply_filters( 'landkit_register_password_enabled', true ) ) : ?>

                        <div <?php echo $this->get_render_attribute_string( 'field-group' ); ?>>
                            <?php $this->render_label( 'register_password_label', $settings, 'register_password_label' ); ?>
                            <input <?php echo $this->get_render_attribute_string( 'register_password_input' );?>>
                        </div>

                        <div <?php echo $this->get_render_attribute_string( 'field-group' ); ?>>
                            <input <?php echo $this->get_render_attribute_string( 'register_confirm_password_input' );?>>
                        </div>

                    <?php else : ?>
                        <p><?php echo esc_html__( 'A password will be sent to your email address.', 'landkit-elementor' ); ?></p>
                    <?php endif; ?>
                </div>


                <div <?php echo $this->get_render_attribute_string( 'submit-group' ); ?>>
                    <?php if ( ! empty( $settings['button_text'] ) ) : ?>
                        <input type="hidden" name="landkit_register_nonce" value="<?php echo wp_create_nonce('landkit-register-nonce'); ?>"/>
                        <input type="hidden" name="landkit_register_check" value="1"/>
                        <button type="submit" <?php echo $this->get_render_attribute_string( 'button_text' ); ?> name="register"><?php echo $settings['register_button_text']; ?></button>
                    <?php endif; ?>
                </div>
                
            </div>

            <?php $this->render_login_form_link( $settings ); ?>
                         
        </form><?php
    }

    private function render_password_reset_form( $settings ) {
        
        $this->render_form_header( $settings['password_title'], $settings['password_description'], $settings ); ?>

        <form class="lk-forget-password elementor-form forget-password" name="lostpasswordform" method="post">

            <?php if ( isset( $_POST['recoverPassword'] ) ) { ?>
                <div class="mb-3">
                    <?php landkit_show_error_messages(); ?>
                    <?php landkit_show_success_messages(); ?>
                </div>
            <?php } ?>
           
            <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
                <div <?php echo $this->get_render_attribute_string( 'field-group' ); ?>>
                    <?php $this->render_label( 'user_forget_password_label', $settings, 'user_label' ); ?>
                    <input <?php echo $this->get_render_attribute_string( 'user_forget_password_input' );?>>
                </div>

                <div <?php echo $this->get_render_attribute_string( 'submit-group' ); ?>>
                    <?php if ( ! empty( $settings['button_text'] ) ) : ?>
                        <input type="hidden" name="landkit_lost_password_nonce" value="<?php echo wp_create_nonce('landkit-lost-password-nonce'); ?>"/>
                        <input type="hidden" name="landkit_lost_password_check" value="1"/>
                        <?php  wp_nonce_field( 'ajax-lost-password-nonce', 'lost-password-security' );  ?>
                        <button type="submit" name="recoverPassword" <?php echo $this->get_render_attribute_string( 'button_text' ); ?>><?php echo $settings['reset_pasword_button_text']; ?></button>
                    <?php endif; ?>
                </div>
            </div>
            
            <?php $this->render_rp_login_form_link( $settings ); ?>
            
        </form><?php
    }
    
    public function render_plain_content() {}
}


