<?php
namespace LandkitElementor\Modules\Map\Widgets;

use LandkitElementor\Base\Base_Widget;
use Elementor\Modules\DynamicTags\Module as TagsModule;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Css_Filter;
use LandkitElementor\Includes\Controls\Groups\Group_Control_Shape_Divider;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Map extends Base_Widget {

	public function get_name() {
		return 'lk-map';
	}

	public function get_title() {
		return esc_html__( 'Map Box', 'landkit-elementor' );
	}

	public function get_icon() {
		return 'eicon-google-maps';
	}

	public function get_keywords() {
		return [ 'map', 'embed', 'location' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_map',
			[
				'label' => esc_html__( 'Map', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'map_style',
			[
				'label'   => esc_html__( 'Styles', 'landkit-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'light-v9',
				'options' => [
					'light-v9'              => 'Light',
					'dark-v10'              => 'Dark',
					'streets-v11'           => 'Streets',
					'satellite-v9'          => 'Satellite',
					'satellite-streets-v11' => 'Satellite Streets',
				],
			]
		);

		$this->add_control(
			'longitude',
			[
				'label'     => esc_html__( 'Longitude', 'landkit-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '-118.244615',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'latitude',
			[
				'label'   => esc_html__( 'Latitude', 'landkit-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '34.052979'
			]
		);

		$this->add_control(
			'zoom',
			[
				'label'   => esc_html__( 'Zoom', 'landkit-elementor' ),
				'type'    => Controls_Manager::SLIDER,
				'default' => [
					'size' => 12,
				],
				'range'   => [
					'px' => [
						'min' => 1,
						'max' => 20,
					],
				],
			]
		);

		$this->add_control(
			'enable_custom_height',
			[
				'label'       => esc_html__( 'Custom Height ?', 'landkit-elementor' ),
				'description' => esc_html__( 'Use custom height if widget inserted outside of inner section widget.', 'landkit-elementor' ),
				'type'        => Controls_Manager::SWITCHER,
				'default'     => 'no',
				'separator'   => 'before',
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'custom_height',
			[
				'label'     => esc_html__( 'Height', 'landkit-elementor' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 40,
						'max' => 1440,
					],
				],
				'default'   => [
					'size' => 500,
				],
				'condition' => [
					'enable_custom_height' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_map_shape_divider',
			[
				'label' => esc_html__( 'Shape', 'landkit-elementor' ),
			]
		);

		$this->add_group_control(
			Group_Control_Shape_Divider::get_type(),
			[
				'name' => 'map_shape_divider'
			]
		);

		$this->add_control(
			'shape_color',
			[
				'label'     => esc_html__( 'Shape Color', 'landkit-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .landkit-elementor-map_shape' => 'color: {{VALUE}};',
				],
				'default'   => '#F9FBFD',
				'condition' => [ 
					'enable_shape' => 'yes',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_map_style',
			[
				'label' => esc_html__( 'Map', 'landkit-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'map_filter' );

		$this->start_controls_tab( 'normal',
			[
				'label' => esc_html__( 'Normal', 'landkit-elementor' ),
			]
		);

		$this->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'css_filters',
				'selector' => '{{WRAPPER}} .landkit-elementor-map',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'hover',
			[
				'label' => esc_html__( 'Hover', 'landkit-elementor' ),
			]
		);

		$this->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name' => 'css_filters_hover',
				'selector' => '{{WRAPPER}}:hover .landkit-elementor-map',
			]
		);

		$this->add_control(
			'hover_transition',
			[
				'label' => esc_html__( 'Transition Duration', 'landkit-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 3,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .landkit-elementor-map' => 'transition-duration: {{SIZE}}s',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'map_additional_css_classes',
			[
				'label'       => esc_html__( 'Map Additional CSS Classes', 'landkit-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'separator'   => 'before',
				'label_block' => true,
				'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$data_options = array(
			'zoom'   => $settings['zoom']['size'],
			'center' => [ $settings[ 'longitude' ], $settings[ 'latitude' ] ],
			'style'  => 'mapbox://styles/mapbox/' . esc_attr( $settings[ 'map_style' ] ),
		);

		$this->add_render_attribute( 'map', [
			'data-toggle'  => 'map',
			'data-options' => htmlspecialchars( json_encode( $data_options ), ENT_QUOTES, 'UTF-8' ),
			'data-aos-id'  => 'map:in',
			'data-aos'     => '1',
			'class'        => [
				'landkit-elementor-map', 'h-100', 'w-100'
			]
		] );

		$this->add_render_attribute( 'map_mobile', [
			'data-toggle'  => 'map',
			'data-options' => htmlspecialchars( json_encode( $data_options ), ENT_QUOTES, 'UTF-8' ),
			'data-aos-id'  => 'map:in',
			'data-aos'     => '1',
			'class'        => [
				'landkit-elementor-map', 'embed-responsive-item'
			]
		] );

		$this->add_render_attribute( 'map_wrapper', 'class', [
			'position-relative', 'h-100', 'd-none', 'd-md-block'
		] );

		if ( $settings[ 'enable_custom_height' ] == 'yes' ) {
			$this->add_render_attribute( 'map_wrapper', 'class', 'w-100' );
		}

		if ( ! empty( $settings[ 'map_additional_css_classes' ] ) ) {
			$this->add_render_attribute( 'map_wrapper', 'class', $settings[ 'map_additional_css_classes' ] );
		}

		if ( 'yes' === $settings['enable_custom_height'] ) {
			$this->add_render_attribute( 'map_wrapper', 'style', 'height:' . $settings['custom_height']['size'] . 'px !important' );
		}

		?>
		<!-- Map (mobile) -->
		<div class="embed-responsive embed-responsive-1by1 d-md-none">
			<div <?php echo $this->get_render_attribute_string( 'map_mobile' ); ?>></div>
		</div>
		<!-- Map & Shape -->
		<div <?php echo $this->get_render_attribute_string( 'map_wrapper' ); ?>>
			<!-- Map -->
			<div <?php echo $this->get_render_attribute_string( 'map' ); ?>></div>
			<!-- Shape -->
			<?php echo Group_Control_Shape_Divider::get_shape_divider( $settings, 'map_shape_divider' ); ?>
		</div>
		<?php
	}

	protected function content_template() {}
}
