<?php

namespace LandkitElementor\Modules\Overlay;

use LandkitElementor\Base\Module_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Module extends Module_Base {

    public function __construct() {
        parent::__construct();

        $this->add_actions();
    }

    public function get_name() {
        return 'override-overlay';
    }

    public function add_actions() {
        add_action( 'elementor/element/before_section_end', [ $this, 'set_overlay_effects' ], 10, 3 );
        add_action( 'elementor/element/after_add_attributes', [ $this, 'overlay_attributes' ], 10 );
    }

    public function set_overlay_effects( $widget, $section_id, $args ) {
        if( $section_id == 'section_background_overlay' ) {

            $widget->add_control(
                '_enable_overlay',
                [
                    'label'        => esc_html__( 'Enable Overlay', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'separator'    => 'before',
                    'description'  => esc_html__( 'Enable Overlay option.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
                    'return_value' => 'overlay',
                    'default'      => '',
                    'prefix_class' => '',
                    'condition' => [
                        'background_background!' => 'between',
                    ],
                ]
            );

            $widget->add_control(
            'overlay_colors',
                [

                    'label'   => esc_html__( 'Overlay Color', 'landkit-elementor' ),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'primary'   => esc_html__( 'Primary', 'landkit-elementor' ),
                        'secondary' => esc_html__( 'Secondary', 'landkit-elementor' ),
                        'success'   => esc_html__( 'Success', 'landkit-elementor' ),
                        'primary-desat' => esc_html__( 'Primary Desat', 'landkit-elementor' ),
                        'danger'    => esc_html__( 'Danger', 'landkit-elementor' ),
                        'warning'   => esc_html__( 'Warning', 'landkit-elementor' ),
                        'info'      => esc_html__( 'Info', 'landkit-elementor' ),
                        'light'     => esc_html__( 'Light', 'landkit-elementor' ),
                        'dark'      => esc_html__( 'Dark', 'landkit-elementor' ),
                        'black'     => esc_html__( 'Black', 'landkit-elementor' ),
                        'white'     => esc_html__( 'White', 'landkit-elementor' ),
                    ],
                    'condition'    => [
                        '_enable_overlay' => 'overlay',
                    ],
                    'default'      => 'primary',
                    'prefix_class' => 'overlay-',
                ]
            );

            $widget->add_control(
                'overlay_opacity',
                [
                    'label'      => esc_html__( 'Opacity', 'landkit-elementor' ),
                    'type'       => Controls_Manager::SELECT,
                    'options'    => [
                        '10' => 10,
                        '20' => 20,
                        '30' => 30,
                        '40' => 40,
                        '50' => 50,
                        '60' => 60,
                        '70' => 70,
                        '80' => 80,
                        '90' => 90,
                    ],
                    'condition'    => [
                        '_enable_overlay' => 'overlay',
                    ],
                    'default'      => '60',
                    'prefix_class' => 'overlay-',
                ]
            );

            $widget->add_control(
                '_enable_gradient',
                [
                    'label'        => esc_html__( 'Enable Gradient', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ),
                    'return_value' => 'yes',
                    'default'      => 'no',
                    'condition' => [
                        '_enable_overlay' => 'overlay',
                    ],
                ]
            );

            $widget->add_control(
                'gradient_flow',
                [
                    'label'   => esc_html__( 'Gradient Flow', 'landkit-elementor' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'right',
                    'options' => [
                        'right' => esc_html__( 'Right', 'landkit-elementor' ),
                        'left'  => esc_html__( 'Left', 'landkit-elementor' ),
                        'down'  => esc_html__( 'Down', 'landkit-elementor' )
                    ],
                    'condition' => [
                        '_enable_gradient' => 'yes',
                        '_enable_overlay'  => 'overlay',
                    ],
                ]
            );
        }
    }

    public function overlay_attributes( $element ) {
        $settings = $element->get_settings_for_display();

        if ( $element->get_settings( '_enable_overlay' ) == 'yes' ) {
            $element->add_render_attribute( '_wrapper', 'class', [
                'overlay',
                'overlay-'. $settings[ 'overlay_opacity' ],
            ] );
        }

        if ( ( $element->get_settings( '_enable_overlay' ) == 'yes' ) && ( $settings['_enable_gradient'] != 'yes' ) ) {
            $element->add_render_attribute( '_wrapper', 'class', [
                'overlay-'. $settings['overlay_colors'],
            ] );
        }

        if ( ( $element->get_settings( '_enable_overlay' ) == 'yes' ) && ( $settings['_enable_gradient'] == 'yes' ) ) {
            $element->add_render_attribute( '_wrapper', 'class', [
                'overlay-gradient-'. $settings['overlay_colors'] .'-'. $settings['gradient_flow'],
            ] );
        }
    }
}