<?php
namespace LandkitElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Skin_Base as Elementor_Skin_Base;
use Elementor\Widget_Base;
use LandkitElementor;
use Elementor\Repeater;
use LandkitElementor\Plugin;
use LandkitElementor\Core\Utils as LE_Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

abstract class Skin_Base extends Elementor_Skin_Base {

	/**
	 * @var string Save current permalink to avoid conflict with plugins the filters the permalink during the post render.
	 */
	protected $current_permalink;

	protected function _register_controls_actions() {
		add_action( 'elementor/element/lk-posts/section_layout/before_section_end', [ $this, 'register_controls' ] );
		add_action( 'elementor/element/lk-posts/section_query/after_section_end', [ $this, 'register_design_controls' ] );
	}

	public function register_controls( Widget_Base $widget ) {
		$this->parent = $widget;

		$this->register_post_count_control();
		$this->register_title_controls();
		$this->register_excerpt_controls();
	}

	public function register_design_controls( Widget_Base $widget ) {
		$this->parent = $widget;
		
		$this->register_design_content_controls();
	}

	protected function register_post_count_control() {
		$this->add_control(
			'posts_per_page',
			[
				'label'   => esc_html__( 'Posts Per Page', 'landkit-elementor' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
			]
		);
	}

	protected function register_title_controls() {
		$this->add_control(
			'show_title',
			[
				'label'     => esc_html__( 'Title', 'landkit-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
				'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
				'default'   => 'yes',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'     => esc_html__( 'Title HTML Tag', 'landkit-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options' => [
					'h1'   => 'H1',
					'h2'   => 'H2',
					'h3'   => 'H3',
					'h4'   => 'H4',
					'h5'   => 'H5',
					'h6'   => 'H6',
					'div'  => 'div',
					'span' => 'span',
					'p'    => 'p',
				],
				'default'   => 'h3',
				'condition' => [
					$this->get_control_id( 'show_title' ) => 'yes',
				],
			]
		);
	}
	protected function register_excerpt_controls() {
		$this->add_control(
		'show_excerpt',
		[
		'label'     => esc_html__( 'Excerpt', 'landkit-elementor' ),
		'type'      => Controls_Manager::SWITCHER,
		'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
		'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
		'default'   => 'yes',
		]
		);
	}

	/**
	 * Style Tab
	 */

	protected function register_design_content_controls() {
		$this->start_controls_section(
			'section_design_content',
			[
				'label' => esc_html__( 'Content', 'landkit-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_title_style',
			[
				'label'     => esc_html__( 'Title', 'landkit-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'condition' => [
					$this->get_control_id( 'show_title' ) => 'yes',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color', 'landkit-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-post__title, {{WRAPPER}} .elementor-post__title a' => 'color: {{VALUE}};',
				],
				'condition' => [
					$this->get_control_id( 'show_title' ) => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'title_typography',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
				'selector'  => '{{WRAPPER}} .elementor-post__title, {{WRAPPER}} .elementor-post__title a',
				'condition' => [
					$this->get_control_id( 'show_title' ) => 'yes',
				],
			]
		);

		$this->add_control(
			'heading_excerpt_style',
			[
				'label'     => esc_html__( 'Excerpt', 'landkit-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					$this->get_control_id( 'show_excerpt' ) => 'yes',
				],
			]
		);

		$this->add_control(
			'excerpt_color',
			[
				'label'     => esc_html__( 'Color', 'landkit-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-post__excerpt p' => 'color: {{VALUE}};',
				],
				'condition' => [
					$this->get_control_id( 'show_excerpt' ) => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'excerpt_typography',
				'global'    => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
				'selector'  => '{{WRAPPER}} .elementor-post__excerpt p',
				'condition' => [
					$this->get_control_id( 'show_excerpt' ) => 'yes',
				],
			]
		);
		$this->end_controls_section();
	}

    /**
    * Function to display Portfolio Category
    */
   protected function render_portfolio_category() { ?>
        <h6 class="text-uppercase mb-1 text-muted"><?php echo strip_tags( get_the_term_list( get_the_ID(), 'jetpack-portfolio-type', '', ', ' ) ); ?></h6>
   <?php }

	protected function render_loop_start() {
		?><div class="row"><?php 
	}

	protected function render_loop_end() {
		?></div> <!-- / .row --><?php 
	}

	public function render() {
		$this->parent->query_posts();
		$settings = $this->parent->get_settings();
		/** @var \WP_Query $query */
		$query = $this->parent->get_query();

		if ( ! $query->found_posts ) {
			return;
		}
		$this->render_loop_start();
		// It's the global `wp_query` it self. and the loop was started from the theme.
		if ( $query->in_the_loop ) {
			$this->current_permalink = get_permalink();
			$this->render_post();
		} else {
			while ( $query->have_posts() ) {
				$query->the_post();

				$this->current_permalink = get_permalink();
				$this->render_post();
			}
		}
		wp_reset_postdata();
		$this->render_loop_end();
		$this->render_loop_footer();
	}

	protected function render_thumbnail( $img_classes ) {
		$thumbnail = $this->get_instance_value( 'thumbnail' );

		if ( 'none' === $thumbnail && ! LandkitElementor\Plugin::elementor()->editor->is_edit_mode() ) {
			return;
		}

		$settings = $this->parent->get_settings();
		$setting_key = $this->get_control_id( 'thumbnail_size' );
		$settings[ $setting_key ] = [
			'id' => get_post_thumbnail_id(),
		];
		$thumbnail_html = Group_Control_Image_Size::get_attachment_image_html( $settings, $setting_key );
		$thumbnail_html = LE_Utils::add_class_to_image_html( $thumbnail_html, $img_classes );

		if ( empty( $thumbnail_html ) ) {
			return;
		} 		
				 echo $thumbnail_html; ?>	
		<?php
	}

	protected function render_portfolio_title() {
		$settings    = $this->parent->get_settings();
		$show_title  = $settings['show_title'];
		if ( $show_title != 'yes') {
			return;
		}
		$tag = $settings['title_tag'];
		?>
		<<?php echo $tag;?> <?php echo $this->parent->get_render_attribute_string( 'title' ); ?>><?php the_title(); ?></<?php echo $tag; ?>><?php
	}
}
