<?php
namespace LandkitElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
exit; // Exit if accessed directly
}

class Skin_Grid_Rows extends Skin_Base {

    public function get_id() {
        return 'grid_rows';
    }

    public function get_title() {
        return esc_html__( 'Grid Rows', 'landkit-elementor' );
    }

    protected function _register_controls_actions() {
        parent::_register_controls_actions();
        add_action( 'elementor/element/lk-portfolio/section_layout/after_section_end', [ $this, 'register_style_pattern_section' ] );
    }

    public function register_style_pattern_section() {
        $this->start_controls_section( 'section_style_pattern', [
            'label' => esc_html__( 'Style Pattern', 'landkit-elementor' ),
        ] );

        $repeater = new Repeater();

        $repeater->add_control( 'name', [
            'label' => esc_html__( 'Pattern Name', 'landkit-elementor' ),
            'type'  => Controls_Manager::TEXT,
        ] );

        $repeater->add_control( 'width', [
            'label'     => esc_html__( 'Width', 'landkit-elementor' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => '4',
            'options'   => [
                '4'  => esc_html__( 'One Third', 'landkit-elementor' ),
                '5'  => esc_html__( 'Two Third', 'landkit-elementor' ),
                '7'  => esc_html__( 'Half', 'landkit-elementor' ),
                '0' => esc_html__( 'Full', 'landkit-elementor' ),
            ],
        ] );

        $this->add_control( 'pattern_list', [
            'label'   => esc_html__( 'Style Patterns', 'landkit-elementor' ),
            'type'    => Controls_Manager::REPEATER,
            'fields'  => $repeater->get_controls(),
            'default' => [
                [
                    'name'          => esc_html__( 'Portfolio Image 1', 'landkit-elementor' ),                    
                ],
                [
                    'name'          => esc_html__( 'Portfolio Image 2', 'landkit-elementor' ),                    
                ],
                [
                    'name'          => esc_html__( 'Portfolio Image 3', 'landkit-elementor' ),
                ],
            ],
            'title_field' => '{{{ name }}}',
        ] );

        $this->end_controls_section();
    }

     private function get_style_pattern() {
        $widget        = $this->parent;
        $query         = $widget->get_query();
        $current_index = $query->current_post;
        $patterns      = $this->get_style_patterns();
       
        $pattern = [ 'width'    => '4', ];
        
        if ( isset( $patterns[ $current_index ] ) ) {
            $pattern = [
                'width'    => $patterns[ $current_index ] [ 'width' ],
            ];
        }
        return $pattern;
    }

    private function get_style_patterns() {
        $widget   = $this->parent;
        $settings = $widget->get_settings();
        $patterns = $settings[ $this->get_control_id( 'pattern_list' ) ];
        return $patterns;
    }


    public function render_grid_rows_shape() { ?>
        <div class="shape shape-bottom-100 shape-fluid-x svg-shim text-white">
            <svg viewBox="0 0 2880 48" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0 48h2880V0h-720C1442.5 52 720 0 720 0H0v48z" fill="currentColor"></path></svg>
        </div>
    <?php }

    /**
    * Function for Portfolio loop
    */
    public function render_portfolio_post() { 
        $pattern = $this->get_style_pattern();
        extract( $pattern );?>

        <div <?php post_class( 'col-12 col-md-'. $width); ?>>
            <!-- Card -->
            <a class="card lift lift-lg shadow-light-lg mb-7" href="<?php echo esc_url( get_permalink() ); ?>">
                <!-- Image -->
                    <?php $this->render_thumbnail("card-img-top"); ?>
                
                <!-- Body -->
                <div class="card-body">
                    <!-- Shapes -->
                    <?php $this->render_grid_rows_shape(); ?>
                    <!-- Preheading -->
                    <?php $this->render_portfolio_category(); ?>
                    <!-- Heading -->
                    <?php $this->render_portfolio_title(); ?>
                </div>
            </a>
        </div>
    <?php  }

    protected function render_grid_rows_loop_header() { ?>
        <div class='row' id="portfolio" data-isotope='{"layoutMode": "fitRows"}'>
    <?php }

    protected function render_grid_rows_loop_footer() {?>
        </div> <!-- / .row -->
    <?php }

    public function set_render_attributes() {
        $this->parent->add_render_attribute( 'title', 'class', 'mb-0' );
    }

    public function render() {
        $settings = $this->parent->get_settings();
        $this->parent->query_posts();
        /** @var \WP_Query $query */
        $query = $this->parent->get_query();
        if ( ! $query->found_posts ) {
            return;
        }
        $this->render_grid_rows_loop_header();
        // It's the global `wp_query` it self. and the loop was started from the theme.
        if ( $query->in_the_loop ) {
            $this->current_permalink = get_permalink();
            $this->render_portfolio_post();
        } else {
            $this->set_render_attributes();
            while ( $query->have_posts() ) {
                $query->the_post();
                $this->current_permalink = get_permalink();
                $this->render_portfolio_post();
            }
        }
        wp_reset_postdata();
        $this->render_grid_rows_loop_footer();
    }
}
