<?php
namespace LandkitElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Skin_Landkit_Card extends Skin_Base {

    public function get_id() {
        return 'landkit-card';
    }

    public function get_title() {
        return esc_html__( 'Landkit Card', 'landkit-elementor' );
    }

    protected function _register_controls_actions() {
        parent::_register_controls_actions();
        add_action( 'elementor/element/lk-posts/section_layout/after_section_end', [ $this, 'register_style_pattern_section' ] );
    }

    public function register_style_pattern_section() {
        $this->start_controls_section( 'section_style_pattern', [
            'label' => esc_html__( 'Style Pattern', 'landkit-elementor' ),
        ] );

        $repeater = new Repeater();

        $repeater->add_control( 'name', [
            'label' => esc_html__( 'Pattern Name', 'landkit-elementor' ),
            'type'  => Controls_Manager::TEXT,
        ] );

        $repeater->add_control( 'width', [
            'label'     => esc_html__( 'Width', 'landkit-elementor' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => '4',
            'options'   => [
                '4'  => esc_html__( 'One Third', 'landkit-elementor' ),
                '8'  => esc_html__( 'Two Third', 'landkit-elementor' ),
                '6'  => esc_html__( 'Half', 'landkit-elementor' ),
                '12' => esc_html__( 'Full', 'landkit-elementor' ),
            ],
        ] );

        $repeater->add_control( 'featured', [
                'label'     => esc_html__( 'Featured', 'landkit-elementor' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => 'in',
            'options'   => [
                'in'  => esc_html__( 'In', 'landkit-elementor' ),
                'out'  => esc_html__( 'Out', 'landkit-elementor' ),
            ],
        ] );

        $repeater->add_control( 'style', [
            'label'   => esc_html__( ' Style ', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'vertical',
            'options' => [
                'horizontal' => esc_html__( 'Horizontal', 'landkit-elementor' ),
                'vertical'   => esc_html__( 'Vertical', 'landkit-elementor' ),
            ],
        ] );

        $repeater->add_control( 'thumbnail', [
            'label'   => esc_html__( 'Image Position', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'top',
            'options' => [
                'top'   => esc_html__( 'Top', 'landkit-elementor' ),
                'left'  => esc_html__( 'Left', 'landkit-elementor' ),
                'right' => esc_html__( 'Right', 'landkit-elementor' ),
                'full'  => esc_html__( 'Background', 'landkit-elementor' ),
                'none'  => esc_html__( 'None', 'landkit-elementor' ),
            ],
        ] );

        $repeater->add_control( 'curve_more', [
            'label'     => esc_html__( 'Curve More', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'default'   => '',
            'condition' => [ 'thumbnail' => 'top' ]
        ] );

        $repeater->add_control( 'body_pos', [
            'label'     => esc_html__( 'Body Position', 'landkit-elementor' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => 'left',
            'options'   => [
                'left'  => esc_html__( 'Left', 'landkit-elementor' ),
                'right' => esc_html__( 'Right', 'landkit-elementor' ),
            ],
            'condition' => [ 
                'thumbnail' => 'full',
                'style'     => 'horizontal'
            ]
        ] );

        $repeater->add_control( 'overlay', [
            'label'     => esc_html__( 'Overlay', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'default'   => 'no',
            'separator' => 'before',
        ] );

        $repeater->add_control( 'overlay_color', [
            'label'     => esc_html__( 'Overlay Color', 'landkit-elementor' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => 'primary',
            'options'   => [
                'primary'       => esc_html__( 'Primary', 'landkit-elementor' ),
                'secondary'     => esc_html__( 'Secondary', 'landkit-elementor' ),
                'primary_desat' => esc_html__( 'Primary Desat', 'landkit-elementor' ),
                'success'       => esc_html__( 'Success', 'landkit-elementor' ),
                'info'          => esc_html__( 'Info', 'landkit-elementor' ),
                'warning'       => esc_html__( 'Warning', 'landkit-elementor' ),
                'danger'        => esc_html__( 'Danger', 'landkit-elementor' ),
                'light'         => esc_html__( 'Light', 'landkit-elementor' ),
                'dark'          => esc_html__( 'Dark', 'landkit-elementor' ),
                'black'         => esc_html__( 'Black', 'landkit-elementor' ),
                'white'         => esc_html__( 'White', 'landkit-elementor' ),
            ],
            'condition' => [ 'overlay' => 'yes' ]
        ] );

        $repeater->add_control( 'opacity', [
            'label'     => esc_html__( 'Opacity', 'landkit-elementor' ),
            'type'      => Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min'  => 10,
                    'max'  => 90,
                    'step' => 10,
                ],
            ],
            'condition' => [ 'overlay' => 'yes' ]
        ] );

        $repeater->add_control( 'enable_gradient', [
            'label'     => esc_html__( 'Enable Gradient', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
            'default'   => 'no',
            'separator' => 'before',
            'condition' => [ 'overlay' => 'yes' ]
        ] );

        $repeater->add_control( 'choose_flow', [
            'label'   => esc_html__( ' Choose Flow ', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'right',
            'options' => [
                'right' => esc_html__( 'Right', 'landkit-elementor' ),
                'left'  => esc_html__( 'Left', 'landkit-elementor' ),
                'down'  => esc_html__( 'Down', 'landkit-elementor' ),
            ],
            'condition' => [ 
                'overlay'         => 'yes',
                'enable_gradient' => 'yes'
            ]
        ] );

        $this->add_control( 'pattern_list', [
            'label'   => esc_html__( 'Style Patterns', 'landkit-elementor' ),
            'type'    => Controls_Manager::REPEATER,
            'fields'  => $repeater->get_controls(),
            'default' => [
                [
                    'name'          => esc_html__( 'Background + 30% Dark Overlay', 'landkit-elementor' ),
                    'overlay_color' => 'dark',
                    'thumbnail'     => 'full'
                ],
                [
                    'name'          => esc_html__( 'Photo on Top', 'landkit-elementor' ),
                    'thumbnail'     => 'top'
                ],
                [
                    'name'          => esc_html__( 'All Text Card', 'landkit-elementor' ),
                    'thumbnail'     => 'none'
                ],
            ],
            'title_field' => '{{{ name }}}',
        ] );


        $this->end_controls_section();
    }

    private function get_style_pattern() {
        $widget        = $this->parent;
        $query         = $widget->get_query();
        $current_index = $query->current_post;
        $patterns      = $this->get_style_patterns();
        $last_index    = array_key_last( $patterns );
    
        $pattern = [
            'img_pos'  => 'top',
            'overlay'  => '',
            'gradient' => '',
            'opacity'  => '',
            'color'    => '', 
            'flow'     => '',
            'width'    => '4',
            'style'    => 'vertical',
            'featured' => 'in',
            'curve_more'  => 'no',

        ];
        
        if ( isset( $patterns[ $current_index ] ) ) {
            $pattern = [
                'img_pos'    => $patterns[ $current_index ] [ 'thumbnail' ],
                'overlay'    => $patterns[ $current_index ] [ 'overlay' ],
                'gradient'   => $patterns[ $current_index ] [ 'enable_gradient' ],
                'opacity'    => $patterns[ $current_index ] [ 'opacity' ]['size'],
                'color'      => $patterns[ $current_index ] [ 'overlay_color' ], 
                'flow'       => $patterns[ $current_index ] [ 'choose_flow' ],
                'width'      => $patterns[ $current_index ] [ 'width' ],
                'style'      => $patterns[ $current_index ] [ 'style' ],
                'body_pos'   => $patterns[ $current_index ] [ 'body_pos' ],
                'featured'   => $patterns[ $current_index ] [ 'featured' ],
                'curve_more' => $patterns[ $current_index ] [ 'curve_more' ],
            ];
        } elseif ( isset( $last_index ) && isset( $patterns[ $last_index ] ) ) {
            $pattern = [
                'img_pos'    => $patterns[ $last_index ] [ 'thumbnail' ],
                'overlay'    => $patterns[ $last_index ] [ 'overlay' ],
                'gradient'   => $patterns[ $last_index ] [ 'enable_gradient' ],
                'opacity'    => $patterns[ $last_index ] [ 'opacity' ]['size'],
                'color'      => $patterns[ $last_index ] [ 'overlay_color' ], 
                'flow'       => $patterns[ $last_index ] [ 'choose_flow' ],
                'width'      => $patterns[ $last_index ] [ 'width' ],
                'style'      => $patterns[ $last_index ] [ 'style' ],
                'body_pos'   => $patterns[ $last_index ] [ 'body_pos' ],
                'featured'   => $patterns[ $last_index ] [ 'featured' ],
                'curve_more' => $patterns[ $last_index ] [ 'curve_more' ],
            ];
        }

        return $pattern;
    }

    private function get_style_patterns() {
        $widget   = $this->parent;
        $settings = $widget->get_settings();
        $patterns = $settings[ $this->get_control_id( 'pattern_list' ) ];
        return $patterns;
    }

    protected function render_shape( $img_pos, $width, $curve_more ) {
        if ( $img_pos == 'left' ) : ?>
        
            <div class="shape shape-right shape-fluid-y svg-shim text-white d-none d-md-block">
                <svg viewBox="0 0 112 690" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M116 0H51v172C76 384 0 517 0 517v173h116V0z" fill="currentColor"></path>
                </svg>
            </div>
        
        <?php elseif ( $img_pos == 'right' ) : ?>
        
            <div class="shape shape-left shape-fluid-y svg-shim text-white d-none d-md-block">
                <svg viewBox="0 0 112 690" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0 0h62.759v172C38.62 384 112 517 112 517v173H0V0z" fill="currentColor"></path></svg>
            </div>
        
        <?php elseif ( $img_pos == 'top' && $curve_more == '' ) : ?>
            <!-- Shape -->
            <div class="position-relative">
                <div class="shape shape-bottom shape-fluid-x svg-shim text-white">
                    <svg viewBox="0 0 2880 48" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0 48h2880V0h-720C1442.5 52 720 0 720 0H0v48z" fill="currentColor"></path></svg>
                </div>
            </div>

            <?php elseif ( $img_pos == 'top' && $curve_more == 'yes' ) : ?>
        
            <div class="position-relative">
                <div class="shape shape-bottom shape-fluid-x svg-shim text-white">
                    <svg viewBox="0 0 2880 480" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M2160 0C1440 240 720 240 720 240H0v240h2880V0h-720z" fill="currentColor"></path></svg>
                </div>
            </div>

        <?php endif; 
    }

    protected function render_image_display_end() {?>
        <!-- Image (placeholder) -->
        </a> 
    <?php  }

    private function get_text_color_class( $opacity, $img_pos ) {
        
        if ( 'full' === $img_pos ) {
            if ( $opacity >= 40 ) {
                $class = 'text-white-80';
            } elseif( $opacity == 30 ) {
                $class = 'text-white';
            } else {
                $class = 'text-muted';
            }
        } else {
            $class = 'text-muted';
        }

        return $class;
    }

    private function get_border_color_class( $img_pos ) {
        
        if ( 'full' === $img_pos ) {
            $class = 'border-white-20';
        } else {
            $class = '';
        }

        return $class;
    }

    private function card_body_horizontal( $img_pos ) {
        
        if ( 'right' === $img_pos ) {
            $class = 'order-md-1';
        } else {
            $class = '';
        }

        return $class;
    }

    protected function render_vertical_post( $pattern ) {
        extract( $pattern );
        //echo '<pre>' . print_r( $pattern, 1 ) . '</pre>';
        $card = 'card shadow-light-lg lift lift-lg mb-6';
        $bg   = '';

        if ( 'full' === $img_pos ) {
            $card .= ' pt-14 bg-cover overlay';
            $card .= ' overlay-' . $color;
            $card .= ' overlay-' . $opacity;
            $bg   = ' style="background-image: url( ' . get_the_post_thumbnail_url() . ' );"';
        }

        if ( $width < 6 ) {
            //$card .= ' mb-lg-0';
        }

        ?><div class="<?php echo esc_attr( $card ); ?>"<?php echo $bg; ?>>

            <?php if ( is_sticky() ) {
                $this->render_is_featured_sticky($featured);
            } ?>

            <?php $this->render_featured_image( $img_pos, $width, $curve_more ); ?>

            <?php $this->render_card_body( $img_pos, $opacity, $style ); ?>

            <?php $this->render_card_meta( $img_pos, $opacity ); ?>

        </div><?php
    }

     protected function render_image( $img_pos, $width ) {

        if ( 'none' === $img_pos || 'full' === $img_pos ) {
            return;
        }

        if ( $width <= 6 ) {
            $img_class = 'card-img-top';
        } elseif ( 'right' === $img_pos || 'left' === $img_pos ) {
            $img_class = 'img-fluid d-md-none invisible';
        } else {
            $img_class = 'img-fluid';
        }

        the_post_thumbnail( 'full', [ 'class' => $img_class ] ); 
     }

    protected function render_featured_image( $img_pos, $width, $curve_more ) {

        if ( ! has_post_thumbnail() ) {
            return;
        }

        ?><!-- Image -->
        <a class="card-img-top" href="<?php echo esc_url( get_permalink() ); ?>">
            <?php $this->render_image( $img_pos, $width ); ?>
        </a>

        <?php $this->render_shape( $img_pos, $width, $curve_more );
    }

    protected function render_card_body( $img_pos, $opacity , $style ) {

        $card_body = 'card-body';
        $heading   = 'card-body__heading d-box box-orient-vertical post__title overflow-hidden';
        $excerpt   = 'card-body__excerpt post__excerpt overflow-hidden mb-0 ' . $this->get_text_color_class( $opacity, $img_pos );
        $title_tag = $this->get_instance_value( 'title_tag' );

        if ( ( 'full' === $img_pos) && ('vertical' === $style ) ) {
            $card_body .= ' mt-auto';
            $heading   .= ' text-white';
        } elseif ( 'none' === $img_pos || ! has_post_thumbnail() ) {
            $card_body .= ' my-auto';
            $heading   .= ' mt-auto';
        }

        ?><!-- Body -->
        <a class="<?php echo esc_attr( $card_body ); ?>" href="<?php echo esc_url( get_permalink() ); ?>">

            
            <?php if ( $this->get_instance_value( 'show_title' ) ) : ?>
            <!-- Heading -->
            <<?php echo $title_tag; ?> class="<?php echo esc_attr( $heading ); ?>">
                <?php the_title(); ?>
            </<?php echo $title_tag; ?>>
            <?php endif; ?>
            
            <?php if ( $this->get_instance_value( 'show_excerpt' ) ) : ?>
            <!-- Text -->
            <p class="<?php echo esc_attr( $excerpt ); ?>">
                <?php echo wp_strip_all_tags( get_the_excerpt() ); ?>
            </p>
            <?php endif; ?>

        </a><?php
    }

    protected function render_card_meta( $img_pos, $opacity ) {
        ?><!-- Meta -->
        <a class="card-meta" href="<?php echo esc_url( get_permalink() ); ?>">

            <?php $this->render_meta_divider( $img_pos ); ?>

            <?php $this->render_avatar(); ?>

            <?php $this->render_author( $opacity, $img_pos ); ?>

            <?php $this->render_date( $opacity, $img_pos ); ?>

        </a><?php
    }

    protected function render_meta_divider( $img_pos ) {
        ?><!-- Divider -->
        <hr class="card-meta-divider <?php echo $this->get_border_color_class( $img_pos ); ?>"><?php
    }

    protected function render_avatar() {
        ?><!-- Avatar -->
        <div class="avatar avatar-sm mr-2">
            <?php echo get_avatar( get_the_author_meta( 'ID' ), 256, '', '', [ 'class' => 'avatar-img rounded-circle' ] ); ?>
        </div><?php 
    }

    protected function render_author( $opacity = '', $img_pos = 'full' ) {
        ?><!-- Author -->
        <h6 class="text-uppercase mr-2 mb-0 <?php echo $this->get_text_color_class( $opacity, $img_pos ); ?>">
            <?php the_author(); ?>
        </h6><?php
    }

    protected function render_date( $opacity = '', $img_pos = 'full' ) {
        ?><!-- Date -->
        <p class="h6 text-uppercase mb-0 ml-auto <?php echo $this->get_text_color_class( $opacity, $img_pos ); ?>">
            <time datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>"><?php echo get_the_date( 'M j'); ?></time>
        </p><?php
    }

    private function image_wrapper( $card_img, $img_pos, $width, $bglr, $curve_more ){ 

        if ( ! has_post_thumbnail() ) {
            return;
        }

        ?>

        <a class="<?php echo esc_attr( $card_img ); ?>" <?php echo $bglr; ?> href="<?php echo esc_url( get_permalink() ); ?>">
            <!-- Image (placeholder) -->
            <?php $this->render_image( $img_pos, $width ); ?>
            <!-- Shape -->
            <?php $this->render_shape( $img_pos, $width, $curve_more ); ?>

        </a><?php 
    }

    public function render_featured_inside() { ?>
        <span class="badge badge-pill badge-light badge-float badge-float-inside">
            <span class="h6 text-uppercase"><?php echo esc_html__( 'Featured', 'landkit-elementor' ); ?></span>
        </span><?php
    }

    public function render_featured_outside() { ?>
        <span class="badge badge-pill badge-gray-600 badge-float badge-float-outside">
            <span class="h6 text-uppercase"><?php echo esc_html__( 'Featured', 'landkit-elementor' ); ?></span>
        </span><?php    
    }

    public function render_is_featured_sticky($featured) { 
        if( 'in' === $featured ){
            $this->render_featured_inside();
        } else {
            $this->render_featured_outside();
        }
    }


    public function render_horizontal_post( $pattern ) {
        extract( $pattern );
        $card      = 'card card-row shadow-light-lg lift lift-lg mb-6';
        $bglr      = ' style="background-image: url( ' . get_the_post_thumbnail_url() . ' );"';
        $gap       = 'row no-gutters';
        $card_img  = 'col-12 col-md-6 bg-cover card-img-'.$img_pos;
        $bg        = '';

        if ( 'right' === $body_pos ) {
            $gap .= ' justify-content-end';
        }

        if ( 'full' === $img_pos && 'yes'=== $gradient ) {
            $card .= ' bg-cover overlay text-white';
            $card .= ' overlay-gradient-' . $color. '-' . $flow;
            $card .= ' overlay-' . $opacity;
            $bg    = ' style="background-image: url( ' . get_the_post_thumbnail_url() . ' );"';

        } elseif ( 'full' === $img_pos ) {
            $card .= ' bg-cover overlay text-white';
            $card .= ' overlay-' . $color;
            $card .= ' overlay-' . $opacity;
            $bg    = ' style="background-image: url( ' . get_the_post_thumbnail_url() . ' );"';
        } elseif ('right' === $img_pos ) {
            $card_img .= ' order-md-2';
        }
        ?> 
        <div class="<?php echo esc_attr( $card ); ?>"<?php echo $bg; ?>>

            <div class="<?php echo esc_attr( $gap ); ?>"><?php

            if ( 'full' === $img_pos && is_sticky() ) { ?>
                <div class='col-12'>
                    <?php  $this->render_is_featured_sticky($featured); ?>
                </div>
            <?php } elseif( is_sticky() ) {
                $this->render_is_featured_sticky($featured);
            }
            
                if ( 'right' === $img_pos || 'left' === $img_pos ) : 
                    $this->image_wrapper($card_img, $img_pos, $width, $bglr, $curve_more ); 
                endif; ?>                  <!-- Image (placeholder) -->
                <div class="col-12 col-md-6 <?php echo $this->card_body_horizontal( $img_pos ); ?>">
                    <?php 
                        $this->render_card_body( $img_pos, $opacity, $style );
                        $this->render_card_meta( $img_pos, $opacity ); 
                    ?>
                </div>
            </div> <!-- / .row -->
        </div><?php
    }

    protected function render_loop_footer() {
         $settings    = $this->parent->get_settings();
         

        $parent_settings = $this->parent->get_settings();
        if ( '' === $parent_settings['pagination_type'] ) {
            return;
        }

        $page_limit = $this->parent->get_query()->max_num_pages;
        if ( '' !== $parent_settings['pagination_page_limit'] ) {
            $page_limit = min( $parent_settings['pagination_page_limit'], $page_limit );
        }

        if ( 2 > $page_limit ) {
            return;
        }

        $this->parent->add_render_attribute( 'pagination', 'class', 'elementor-pagination' );

        $has_numbers = in_array( $parent_settings['pagination_type'], [ 'numbers', 'numbers_and_prev_next' ] );
        $has_prev_next = in_array( $parent_settings['pagination_type'], [ 'prev_next', 'numbers_and_prev_next' ] );

        $links = [];

        if ( $has_numbers ) {
            $paginate_args = [
                'type' => 'array',
                'current' => $this->parent->get_current_page(),
                'total' => $page_limit,
                'prev_next' => false,
                'show_all' => 'yes' !== $parent_settings['pagination_numbers_shorten'],
                'before_page_number' => '<span class="elementor-screen-only">' . __( 'Page', 'landkit-elementor' ) . '</span>',
            ];

            if ( is_singular() && ! is_front_page() ) {
                global $wp_rewrite;
                if ( $wp_rewrite->using_permalinks() ) {
                    $paginate_args['base'] = trailingslashit( get_permalink() ) . '%_%';
                    $paginate_args['format'] = user_trailingslashit( '%#%', 'single_paged' );
                } else {
                    $paginate_args['format'] = '?page=%#%';
                }
            }

            $links = paginate_links( $paginate_args );
        }

        if ( $has_prev_next ) {
            $prev_next = $this->parent->get_posts_nav_link( $page_limit );
            array_unshift( $links, $prev_next['prev'] );
            $links[] = $prev_next['next'];
        }

        ?>
        <nav class="elementor-pagination" role="navigation" aria-label="<?php esc_attr_e( 'Pagination', 'landkit-elementor' ); ?>">
            <?php echo implode( PHP_EOL, $links ); ?>
        </nav>
        <?php
    }

    protected function render_post() {
            $pattern = $this->get_style_pattern();
            extract( $pattern ); ?>
            <div class="col-12 col-md-6 col-lg-<?php echo $width;?> d-flex<?php if ( has_post_thumbnail() ):?> has-post-thumbnail<?php endif; ?>">
            <?php 
                if ( 'vertical' === $style) {
                    $this->render_vertical_post( $pattern );
                } else {
                    $this->render_horizontal_post( $pattern ); 
                }   
            ?>
            </div><?php
    }
}