<?php
namespace LandkitElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Skin_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Skin_List extends Skin_Base {

	public function get_id() {
		return 'list';
	}

	public function get_title() {
		return esc_html__( 'List', 'landkit-elementor' );
	}

	public function render_meta_data() {
		/** @var array $settings e.g. [ 'author', 'date', ... ] */
		$settings = $this->parent->get_settings( 'meta_data' );
		$setting  = $this->parent->get_settings();
		if ( empty( $settings ) ) {
			return;
		}

		$meta_array = [];

		if ( in_array( 'excerpt', $settings ) && has_excerpt() ) {
			ob_start();
			$this->render_excerpt();
			$meta_array[] = ob_get_clean();
		}

		if ( function_exists( 'get_the_job_location' ) && ! empty( get_the_job_location() ) && in_array( 'location', $settings ) ) {
			ob_start();
			$this->render_location();
			$meta_array[] = ob_get_clean();
		}

		if ( in_array( 'author', $settings ) ) {
			ob_start();
			$this->render_author();
			$meta_array[] = ob_get_clean();
		}

		if ( in_array( 'date', $settings ) ) {
			ob_start();
			$this->parent->render_date_by_type();
			$meta_array[] = ob_get_clean();
		}

		if ( in_array( 'time', $settings ) ) {
			ob_start();
			$this->render_time();
			$meta_array[]= ob_get_clean();
		}

		if ( in_array( 'comments', $settings ) ) {
			ob_start();
			$this->render_comments();
			$meta_array[] = ob_get_clean();
		}

		if ( in_array( 'modified', $settings ) ) {
			ob_start();
			$this->parent->render_date_by_type( 'modified' );
			$meta_array[] = ob_get_clean();
		}

		$this->parent->add_render_attribute( 'meta_css', 'class',[ 
				'mb-0',
				'lk-elementor-jobs-meta-data', 
			] );
		$meta_css = $setting[ 'meta_css' ];

		if ( !empty( $setting[ 'meta_css' ] ) ) {
			$this->parent->add_render_attribute( 'meta_css', 'class', $meta_css
			);
		}

		if ( ! empty( $meta_array ) ) {
			?><p <?php echo $this->parent->get_render_attribute_string( 'meta_css' ); ?>><?php echo wp_kses_post( join( ' ' . $this->parent->get_settings( 'meta_separator' ) . ' ', $meta_array ) ); ?></p><?php
		}
	}

	public function render_excerpt() {
		$settings = $this->parent->get_settings();
		echo wp_trim_words( get_the_excerpt(), $settings[ 'excerpt_length' ], '' );
	}
	public function render_location() {
		if ( function_exists( 'get_the_job_location' ) ) {
			echo get_the_job_location();
		}
	}

	public function render_author() {
		the_author();
	}

	public function render_time() {
		the_time();
	}

	public function render_comments() {
		comments_number();
	}

	/**
	* Function for jobs list loop
	*/
	public function render_jobs_list_post() { 
		$settings = $this->parent->get_settings();

		$title_tag = $settings[ 'title_tag' ];
		$title_css = $settings[ 'title_css' ];
		$this->parent->add_render_attribute( 'title_css', 'class', [
				'mb-1',
				'lk-elementor-jobs-title', 
			] );

		if ( !empty( $settings[ 'title_css' ] ) ) {
			$this->parent->add_render_attribute( 'title_css', 'class', $title_css
			);
		}
		?>
		<a class="list-group-item text-reset text-decoration-none" href="<?php echo esc_url( get_permalink() ); ?>">
			<?php if ( $settings[ 'show_title' ] == 'yes' ): ?>
				<<?php echo $title_tag; ?> <?php echo $this->parent->get_render_attribute_string( 'title_css' ); ?>><?php the_title(); ?></<?php echo $title_tag; ?>>
			<?php endif;
			if ( $settings[ 'show_meta' ] == 'yes' ) {
				$this->render_meta_data();
			}
			?>
		</a>
		<?php
	}

	public function render() {
		$this->parent->query_posts();
		$query = $this->parent->get_query();
		$settings = $this->parent->get_settings();
		if ( ! $query->found_posts ) {
			$empty_post_text = apply_filters( 'landkit_elementor_jobs_empty_post_text', 'No posts found' );

			$this->parent->add_render_attribute( 'post_icon', 'class', [
				'h3',
				'mb-0',
				$this->parent->get_icon(), 
			] );?>
			
			<div class="bg-light text-center py-10 rounded">
				<i <?php echo $this->parent->get_render_attribute_string( 'post_icon' ); ?>></i>
				<h3><?php echo esc_html__( $empty_post_text, 'landkit-elementor' ) ?></h3>
			</div>
			<?php
			return;
		}

		$this->parent->add_render_attribute( 'post_card', 'class', [
			'lk-elementor-widget-jobs__inner',
			'card',
			'shadow-light-lg',
		] );

		if ( $settings[ 'show_border' ] == 'yes' ) {
			$this->parent->add_render_attribute( 'post_card', 'class', [
				'card-border',
			] );
		}

		if ( empty( $settings[ 'border_color' ] ) ) {
			$this->parent->add_render_attribute( 'post_card', 'class', [
				'border-' . $settings[ 'border_predefined_color' ],
			] );
		}

		$border_css = $settings[ 'border_css' ];


		if ( !empty( $border_css ) ) {
			$this->parent->add_render_attribute( 'post_card', 'class', $border_css
			);
		}


		$post_count = $query->found_posts < $settings[ 'posts_per_page' ] ? $query->found_posts : $settings[ 'posts_per_page' ];
		?>
		<div <?php echo $this->parent->get_render_attribute_string( 'post_card' ); ?>>
			<div class="card-body">
				<?php
				$this->parent->add_render_attribute( 'post_terms', 'class', [
					'lk-elementor-jobs-terms',
					'd-inline-block',
					'mb-5',
					'mr-1',
				] );

				if ( empty( $settings[ 'term_color' ] ) ) {
					$this->parent->add_render_attribute( 'post_terms', 'class', [
						'text-' . $settings[ 'term_predefined_color' ],
					] );
				}

				$term_css = $settings[ 'term_css' ];

				if ( !empty( $settings[ 'term_css' ] ) ) {
					$this->parent->add_render_attribute( 'post_terms', 'class', $term_css );
				}

				$this->parent->add_render_attribute( 'post_terms_count', 'class', [
					'lk-elementor-jobs-terms-count',
					'badge',
					'badge-rounded-circle',
					$settings[ 'enable_soft_term_badge' ] == 'yes' ? 'badge-' . $settings[ 'term_predefined_color' ] . '-soft' : 'badge-' . $settings[ 'term_predefined_color' ], 
				] );

				if ( ! empty( $settings[ 'posts_include_term_ids' ] ) && $settings[ 'posts_include' ][0] == 'terms' && $settings[ 'show_term' ] == 'yes' ): ?>
					<h6 <?php echo $this->parent->get_render_attribute_string( 'post_terms' );?>>
						<?php
						foreach ( $settings[ 'posts_include_term_ids' ] as $term_id ) {
							$term = get_term( $term_id );

							if ( is_numeric( $term_id ) ) {
								$field = 'term_taxonomy_id';
								$term = get_term_by( $field, $term_id );
							} else {
								$field      = 'slug';
								$post_type  = $settings[ 'posts_post_type' ];
								$taxonomies = get_object_taxonomies( $post_type );
								
								foreach( $taxonomies as $tax ) {
									$term = get_term_by( $field, $term_id, $tax );
									if ( false !== $term ) {
										break;
									}
								}
							}
							
							if ( isset( $term ) && ! is_wp_error( $term ) ) {
								print( $term->name );	
							}
							
							if ( next( $settings[ 'posts_include_term_ids' ] ) ) {
								echo ', '; // Add comma for all elements instead of last
							}
						}
						?>
					</h6>
					<span <?php echo $this->parent->get_render_attribute_string( 'post_terms_count' ); ?>>
						<span><?php echo esc_html( $post_count ); ?></span>
					</span>
				<?php endif; ?>
				<div>
					<div class="list-group list-group-flush">
					<?php
					// It's the global `wp_query` it self. and the loop was started from the theme.
					if ( $query->in_the_loop ) {
						$this->current_permalink = get_permalink();
						$this->render_jobs_list_post();
					} else {
						while ( $query->have_posts() ) {
							$query->the_post();
							$this->current_permalink = get_permalink();
							$this->render_jobs_list_post();
						}
					}
					wp_reset_postdata();
					?>
					</div>
				</div>
			</div>
		</div><?php
	}
}