<?php
namespace LandkitElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
exit; // Exit if accessed directly
}

class Skin_Masonry extends Skin_Base {

    public function get_id() {
        return 'masonry';
    }

    public function get_title() {
        return esc_html__( 'Masonry', 'landkit-elementor' );
    }

    /**
    * Function for Portfolio loop
    */
    public function render_portfolio_post() { ?>
        <div <?php post_class( 'col' ); ?>>
            <!-- Card -->
            <a class="card shadow-light-lg mb-7" href="<?php echo esc_url( get_permalink() ); ?>">
                <!-- Image -->
                <div class="card-zoom">
                    <?php $this->render_thumbnail("card-img"); ?>
                </div>
                <!-- Overlay -->
                <div class="card-img-overlay card-img-overlay-hover">
                    <div class="card-body bg-white">
                        <!-- Shapes -->
                        <?php $this->render_masonry_shape(); ?>
                        <!-- Preheading -->
                        <?php $this->render_portfolio_category(); ?>
                        <!-- Heading -->
                        <?php $this->render_portfolio_title(); ?>
                    </div>
                </div>
            </a>
        </div>
    <?php  }

    public function render_masonry_shape() { ?>
        <div class="shape shape-bottom-100 shape-fluid-x svg-shim text-white">
            <svg viewBox="0 0 2880 48" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0 48h2880V0h-720C1442.5 52 720 0 720 0H0v48z" fill="currentColor"></path></svg>
        </div>
    <?php }

    protected function render_masonry_loop_header() {
        $settings    = $this->parent->get_settings();
        $columns_key = $this->get_control_id( 'columns' );?>              
        <div id="portfolio" class="row row-cols-<?php echo $settings['columns_mobile']; ?> row-cols-md-<?php echo $settings['columns_tablet']; ?> row-cols-lg-<?php echo $settings[ 'columns' ]; ?>" data-isotope='{"layoutMode": "masonry"}'>
        <?php }

    protected function render_masonry_loop_footer() {?>
        </div> <!-- / .row -->
    <?php }

    public function set_render_attributes() {
        $this->parent->add_render_attribute( 'title', 'class', 'mb-0' );
    }

    public function render() {
        $this->parent->query_posts();
        /** @var \WP_Query $query */
        $query = $this->parent->get_query();
        if ( ! $query->found_posts ) {
            return;
        }
        $this->render_masonry_loop_header();
        // It's the global `wp_query` it self. and the loop was started from the theme.
        if ( $query->in_the_loop ) {
            $this->current_permalink = get_permalink();
            $this->render_portfolio_post();
        } else {
            $this->set_render_attributes();
            while ( $query->have_posts() ) {
                $query->the_post();
                $this->current_permalink = get_permalink();
                $this->render_portfolio_post();
            }
        }
        wp_reset_postdata();
        $this->render_masonry_loop_footer();
    }
}
