<?php
namespace LandkitElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Skin_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Skin_Table extends Skin_Base {

	public function get_id() {
		return 'table';
	}

	public function get_title() {
		return esc_html__( 'Table', 'landkit-elementor' );
	}

	public function render_meta_data( $settings, $setting_key ) {
		/** @var array $settings e.g. [ 'author', 'date', ... ] */
		if ( empty( $settings ) ) {
			return;
		}

		$output = '';
		$permalink = get_permalink();

		switch ( $settings[ $setting_key ] ) {
			case 'author':
				$permalink = get_author_posts_url( get_the_author_meta('ID') );
				$output = get_the_author();
			break;

			case 'date':
				ob_start();
				$this->parent->render_date_by_type();
				$output = ob_get_clean();
			break;

			case 'time':
				ob_start();
				the_time();
				$output = ob_get_clean();
			break;

			case 'comments':
				ob_start();
				comments_number();
				$output = ob_get_clean();
			break;

			case 'modified':
				ob_start();
				$this->parent->render_date_by_type( 'modified' );
				$output = ob_get_clean();
			break;

			case 'location':
				if ( function_exists( 'get_the_job_location' ) && ! empty( get_the_job_location() ) ) {
					$output = get_the_job_location();
				}
			break;

			case 'team':
				if ( function_exists( 'landkit_get_the_job_team' ) ) {
					$output = landkit_get_the_job_team();
				}
			break;

			case 'category':
				$categories = get_the_category(); 
				$output = '';
				foreach ( $categories as $category ) {
					$permalink = get_term_link( $category );
					$output .= $category->name;
					if ( next( $categories ) ) {
						$output .= ', '; // Add comma for all elements instead of last
					}
				}
			break;

			case 'job-category':
				$term_obj_list = get_the_terms( get_the_ID(), 'job_listing_category' );
				if ( ! empty( $term_obj_list ) ) {
					$terms = join( ', ', wp_list_pluck( $term_obj_list, 'name' ) );
				} else {
					$terms = '';
				}

				$output = $terms;
			break;
		}

		?>
		<a href="<?php echo esc_url( $permalink ); ?>" class="text-reset text-decoration-none">
			<p class="lk-elementor-jobs-meta-data mb-0"><?php echo wp_kses_post( $output ); ?></p>
		</a>
		<?php
	}

	/**
	* Function for jobs table loop
	*/
	public function render_jobs_table_post() { 
		$settings = $this->parent->get_settings();

		$title_tag = $settings[ 'title_tag' ];
		?>
		<tr>
			<td>
				<a class="text-reset text-decoration-none" href="<?php echo esc_url( get_permalink() ); ?>">
					<?php if ( $settings[ 'show_title' ] == 'yes' ): ?>
						<<?php echo $title_tag; ?> class="lk-elementor-jobs-title mb-1"><?php the_title(); ?></<?php echo $title_tag; ?>>
					<?php endif; ?>
					<?php if ( $settings[ 'show_excerpt' ] == 'yes' && has_excerpt() ): ?>
						<p class="lk-elementor-jobs-excerpt mb-0 " style="max-width:530px;"><?php echo wp_strip_all_tags( get_the_excerpt() ); ?></p>
					<?php endif; ?>
				</a>
			</td>
			<td><?php $this->render_meta_data( $settings, 'meta_data_1' ); ?></td>
			<td><?php $this->render_meta_data( $settings, 'meta_data_2' ); ?></td>
		</tr>
		<?php
	}

	public function render() {
		$this->parent->query_posts();
		$query = $this->parent->get_query();
		$settings = $this->parent->get_settings();
		if ( ! $query->found_posts ) {
			$empty_post_text = apply_filters( 'landkit_elementor_jobs_empty_post_text', 'No posts found' );

			$this->parent->add_render_attribute( 'post_icon', 'class', [
				'h3',
				'mb-0',
				$this->parent->get_icon(), 
			] );

			?>
			<div class="bg-light text-center py-10 rounded">
				<i <?php echo $this->parent->get_render_attribute_string( 'post_icon' ); ?>></i>
				<h3 class="mb-0 font-weight-bold"><?php echo esc_html__( $empty_post_text, 'landkit-elementor' ) ?></h3>
			</div>
			<?php
			return;
		}
		?>
		<div class="table-responsive">
			<table class="table table-align-middle">
				<?php if ( $settings[ 'show_table_title' ] == 'yes' ): ?>
					<thead>
						<tr>
							<?php
								for ( $i = 1; $i <= 3 ; $i++ ) { 
									?><th><span class="h6 lk-elementor-jobs-table-title <?php echo wp_kses_post( $settings[ 'table_title_css'] ); ?>"><?php echo wp_kses_post( $settings[ 'table_title_' . $i ] ); ?></span></th><?php
								}
							?>
						</tr>
					</thead>
				<?php endif; ?>
				<tbody>
					<?php
					// It's the global `wp_query` it self. and the loop was started from the theme.
					if ( $query->in_the_loop ) {
						$this->current_permalink = get_permalink();
						$this->render_jobs_table_post();
					} else {
						while ( $query->have_posts() ) {
							$query->the_post();
							$this->current_permalink = get_permalink();
							$this->render_jobs_table_post();
						}
					}
					wp_reset_postdata();
					?>
				</tbody>
			</table>
		</div><?php
	}
}
