<?php
namespace LandkitElementor\Modules\Posts\Widgets;

use Elementor\Group_Control_Typography;
use LandkitElementor\Base\Base_Widget;
use LandkitElementor\Modules\QueryControl\Module as Module_Query;
use LandkitElementor\Modules\QueryControl\Controls\Group_Control_Related;
use Elementor\Controls_Manager;
use LandkitElementor\Modules\Posts\Skins;
use Elementor\Core\Schemes;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Class Jobs
 */
class Jobs extends Base_Widget {

	/**
	 * @var \WP_Query
	 */
	private $_query = null;

	protected $_has_template_content = false;

	public function get_name() {
		return 'lk-jobs';
	}

	public function get_title() {
		return __( 'Jobs', 'landkit-elementor' );
	}

	public function get_keywords() {
		return [ 'jobs', 'cpt', 'item', 'loop', 'query', 'cards', 'custom post type' ];
	}

	public function get_icon() {
		return 'eicon-table-of-contents';
	}

	public function get_script_depends() {
		return [ 'imagesloaded' ];
	}

	public function on_import( $element ) {
		if ( ! get_post_type_object( $element['settings']['posts_post_type'] ) ) {
			$element['settings']['posts_post_type'] = 'post';
		}

		return $element;
	}

	protected function register_skins() {
		$this->add_skin( new Skins\Skin_List( $this ) );
		$this->add_skin( new Skins\Skin_Table( $this ) );
	}

	public function get_query() {
		return $this->_query;
	}

	public function render_date_by_type( $type = 'publish' ) {
		switch ( $type ) :
			case 'modified':
				$date = get_the_modified_date();
			break;
			default:
				$date = get_the_date();
		endswitch;
		/** This filter is documented in wp-includes/general-template.php */
		echo apply_filters( 'the_date', $date, get_option( 'date_format' ), '', '' );
	}

	protected function register_controls() {
		$this->register_query_section_controls();
	}

	public function register_query_section_controls() {
		$this->start_controls_section(
			'section_layout',
			[
				'label' => __( 'Layout', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Posts Per Page', 'landkit-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'default' => 3,
			]
		);


		$this->add_control(
			'show_border',
			[
				'label' => __( 'Show Border ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'separator' => 'before',
				'condition' => [
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'border_predefined_color',
			[
				'label' => __( 'Border Color', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'primary'   =>  __( 'Primary', 'landkit-elementor' ),
					'secondary' =>  __( 'Secondary', 'landkit-elementor' ),
					'success'   =>  __( 'Success', 'landkit-elementor' ),
					'danger'    =>  __( 'Danger', 'landkit-elementor' ),
					'warning'   =>  __( 'Warning', 'landkit-elementor' ),
					'dark'      =>  __( 'Dark', 'landkit-elementor' ),
					'gray-800'  =>  __( 'Gray', 'landkit-elementor' ),
				],
				'default' => 'primary',
				'condition' => [
					'show_border' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'show_term',
			[
				'label' => __( 'Show Term ?', 'landkit-elementor' ),
				'description' => __( 'Visible if posts is filterd by terms', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'separator' => 'before',
				'condition' => [
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'term_predefined_color',
			[
				'label' => __( 'Term Color', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'primary'   =>  __( 'Primary', 'landkit-elementor' ),
					'secondary' =>  __( 'Secondary', 'landkit-elementor' ),
					'success'   =>  __( 'Success', 'landkit-elementor' ),
					'danger'    =>  __( 'Danger', 'landkit-elementor' ),
					'warning'   =>  __( 'Warning', 'landkit-elementor' ),
					'dark'      =>  __( 'Dark', 'landkit-elementor' ),
				],
				'default' => 'primary',
				'condition' => [
					'show_term' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'enable_soft_term_badge',
			[
				'label' => __( 'Enable Soft Badge ?', 'landkit-elementor' ),
				'description' => __( 'Enable to make soft badge', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Disable', 'landkit-elementor' ),
				'label_on' => __( 'Enable', 'landkit-elementor' ),
				'condition' => [
					'show_term' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'show_title',
			[
				'label' => __( 'Show Title ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label' => __( 'Title HTML Tag', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
					'span' => 'span',
					'p' => 'p',
				],
				'default' => 'p',
				'condition' => [
					'show_title' => 'yes',
				],
			]
		);

		$this->add_control(
			'show_excerpt',
			[
				'label' => __( 'Show Excerpt ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'condition' => [
					'_skin' => 'table',
				],
			]
		);

		$meta_options = apply_filters( 'landkit_elementor_jobs_widget_meta_options', [
			'excerpt' => __( 'Excerpt', 'landkit-elementor' ),
			'author' => __( 'Author', 'landkit-elementor' ),
			'date' => __( 'Date', 'landkit-elementor' ),
			'time' => __( 'Time', 'landkit-elementor' ),
			'comments' => __( 'Comments', 'landkit-elementor' ),
			'modified' => __( 'Date Modified', 'landkit-elementor' ),
			'location' => __( 'Location', 'landkit-elementor' ),
		] );

		$this->add_control(
			'show_meta',
			[
				'label' => __( 'Show Meta ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'separator' => 'before',
				'condition' => [
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'meta_data',
			[
				'label' => __( 'Meta Data', 'landkit-elementor' ),
				'label_block' => true,
				'type' => Controls_Manager::SELECT2,
				'default' => [ 'excerpt', 'location' ],
				'multiple' => true,
				'options' => $meta_options,
				'condition' => [
					'show_meta' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'meta_separator',
			[
				'label' => __( 'Separator Between', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '.',
				'condition' => [
					'meta_data!' => [],
					'show_meta' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'excerpt_length',
			[
				'label' => __( 'Excerpt Length', 'landkit-elementor' ),
				'type' =>Controls_Manager::NUMBER,
				'min' => 1,
				'default' => 3,
				'condition' => [
					'meta_data' => 'excerpt',
					'show_meta' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'show_table_title',
			[
				'label' => __( 'Show Table Title ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Hide', 'landkit-elementor' ),
				'label_on' => __( 'Show', 'landkit-elementor' ),
				'separator' => 'before',
				'condition' => [
					'_skin' => 'table',
				],
			]
		);

		for ( $i = 1; $i <= 3 ; $i++ ) {
			$default_title = __( 'Role', 'landkit-elementor' );

			switch ( $i ) {
				case 2:
					$default_title = __( 'Team', 'landkit-elementor' );
				break;

				case 3:
					$default_title = __( 'Location', 'landkit-elementor' );
				break;
			}

			$this->add_control(
				'table_title_' . $i,
				[
					'label' => __( 'Table Title #', 'landkit-elementor' ) . $i,
					'type' => Controls_Manager::TEXT,
					'default' => $default_title,
					'condition' => [
						'_skin' => 'table',
						'show_table_title' => 'yes',
					],
				]
			);
		}

		$meta_options_skin_table = apply_filters( 'landkit_elementor_jobs_widget_meta_options_skin_table', [
			'author' => __( 'Author', 'landkit-elementor' ),
			'date' => __( 'Date', 'landkit-elementor' ),
			'time' => __( 'Time', 'landkit-elementor' ),
			'comments' => __( 'Comments', 'landkit-elementor' ),
			'modified' => __( 'Date Modified', 'landkit-elementor' ),
			'location' => __( 'Location', 'landkit-elementor' ),
			'category' => __( 'Category', 'landkit-elementor' ),
			'job-category' => __( 'Job Category', 'landkit-elementor' ),
			'team'         => esc_html__( 'Team', 'landkit-elementor' ),
		] );

		$this->add_control(
			'meta_data_1',
			[
				'label' => __( 'Meta Data #1', 'landkit-elementor' ),
				'label_block' => true,
				'type' => Controls_Manager::SELECT2,
				'default' => 'author',
				'options' => $meta_options_skin_table,
				'separator' => 'before',
				'condition' => [
					'_skin' => 'table',
				],
			]
		);

		$this->add_control(
			'meta_data_2',
			[
				'label' => __( 'Meta Data #2', 'landkit-elementor' ),
				'label_block' => true,
				'type' => Controls_Manager::SELECT2,
				'default' => 'location',
				'options' => $meta_options_skin_table,
				'separator' => 'before',
				'condition' => [
					'_skin' => 'table',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_query',
			[
				'label' => __( 'Query', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_group_control(
			Group_Control_Related::get_type(),
			[
				'name' => 'posts',
				'exclude' => [
					'posts_per_page',
					'ignore_sticky_posts',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_card_style',
			[
				'label' => __( 'Card', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'show_border' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_control(
			'border_color',
			[
				'label' => __( 'Border Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-widget-jobs__inner' => 'border-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
            'border_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_term_style',
			[
				'label' => __( 'Terms', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'show_term' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'term_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-jobs-terms, {{WRAPPER}} .lk-elementor-jobs-terms-count',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
				'fields_options' => [
					'typography' => [ 
						'default' => 'yes'
					],
					'font_family' => [
						'default' => '',
					],
					'text_transform' => [
						'default' => 'uppercase',
					],
				],
			]
		);

		$this->add_control(
			'term_color',
			[
				'label' => __( 'Terms Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-jobs-terms' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
            'term_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_table_title_style',
			[
				'label' => __( 'Table Title', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin' => 'table',
					'show_table_title' => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'table_title_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-jobs-table-title',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
				'fields_options' => [
					'typography' => [ 
						'default' => 'yes'
					],
					'font_family' => [
						'default' => '',
					],
					'font_weight' => [
						'default' => 600,
					],
					'text_transform' => [
						'default' => 'uppercase',
					],
				],
			]
		);

		$this->add_control(
			'table_title_color',
			[
				'label' => __( 'Table Title Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-jobs-table-title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
            'table_title_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_title_style',
			[
				'label' => __( 'Title', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'show_title' => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-jobs-title',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
				'fields_options' => [
					'typography' => [ 
						'default' => 'yes'
					],
					'font_family' => [
						'default' => '',
					],
					'font_weight' => [
						'default' => 600,
					],
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-jobs-title' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
            'title_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'mb-0 font-weight-bold'
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_excerpt_style',
			[
				'label' => __( 'Excerpt', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'show_excerpt' => 'yes',
					'_skin' => 'table',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'excerpt_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-jobs-excerpt',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
				'fields_options' => [
					'typography' => [ 
						'default' => 'yes'
					],
					'font_family' => [
						'default' => '',
					],
					'font_size' => [ 
						'default' => [ 
							'size' => 15,
							'unit' => 'px',
						] 
					],
				],
			]
		);

		$this->add_control(
			'excerpt_color',
			[
				'label' => __( 'Excerpt Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-jobs-excerpt' => 'color: {{VALUE}}',
				],
				'default' => '#869ab8',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_meta_style',
			[
				'label' => __( 'Meta', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'show_meta' => 'yes',
					'_skin' => 'list',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-jobs-meta-data',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
				'fields_options' => [
					'typography' => [ 
						'default' => 'yes'
					],
					'font_family' => [
						'default' => '',
					],
					'font_size' => [ 
						'default' => [ 
							'size' => 15,
							'unit' => 'px',
						] 
					],
				],
			]
		);

		$this->add_control(
			'meta_color',
			[
				'label' => __( 'Meta Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-jobs-meta-data' => 'color: {{VALUE}}',
				],
				'default' => '#869ab8',
			]
		);

		$this->add_control(
            'meta_css', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_meta_skin_table_style',
			[
				'label' => __( 'Meta', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin' => 'table',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_skin_table_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-jobs-meta-data',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
				'fields_options' => [
					'typography' => [ 
						'default' => 'yes'
					],
					'font_family' => [
						'default' => '',
					],
					'font_size' => [ 
						'default' => [ 
							'size' => 15,
							'unit' => 'px',
						] 
					],
				],
			]
		);

		$this->add_control(
			'meta_skin_table_color',
			[
				'label' => __( 'Meta Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-jobs-meta-data' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
	}

	public function query_posts() {

		$query_args = [
			'posts_per_page' => $this->get_settings( 'posts_per_page' ),
		];

		/** @var Module_Query $elementor_query */
		$elementor_query = Module_Query::instance();
		$this->_query = $elementor_query->get_query( $this, 'posts', $query_args, [] );
	}
}
