<?php
namespace LandkitElementor\Modules\PriceTable\Skins;

use Elementor\Widget_Base;
use Elementor\Skin_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Icons_Manager;
use Elementor\Core\Schemes;
use Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Box extends Skin_Base {

	public function __construct( Widget_Base $parent ) {
		$this->parent = $parent;

		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
	}

	public function get_id() {
		return 'lk-price-table-box';
	}

	public function get_title() {
		return __( 'Box', 'landkit-elementor' );
	}

	public function render() {
		$widget   = $this->parent;
		$settings = $widget->get_settings();

		$symbol = '';

		if ( ! empty( $settings['skin_currency_symbol'] ) ) {
			if ( 'custom' !== $settings['skin_currency_symbol'] ) {
				$symbol = $widget->get_currency_symbol( $settings['skin_currency_symbol'] );
			} else {
				$symbol = $settings['currency_symbol_custom'];
			}
		}

		$widget->add_render_attribute( 'skin_title', 'class', 'lk-elementor-price-table-skin__title font-weight-bold' );
		$widget->add_inline_editing_attributes( 'skin_title' );

		$widget->add_render_attribute( 'skin_description', 'class', 'lk-elementor-price-table-skin__description' );
		$widget->add_inline_editing_attributes( 'skin_description' );

		$widget->add_render_attribute( 'skin_link', 'class', 'lk-elementor-price-table-skin__link font-size-sm font-weight-bold text-decoration-none' );
		if ( ! empty( $settings['skin_link']['url'] ) ) {
			$widget->add_link_attributes( 'skin_link', $settings['skin_link'] );
		}

		$migration_allowed = Icons_Manager::is_migration_allowed();
		$skin_link_icon_migrated = isset( $settings['__fa4_migrated']['skin_link_selected_icon'] );
		$is_new_skin_link_icon = empty( $settings['skin_link_icon'] ) && $migration_allowed;

		$widget->add_render_attribute( 'card', 'class', [ 'card', 'shadow-light-lg', 'lift', 'lift-lg' ] );

		if ( ! empty( $settings['card_classes'] ) ) {
			$widget->add_render_attribute( 'card', 'class', $settings['card_classes'] );
		}

		?>
		<div <?php echo $widget->get_render_attribute_string( 'card' ); ?>>
			<div class="card-body">
				<!-- Badge -->
				<?php if ( ! empty( $symbol ) || ! empty( $settings['skin_price_text'] ) ): ?>
					<span class="lk-elementor-price-table-skin__price badge <?php echo esc_attr( $settings[ 'skin_price_size' ] == 'lg' ? 'badge-lg ' : '' ); ?>badge-pill badge-<?php echo esc_attr( $settings[ 'skin_price_predefined_color' ] ); ?> badge-float badge-float-outside">
						<span class="lk-elementor-price-table-skin__currency"><?php echo $symbol; ?></span><?php echo $settings['skin_price_text']; ?>
					</span>
				<?php endif; ?>
				
				<?php if ( ! empty( $settings['skin_title'] ) ): ?>
					<!-- Heading -->
					<<?php echo $settings['skin_title_tag'] . ' ' . $widget->get_render_attribute_string( 'skin_title' ); ?>><?php echo $settings['skin_title'] . '</' . $settings['skin_title_tag']; ?>>
				<?php endif; ?>

				<?php if ( ! empty( $settings['skin_description'] ) ): ?>
					<!-- Text -->
					<p <?php echo $widget->get_render_attribute_string( 'skin_description' ); ?>><?php echo $settings['skin_description']; ?></p>
				<?php endif; ?>

				<?php if ( ! empty( $settings['skin_link_text'] ) ): ?>
					<!-- Link -->
					<a <?php echo $widget->get_render_attribute_string( 'skin_link' ); ?>>
						<?php echo $settings['skin_link_text']; ?>
						<?php if ( ! empty( $settings['skin_link_icon'] ) || ! empty( $settings['skin_link_selected_icon']['value'] ) ) : ?>
							<?php if ( $is_new_skin_link_icon || $skin_link_icon_migrated ) :
								Icons_Manager::render_icon( $settings['skin_link_selected_icon'], [ 'aria-hidden' => 'true', 'class' => 'ml-3' ] );
							else : ?>
								<i class="<?php echo esc_attr( $settings['skin_link_icon'] ); ?> ml-3" aria-hidden="true"></i>
							<?php endif; ?>
						<?php endif; ?>
					</a>
				<?php endif; ?>
			</div>
		</div><?php
	}

	public function skin_print_template( $content, $widget ) {
		if( 'lk-price-table' == $widget->get_name() ) {
			return '';
		}
		return $content;
	}
}