<?php
namespace LandkitElementor\Modules\PriceTable\Skins;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Skin_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;
use Elementor\Icons_Manager;
use Elementor\Core\Schemes;
use Elementor\Group_Control_Typography;
use Elementor\Utils;

class Skin_Image_Box extends Skin_Base {

	public function __construct( Widget_Base $parent ) {
		$this->parent = $parent;

		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
		add_action( 'elementor/element/lk-price-table/section_general/after_section_end', [ $this, 'add_controls' ] );
	}

	public function add_controls( Widget_Base $widget) {
		$widget->start_controls_section(
			'section_skin_image',
			[
				'label' => __( 'Image', 'landkit-elementor' ),
				'condition' => [
					'_skin' => 'lk-price-table-image-box',
				],
			]
		);

		$widget->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'landkit-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$widget->add_control(
			'show_curves',
			[
				'label' => __( 'Show Curve ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => __( 'Enable to display curve.', 'landkit-elementor' ),
				'frontend_available' => true,
			]
		);

		$widget->add_control(
			'curves_styles',
			[
				'label'   => __( 'Curve Styles', 'landkit-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'curve-1',
				'options' => [
					'curve-1'   => 'Curve-1',
					'curve-2'   => 'Curve-2',
					'curve-3'   => 'Curve-3',
					'curve-4'   => 'Curve-4',
				],
				'condition' => [
					'show_curves' => 'yes',
				],
			]
		);

		$widget->add_control(
			'curves_color',
			[
				'label' => __( 'Curve Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table-skin__curve' => 'color: {{VALUE}}',
				],
				'default' => '#ffffff',
			]
		);

		$widget->end_controls_section();
	}

	public function get_id() {
		return 'lk-price-table-image-box';
	}

	public function get_title() {
		return esc_html__( 'Image Box', 'landkit-elementor' );
	}

	public function render() {
		$widget   = $this->parent;
		$settings = $widget->get_settings();

		$symbol = '';

		if ( ! empty( $settings['skin_currency_symbol'] ) ) {
			if ( 'custom' !== $settings['skin_currency_symbol'] ) {
				$symbol = $widget->get_currency_symbol( $settings['skin_currency_symbol'] );
			} else {
				$symbol = $settings['currency_symbol_custom'];
			}
		}

		$widget->add_render_attribute( 'skin_title', 'class', 'lk-elementor-price-table-skin__title' );
		$widget->add_inline_editing_attributes( 'skin_title' );

		$widget->add_render_attribute( 'skin_description', 'class', 'lk-elementor-price-table-skin__description' );
		$widget->add_inline_editing_attributes( 'skin_description' );

		$widget->add_render_attribute( 'skin_link', 'class', 'lk-elementor-price-table-skin__link font-weight-bold text-decoration-none' );
		if ( ! empty( $settings['skin_link']['url'] ) ) {
			$widget->add_link_attributes( 'skin_link', $settings['skin_link'] );
		}

		$migration_allowed = Icons_Manager::is_migration_allowed();
		$skin_link_icon_migrated = isset( $settings['__fa4_migrated']['skin_link_selected_icon'] );
		$is_new_skin_link_icon = empty( $settings['skin_link_icon'] ) && $migration_allowed;

		$widget->add_render_attribute( 'card', 'class', [ 'card', 'shadow-light-lg', 'lift', 'lift-lg' ] );

		if ( ! empty( $settings['image']['url'] ) ) {
			$widget->add_render_attribute( 'card', 'class', 'overflow-hidden' );
		}

		if ( ! empty( $settings['card_classes'] ) ) {
			$widget->add_render_attribute( 'card', 'class', $settings['card_classes'] );
		}

		?>
		<div <?php echo $widget->get_render_attribute_string( 'card' ); ?>>
			<?php if ( ! empty( $settings['image']['url'] ) ): ?>
				<!-- Image -->
				<img class="card-img-top lk-elementor-price-table-skin__image" alt="<?php echo esc_attr( $settings['image']['id'] ); ?>" src=<?php echo $settings['image']['url'] ?>>
			<?php endif ?>

			<?php if ( $settings['show_curves'] == 'yes' ): ?>
				<!-- Shape -->
				<div class="position-relative">
					<?php
						switch ( $settings['curves_styles'] ) {
							case 'curve-1':
								?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-price-table-skin__curve">
									<?php require get_theme_file_path( 'assets/img/shapes/curves/curve-1.svg' ); ?>
								</div><?php
							break;
							case 'curve-2':
								?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-price-table-skin__curve">
									<?php require get_theme_file_path( 'assets/img/shapes/curves/curve-2.svg' ); ?>
								</div><?php
							break;
							case 'curve-3':
								?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-price-table-skin__curve">
									<?php require get_theme_file_path( 'assets/img/shapes/curves/curve-3.svg' ); ?>
								</div><?php
							break;
							case 'curve-4':
								?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-price-table-skin__curve">
									<?php require get_theme_file_path( 'assets/img/shapes/curves/curve-4.svg' ); ?>
								</div><?php
							break;
						}
					?>
				</div>
			<?php endif; ?>

			<!-- Body -->
			<div class="card-body position-relative">
				<!-- Badge -->
				<?php if ( ! empty( $symbol ) || ! empty( $settings['skin_price_text'] ) ): ?>
					<div class="position-relative text-right mt-n8 mr-n4 mb-3">
						<span class="lk-elementor-price-table-skin__price h6 text-uppercase mb-0 badge <?php echo esc_attr( $settings[ 'skin_price_size' ] == 'lg' ? 'badge-lg ' : '' ); ?>badge-pill badge-<?php echo esc_attr( $settings[ 'skin_price_predefined_color' ] ); ?>">
							<span class="lk-elementor-price-table-skin__currency"><?php echo $symbol; ?></span><?php echo $settings['skin_price_text']; ?>
						</span>
					</div>
				<?php endif; ?>
					
				<?php if ( ! empty( $settings['skin_title'] ) ): ?>
					<!-- Heading -->
					<<?php echo $settings['skin_title_tag'] . ' ' . $widget->get_render_attribute_string( 'skin_title' ); ?>><?php echo $settings['skin_title'] . '</' . $settings['skin_title_tag']; ?>>
				<?php endif; ?>

				<?php if ( ! empty( $settings['skin_description'] ) ): ?>
					<!-- Text -->
					<p <?php echo $widget->get_render_attribute_string( 'skin_description' ); ?>><?php echo $settings['skin_description']; ?></p>
				<?php endif; ?>

				<?php if ( ! empty( $settings['skin_link_text'] ) ): ?>
					<!-- Link -->
					<a <?php echo $widget->get_render_attribute_string( 'skin_link' ); ?>>
						<?php echo $settings['skin_link_text']; ?>
						<?php if ( ! empty( $settings['skin_link_icon'] ) || ! empty( $settings['skin_link_selected_icon']['value'] ) ) : ?>
							<?php if ( $is_new_skin_link_icon || $skin_link_icon_migrated ) :
								Icons_Manager::render_icon( $settings['skin_link_selected_icon'], [ 'aria-hidden' => 'true', 'class' => 'ml-3' ] );
							else : ?>
								<i class="<?php echo esc_attr( $settings['skin_link_icon'] ); ?> ml-3" aria-hidden="true"></i>
							<?php endif; ?>
						<?php endif; ?>
					</a>
				<?php endif; ?>
			</div>
		</div><?php
	}

	public function skin_print_template( $content, $widget ) {
		if( 'lk-price-table' == $widget->get_name() ) {
			return '';
		}
		return $content;
	}
}