<?php
namespace LandkitElementor\Modules\PriceTable\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Schemes;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use LandkitElementor\Modules\PriceTable\Skins;
use LandkitElementor\Base\Base_Widget;

if ( ! defined( 'ABSPATH' ) ) {
exit; // Exit if accessed directly
}

class Price_Switcher extends Base_Widget {

	public function get_name() {
		return 'lk-price-switcher';
	}

	/**
	* Get widget title.
	*
	* Retrieve button widget title.
	*
	* @since 1.0.0
	* @access public
	*
	* @return string Widget title.
	*/
	public function get_title() {
		return __( 'Price Switcher', 'landkit-elementor' );
	}

	/**
	* Get widget icon.
	*
	* Retrieve button widget icon.
	*
	* @since 1.0.0
	* @access public
	*
	* @return string Widget icon.
	*/
	public function get_icon() {
		return 'eicon-meta-data';
	}

	/**
	* Get widget keywords.
	*
	* Retrieve the list of keywords the widget belongs to.
	*
	* @since 2.1.0
	* @access public
	*
	* @return array Widget keywords.
	*/
	public function get_keywords() {
		return [ 'pricing', 'switcher' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_step', [
				'label' => esc_html__( 'Step', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'form_css',
			[
				'label'     => esc_html__( 'Form CSS Class', 'landkit-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'title'     => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
				'default'   => 'mb-7 mb-md-9',
			]
		);

		$this->add_control(
			'text_css',
			[
				'label'     => esc_html__( 'Text CSS Class', 'landkit-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'title'     => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
				'default'   => 'text-muted',
			]
		);

		$this->add_control(
			'left_label',
			[
				'label'     => esc_html__( 'Left Label', 'landkit-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'title'     => esc_html__( 'Add Your Left Label Here', 'landkit-elementor' ),
				'default'   => 'Annual',
			]
		);

		$this->add_control(
			'right_label',
			[
				'label'     => esc_html__( 'Right Label', 'landkit-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'title'     => esc_html__( 'Add Your Right Label Here', 'landkit-elementor' ),
				'default'   => 'Monthly',
			]
		);
		$this->add_control(
			'data_target',
			[
				'label'     => esc_html__( 'Data Target', 'landkit-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'title'     => esc_html__( 'Add your data target for Switch with the dot. e.g: .price', 'landkit-elementor' ),
				'default'   => '.price',
			]
		);
		$this->end_controls_section();
	}

	/**
	* Render Price Table widget output on the frontend.
	*
	* Written in PHP and used to generate the final HTML.
	*
	* @since 1.0.0
	* @access protected
	*/
	protected function render() { 

		$settings    = $this->get_settings();
		$text_css    = $settings[ 'text_css' ];
		$form_css    = $settings[ 'form_css' ];
		$left_label  = $settings[ 'left_label' ];
		$right_label = $settings[ 'right_label' ];
		$data_target = $settings[ 'data_target' ];

		$this->add_render_attribute( 'form_css', 'class', $form_css );

		if ( $form_css != '' ) {
			$this->add_render_attribute( 'form_css', 'class', $form_css );
		} 

		$this->add_render_attribute( 'text_css', 'class', 'text__css' );

		if ( $text_css != '' ) {
			$this->add_render_attribute( 'text_css', 'class', $text_css );
		} ?>

		<form class="d-flex form__css align-items-center justify-content-center">
			<!-- Label -->
			<span <?php echo $this->get_render_attribute_string( 'text_css' ); ?>>
				<?php echo $left_label; ?>
			</span>
			<!-- Switch -->
			<div class="mx-3 switch__css custom-control custom-switch">
				<input type="checkbox" class="custom-control-input" id="billingSwitch" data-toggle="price" data-target="<?php echo $data_target; ?>">
				<label class="custom-control-label" for="billingSwitch"></label>
			</div>
			<!-- Label -->
			<span <?php echo $this->get_render_attribute_string( 'text_css' ); ?>>
				<?php echo $right_label; ?>
			</span>
		</form>
	<?php }
}