<?php
namespace LandkitElementor\Modules\PriceTable\Widgets;

use Elementor\Controls_Manager;
// use Elementor\Core\Schemes;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use LandkitElementor\Modules\PriceTable\Skins;
use LandkitElementor\Base\Base_Widget;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Price_Table extends Base_Widget {
	
	protected function register_skins() {
		$this->add_skin( new Skins\Skin_Box( $this ) );
		$this->add_skin( new Skins\Skin_Image_Box( $this ) );
	}

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'lk-price-table';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Price Table', 'landkit-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-price-table';
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 2.1.0
	 * @access public
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return [ 'pricing', 'table' ];
	}

	protected function register_controls() {
		// Content Tab
		$this->pricing_table_general_controls_content_tab();
		$this->pricing_table_heading_controls_content_tab();
		$this->pricing_table_price_controls_content_tab();
		$this->pricing_table_description_controls_content_tab();
		$this->pricing_table_features_controls_content_tab();
		$this->pricing_table_button_controls_content_tab();

		// Style Tab
		$this->pricing_table_heading_controls_style_tab();
		$this->pricing_table_price_controls_style_tab();
		$this->pricing_table_description_controls_style_tab();
		$this->pricing_table_features_controls_style_tab();
		$this->pricing_table_button_controls_style_tab();

		$this->pricing_table_skins_add_controls();
	}

	public function pricing_table_skins_add_controls() {
		$this->start_controls_section(
			'section_skin_pricing',
			[
				'label' => __( 'Pricing', 'landkit-elementor' ),
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_currency_symbol',
			[
				'label' => __( 'Currency Symbol', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => __( 'None', 'landkit-elementor' ),
					'dollar' => '&#36; ' . _x( 'Dollar', 'Currency Symbol', 'landkit-elementor' ),
					'euro' => '&#128; ' . _x( 'Euro', 'Currency Symbol', 'landkit-elementor' ),
					'baht' => '&#3647; ' . _x( 'Baht', 'Currency Symbol', 'landkit-elementor' ),
					'franc' => '&#8355; ' . _x( 'Franc', 'Currency Symbol', 'landkit-elementor' ),
					'guilder' => '&fnof; ' . _x( 'Guilder', 'Currency Symbol', 'landkit-elementor' ),
					'krona' => 'kr ' . _x( 'Krona', 'Currency Symbol', 'landkit-elementor' ),
					'lira' => '&#8356; ' . _x( 'Lira', 'Currency Symbol', 'landkit-elementor' ),
					'peseta' => '&#8359 ' . _x( 'Peseta', 'Currency Symbol', 'landkit-elementor' ),
					'peso' => '&#8369; ' . _x( 'Peso', 'Currency Symbol', 'landkit-elementor' ),
					'pound' => '&#163; ' . _x( 'Pound Sterling', 'Currency Symbol', 'landkit-elementor' ),
					'real' => 'R$ ' . _x( 'Real', 'Currency Symbol', 'landkit-elementor' ),
					'ruble' => '&#8381; ' . _x( 'Ruble', 'Currency Symbol', 'landkit-elementor' ),
					'rupee' => '&#8360; ' . _x( 'Rupee', 'Currency Symbol', 'landkit-elementor' ),
					'indian_rupee' => '&#8377; ' . _x( 'Rupee (Indian)', 'Currency Symbol', 'landkit-elementor' ),
					'shekel' => '&#8362; ' . _x( 'Shekel', 'Currency Symbol', 'landkit-elementor' ),
					'yen' => '&#165; ' . _x( 'Yen/Yuan', 'Currency Symbol', 'landkit-elementor' ),
					'won' => '&#8361; ' . _x( 'Won', 'Currency Symbol', 'landkit-elementor' ),
					'custom' => __( 'Custom', 'landkit-elementor' ),
				],
				'default' => 'dollar',
			]
		);

		$this->add_control(
			'skin_price_text',
			[
				'label' => __( 'Price', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '29/mo', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'skin_price_size',
			[
				'label' => __( 'Price Size', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'default' => 'Default',
					'lg'      => 'Large',
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'skin_price_predefined_color',
			[
				'label' => __( 'Price Color', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'primary'       => 'Primary',
					'secondary'     => 'Secondary',
					'success'       => 'Success',
					'danger'        => 'Danger',
					'warning'       => 'Warning',
					'info'          => 'Info',
					'light'         => 'Light',
					'dark'          => 'Dark',
					'primary-desat' => 'Primary Desat',
				],
				'default' => 'primary-desat',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skin_section_price_style',
			[
				'label' => __( 'Price', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_price_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table-skin__price' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'skin_price_backgroundcolor',
			[
				'label' => __( 'Background Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table-skin__price' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'skin_price_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table-skin__price',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skin_section_title',
			[
				'label' => __( 'Title', 'landkit-elementor' ),
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_title',
			[
				'label' => __( 'Title', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Shared Coworking', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'skin_title_tag',
			[
				'label' => __( 'Title HTML Tag', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h2'   => 'H2',
					'h3'   => 'H3',
					'h4'   => 'H4',
					'h5'   => 'H5',
					'h6'   => 'H6',
					'span' => 'SPAN',
				],
				'default' => 'h4',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skin_section_title_style',
			[
				'label' => __( 'Title', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_title_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table-skin__title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'skin_title_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table-skin__title',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skin_section_description',
			[
				'label' => __( 'Description', 'landkit-elementor' ),
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_description',
			[
				'label' => __( 'Description', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 10,
				'default' => __( 'Affordable, scalable and performant. The perfect solution for small apps.', 'landkit-elementor' ),
				'placeholder' => __( 'Type your description here', 'landkit-elementor' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skin_section_description_style',
			[
				'label' => __( 'Description', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_description_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table-skin__description' => 'color: {{VALUE}}',
				],
				'default' => '#869AB8',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'skin_description_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table-skin__description',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'skin_section_link',
			[
				'label' => __( 'Link', 'landkit-elementor' ),
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_link_text',
			[
				'label' => __( 'Link Text', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Start a 30-day trial', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'skin_link',
			[
				'label' => __( 'Link', 'landkit-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'landkit-elementor' ),
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_control(
			'skin_link_selected_icon',
			[
				'label' => __( 'Icon', 'landkit-elementor' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'skin_link_icon',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'skin_section_link_style',
			[
				'label' => __( 'Link', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'skin_link_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table-skin__link' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'skin_link_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table-skin__link',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();
	}

	public function pricing_table_general_controls_content_tab() {

		// General Content Tab Start
		$this->start_controls_section(
			'section_general',
			[
				'label' => __( 'General', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'pricing_box_border_radius',
			[
				'label' => __( 'Pricing Border Radius', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					''           => __( 'Default', 'landkit-elementor' ),
					'rounded-0'  => __( 'Rounded 0', 'landkit-elementor' ),
					'rounded-lg' => __( 'Rounded Lg', 'landkit-elementor' ),
				],
				'default' => 'rounded-lg',
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'show_price',
			[
				'label' => __( 'Show Price ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => __( 'Enable to display price.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'show_features',
			[
				'label' => __( 'Show Features ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => __( 'Enable to display features.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'show_description',
			[
				'label' => __( 'Show Description ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => false,
				'description' => __( 'Enable to display description.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'show_button',
			[
				'label' => __( 'Show Button ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => __( 'Enable to display button.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'enable_border_top',
			[
				'label' => __( 'Border Top ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => false,
				'description' => __( 'Enable to add border in top.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'border_top_color',
			[
				'label' => __( 'Border Top Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table' => 'border-top-color: {{VALUE}};',
				],
				'condition' => [
					'enable_border_top' => 'yes',
				],
				'default' => '#42ba96',
			]
		);

		$this->add_control(
			'enable_around_padding',
			[
				'label' => __( 'Pricing Padding Around ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => false,
				'description' => __( 'Enable to add padding around card.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'card_classes',
			[
				'label' => __( 'CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'title' => __( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);

		// General Content Tab End
		$this->end_controls_section();
	}

	public function pricing_table_heading_controls_content_tab() {

		// Heading Content Tab Start
		$this->start_controls_section(
			'section_header',
			[
				'label' => __( 'Heading', 'landkit-elementor' ),
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'enable_badge',
			[
				'label' => __( 'Badge ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => __( 'Enable to add text as badge.', 'landkit-elementor' ),
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => __( 'Heading', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Standard', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'heading_tag',
			[
				'label' => __( 'Heading HTML Tag', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h2'   => 'H2',
					'h3'   => 'H3',
					'h4'   => 'H4',
					'h5'   => 'H5',
					'h6'   => 'H6',
					'span' => 'SPAN',
				],
				'default' => 'span',
			]
		);

		$this->add_control(
			'heading_size',
			[
				'label' => __( 'Heading Size', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'default' => 'Default',
					'lg'      => 'Large',
				],
				'default' => 'default',
				'condition' => [
					'enable_badge' => 'yes',
				],
			]
		);

		$this->add_control(
			'heading_predefined_color',
			[
				'label' => __( 'Heading Color', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'primary'   => 'Primary',
					'secondary' => 'Secondary',
					'success'   => 'Success',
					'danger'    => 'Danger',
					'warning'   => 'Warning',
					'info'      => 'Info',
					'light'     => 'Light',
					'dark'      => 'Dark',
				],
				'default' => 'primary',
				'condition' => [
					'enable_badge' => 'yes',
				],
			]
		);

		$this->add_control(
			'heading_bg_soft',
			[
				'label' => __( 'Heading Soft Background ?', 'landkit-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => __( 'Enable to make soft background color for heading.', 'landkit-elementor' ),
				'frontend_available' => true,
				'condition' => [
					'enable_badge' => 'yes',
				],
			]
		);

		// Heading Content Tab End
		$this->end_controls_section();
	}

	public function pricing_table_price_controls_content_tab() {

		// Pricing Content Tab Start
		$this->start_controls_section(
			'section_pricing',
			[
				'label' => __( 'Pricing', 'landkit-elementor' ),
				'condition' => [ 
					'show_price' => 'yes',
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'currency_symbol',
			[
				'label' => __( 'Currency Symbol', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => __( 'None', 'landkit-elementor' ),
					'dollar' => '&#36; ' . _x( 'Dollar', 'Currency Symbol', 'landkit-elementor' ),
					'euro' => '&#128; ' . _x( 'Euro', 'Currency Symbol', 'landkit-elementor' ),
					'baht' => '&#3647; ' . _x( 'Baht', 'Currency Symbol', 'landkit-elementor' ),
					'franc' => '&#8355; ' . _x( 'Franc', 'Currency Symbol', 'landkit-elementor' ),
					'guilder' => '&fnof; ' . _x( 'Guilder', 'Currency Symbol', 'landkit-elementor' ),
					'krona' => 'kr ' . _x( 'Krona', 'Currency Symbol', 'landkit-elementor' ),
					'lira' => '&#8356; ' . _x( 'Lira', 'Currency Symbol', 'landkit-elementor' ),
					'peseta' => '&#8359 ' . _x( 'Peseta', 'Currency Symbol', 'landkit-elementor' ),
					'peso' => '&#8369; ' . _x( 'Peso', 'Currency Symbol', 'landkit-elementor' ),
					'pound' => '&#163; ' . _x( 'Pound Sterling', 'Currency Symbol', 'landkit-elementor' ),
					'real' => 'R$ ' . _x( 'Real', 'Currency Symbol', 'landkit-elementor' ),
					'ruble' => '&#8381; ' . _x( 'Ruble', 'Currency Symbol', 'landkit-elementor' ),
					'rupee' => '&#8360; ' . _x( 'Rupee', 'Currency Symbol', 'landkit-elementor' ),
					'indian_rupee' => '&#8377; ' . _x( 'Rupee (Indian)', 'Currency Symbol', 'landkit-elementor' ),
					'shekel' => '&#8362; ' . _x( 'Shekel', 'Currency Symbol', 'landkit-elementor' ),
					'yen' => '&#165; ' . _x( 'Yen/Yuan', 'Currency Symbol', 'landkit-elementor' ),
					'won' => '&#8361; ' . _x( 'Won', 'Currency Symbol', 'landkit-elementor' ),
					'custom' => __( 'Custom', 'landkit-elementor' ),
				],
				'default' => 'dollar',
			]
		);

		$this->add_control(
			'currency_symbol_custom',
			[
				'label' => __( 'Custom Symbol', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'currency_symbol' => 'custom',
				],
			]
		);

		$this->add_control(
			'price',
			[
				'label' => __( 'Price', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '29',
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'annual_price',
			[
				'label' => __( 'Annual Price', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '49',
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'allowed_decimals',
			[
				'label' => __( 'Allowed Decimals', 'landkit-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 0,
			]
		);

		$this->add_control(
			'currency_format',
			[
				'label' => __( 'Currency Format', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => '1,234.56 (Default)',
					',' => '1.234,56',
				],
			]
		);

		$this->add_control(
			'period',
			[
				'label' => __( 'Period', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '/mo', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'price_subtext',
			[
				'label' => __( 'Price Subtext', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'per seat', 'landkit-elementor' ),
			]
		);

		// Pricing Content Tab End
		$this->end_controls_section();
	}

	public function pricing_table_description_controls_content_tab() {

		// Description Content Tab Start
		$this->start_controls_section(
			'section_description',
			[
				'label' => __( 'Description', 'landkit-elementor' ),
				'condition' => [ 
					'show_description' => 'yes',
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'pricing_box_description',
			[
				'label' => __( 'Description', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 10,
				'default' => __( 'We offer variable pricing with discounts for larger organizations. Get in touch with us and we’ll figure out something that works for everyone.', 'landkit-elementor' ),
				'placeholder' => __( 'Type your description here', 'landkit-elementor' ),
			]
		);

		// Description Content Tab End
		$this->end_controls_section();
	}

	public function pricing_table_features_controls_content_tab() {

		// Features Content Tab Start
		$this->start_controls_section(
			'section_features',
			[
				'label' => __( 'Features', 'landkit-elementor' ),
				'condition' => [ 
					'show_features' => 'yes',
					'_skin' => '',
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_text',
			[
				'label' => __( 'List Text', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'List Item', 'landkit-elementor' ),
			]
		);

		$default_icon = [
			'value' => 'fe fe-check',
			'library' => 'fa-regular',
		];

		$repeater->add_control(
			'selected_item_icon',
			[
				'label' => __( 'Icon', 'landkit-elementor' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'item_icon',
				'default' => $default_icon,
			]
		);

		$repeater->add_control(
			'item_icon_color',
			[
				'label' => __( 'Icon Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} i' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} svg' => 'fill: {{VALUE}}',
				],
			]
		);

		$repeater->add_control(
			'item_icon_background_color',
			[
				'label' => __( 'Icon Background Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .badge' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'features_list',
			[
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'item_text' => __( 'Rich, responsive landing pages', 'landkit-elementor' ),
						'selected_item_icon' => $default_icon,
					],
					[
						'item_text' => __( '100+ styled components', 'landkit-elementor' ),
						'selected_item_icon' => $default_icon,
					],
					[
						'item_text' => __( 'Flexible, simple license', 'landkit-elementor' ),
						'selected_item_icon' => $default_icon,
					],
					[
						'item_text' => __( 'Speedy build tooling', 'landkit-elementor' ),
						'selected_item_icon' => $default_icon,
					],
					[
						'item_text' => __( '6 months free support included', 'landkit-elementor' ),
						'selected_item_icon' => $default_icon,
					],
				],
				'title_field' => '{{{ item_text }}}',
			]
		);

		// Features Content Tab End
		$this->end_controls_section();
	}

	public function pricing_table_button_controls_content_tab() {

		// Button Content Tab Start
		$this->start_controls_section(
			'section_button',
			[
				'label' => __( 'Button', 'landkit-elementor' ),
				'condition' => [
					'_skin' => '',
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Get it now', 'landkit-elementor' ),
				'placeholder' => __( 'Click here', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'landkit-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'landkit-elementor' ),
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_control(
			'button_type',
			[
				'label'   => __( 'Type', 'landkit-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'primary',
				'options' => [
					'primary'           => __( 'Primary', 'landkit-elementor' ),
					'secondary'         => __( 'Secondary', 'landkit-elementor' ),
					'success'           => __( 'Success', 'landkit-elementor' ),
					'danger'            => __( 'Danger', 'landkit-elementor' ),
					'warning'           => __( 'Warning', 'landkit-elementor' ),
					'info'              => __( 'Info', 'landkit-elementor' ),
					'light'             => __( 'Light', 'landkit-elementor' ),
					'dark'              => __( 'Dark', 'landkit-elementor' ),
					'link'              => __( 'Link', 'landkit-elementor' ),
					'outline-primary'   => __( 'Primary outline', 'landkit-elementor' ),
					'outline-secondary' => __( 'Secondary outline', 'landkit-elementor' ),
					'outline-success'   => __( 'Success outline', 'landkit-elementor' ),
					'outline-danger'    => __( 'Danger outline', 'landkit-elementor' ),
					'outline-warning'   => __( 'Warning outline', 'landkit-elementor' ),
					'outline-info'      => __( 'Info outline', 'landkit-elementor' ),
					'outline-light'     => __( 'Light outline', 'landkit-elementor' ),
					'outline-dark'      => __( 'Dark outline', 'landkit-elementor' ),
					'primary-soft'      => __( 'Primary soft', 'landkit-elementor' ),
					'secondary-soft'    => __( 'Secondary soft', 'landkit-elementor' ),
					'success-soft'      => __( 'Success soft', 'landkit-elementor' ),
					'danger-soft'       => __( 'Danger soft', 'landkit-elementor' ),
					'warning-soft'      => __( 'Warning soft', 'landkit-elementor' ),
					'info-soft'         => __( 'Info soft', 'landkit-elementor' ),
				],
			]
		);

		$this->add_control(
			'button_size',
			[
				'label'          => __( 'Size', 'landkit-elementor' ),
				'type'           => Controls_Manager::SELECT,
				'options'        => [
					'xs' => __( 'Extra Small', 'landkit-elementor' ),
					'sm' => __( 'Small', 'landkit-elementor' ),
					''   => __( 'Base', 'landkit-elementor' ),
					'lg' => __( 'Large', 'landkit-elementor' ),
				],
				'style_transfer' => true,
				'default'        => 'lg',
			]
		);

		$this->add_control(
			'button_radius',
			[
				'label'          => __( 'Border Radius', 'landkit-elementor' ),
				'type'           => Controls_Manager::SELECT,
				'options'        => [
					''          => __( 'Normal', 'landkit-elementor' ),
					'pill'      => __( 'Pill', 'landkit-elementor' ),
					'rounded-0' => __( 'Rounded 0', 'landkit-elementor' ),
					'card-btn'  => __( 'Card Btn', 'landkit-elementor' ),
				],
				'default'        => 'card-btn',
				'style_transfer' => true,
			]
		);

		$this->add_control(
			'button_selected_icon',
			[
				'label' => __( 'Icon', 'landkit-elementor' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'button_icon',
			]
		);

		$this->add_control(
			'button_css_id',
			[
				'label' => __( 'Button ID', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'title' => __( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'landkit-elementor' ),
				'description' => __( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'landkit-elementor' ),
				'separator' => 'before',
			]
		);

		// Button Content Tab End
		$this->end_controls_section();
	}

	public function pricing_table_heading_controls_style_tab() {

		// Heading Style Tab Start
		$this->start_controls_section(
			'section_header_style',
			[
				'label' => __( 'Heading', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [
					'_skin' => '',
				],
			]
		);

		$this->add_responsive_control(
			'header_padding',
			[
				'label' => __( 'Padding', 'landkit-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__heading-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'enable_badge' => 'yes',
				],
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__heading' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'heading_background_color',
			[
				'label' => __( 'Background Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__heading-container' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'enable_badge' => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'heading_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__heading',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'heading_classes',
			[
				'label' => __( 'CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'title' => __( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);

 		// Heading Style Tab End
		$this->end_controls_section();
	}

	public function pricing_table_price_controls_style_tab() {

		// Pricing Style Tab Start
		$this->start_controls_section(
			'section_pricing_element_style',
			[
				'label' => __( 'Pricing', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [ 
					'show_price' => 'yes' ,
					'_skin' => '',
				],
			]
		);

		$this->add_responsive_control(
			'pricing_element_padding',
			[
				'label' => __( 'Padding', 'landkit-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'price_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__currency, {{WRAPPER}} .lk-elementor-price-table__integer-part, {{WRAPPER}} .lk-elementor-price-table__fractional-part' => 'color: {{VALUE}}',
				],
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'price_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__price',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'heading_currency_style',
			[
				'label' => __( 'Currency Symbol', 'landkit-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'currency_symbol!' => '',
				],
			]
		);

		$this->add_control(
			'currency_position',
			[
				'label' => __( 'Position', 'landkit-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'default' => 'before',
				'options' => [
					'before' => [
						'title' => __( 'Before', 'landkit-elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'after' => [
						'title' => __( 'After', 'landkit-elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
			]
		);

		$this->add_control(
			'currency_vertical_position',
			[
				'label' => __( 'Vertical Position', 'landkit-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => __( 'Top', 'landkit-elementor' ),
						'icon' => 'eicon-v-align-top',
					],
					'middle' => [
						'title' => __( 'Middle', 'landkit-elementor' ),
						'icon' => 'eicon-v-align-middle',
					],
					'bottom' => [
						'title' => __( 'Bottom', 'landkit-elementor' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'default' => 'top',
				'selectors_dictionary' => [
					'top' => 'flex-start',
					'middle' => 'center',
					'bottom' => 'flex-end',
				],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__currency' => 'align-self: {{VALUE}}',
				],
				'condition' => [
					'currency_symbol!' => '',
				],
			]
		);

		$this->add_control(
			'fractional_part_style',
			[
				'label' => __( 'Fractional Part', 'landkit-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'fractional_part_size',
			[
				'label' => __( 'Size', 'landkit-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__fractional-part' => 'font-size: calc({{SIZE}}em/100)',
				],
			]
		);

		$this->add_control(
			'heading_period_style',
			[
				'label' => __( 'Period', 'landkit-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_control(
			'period_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__period' => 'color: {{VALUE}}',
				],
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'period_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__period',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_2,
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_control(
			'period_position',
			[
				'label' => __( 'Position', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => false,
				'options' => [
					'below' => __( 'Below', 'landkit-elementor' ),
					'beside' => __( 'Beside', 'landkit-elementor' ),
				],
				'default' => 'beside',
				'condition' => [
					'period!' => '',
				],
			]
		);

		$this->add_control(
			'heading_price_subtext_style',
			[
				'label' => __( 'Price Subtext', 'landkit-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'price_subtext!' => '',
				],
			]
		);

		$this->add_control(
			'price_subtext_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__subtext' => 'color: {{VALUE}}',
				],
				'condition' => [
					'price_subtext!' => '',
				],
				'default' => '#869AB8',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'price_subtext_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__subtext',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_2,
				'condition' => [
					'price_subtext!' => '',
				],
			]
		);

     $this->add_control(
			'pricing_classes',
			[
				'label' => __( 'CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'title' => __( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);


		// Pricing Style Tab End
		$this->end_controls_section();
	}

	public function pricing_table_description_controls_style_tab() {

		// Description Style Tab Start
		$this->start_controls_section(
			'section_description_style',
			[
				'label' => __( 'Description', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [ 
					'show_description' => 'yes',
					'_skin' => '',
				],
			]
		);

		$this->add_control(
			'pricing_box_description_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__description' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'pricing_box_description',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__description',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_2,
			]
		);

		// Description Style Tab End
		$this->end_controls_section();
	}		

	public function pricing_table_features_controls_style_tab() {

		// Features Style Tab Start
		$this->start_controls_section(
			'section_features_list_style',
			[
				'label' => __( 'Features', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'show_label' => false,
				'condition' => [ 
					'show_features' => 'yes',
					'_skin' => '',
				],
			]
		);

		$this->add_responsive_control(
			'features_list_padding',
			[
				'label' => __( 'Padding', 'landkit-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__features-list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'features_list_color',
			[
				'label' => __( 'Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'separator' => 'before',
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__features-list' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'features_list_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__features-list .lk-list-item',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_3,
			]
		);

		$this->add_control(
			'features_list_alignment',
			[
				'label' => __( 'Alignment', 'landkit-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => __( 'Left', 'landkit-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'landkit-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => __( 'Right', 'landkit-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__features-list .lk-list-item' => 'justify-content: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'item_width',
			[
				'label' => __( 'Width', 'landkit-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'%' => [
						'min' => 25,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__features-list' => 'margin-left: calc((100% - {{SIZE}}%)/2); margin-right: calc((100% - {{SIZE}}%)/2)',
				],
			]
		);
        
        $this->add_control(
			'features_classes',
			[
				'label' => __( 'CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'title' => __( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);


		// Features Style Tab End
		$this->end_controls_section();
	}

	public function pricing_table_button_controls_style_tab() {

		// Button Style Tab Start
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => __( 'Button', 'landkit-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'_skin' => '',
					'show_button' => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				// 'scheme' => Schemes\Typography::TYPOGRAPHY_4,
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__button',
			]
		);

		 $this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Text Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__button' => 'fill: {{VALUE}}; color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Background Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'button_text_hover_color',
			[
				'label' => __( 'Text Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__button:hover, {{WRAPPER}} .lk-elementor-price-table__button:focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} .lk-elementor-price-table__button:hover svg, {{WRAPPER}} .lk-elementor-price-table__button:focus svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_hover_color',
			[
				'label' => __( 'Background Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__button:hover, {{WRAPPER}} .lk-elementor-price-table__button:focus' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'hover_animation',
			[
				'label' => __( 'Hover Animation', 'landkit-elementor' ),
				'type' => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Border Radius', 'landkit-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .lk-elementor-price-table__button',
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' => __( 'Padding', 'landkit-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-price-table__button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_classes',
			[
				'label' => __( 'Button CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'title' => __( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);

		// Button Style Tab End
		$this->end_controls_section();
	}

	public function render_currency_symbol( $symbol, $location ) {
		$currency_position = $this->get_settings( 'currency_position' );
		$location_setting = ! empty( $currency_position ) ? $currency_position : 'before';
		if ( ! empty( $symbol ) && $location === $location_setting ) {
			echo '<span class="lk-elementor-price-table__currency lk-elementor-currency--' . $location . ' h2 mb-0 mt-2">' . $symbol . '</span>';
		}
	}

	public function get_currency_symbol( $symbol_name ) {
		$symbols = [
			'dollar' => '&#36;',
			'euro' => '&#128;',
			'franc' => '&#8355;',
			'pound' => '&#163;',
			'ruble' => '&#8381;',
			'shekel' => '&#8362;',
			'baht' => '&#3647;',
			'yen' => '&#165;',
			'won' => '&#8361;',
			'guilder' => '&fnof;',
			'peso' => '&#8369;',
			'peseta' => '&#8359',
			'lira' => '&#8356;',
			'rupee' => '&#8360;',
			'indian_rupee' => '&#8377;',
			'real' => 'R$',
			'krona' => 'kr',
		];

		return isset( $symbols[ $symbol_name ] ) ? $symbols[ $symbol_name ] : '';
	}

	/**
	 * Render Price Table widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$symbol = '';

		if ( ! empty( $settings['currency_symbol'] ) ) {
			if ( 'custom' !== $settings['currency_symbol'] ) {
				$symbol = $this->get_currency_symbol( $settings['currency_symbol'] );
			} else {
				$symbol = $settings['currency_symbol_custom'];
			}
		}
		$currency_format = empty( $settings['currency_format'] ) ? '.' : $settings['currency_format'];
		
		if ( ! empty( $settings['annual_price'] ) ) {
			$price = explode( $currency_format, $settings['annual_price'] );
		} else {
			if ( 'yes' === $settings['show_price'] ) {
				$price = explode( $currency_format, $settings['price'] );
			}
			
		}

		if ( 'yes' === $settings['show_price'] ) {
			$intpart = $price[0];
			$fraction = '';
			if ( 2 === count( $price ) ) {
				$fraction = $price[1];
			}
		}

		$this->add_render_attribute( 'button_text', 'class', [
			'lk-elementor-price-table__button',
			'btn',
			'btn-block',
		] );

		if ( ! empty( $settings['button_type'] ) ) {
			$this->add_render_attribute( 'button_text', 'class', 'btn-' . $settings['button_type'] );
		}

		if ( ! empty( $settings['button_radius'] ) ) {
			if ( $settings['button_radius'] == 'rounded-0' ) {
				$this->add_render_attribute( 'button_text', 'class', $settings['button_radius'] );
			} else if ( $settings['button_radius'] == 'card-btn' ) {
				$this->add_render_attribute( 'button_text', 'class', $settings['button_radius'] );
			} else {
				$this->add_render_attribute( 'button_text', 'class', 'btn-' . $settings['button_radius'] );
			}
		}

		if ( ! empty( $settings['button_size'] ) ) {
			$this->add_render_attribute( 'button_text', 'class', 'btn-' . $settings['button_size'] );
		}

		if ( $settings['hover_animation'] ) {
			$this->add_render_attribute( 'button_text', 'class', 'elementor-animation-' . $settings['hover_animation'] );
		}

		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'button_text', $settings['link'] );
		}

		if ( ! empty( $settings[ 'button_classes' ] ) ) {
			$this->add_render_attribute( 'button_text', 'class', $settings['button_classes'] );
		}

		if ( ! empty( $settings[ 'heading_classes' ] ) ) {
			$this->add_render_attribute( 'heading', 'class', $settings['heading_classes'] );
		}

		$this->add_render_attribute( 'heading', 'class', 'lk-elementor-price-table__heading h6 font-weight-bold text-uppercase' );
		$this->add_render_attribute( 'period', 'class', [ 'lk-elementor-price-table__period', 'lk-elementor-typo-excluded', 'h2', 'align-self-end', 'mb-1' ] );
		$this->add_render_attribute( 'price_subtext', 'class', [ 'lk-elementor-price-table__subtext text-center', $settings[ 'enable_around_padding' ] == 'yes' ? 'mb-5' : 'mb-6 mb-md-8' ] );
		$this->add_render_attribute( 'pricing_box_description', 'class', 'lk-elementor-price-table__description lead text-center text-muted mb-0 mb-md-10' );

		$this->add_inline_editing_attributes( 'heading' );
		$this->add_inline_editing_attributes( 'period' );
		$this->add_inline_editing_attributes( 'price_subtext' );
		$this->add_inline_editing_attributes( 'button_text' );
		$this->add_inline_editing_attributes( 'pricing_box_description' );

		$period_position = $settings['period_position'];
		$period_element = '<span ' . $this->get_render_attribute_string( 'period' ) . '>' . $settings['period'] . '</span>';
		$heading_tag = $settings['heading_tag'];

		$migration_allowed = Icons_Manager::is_migration_allowed();
		$button_icon_migrated = isset( $settings['__fa4_migrated']['button_selected_icon'] );
		$is_new_button_icon = empty( $settings['button_icon'] ) && $migration_allowed;

		// Pricing Table Header Content
		ob_start();
			if ( $settings[ 'enable_badge' ] == 'yes' ) {
				?><span class="lk-elementor-price-table__heading-container badge <?php echo esc_attr( $settings[ 'heading_size' ] == 'lg' ? 'badge-lg ' : '' ); ?>badge-pill badge-<?php echo esc_attr( $settings[ 'heading_predefined_color' ] ); echo esc_attr( $settings[ 'heading_bg_soft' ] ? '-soft' : '' ) ?>">
					<<?php echo $heading_tag . ' ' . $this->get_render_attribute_string( 'heading' ); ?>><?php echo $settings['heading'] . '</' . $heading_tag; ?>>
				</span><?php 
			} else {
				?><<?php echo $heading_tag . ' ' . $this->get_render_attribute_string( 'heading' ); ?>><?php echo $settings['heading'] . '</' . $heading_tag; ?>><?php
			}		
		$pricing_table_header_content = ob_get_clean();

		// Pricing Table Price Content
		ob_start();
			if ( $settings[ 'show_price' ] == 'yes' ): ?>
				<div class="lk-elementor-price-table__price <?php echo $settings[ 'pricing_classes' ];?>">
					<div class="lk-elementor-price-table__price-wrapper d-flex justify-content-center">
						<?php $this->render_currency_symbol( $symbol, 'before' ); ?>
						<?php if ( ! empty( $intpart ) || 0 <= $intpart ) : ?>
							<span class="lk-elementor-price-table__integer-part price display-2 mb-0" data-decimals="<?php echo esc_attr( $settings[ 'allowed_decimals' ] ); ?>" data-annual="<?php echo $settings[ 'annual_price' ];?>" data-monthly="<?php echo $settings[ 'price' ];?>"><?php echo $intpart; ?></span>
						<?php endif; ?>

						<?php if ( '' !== $fraction || ( ! empty( $settings['period'] ) && 'below' == $period_position ) ) : ?>
							<div class="lk-elementor-price-table__after-price d-flex">
								<?php if ( '' != $fraction ): ?>
									<span class="lk-elementor-price-table__fractional-part"><?php echo $fraction; ?></span>
								<?php endif ?>
								<?php if ( ! empty( $settings['period'] ) && 'below' == $period_position ) : ?>
									<?php echo $period_element; ?>
								<?php endif; ?>
							</div>
						<?php endif; ?>

						<?php $this->render_currency_symbol( $symbol, 'after' ); ?>

						<?php if ( ! empty( $settings['period'] ) && 'beside' == $period_position ) : ?>
							<?php echo $period_element; ?>
						<?php endif; ?>
					</div>
					<?php if ( ! empty( $settings['price_subtext'] ) ): ?>
						<p <?php echo $this->get_render_attribute_string( 'price_subtext' ); ?>><?php echo $settings['price_subtext']; ?></p>
					<?php endif; ?>
				</div>
			<?php endif;
		$pricing_table_price_content = ob_get_clean();

		// Pricing Table Description Content
		ob_start();
			if ( $settings[ 'show_description' ] == 'yes' && ! empty( $settings['pricing_box_description'] ) ): ?>
				<p <?php echo $this->get_render_attribute_string( 'pricing_box_description' ); ?>><?php echo $settings['pricing_box_description']; ?></p>
			<?php endif;
		$pricing_table_desciption_content = ob_get_clean();

		// Pricing Table Features Content
		ob_start();
			if ( ! empty( $settings['features_list'] ) && $settings[ 'show_features' ] == 'yes' ) : ?>
				<div class="lk-elementor-price-table__features-list <?php echo $settings[ 'features_classes' ];?>">
					<?php
					foreach ( $settings['features_list'] as $index => $item ) :
						$repeater_setting_key = $this->get_repeater_setting_key( 'item_text', 'features_list', $index );

						if ( count( $settings['features_list'] ) == $index + 1 ) {
							$this->add_render_attribute( $repeater_setting_key, [
								'class' => $settings[ 'enable_around_padding' ] == 'yes' ? 'mb-5' : 'mb-0',
							] );
						}

						$this->add_inline_editing_attributes( $repeater_setting_key );

						$migrated = isset( $item['__fa4_migrated']['selected_item_icon'] );
						// add old default
						if ( ! isset( $item['item_icon'] ) && ! $migration_allowed ) {
							$item['item_icon'] = 'fa fa-check-circle';
						}
						$is_new = ! isset( $item['item_icon'] ) && $migration_allowed;
						?>
						<div class="lk-list-item elementor-repeater-item-<?php echo $item['_id']; ?> d-flex">
							<?php if ( ! empty( $item['item_icon'] ) || ! empty( $item['selected_item_icon'] ) ) : ?>
								<div class="badge badge-rounded-circle badge-success-soft mt-1 mr-4">
									<?php if ( $is_new || $migrated ) :
										Icons_Manager::render_icon( $item['selected_item_icon'], [ 'aria-hidden' => 'true' ] );
									else : ?>
										<i class="<?php echo esc_attr( $item['item_icon'] ); ?>" aria-hidden="true"></i>
									<?php endif; ?>
								</div>
							<?php endif; ?>
							<?php if ( ! empty( $item['item_text'] ) ) : ?>
								<p <?php echo $this->get_render_attribute_string( $repeater_setting_key ); ?>><?php echo $item['item_text']; ?></p>
							<?php else :
								echo '&nbsp;';
							endif; ?>
						</div>
					<?php endforeach; ?>
				</div>
			<?php endif;
		$pricing_table_features_content = ob_get_clean();

		// Pricing Table Button Content
		ob_start();
			if ( ! empty( $settings['button_text'] ) && $settings[ 'show_button' ] === 'yes' ) : ?>
				<a <?php if ( $settings[ 'button_css_id' ] ): ?>id="<?php echo esc_attr( $settings[ 'button_css_id' ] ); ?>"<?php endif; ?> <?php echo $this->get_render_attribute_string( 'button_text' ); ?>>		
					<?php echo $settings['button_text']; ?>
					<?php if ( ! empty( $settings['button_icon'] ) || ! empty( $settings['button_selected_icon']['value'] ) ) : ?>
						<?php if ( $is_new_button_icon || $button_icon_migrated ) :
							Icons_Manager::render_icon( $settings['button_selected_icon'], [ 'aria-hidden' => 'true', 'class' => 'ml-3' ] );
						else : ?>
							<i class="<?php echo esc_attr( $settings['button_icon'] ); ?> ml-3" aria-hidden="true"></i>
						<?php endif; ?>
					<?php endif; ?>
				</a>
			<?php endif;
		$pricing_table_button_content = ob_get_clean();

		if ( ! empty( $settings[ 'card_classes' ] ) ) {
			$this->add_render_attribute( 'pricing_table_card_wrapper', 'class', $settings['card_classes'] );
		}

		$this->add_render_attribute( 'pricing_table_card_wrapper', 'class', [ 
			'lk-elementor-price-table', 
			'card',
			$settings[ 'pricing_box_border_radius' ]
		] );

		if ( $settings[ 'enable_border_top' ] == 'yes' ) {
			$this->add_render_attribute( 'pricing_table_card_wrapper', 'class', [ 
				'card-border',
				'card-border-xl',
				'shadow-light-lg',
				'lift',
				'lift-lg',
			] );
		} else {
			$this->add_render_attribute( 'pricing_table_card_wrapper', 'class', 'shadow-lg' );
		}

		?>
		<div <?php echo $this->get_render_attribute_string( 'pricing_table_card_wrapper' ); ?>>
			<?php if ( $settings[ 'enable_around_padding' ] == 'yes' || $settings[ 'enable_border_top' ] == 'yes' ): ?>
				<div class="card-body"><?php 
					if ( $settings['heading'] && ! empty( $settings['heading'] ) ): ?>
						<div class="text-center <?php echo esc_attr( $settings[ 'enable_border_top' ] == 'yes' ? 'mb-5' : 'mb-3' ); ?>">
							<?php echo wp_kses_post( $pricing_table_header_content ); ?>
						</div><?php 
					endif; 
					echo wp_kses_post( $pricing_table_price_content );
					echo wp_kses_post( $pricing_table_desciption_content );
					echo wp_kses_post( $pricing_table_features_content ); 
					echo wp_kses_post( $pricing_table_button_content ); ?>
				</div><?php 
			else: ?>
				<div class="card-body py-6 py-md-8">
					<div class="row justify-content-center">
						<div class="col-12 col-xl-<?php echo esc_attr( $settings[ 'show_description' ] == 'yes' ? '10' : '9' ); ?>"><?php 
							if ( $settings['heading'] && ! empty( $settings['heading'] ) ): ?>
								<div class="text-center <?php echo esc_attr( ( $settings[ 'show_description' ] == 'yes' && $settings[ 'show_price' ] != 'yes' ) ? 'mb-8 mb-md-11' : 'mb-5' ); ?>">
									<?php echo wp_kses_post( $pricing_table_header_content ); ?>
								</div><?php 
							endif;
							echo wp_kses_post( $pricing_table_price_content );
							echo wp_kses_post( $pricing_table_desciption_content );
							echo wp_kses_post( $pricing_table_features_content ); ?>
						</div>
					</div>
				</div>
				<?php echo wp_kses_post( $pricing_table_button_content ); ?>
			<?php endif; ?>
		</div><?php
	}

	/**
	 * Render Price Table widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 2.9.0
	 * @access protected
	 */
	protected function content_template() {
		?>
		<#
			let symbols = {
				dollar: '&#36;',
				euro: '&#128;',
				franc: '&#8355;',
				pound: '&#163;',
				ruble: '&#8381;',
				shekel: '&#8362;',
				baht: '&#3647;',
				yen: '&#165;',
				won: '&#8361;',
				guilder: '&fnof;',
				peso: '&#8369;',
				peseta: '&#8359;',
				lira: '&#8356;',
				rupee: '&#8360;',
				indian_rupee: '&#8377;',
				real: 'R$',
				krona: 'kr'
			};

			let symbol = '',
				iconsHTML = {};

			if ( settings.currency_symbol ) {
				if ( 'custom' !== settings.currency_symbol ) {
					symbol = symbols[ settings.currency_symbol ] || '';
				} else {
					symbol = settings.currency_symbol_custom;
				}
			}

			let buttonClasses = 'lk-elementor-price-table__button btn btn-block';

			if ( settings.button_type ) {
				buttonClasses += ' btn-' + settings.button_type;
			}

			if ( settings.button_size ) {
				buttonClasses += ' btn-' + settings.button_size;
			}

			if ( settings.button_radius ) {
				if ( settings.button_radius === 'rounded-0' ) {
					buttonClasses += ' ' + settings.button_radius;
				} else if ( settings.button_radius === 'card-btn' ) {
					buttonClasses += ' ' + settings.button_radius;
				} else {
					buttonClasses += ' btn-' + settings.button_radius;
				}
			}

			if ( settings.hover_animation ) {
				buttonClasses += ' elementor-animation-' + settings.hover_animation;
			}

			if ( settings.button_classes ) {
				buttonClasses += ' ' + settings.button_classes;
			}

			let buttonIconHTML = elementor.helpers.renderIcon( view, settings.button_selected_icon, { 'aria-hidden': true, 'class': 'ml-3' }, 'i' , 'object' );
			let buttonIconMigrated = elementor.helpers.isIconMigrated( settings, 'button_selected_icon' );

			view.addRenderAttribute( 'heading', 'class', 'lk-elementor-price-table__heading h6 font-weight-bold text-uppercase' );
			view.addRenderAttribute( 'period', 'class', [ 'lk-elementor-price-table__period', 'lk-elementor-typo-excluded', 'h2', 'align-self-end', 'mb-1' ] );
			view.addRenderAttribute( 'button_text', 'class', buttonClasses  );
			view.addRenderAttribute( 'price_subtext', 'class', [ 'lk-elementor-price-table__subtext text-center', settings.enable_around_padding ? 'mb-5' : 'mb-6 mb-md-8' ] );
			view.addRenderAttribute( 'pricing_box_description', 'class', 'lk-elementor-price-table__description lead text-center text-muted mb-0 mb-md-10' );

			view.addInlineEditingAttributes( 'heading' );
			view.addInlineEditingAttributes( 'period' );
			view.addInlineEditingAttributes( 'price_subtext' );
			view.addInlineEditingAttributes( 'button_text' );
			view.addInlineEditingAttributes( 'pricing_box_description' );

			let currencyFormat = settings.currency_format || '.';
			let	price = settings.price.split( currencyFormat );
			let	intpart = price[0];
			let	fraction = price[1];
			let	periodElement = '<span ' + view.getRenderAttributeString( "period" ) + '>' + settings.period + '</span>';

			view.addRenderAttribute( 'pricing_table_card_wrapper', 'class', [
				'lk-elementor-price-table', 
				'card',
				settings.pricing_box_border_radius
			] );

			if ( settings.enable_border_top ) {
				view.addRenderAttribute( 'pricing_table_card_wrapper', 'class', [
					'card-border',
					'card-border-xl',
					'shadow-light-lg',
					'lift',
					'lift-lg',
				] );
			} else {
				view.addRenderAttribute( 'pricing_table_card_wrapper', 'class', shadow-lg  );
			}
		#>
		<div {{{ view.getRenderAttributeString( 'pricing_table_card_wrapper' ) }}}>
			<# if ( settings.enable_around_padding || settings.enable_border_top ) { #>
				<div class="card-body">
					<# if ( settings.heading ) { #>
						<# if ( settings.enable_badge ) { #>
							<div class="text-center mb-3">
								<span class="lk-elementor-price-table__heading-container badge <# settings.heading_size === 'lg' ? print( 'badge-lg ' ) : '' #>badge-pill badge-<# print( settings.heading_predefined_color ); settings.heading_bg_soft ? print( '-soft' ) : '' #>">
									<{{ settings.heading_tag }} {{{ view.getRenderAttributeString( 'heading' ) }}}>{{{ settings.heading }}}</{{ settings.heading_tag }}>
								</span>
							</div>
						<# } else { #>
							<div class="text-center mb-5">
								<{{ settings.heading_tag }} {{{ view.getRenderAttributeString( 'heading' ) }}}>{{{ settings.heading }}}</{{ settings.heading_tag }}>
							</div>
						<# }
					} #>

					<# if ( settings.show_price ) { #>
						<div class="lk-elementor-price-table__price">
							<div class="lk-elementor-price-table__price-wrapper d-flex justify-content-center">
								<# if ( ! _.isEmpty( symbol ) && ( 'before' === settings.currency_position || _.isEmpty( settings.currency_position ) ) ) { #>
									<span class="lk-elementor-price-table__currency lk-elementor-currency--before h2 mb-0 mt-2">{{{ symbol }}}</span>
								<# } #>
								<# if ( intpart ) { 
									view.addRenderAttribute( 'price', 'class', [
										'lk-elementor-price-table__integer-part', 'price', 'display-2', 'mb-0'
									] );

									view.addRenderAttribute( 'price', 'data-monthly', settings.price );

									view.addRenderAttribute( 'price', 'data-annual', settings.annual_price );

									view.addRenderAttribute( 'price', 'data-decimals', settings.allowed_decimals );
								#>
									<span {{{ view.getRenderAttributeString( 'price' ) }}}>{{{ intpart }}}</span>
								<# } #>
								<div class="lk-elementor-price-table__after-price d-flex">
									<# if ( fraction ) { #>
										<span class="lk-elementor-price-table__fractional-part">{{{ fraction }}}</span>
									<# } #>
									<# if ( settings.period && 'below' === settings.period_position ) { #>
										{{{ periodElement }}}
									<# } #>
								</div>

								<# if ( ! _.isEmpty( symbol ) && 'after' == settings.currency_position ) { #>
								<span class="lk-elementor-price-table__currency lk-elementor-currency--after h2 mb-0 mt-2">{{{ symbol }}}</span>
								<# } #>

								<# if ( settings.period && 'beside' === settings.period_position ) { #>
									{{{ periodElement }}}
								<# } #>
							</div>
							<# if ( settings.price_subtext ) { #>
								{{{ '<p ' + view.getRenderAttributeString( "price_subtext" ) + '>' + settings.price_subtext + '</p>' }}}
							<# } #>
						</div>
					<# } #>

					<# if ( settings.show_description && settings.pricing_box_description ) { #>
						{{{ '<p ' + view.getRenderAttributeString( "pricing_box_description" ) + '>' + settings.pricing_box_description + '</p>' }}}
					<# } #>

					<# if ( settings.features_list && settings.show_features ) { #>
						<div class="lk-elementor-price-table__features-list">
							<# _.each( settings.features_list, function( item, index ) {

								let featureKey = view.getRepeaterSettingKey( 'item_text', 'features_list', index );
								let	migrated = elementor.helpers.isIconMigrated( item, 'selected_item_icon' );

								if ( settings.features_list.length === index + 1 ) {
									view.addRenderAttribute( featureKey, {
										'class': 'mb-5',
									} );
								}

								view.addInlineEditingAttributes( featureKey );
							#>
								<div class="lk-list-item elementor-repeater-item-{{ item._id }} d-flex">
									<# if ( item.item_icon || item.selected_item_icon ) { #>
										<div class="badge badge-rounded-circle badge-success-soft mt-1 mr-4">
											<# iconsHTML[ index ] = elementor.helpers.renderIcon( view, item.selected_item_icon, { 'aria-hidden': 'true' }, 'i', 'object' );
											if ( ( ! item.item_icon || migrated ) && iconsHTML[ index ] && iconsHTML[ index ].rendered ) { #>
												{{{ iconsHTML[ index ].value }}}
											<# } else { #>
												<i class="{{ item.item_icon }}" aria-hidden="true"></i>
											<# } #>
										</div>
									<# } #>
									<# if ( ! _.isEmpty( item.item_text.trim() ) ) { #>
										<p {{{ view.getRenderAttributeString( featureKey ) }}}>{{{ item.item_text }}}</p>
									<# } else { #>
										&nbsp;
									<# } #>
								</div>
							<# } ); #>
						</div>
					<# } #>

					<# if ( settings.button_text && settings.show_button === 'yes' ) { #>
						<a id="{{ settings.button_css_id }}" href="#!" {{{ view.getRenderAttributeString( 'button_text' ) }}}>
							{{{ settings.button_text }}}
							<# if ( settings.button_icon || settings.button_selected_icon ) {
								if ( ( buttonIconMigrated || ! settings.button_icon ) && buttonIconHTML.rendered ) { #>
									{{{ buttonIconHTML.value }}}
								<# } else { #>
									<i class="{{ settings.button_icon }} ml-3" aria-hidden="true"></i>
								<# }
							} #>
						</a>
					<# } #>
				</div>
			<# } else { #>
				<div class="card-body py-6 py-md-8">
					<div class="row justify-content-center">
						<div class="col-12 col-xl-<# settings.show_description ? print('10') : print('9') #>">
							<# if ( settings.heading ) { #>
								<div class="text-center <# ( settings.show_description && ! settings.show_price ) ? print( 'mb-8 mb-md-11' ) : print( 'mb-5' ) #>">
									<span class="lk-elementor-price-table__heading-container badge <# settings.heading_size === 'lg' ? print( 'badge-lg ' ) : '' #>badge-pill badge-<# print( settings.heading_predefined_color ); settings.heading_bg_soft ? print( '-soft' ) : '' #>">
										<{{ settings.heading_tag }} {{{ view.getRenderAttributeString( 'heading' ) }}}>{{{ settings.heading }}}</{{ settings.heading_tag }}>
									</span>
								</div>
							<# } #>

							<# if ( settings.show_price ) { #>
								<div class="lk-elementor-price-table__price">
									<div class="lk-elementor-price-table__price-wrapper d-flex justify-content-center">
										<# if ( ! _.isEmpty( symbol ) && ( 'before' === settings.currency_position || _.isEmpty( settings.currency_position ) ) ) { #>
											<span class="lk-elementor-price-table__currency lk-elementor-currency--before h2 mb-0 mt-2">{{{ symbol }}}</span>
										<# } #>
										<# if ( intpart ) { 
											view.addRenderAttribute( 'price', 'class', [
												'lk-elementor-price-table__integer-part', 'price', 'display-2', 'mb-0'
											] );

											view.addRenderAttribute( 'price', 'data-monthly', settings.price );

											view.addRenderAttribute( 'price', 'data-monthly', settings.annual_price );
										#>
											<span {{{ view.getRenderAttributeString( 'price' ) }}}>{{{ intpart }}}</span>
										<# } #>
										<div class="lk-elementor-price-table__after-price d-flex">
											<# if ( fraction ) { #>
												<span class="lk-elementor-price-table__fractional-part">{{{ fraction }}}</span>
											<# } #>
											<# if ( settings.period && 'below' === settings.period_position ) { #>
												{{{ periodElement }}}
											<# } #>
										</div>

										<# if ( ! _.isEmpty( symbol ) && 'after' == settings.currency_position ) { #>
										<span class="lk-elementor-price-table__currency lk-elementor-currency--after h2 mb-0 mt-2">{{{ symbol }}}</span>
										<# } #>

										<# if ( settings.period && 'beside' === settings.period_position ) { #>
											{{{ periodElement }}}
										<# } #>
									</div>
									<# if ( settings.price_subtext ) { #>
										{{{ '<p ' + view.getRenderAttributeString( "price_subtext" ) + '>' + settings.price_subtext + '</p>' }}}
									<# } #>
								</div>
							<# } #>

							<# if ( settings.show_description && settings.pricing_box_description ) { #>
								{{{ '<p ' + view.getRenderAttributeString( "pricing_box_description" ) + '>' + settings.pricing_box_description + '</p>' }}}
							<# } #>

							<# if ( settings.features_list && settings.show_features ) { #>
								<div class="lk-elementor-price-table__features-list">
									<# _.each( settings.features_list, function( item, index ) {

										let featureKey = view.getRepeaterSettingKey( 'item_text', 'features_list', index );
										let	migrated = elementor.helpers.isIconMigrated( item, 'selected_item_icon' );

										if ( settings.features_list.length === index + 1 ) {
											view.addRenderAttribute( featureKey, {
												'class': 'mb-0',
											} );
										}

										view.addInlineEditingAttributes( featureKey );
									#>
										<div class="lk-list-item elementor-repeater-item-{{ item._id }} d-flex">
											<# if ( item.item_icon || item.selected_item_icon ) { #>
												<div class="badge badge-rounded-circle badge-success-soft mt-1 mr-4">
													<# iconsHTML[ index ] = elementor.helpers.renderIcon( view, item.selected_item_icon, { 'aria-hidden': 'true' }, 'i', 'object' );
													if ( ( ! item.item_icon || migrated ) && iconsHTML[ index ] && iconsHTML[ index ].rendered ) { #>
														{{{ iconsHTML[ index ].value }}}
													<# } else { #>
														<i class="{{ item.item_icon }}" aria-hidden="true"></i>
													<# } #>
												</div>
											<# } #>
											<# if ( ! _.isEmpty( item.item_text.trim() ) ) { #>
												<p {{{ view.getRenderAttributeString( featureKey ) }}}>{{{ item.item_text }}}</p>
											<# } else { #>
												&nbsp;
											<# } #>
										</div>
									<# } ); #>
								</div>
							<# } #>

						</div>
					</div>
				</div>
				<# if ( settings.button_text && settings.show_button === 'yes' ) { #>
					<a id="{{ settings.button_css_id }}" href="#!" {{{ view.getRenderAttributeString( 'button_text' ) }}}>
						{{{ settings.button_text }}}
						<# if ( settings.button_icon || settings.button_selected_icon ) {
							if ( ( buttonIconMigrated || ! settings.button_icon ) && buttonIconHTML.rendered ) { #>
								{{{ buttonIconHTML.value }}}
							<# } else { #>
								<i class="{{ settings.button_icon }} ml-3" aria-hidden="true"></i>
							<# }
						} #>
					</a>
				<# } #>
			<# } #>
		</div>
		<?php
	}
}