<?php
namespace LandkitElementor\Modules\Search\Widgets;

use LandkitElementor\Base\Base_Widget;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
exit; // Exit if accessed directly
}

class Search extends Base_Widget {

    public function get_name() {
        return 'lk-search';
    }

    public function get_title() {
        return __( 'Search', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-search';
    }

    protected function register_controls() {
        $this->start_controls_section( 'search_content', [
            'label' => esc_html__( 'Search Form', 'landkit-elementor' ),
        ] );

        $search_options = [
            'blog' => esc_html__( 'Posts', 'landkit-elementor' )
        ];

        if ( function_exists( 'landkit_is_wedocs_activated' ) && landkit_is_wedocs_activated() ) {
            $search_options[ 'help_center' ] = esc_html__( 'Docs', 'landkit-elementor');
        }

        if ( function_exists( 'landkit_is_wp_job_manager_activated' ) && landkit_is_wp_job_manager_activated() ) {
            $search_options[ 'job' ] = esc_html__( 'Jobs', 'landkit-elementor');
        }
        
        $this->add_control( 'skin', [
            'label'   => esc_html__( 'Search', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'blog',
            'options' => $search_options,
            'frontend_available' => true,
        ] );

        $this->add_control( 'job_style', [
            'label'   => esc_html__( 'Job Style', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'style_2',
            'options' => [
                ''        => esc_html__( 'Choose a Style', 'landkit-elementor' ),
                'style_1' => esc_html__( 'Style 1', 'landkit-elementor' ),
                'style_2' => esc_html__( 'Style 2', 'landkit-elementor' ),
            ],
            'condition' => [ 'skin' => 'job' ]
        ] );

        $this->add_control( 'job_type_enable', [
            'label'     => esc_html__( 'Enable Job Type', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
            'default'   => '',
            'condition' => [ 'job_style' => 'style_1', 'skin' => 'job' ]
        ] );

        $this->add_control( 'placeholder', [
            'label'     => esc_html__( 'Placeholder', 'landkit-elementor' ),
            'type'      => Controls_Manager::TEXT,
            'separator' => 'before',
            'default'   => esc_html__( 'Search...', 'landkit-elementor' ),
        ] );

        $this->add_control( 'enable_docs_dropdown', [
            'label'     => esc_html__( 'Enable Docs dropdown?', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
            'default'   => 'no',
            'condition' => [ 'skin' => 'help_center' ]
        ] );

        $this->add_control( 'button_style', [
            'label'     => esc_html__( 'Button', 'landkit-elementor' ),
            'type'      => Controls_Manager::HEADING,
            'condition' => [ 'job_style!' => 'style_2' ]
        ] );

        $this->add_control( 'search_btn', [
            'label'     => esc_html__( 'Enable Button', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
            'default'   => '',
            'condition' => [ 'job_style' => 'style_1', 'skin' => 'job' ]
        ] );

        $this->add_control( 'btn_txt', [
            'label'     => esc_html__( 'Button Text', 'landkit-elementor' ),
            'type'      => Controls_Manager::TEXT,
            'default'   => esc_html__( 'Search', 'landkit-elementor' ),
            'condition' => [ 'job_style!' => 'style_2' ]
        ] );

        $this->add_control( 'button_type', [
            'label'   => esc_html__( 'Color', 'landkit-elementor' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 'primary',
            'options' => [
                'primary'   => esc_html__( 'Primary', 'landkit-elementor' ),
                'secondary' => esc_html__( 'Secondary', 'landkit-elementor' ),
                'success'   => esc_html__( 'Success', 'landkit-elementor' ),
                'danger'    => esc_html__( 'Danger', 'landkit-elementor' ),
                'warning'   => esc_html__( 'Warning', 'landkit-elementor' ),
                'info'      => esc_html__( 'Info', 'landkit-elementor' ),
                'light'     => esc_html__( 'Light', 'landkit-elementor' ),
                'dark'      => esc_html__( 'Dark', 'landkit-elementor' ),
                'link'      => esc_html__( 'Link', 'landkit-elementor' ),
                'white'     => esc_html__( 'White', 'landkit-elementor' ),
                'black'     => esc_html__( 'Black', 'landkit-elementor' ),
                'primary-desat' => esc_html__( 'Primary Desat', 'landkit-elementor' ),
            ],
            'condition' => [ 'job_style!' => 'style_2' ]
        ] );

        $this->add_control( 'popular_tags', [
            'label'     => esc_html__( 'Popular Tags', 'landkit-elementor' ),
            'type'      => Controls_Manager::SWITCHER,
            'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
            'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
            'default'   => 'no',
            'condition' => [ 'skin!' => 'job' ]
        ] );

        $this->add_control( 'no_of_tags', [
                'label' => esc_html__( 'Number of Tags Display', 'landkit-elementor' ),
                'type' => Controls_Manager::NUMBER,
                'default' => '4',
                'condition' => [ 'popular_tags' => 'yes','skin!' => 'job' ]
            ]
        );

        $this->end_controls_section();
    }

    protected function render_job_filter( $placeholder, $search_btn,  $job_type_enable ,$button_type, $btn_txt ) { 

        $atts = [
            'per_page'                  => get_option( 'job_manager_per_page' ),
            'orderby'                   => 'featured',
            'order'                     => 'DESC',

            // Filters + cats.
            'show_filters'              => true,
            'show_categories'           => true,
            'show_category_multiselect' => get_option( 'job_manager_enable_default_category_multiselect', false ),
            'show_pagination'           => false,
            'show_more'                 => true,

            // Limit what jobs are shown based on category, post status, and type.
            'categories'                => '',
            'job_types'                 => '',
            'post_status'               => '',
            'featured'                  => null, // True to show only featured, false to hide featured, leave null to show both.
            'filled'                    => null, // True to show only filled, false to hide filled, leave null to show both/use the settings.

            // Default values for filters.
            'location'                  => '',
            'keywords'                  => '',
            'selected_category'         => '',
            'selected_job_types'        => implode( ',', array_values( get_job_listing_types( 'id=>slug' ) ) ),
        ];


        if ( ! empty( $_GET['search_keywords'] ) ) {
            $atts['keywords']     = sanitize_text_field( wp_unslash( $_GET['search_keywords'] ) );
            $disable_client_state = true;
        }
        if ( ! empty( $_GET['search_location'] ) ) {
            $atts['location']      = sanitize_text_field( wp_unslash( $_GET['search_location'] ) );
            $disable_client_state  = true;
        }
        if ( ! empty( $_GET['search_category'] ) ) {
            $atts['selected_category'] = sanitize_text_field( wp_unslash( $_GET['search_category'] ) );
            $disable_client_state      = true;
        }
        if ( ! empty( $_GET['search_job_type'] ) ) {
            $atts['selected_job_types'] = sanitize_text_field( wp_unslash( $_GET['search_job_type'] ) );
            $disable_client_state       = true;
        }
        // phpcs:enable WordPress.Security.NonceVerification.Recommended

        // Array handling.
        $atts['categories']         = is_array( $atts['categories'] ) ? $atts['categories'] : array_filter( array_map( 'trim', explode( ',', $atts['categories'] ) ) );
        $atts['selected_category']  = is_array( $atts['selected_category'] ) ? $atts['selected_category'] : array_filter( array_map( 'trim', explode( ',', $atts['selected_category'] ) ) );
        $atts['job_types']          = is_array( $atts['job_types'] ) ? $atts['job_types'] : array_filter( array_map( 'trim', explode( ',', $atts['job_types'] ) ) );
        $atts['selected_job_types'] = is_array( $atts['selected_job_types'] ) ? $atts['selected_job_types'] : array_filter( array_map( 'trim', explode( ',', $atts['selected_job_types'] ) ) );

        // Normalize field for categories.
        if ( ! empty( $atts['selected_category'] ) ) {
            foreach ( $atts['selected_category'] as $cat_index => $category ) {
                if ( ! is_numeric( $category ) ) {
                    $term = get_term_by( 'slug', $category, 'job_listing_category' );

                    if ( $term ) {
                      $atts['selected_category'][ $cat_index ] = $term->term_id;
                    }
                }
            }
        }
        extract($atts);
        do_action( 'job_manager_job_filters_before', $atts );
        $boolean = false;
        if ('yes' == $search_btn) {
            $boolean = true;
        }
        $show_button = apply_filters( 'job_manager_job_filters_show_submit_button', $boolean );
        $width_css   = $show_button ? 'col-md-3': 'col-md-4';
        $jobs_page_id = get_option( 'job_manager_jobs_page_id' );

        if ( $jobs_page_id ) {
            $action = get_permalink( $jobs_page_id );
        } else {
            $action = home_url( '/' );
        }

        ?>

        <form class="job_filters" method="get" action="<?php echo esc_url( $action ); ?>">
            
            <?php do_action( 'job_manager_job_filters_start', $atts); ?>
            
            <div class="search_jobs row mb-4">
                <?php do_action( 'job_manager_job_filters_search_jobs_start', $atts); ?>
                
                <div class="col-12 col-md-4">
                    <div class="search_keywords form-group mb-5 mb-md-0">
                        <label for="search_keywords"><?php esc_html_e( 'Keywords', 'landkit-elementor' ); ?></label>
                        <input type="text" class="form-control" name="search_keywords" id="search_keywords" placeholder="<?php echo esc_attr( $placeholder );?>" value="<?php echo esc_attr( $keywords ); ?>" />
                    </div>
                </div>

                <div class="col-12 <?php echo esc_attr( $width_css ); ?>">
                    <div class="search_location form-group mb-5 mb-md-0">
                        <label for="search_location"><?php esc_html_e( 'Location', 'landkit-elementor' ); ?></label>
                        <input type="text" class="form-control" name="search_location" id="search_location" placeholder="<?php echo esc_attr( "Any Location" );?>" value="<?php echo esc_attr( $location ); ?>" />
                    </div>
                </div>
                
                <?php if ( $categories ) : ?>
                    <?php foreach ( $categories as $category ) : ?>
                        <input type="hidden" name="search_category" value="<?php echo esc_attr( sanitize_title( $category ) ); ?>" />
                    <?php endforeach; ?>
                <?php elseif ( $show_categories && ! is_tax( 'job_listing_category' ) && get_terms( [ 'taxonomy' => 'job_listing_category' ] ) ) : ?>
                    <div class="col-12 <?php echo esc_attr( $width_css ); ?>">
                        <div class="search_categories form-group mb-5 mb-md-0">
                            <label for="search_categories"><?php esc_html_e( 'Category', 'landkit-elementor' ); ?></label>
                            <?php 
                                $cats = job_manager_dropdown_categories( [ 'taxonomy' => 'job_listing_category', 'hierarchical' => 1, 'show_option_all' => esc_html__( 'Any category', 'landkit-elementor' ), 'name' => 'search_category', 'orderby' => 'name', 'multiple' => false, 'hide_empty' => true, 'class' => 'custom-select', 'echo' => false ] );
                                print( str_replace( 'search_category[]', 'search_category', $cats ) );
                            ?>
                        </div>
                    </div>
                
                <?php endif; ?>
                    
                <?php if ('yes' == $search_btn && $show_button ) : ?>
                
                <div class="col-12 col-md-2 d-flex align-items-end">
                    <div class="form-group mb-5 mb-md-0">
                        <div class="search_submit">
                            <input type="submit" class="btn btn-<?php echo $button_type;?> btn-block" value="<?php echo $btn_txt;?>">
                        </div>
                    </div>
                </div>

                <?php else: ?>

                <input type="submit" class="sr-only" value="<?php esc_attr_e( 'Search Jobs', 'landkit-elementor' ); ?>">
                    
                <?php endif; ?>

                <?php do_action( 'job_manager_job_filters_search_jobs_end', $atts ); ?>
            </div>
                
            <?php if (  'yes' == $job_type_enable ) {
                do_action( 'job_manager_job_filters_end', $atts ); 
            } ?>
                
        </form>

        <?php do_action( 'job_manager_job_filters_after', $atts ); 
    }

    protected function render_job_style_1( $placeholder, $search_btn,  $job_type_enable, $button_type, $btn_txt ) { 
       
        if ( landkit_is_wp_job_manager_activated() ) {
            $this->render_job_filter( $placeholder , $search_btn,  $job_type_enable, $button_type, $btn_txt);
        }
     }

    protected function render_help_center( $placeholder, $button_type, $no_of_tags, $popular_tags, $docs_dropdown, $btn_txt ) { 

        $dropdown_args = [
            'post_type'         => 'docs',
            'echo'              => 0,
            'depth'             => 1,
            'show_option_none'  => esc_html__( 'All Docs', 'landkit-elementor' ),
            'option_none_value' => 'all',
            'name'              => 'search_in_doc',
            'class'             => 'custom-select input-group-text custom-select-lg',
        ];
        ?>

        <form role="search" method="get" class="mb-4 search-form wedocs-search-form rounded shadow" action="<?php echo esc_url( home_url( '/' ) ); ?>'">
            <div class="input-group input-group-lg">
                <!-- Prepend -->
                <div class="input-group-prepend">
                    <span class="input-group-text border-0 pr-1">
                        <i class="fe fe-search"></i>
                    </span>
                </div>
                <!-- Input -->
                <input type="text" class="form-control border-0 px-1" aria-label="<?php echo esc_attr( $placeholder );?>" placeholder="<?php echo esc_attr( $placeholder );?>" name="s" value="<?php echo esc_attr( get_search_query() ); ?>">
                <!-- Append -->
                <div class="input-group-append">
                    <?php if( 'yes'  === $docs_dropdown ) { 
                        echo wp_dropdown_pages( $dropdown_args ); 
                    }?>
                    <span class="input-group-text border-0 py-0 pl-1 pr-3">
                        <button type="submit" class="btn btn-sm btn-<?php echo $button_type;?>">
                            <?php echo $btn_txt;?>
                        </button>
                    </span>
                </div>
            </div>
            <input type="hidden" name="post_type" value="docs" />
        </form>
        <?php 
        if ( landkit_is_wedocs_activated() ) {
            if ( 'yes' === $popular_tags ) :
                $this->landkit_popular_doc_tags( $no_of_tags );
            endif;
        }
    }

    function landkit_popular_doc_tags($no_of_tags = 4) {

        if ( is_search() ){
            return;
        }
        $args         = apply_filters( 'landkit_popular_doc_tags_args', array(
            'orderby'  => 'count',
            'order'    => 'desc',
            'number'   => $no_of_tags,
            'taxonomy' => 'doc_tag',
        ) );
        $popular_tags = get_tags( $args );
        if ( empty ( $popular_tags ) ) {
            return;
        }
        ?><!-- Badges -->
        <div class="row align-items-center mb-6 mb-md-8">
            <div class="col-auto">
                <!-- Heading -->
                <h6 class="font-weight-bold text-uppercase text-muted mb-0"><?php _e( 'Popular Tags:', 'landkit-elementor' ); ?></h6>
            </div>
            <div class="col ml-n5">
                <!-- Badges -->
                <?php 
                $tag_html = [];
                foreach ( $popular_tags as $tag ) {
                    $tag_link = get_tag_link( $tag->term_id );
                    $html  = "<a href='{$tag_link}' title='{$tag->name} Tag' class='text-decoration-none text-reset {$tag->slug}'>";
                    $html .= "{$tag->name}</a>";
                    $tag_html[] = $html;
                } 
                ?>
                <p class="font-size-sm text-muted mb-0">
                    <?php print( implode( ', ', $tag_html ) ); ?>
                </p>
            </div>
        </div> <!-- / .row --><?php
    }

    protected function render_job_style_2( $placeholder ) { 
        $jobs_page_id = get_option( 'job_manager_jobs_page_id' );
        
        if ( $jobs_page_id ) {
            $action = get_permalink( $jobs_page_id );
        } else {
            $action = home_url( '/' );
        }

        ?>
        <form action="<?php echo esc_url( $action ); ?>" method="get">
            <div class="input-group">
                <div class="input-group-prepend">
                    <span class="input-group-text pr-0 border-right-0">
                        <i class="fe fe-search" id="searchAddon"></i>
                    </span>
                </div>
                <input type="search" name="search_keywords" class="form-control pl-2 border-left-0" placeholder="<?php echo esc_attr( $placeholder );?>" aria-label="<?php echo esc_attr( $placeholder );?>" aria-describedby="searchAddon">
            </div>
        </form><?php 
    }

    protected function render_blog( $placeholder, $button_type, $popular_tags, $no_of_tags, $btn_txt ) {
        $landkit_unique_id  = landkit_unique_id( 'search-form-' );
        $landkit_aria_label = ! empty( $args['label'] ) ? 'aria-label="' . esc_attr( $args['label'] ) . '"' : ''; ?>

        <form role="search" <?php echo $landkit_aria_label; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped above. ?> method="get" class="rounded shadow <?php if ( !is_search() ): ?>mb-4<?php endif;?>" action="<?php echo esc_url( home_url( '/' ) ); ?>">
            <div class="input-group input-group-lg">
                <!-- Prepend -->
                <div class="input-group-prepend">
                    <span class="input-group-text border-0 pr-1">
                        <i class="fe fe-search"></i>
                    </span>
                </div>
                <!-- Input -->
                <input type="search" class="form-control border-0 px-1" id="<?php echo esc_attr( $landkit_unique_id ); ?>" aria-label="<?php esc_attr_e( 'Search our blog...', 'landkit' ); ?>" placeholder="<?php echo $placeholder ;?>" value="<?php echo get_search_query(); ?>" name="s">
                <!-- Append -->
                <div class="input-group-append">
                    <span class="input-group-text border-0 py-0 pl-1 pr-3">
                            <?php landkit_result_count(); ?>
                        <button type="submit" class="btn btn-sm btn-<?php echo $button_type;?>"><?php echo $btn_txt; ?></button>
                    </span>
                </div>
            </div>
            <input type="hidden" name="post_type" value="post" />
        </form>
        <?php 
        if ( 'yes' === $popular_tags ) :
            if( function_exists( 'landkit_popular_tags' )){
                landkit_popular_tags($no_of_tags);
            }
        endif;
    }

    protected function render() {
        $settings           = $this->get_settings();
        $skin               = $settings['skin'];
        $placeholder        = $settings['placeholder'];
        $button_type        = $settings['button_type'];
        $popular_tags       = $settings['popular_tags'];
        $no_of_tags         = $settings['no_of_tags'];
        $style              = $settings['job_style'];
        $search_btn         = $settings['search_btn'];
        $job_type_enable    = $settings['job_type_enable'];
        $docs_dropdown      = $settings['enable_docs_dropdown'];
        $btn_txt            = $settings['btn_txt'];
        
        if ('blog' == $skin) {
            $this->render_blog( $placeholder, $button_type, $popular_tags, $no_of_tags, $btn_txt  );
        } elseif ('help_center' == $skin) {
            $this->render_help_center( $placeholder, $button_type, $no_of_tags, $popular_tags, $docs_dropdown, $btn_txt  );
        } elseif ('style_1' == $style) {
            $this->render_job_style_1( $placeholder, $search_btn, $job_type_enable, $button_type, $btn_txt );
        } elseif ('style_2' == $style) {
            $this->render_job_style_2( $placeholder );
        }
    }
}
