<?php
namespace LandkitElementor\Modules\Step\Widgets;

use LandkitElementor\Base\Base_Widget;
use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Step extends Base_Widget {

    public function get_name() {
        return 'lk-step';
    }

    public function get_title() {
        return esc_html__( 'Step', 'landkit-elementor' );
    }

    protected function register_controls() {
        $this->start_controls_section(
            'section_step', [
                'label' => esc_html__( 'Step', 'landkit-elementor' ),
            ]
        );
        
        $this->add_control(
            'enable_icon', [
                'label'     => esc_html__( 'Enable Icon?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'default'   => '',
            ]
        );

        $this->add_control(
            'selected_icon', [
                'label'            => esc_html__( 'Icon', 'landkit-elementor' ),
                'type'             => Controls_Manager::ICONS,
                'default'          => [
                    'value'   => 'fas fa-check',
                    'library' => 'fa-solid',
                ],
                'condition' => [ 'enable_icon' => 'yes' ],
            ]
        );

        $this->add_control(
            'step_num', [
                'label'     => esc_html__( 'Step', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 2,
                'min'       => 1,
                'max'       => 6,
                'step'      => 1,
                'condition' => [ 'enable_icon' => '' ],     
            ]
        );

        $this->add_control(
            'hr_divider', [
                'label'     => esc_html__( 'Enable Horizontal Divider?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'default'   => '',
            ]
        );

        $this->add_control(
            'body_css',
            [
                'label'     => esc_html__( 'Body CSS Class', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'title'     => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default'   => '',
            ]
        );

        $this->add_control(
            'title', [
                'label'       => esc_html__( 'Title', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'title'       => esc_html__( 'Add your Title Here', 'landkit-elementor' ),
                'default'     => esc_html__( 'Create your account', 'landkit-elementor' ),
                'label_block' => true,
            ]
        );

         $this->add_control(
            'description', [
                'label'       => esc_html__( 'Description', 'landkit-elementor' ),
                'description' => esc_html__( 'Enter Your description', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter Your Description', 'landkit-elementor' ),
                'default'     => esc_html__( 'Our sign up is dead simple. We only require your basic company information and what type of data storage you want.', 'landkit-elementor' ),
            ]
        );

         $this->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'landkit-elementor' ),
                'type'         => Controls_Manager::CHOOSE,
                'options'      => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'landkit-elementor' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'landkit-elementor' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'landkit-elementor' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'default'      => '',
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label'     => esc_html__( 'Title HTML Tag', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p',
                ],
                'default'   => 'h3',
            ]
        );

        $this->add_control(
            'step_pos',
            [
                'label'     => esc_html__( 'Step Position', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                        'left' => 'Left',
                        'top'  => 'Top',
                ],
                'default'   => 'top',
            ]
        );

        $this->add_control(
            'step_style',
            [
                'label'     => esc_html__( 'Step Style', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                        'button'   => 'Button',
                        'badge'    => 'Badge',
                ],
                'default'   => 'button',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style_content', [
                'label' => esc_html__( 'Content', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'hrz_divider',
            [
                'label'     => esc_html__( 'Horizontal Divider', 'landkit-elementor' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'hr_divider' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'hr_position',
            [
                'label'     => esc_html__( 'Position', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                        'left'   => 'Left',
                        'right'  => 'Right',
                        'center' => 'Center',
                ],
                'default'   => 'left',
                'condition' => [
                    'hr_divider' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'hrz_div_css_class',
            [
                'label'     => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'title'     => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'condition' => [
                    'hr_divider' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'icon_style',
            [
                'label'     => esc_html__( 'Icon', 'landkit-elementor' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [ 'enable_icon' => 'yes' ],
            ]
        );

        $this->add_control(
            'size',
            [
                'label' => __( 'Size', 'landkit-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .step__icon' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [ 'enable_icon' => 'yes' ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label'     => esc_html__( 'Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .step__icon' => 'color: {{VALUE}};',
                ],
                'condition' => [ 'enable_icon' => 'yes' ],
            ]
        );

        $this->add_control(
            'icon_css_class',
            [
                'label'     => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'title'     => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default'   => '',
                'condition' => [ 'enable_icon' => 'yes' ],
            ]
        );


        $this->add_control(
            'step_number', [
                'label'     => esc_html__( 'Step Number', 'landkit-elementor' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [ 'enable_icon' => '' ],
            ]
        );

        $this->add_control(
            'step_num_color', [
                'label'     => esc_html__( 'Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .step__num' => 'color: {{VALUE}};',
                ],
                'condition' => [ 'enable_icon' => '' ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'number_typography',
                'selector' => '{{WRAPPER}} .step__num',
            ]
        );

        $this->add_control(
            'background_color', [
                'label'     => esc_html__( 'Background Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .step__num' => 'background-color: {{VALUE}};',
                ],
                'condition' => [ 'enable_icon' => '' ],
            ]
        );

        $this->add_control(
            'step_num_css_class', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => '',
                'condition' => [ 'enable_icon' => '' ],
            ]
        );

        $this->add_control(
            'heading_title', [
                'label'     => esc_html__( 'Title', 'landkit-elementor' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title_color', [
                'label'     =>esc_html__( 'Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .step__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .step__title',
            ]
        );

        $this->add_control(
            'title_css_class', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );

        $this->add_control(
            'heading_description', [
                'label' => esc_html__( 'Description', 'landkit-elementor' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'description_color', [
                'label' => esc_html__( 'Color', 'landkit-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .step__desc' => 'color: {{VALUE}};',
                ],
                'global' => [
                    'default' => Global_Colors::COLOR_TEXT,
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'description_typography',
                'selector' => '{{WRAPPER}} .description',
                'global'   => [ 'default' => Global_Typography::TYPOGRAPHY_TEXT, ],
            ]
        );

        $this->add_control(
            'desc_css_class', [
                'label'   => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => ''
            ]
        );
        $this->end_controls_section();
    }

    public function render_body( $settings ) {
        $title       = $settings[ 'title' ];
        $desc        = $settings[ 'description' ];
        $body_css    = $settings[ 'body_css' ];
        $title_css   = $settings[ 'title_css_class' ];
        $desc_css    = $settings[ 'desc_css_class' ];
        $step_pos    = $settings[ 'step_pos'];
        $enable_icon = $settings[ 'enable_icon' ];
        $tag         = $settings[ 'title_tag' ];

        $this->add_render_attribute( 'body_css', 'class', 'step__body' );
        $this->add_render_attribute( 'step_title', 'class', 'step__title' );
        $this->add_render_attribute( 'step_desc', 'class', [
            'step__desc', 'mb-6'
        ] );

        if ( $body_css != '' ) {
            $this->add_render_attribute( 'body_css', 'class', $body_css );
        }
        if ( $title_css != '' ) {
            $this->add_render_attribute( 'step_title', 'class', $title_css );
        }
        if ( $desc_css != '' ) {
            $this->add_render_attribute( 'step_desc', 'class', $desc_css );
        }

        if ( 'left' === $step_pos ) {
            $this->add_render_attribute( 'body_css', 'class', 'ml-5' );
        } elseif ( 'top' === $step_pos && $enable_icon !== 'yes' ) {
            $this->add_render_attribute( 'body_css', 'class', [
               'col', 'col-md-12', 'ml-n5', 'ml-md-0'
            ] );
            $this->add_render_attribute( 'step_desc', 'class', 'mb-md-0' );
        }

        ?><div <?php echo $this->get_render_attribute_string( 'body_css' ); ?>>
            <!-- Heading -->
            <<?php echo $tag;?> <?php echo $this->get_render_attribute_string( 'step_title' ); ?>><?php echo $title; ?></<?php echo $tag;?>>
            <!-- Text -->
            <p <?php echo $this->get_render_attribute_string( 'step_desc' ); ?>><?php echo $desc; ?></p>
        </div><?php
    }

    public function render_step_icon( $settings ) {
        $enable_icon = $settings[ 'enable_icon' ];
        $hr_position = $settings[ 'hr_position' ];

        if ( ! $enable_icon ) {
            return;
        }
    
        $selected_icon = $settings[ 'selected_icon' ];
        $icon_css      = $settings[ 'icon_css_class' ];

        $this->add_render_attribute( 'step_icon', 'class', [ 'step__icon', 'icon', 'mb-3' ] );
        if ( ! empty( $icon_css ) ) {
            $this->add_render_attribute( 'step_icon', 'class', $icon_css );
        }
        ?>
        <div class="row mb-5">
            <div class="col">
                <?php 
                if ( 'center' === $hr_position || 'left' === $hr_position ) {
                  $this->render_hr_divider( $settings );  
                } ?>
            </div>
            <div class="col-auto">
                <!-- Icon -->
                <div <?php echo $this->get_render_attribute_string( 'step_icon' ); ?>>
                    <?php Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );?>
                </div>
            </div>
            <div class="col"><?php 
                if ( 'center' === $hr_position || 'right' === $hr_position ) {
                  $this->render_hr_divider( $settings );  
                } ?>        
            </div>
        </div><?php
    } 

    public function render_hr_divider( $settings ) { 
        $enable_hr   = $settings[ 'hr_divider' ];
        $hrz_div_css = $settings[ 'hrz_div_css_class' ]; 

        if ( ! $enable_hr ) {
            return;
        }

        $this->add_render_attribute( 'step_hr_div_css', 'class', [
            'step__hrdiv', 'd-none', 'd-md-block', 'my-4'
        ] );

        if ( $hrz_div_css != '' ) {
            $this->add_render_attribute( 'step_hr_div_css', 'class', $hrz_div_css );
        } ?>
        <!-- Divider -->
        <hr <?php echo $this->get_render_attribute_string( 'step_hr_div_css' ); ?>><?php 
    }

    public function render_step_num( $settings ) { 
        $step_num     = $settings[ 'step_num' ];
        $step_num_css = $settings[ 'step_num_css_class' ];
        $step_style   = $settings[ 'step_style' ];
        $step_pos     = $settings[ 'step_pos' ];

        $this->add_render_attribute( 'step_number', 'class', 'step__num');

        if ( 'button' === $step_style ) {
            $this->add_render_attribute( 'step_number', 'class', [
                'btn', 'btn-sm', 'btn-rounded-circle'
            ] );
            $tag = 'button';
        } else {
            $this->add_render_attribute( 'step_number', 'class', [
               'badge', 'badge-lg', 'badge-rounded-circle'
            ] );
            $tag = 'span';
        }
        
        if ( $step_num_css != '' ) {
            $this->add_render_attribute( 'step_number', 'class', $step_num_css );
        }

        $this->add_render_attribute( 'step_hr_div_css', 'class', [
            'mr-n7'
        ] );
        ?>

        <?php if ( 'left' === $step_pos ) : ?>
            <!-- Number -->
            <<?php echo $tag;?> <?php echo $this->get_render_attribute_string( 'step_number' ); ?>>
                <span><?php echo $step_num; ?></span>
            </<?php echo $tag;?>>

        <?php else: ?>

        <div class="row no-gutters align-items-center mb-md-5">
            <div class="col-auto">
                <!-- Number -->
                <<?php echo $tag;?> <?php echo $this->get_render_attribute_string( 'step_number' ); ?>>
                    <span><?php echo $step_num; ?></span>
                </<?php echo $tag;?>>
            </div>
            <div class="col">
                <!-- Divider -->
                <?php $this->render_hr_divider( $settings ); ?>
            </div>
        </div> <!-- / .row -->
        
        <?php endif;
    }
    
    protected function render() { 
        $settings    = $this->get_settings();
        $enable_icon = $settings[ 'enable_icon' ];
        $step_pos    = $settings[ 'step_pos' ];

        if ( 'yes' === $enable_icon ):
            $this->render_step_icon($settings);
            $this->render_body($settings);
        else:
            if ( 'left' === $step_pos ) {
                ?><div class="d-flex">
                    <?php 
                        $this->render_step_num($settings);
                        $this->render_body($settings);
                    ?>
                </div><?php
            } else {
                ?><div class="row">
                    <div class="col-auto col-md-12">
                        <?php $this->render_step_num($settings); ?>
                    </div>
                    <?php $this->render_body($settings); ?>
                </div><?php
            }
        endif;
    }
}