<?php

namespace LandkitElementor\Modules\Testimonial;

use LandkitElementor\Base\Module_Base;
use LandkitElementor\Modules\Testimonial\Skins;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Module extends Module_Base {

    public function __construct() {
        parent::__construct();

        $this->add_actions();
    }

    public function get_name() {
        return 'lk-testimonial';
    }

    public function add_actions() {
        add_action( 'elementor/widget/testimonial/skins_init', [ $this, 'init_skins' ], 10 );
        add_action( 'elementor/element/testimonial/section_style_testimonial_content/before_section_end', [ $this, 'add_content_css_classes_controls' ], 10 );
        add_action( 'elementor/element/testimonial/section_style_testimonial_name/before_section_end', [ $this, 'add_name_css_classes_controls' ], 10 );
        add_action( 'elementor/element/testimonial/section_style_testimonial_job/before_section_end', [ $this, 'add_title_css_classes_controls' ], 10 );
        add_action( 'landkit-elementor/widget/testimonial/before_render_content', [ $this, 'before_render' ], 10 );
    }

    public function init_skins( $widget ) { 
        $widget->add_skin( new Skins\Skin_Testimonial_Card( $widget ) );
        $widget->add_skin( new Skins\Skin_Testimonial_Quote( $widget ) );
    }

    public function add_content_css_classes_controls( $element ) {
        $element->add_control(
            'content_css_class',
            [
                'label' => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'title' => esc_html__( 'Add your custom class for Heading title without the dot. e.g: my-class', 'landkit-elementor' ),
                'condition' => [ '_skin' => '' ],
            ]
        );
    }

    public function add_name_css_classes_controls( $element ) {
        $element->add_control(
            'name_css_class',
            [
                'label' => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'title' => esc_html__( 'Add your custom class for Heading title without the dot. e.g: my-class', 'landkit-elementor' ),
                'condition' => [ '_skin' => '' ],
            ]
        );
    }

    public function add_title_css_classes_controls( $element ) {
        $element->add_control(
            'title_css_class',
            [
                'label' => esc_html__( 'CSS Class', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
                'title' => esc_html__( 'Add your custom class for Heading title without the dot. e.g: my-class', 'landkit-elementor' ),
                'condition' => [ '_skin' => '' ],
            ]
        );
    }


    public function before_render( $element ) {

    
        if ( ! empty( $element->get_settings( 'title_css_class' ) ) ) {
            $element->add_render_attribute( 'testimonial_job', 'class', $element->get_settings( 'title_css_class' ) );    
        }
        if ( ! empty( $element->get_settings( 'name_css_class' ) ) ) {
            $element->add_render_attribute( 'testimonial_name', 'class', $element->get_settings( 'name_css_class' ) );    
        }
        if ( ! empty( $element->get_settings( 'content_css_class' ) ) ) {
            $element->add_render_attribute( 'testimonial_content', 'class', $element->get_settings( 'content_css_class' ) );    
        }
    }
}
