<?php
namespace LandkitElementor\Modules\Testimonial\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Skin_Base;
use Elementor\Icons_Manager;
use Elementor\Plugin;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use LandkitElementor\Core\Utils as LE_Utils;

class Skin_Testimonial_Card extends Skin_Base {
    
    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
        add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
        add_action( 'elementor/element/testimonial/section_testimonial/before_section_end', [ $this, 'register_controls' ] );
    }

    public function get_id() {
        return 'testimonial-card';
    }

    public function get_title() {
        return esc_html__( 'Card', 'landkit-elementor' );
    }

    public function register_controls( $widget ) {

        $this->parent = $widget;

        $widget->update_control( 'testimonial_job', [
                'condition' => [
                    '_skin!' => 'testimonial-card'
                ]
            ]
        );

        $widget->update_control( 'testimonial_image_position', [
                'condition' => [
                    'testimonial_image[url]!' => '',
                    '_skin' => '',
                ],
            ]
        );

        $widget->update_control( 'testimonial_alignment', [
            'condition' => [
                '_skin!' => 'testimonial-card'
            ]
        ] );

        $this->add_control(
            'enable_logo', [
                'label'   => esc_html__( 'Enable Logo ?', 'landkit-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'no',
            ]
        );

        $this->add_control(
            'logo', [
                'label'     => esc_html__( 'Choose Logo', 'landkit-elementor' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic'   => [
                    'active' => true,
                ],
                'default'   => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    $this->get_control_id( 'enable_logo' ) => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(), [
                'name'      => 'logo',
                'default'   => 'full',
                'separator' => 'none',
                'condition' => [
                    $this->get_control_id( 'enable_logo' ) => 'yes'
                ]
            ]
        );

        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        if ( $enabled ) {

            $this->add_control(
                'inline_svg',
                [
                   'label'         => esc_html__( 'Inline SVG', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'title'        => esc_html__( 'If you are uploading SVG file, it might be useful to inline the SVG files. Do not inline, if your SVG file is from unknown sources.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ), 
                    'return_value' => 'yes',
                    'default'      => 'no',
                    'condition'    => [
                        $this->get_control_id( 'enable_logo' ) => 'yes'
                    ]
                ]
            );

            $this->add_control(
                'svg_color', [
                    'label'     => esc_html__( 'Logo SVG Color', 'landkit-elementor' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .testimonial__logo' => 'fill: {{VALUE}}; color: {{VALUE}};',
                    ],
                    'condition' => [
                        $this->get_control_id( 'inline_svg' )  => 'yes',
                        $this->get_control_id( 'enable_logo' ) => 'yes'
                    ],
                ]
            );

        }
    }

    public function render_image( $settings ) {
        $has_image = ! ! $settings['testimonial_image']['url'];
        $link      = ! empty( $settings['link']['url'] ) ? $settings['link']['url'] : '#';

        if ( ! $has_image ) {
            return;
        }

        $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'testimonial_image' );
        $image_html = LE_Utils::add_class_to_image_html( $image_html, [ 'img-fluid', 'd-md-none', 'invisible' ] );

        ?><a class="col-12 col-md-6 bg-cover card-img-left" style="background-image: url(<?php echo $settings['testimonial_image']['url']; ?>);" href="<?php echo esc_url( $link ); ?>">

            <!-- Image (placeholder) -->
            <?php echo $image_html; ?>

            <!-- Shape -->
            <div class="shape shape-right shape-fluid-y svg-shim text-white d-none d-md-block">
                <?php require get_theme_file_path( 'assets/img/shapes/curves/curve-4.svg' ); ?>
            </div>

        </a><?php
    }

    public function render_logo( $settings ) {
        $widget     = $this->parent;
        $has_logo   = ! ! $settings[ $this->get_control_id( 'logo' ) ];
        $alignment  = $settings[ 'testimonial_alignment' ];
        $inline_svg = $settings[ $this->get_control_id( 'inline_svg' ) ];

        if ( ! $has_logo ) {
            return;
        }
        
        $widget->add_render_attribute( 'logo', [
            'class' => [
                'testimonial__logo', 'img-fluid', 'mb-5', 'mb-md-7', 'mx-auto'
            ],
            'style' => 'max-width: 120px;'   
        ] );

        if ( 'yes' === $inline_svg ) {
            $widget->add_render_attribute( 'logo', 'class', 'svg-shim' );
            $logo_html = file_get_contents( $settings[ $this->get_control_id( 'logo' ) ]['url'] );
        } else {
            $logo_html = Group_Control_Image_Size::get_attachment_image_html( $settings, $this->get_control_id( 'logo' ) );
        }

        ?><!-- Logo -->
        <div <?php echo $widget->get_render_attribute_string( 'logo' ); ?>><?php echo $logo_html; ?></div><?php
    }

    public function render_content( $settings ) {
        $has_content = ! ! $settings['testimonial_content'];

        if ( ! $has_content ) {
            return;
        }

        ?><!-- Text -->
        <p class="testimonial__content mb-5 mb-md-7"><?php echo $settings['testimonial_content']; ?></p><?php
    }

    public function render_footer( $settings ) {
        $has_name    = ! ! $settings['testimonial_name'];

        if ( ! $has_name ) {
            return;
        }

        ?><!-- Footer -->
        <footer class="blockquote-footer">
            <span class="testimonial__name h6 text-uppercase"><?php echo $settings['testimonial_name']; ?></span>
        </footer><?php
    }

    public function render() {
        $settings = $this->parent->get_settings_for_display();

        ?><div class="card card-row shadow-light-lg">
            <div class="row no-gutters">
                
                <?php $this->render_image( $settings ); ?>

                <div class="col-12 col-md-6 order-md-1">

                    <!-- Body -->
                    <div class="card-body">
                        <blockquote class="blockquote mb-0 text-center">

                            <?php $this->render_logo( $settings ); ?>

                            <?php $this->render_content( $settings ); ?>

                            <?php $this->render_footer( $settings ); ?>

                        </blockquote>
                    </div>
                </div>
            </div>
        </div><?php
    }

    public function skin_print_template( $content, $widget ) {
        if( 'testimonial' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }
}