<?php
namespace LandkitElementor\Modules\Testimonial\Skins;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Skin_Base;
use Elementor\Icons_Manager;
use Elementor\Plugin;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use LandkitElementor\Core\Controls_Manager as LE_Controls_Manager;
use LandkitElementor\Core\Utils as LE_Utils;

class Skin_Testimonial_Quote extends Skin_Base {
    public function __construct( Elementor\Widget_Base $parent ) {
        parent::__construct( $parent );
        add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
        add_action( 'elementor/element/testimonial/section_testimonial/before_section_end', [ $this, 'register_controls' ], 10, 3 );
        add_action( 'elementor/element/testimonial/section_style_testimonial_content/before_section_end', [ $this, 'update_content_controls' ] );
        add_action( 'elementor/element/testimonial/section_style_testimonial_image/before_section_end', [ $this, 'update_image_controls' ] );
        add_action( 'elementor/element/testimonial/section_style_testimonial_name/before_section_end', [ $this, 'update_name_controls' ] );
        add_action( 'elementor/element/testimonial/section_style_testimonial_job/before_section_end', [ $this, 'update_job_controls' ] );
    }

    public function get_id() {
        return 'testimonial-quote';
    }

    public function get_title() {
        return esc_html__( 'Quote', 'landkit-elementor' );
    }

    public function register_controls( $widget ) {
        $this->parent = $widget;

        $this->add_control(
            'logo', [
                'label'     => esc_html__( 'Choose Logo', 'landkit-elementor' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic'   => [
                    'active' => true,
                ],
                'default'   => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(), [
                'name'      => 'logo',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );

        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        if ( $enabled ) {

            $this->add_control(
                'inline_svg',
                [
                   'label'         => esc_html__( 'Inline SVG', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'title'        => esc_html__( 'If you are uploading SVG file, it might be useful to inline the SVG files. Do not inline, if your SVG file is from unknown sources.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ), 
                    'return_value' => 'yes',
                    'default'      => 'no',
                ]
            );

            $this->add_control(
                'svg_color', [
                    'label'     => esc_html__( 'Logo SVG Color', 'landkit-elementor' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .testimonial__logo' => 'fill: {{VALUE}}; color: {{VALUE}};',
                    ],
                    'condition' => [
                        $this->get_control_id( 'inline_svg' ) => 'yes',
                    ],
                ]
            );

        }

        $this->add_control(
            'quote_css', [
                'label'       => esc_html__( 'CSS Classes', 'landkit-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true,
                ],
                'title'       => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
                'description' => esc_html__( 'CSS Classes applied to the blockquote', 'landkit-elementor' ),
        ] );
    }

    public function update_image_controls( $widget ) {
        $this->parent = $widget;

        $widget->update_control( 'section_style_testimonial_image', [ 'condition' => [ '_skin' => '' ] ] );
    }

    public function update_content_controls( $widget ) {
        $this->parent = $widget;

        $widget->update_control(
            'content_content_color', [
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonial-content' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .testimonial__content' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->update_control(
            'content_typography_typography', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'      => 't_content_typography',
                'selector'  => '{{WRAPPER}} .testimonial__content',
                'condition' => [
                    '_skin' => [ 'testimonial-card', 'testimonial-quote' ]
                ]
            ]
        );

        $this->add_control(
            'content_size', [
                'label'   => esc_html__( 'Size', 'landkit-elementor' ),
                'type'    => LE_Controls_Manager::FONT_SIZE,
                'default' => 'default',
        ] );

        $this->add_control(
            'content_css', [
                'label'   => esc_html__( 'CSS Classes', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
                'title'   => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
        ] );
    }

    public function update_name_controls( $widget ) {
        $this->parent = $widget;

        $widget->update_control(
            'name_text_color', [
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonial-name' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .testimonial__name' => 'color: {{VALUE}};',
                ],
            ]
        );

        $widget->update_control(
            'name_typography_typography', [
                'condition' => [
                    '_skin' => ''
                ]
            ]
        );

        $widget->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 't_name_typography',
                'selector' => '{{WRAPPER}} .testimonial__name',
                'condition' => [
                    '_skin' => [ 'testimonial-card', 'testimonial-quote' ]
                ]
            ]
        );

        $this->add_control(
            'footer_size', [
                'label'   => esc_html__( 'Size', 'landkit-elementor' ),
                'type'    => LE_Controls_Manager::FONT_SIZE,
                'default' => 'default',
        ] );

        $this->add_control(
            'name_css', [
                'label'   => esc_html__( 'CSS Classes', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
                'title'   => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
        ] );
    }

    public function update_job_controls( $widget ) {
        $this->parent = $widget;

        $widget->update_control( 'section_style_testimonial_job', [
            'condition' => [
                '_skin!' => 'testimonial-card'
            ]
        ] );

        $this->add_control(
            'job_css', [
                'label'   => esc_html__( 'CSS Classes', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
                'title'   => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
        ] );
    }

    public function render_logo( $settings ) {
        $widget     = $this->parent;
        $has_logo   = ! ! $settings[ $this->get_control_id( 'logo' ) ]['url'];
        $alignment  = $settings[ 'testimonial_alignment' ];
        $inline_svg = $settings[ $this->get_control_id( 'inline_svg' ) ];

        if ( ! $has_logo ) {
            return;
        }
        
        $widget->add_render_attribute( 'logo', [
            'class' => [
                'testimonial__logo', 'img-fluid', 'mb-5'
            ],
            'style' => 'max-width: 120px;'   
        ] );

        if ( 'center' === $alignment ) {
            $widget->add_render_attribute( 'logo', 'class', [
                'mb-md-7', 'mx-auto'
            ] );
        } else {
            $widget->add_render_attribute( 'logo', 'class', 'mb-md-6' );
        }

        if ( 'yes' === $inline_svg ) {
            $widget->add_render_attribute( 'logo', 'class', 'svg-shim' );
            $logo_html = file_get_contents( $settings[ $this->get_control_id( 'logo' ) ]['url'] );
        } else {
            $logo_html = Group_Control_Image_Size::get_attachment_image_html( $settings, $this->get_control_id( 'logo' ) );
        }

        ?><!-- Logo -->
        <div <?php echo $widget->get_render_attribute_string( 'logo' ); ?>><?php echo $logo_html; ?></div><?php
    }

    public function render_content( $settings ) {
        $widget  = $this->parent;
        $size    = $settings[ $this->get_control_id( 'content_size' ) ];
        $css     = $settings[ $this->get_control_id( 'content_css' ) ];
        $content = $settings['testimonial_content'];
        
        $widget->add_render_attribute( 'testimonial_content', 'class', [
            'testimonial__content', 'mb-5', 'mb-md-7'
        ] );

        if ( ! empty( $size ) ) {
            $widget->add_render_attribute( 'testimonial_content', 'class', $size );
        }

        if ( ! empty( $css ) ) {
            $widget->add_render_attribute( 'testimonial_content', 'class', $css );
        }

        ?>
        <!-- Text -->
        <p <?php echo $widget->get_render_attribute_string( 'testimonial_content' ); ?>><?php echo esc_html( $content ); ?></p><?php
    }

    public function render_avatar( $settings ) {
        $widget     = $this->parent;
        $has_avatar = ! ! $settings['testimonial_image']['url'];
        if ( ! $has_avatar ) {
            return;
        }

        $widget->add_render_attribute( 'avatar', 'class', [
            'testimonial__avatar', 'avatar', 'mr-3'
        ] );
        ?><div <?php echo $widget->get_render_attribute_string( 'avatar' ); ?>>
            <?php
                $image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'testimonial_image' );
                $image_html = LE_Utils::add_class_to_image_html( $image_html, [ 'avatar-img', 'rounded-circle' ] );
                if ( ! empty( $settings['link']['url'] ) ) :
                    $image_html = '<a ' . $this->get_render_attribute_string( 'link' ) . '>' . $image_html . '</a>';
                endif;
                echo $image_html;
            ?>
        </div><?php
    }

    public function render_footer( $settings ) {
        $widget      = $this->parent;
        $has_avatar  = ! ! $settings['testimonial_image']['url'];
        $has_job     = ! ! $settings['testimonial_job'];
        $name        = $settings['testimonial_name'];
        $job         = $settings['testimonial_job'];
        $footer_size = $settings[ $this->get_control_id( 'footer_size' ) ];
        $name_css    = $settings[ $this->get_control_id( 'name_css' ) ];
        $job_css     = $settings[ $this->get_control_id( 'job_css' ) ];

        $widget->add_render_attribute( 'name', 'class', 'testimonial__name' );

        if ( ! empty( $footer_size ) ) {
            $widget->add_render_attribute( 'name', 'class', $footer_size );
            $widget->add_render_attribute( 'job', 'class', $footer_size );
        }

        if ( ! empty( $name_css ) ) {
            $widget->add_render_attribute( 'name', 'class', $name_css );
        }

        if ( ! empty( $job_css ) ) {
            $widget->add_render_attribute( 'job', 'class', $job_css );
        }
        
        if ( $has_avatar ):
            $widget->add_render_attribute( 'footer', 'class', [
                'testimonial__footer', 'blockquote-footer'
            ] );
        ?>
            <!-- Footer -->
            <footer <?php echo $widget->get_render_attribute_string( 'footer' ); ?>>
                <?php $this->render_avatar( $settings ); ?>
                <span <?php echo $widget->get_render_attribute_string( 'name' ); ?>>
                    <?php echo $name; ?><?php if ( $has_job ): ?>, <?php print( $job ); ?><?php endif; ?>    
                </span>
            </footer>
        <?php else: 
            $widget->add_render_attribute( 'name', 'class', 'mb-0' );
            $widget->add_render_attribute( 'job', 'class', [
                'testimonial__job', 'mb-0'
            ] );
        ?>
            <!-- Footer -->
            <p <?php echo $widget->get_render_attribute_string( 'name' ); ?>><?php print( $name ); ?></p>
            <?php if ( $has_job ) : ?>
            <p <?php echo $widget->get_render_attribute_string( 'job' ); ?>><?php print( $job ); ?></p>
            <?php endif;
        endif;
    }

    public function render() {
        $widget   = $this->parent;
        $settings = $widget->get_settings_for_display();

        $widget->add_render_attribute( 'blockquote', 'class', [
            'blockquote', 'text-' . $settings['testimonial_alignment']
        ] );

        $quote_css = $settings[ $this->get_control_id( 'quote_css' ) ];
        if ( ! empty( $quote_css ) ) {
            $widget->add_render_attribute( 'blockquote', 'class', $quote_css );
        }


        ?><blockquote <?php echo $widget->get_render_attribute_string( 'blockquote' ); ?>>

            <?php $this->render_logo( $settings ); ?>

            <?php $this->render_content( $settings ); ?>

            <?php $this->render_footer( $settings ); ?>

        </blockquote><?php
    }

    public function skin_print_template( $content, $widget ) {
        if( 'testimonial' == $widget->get_name() ) {
            return '';
        }
        return $content;
    }
}