<?php
namespace LandkitElementor\Modules\TypedHeadline\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Modules\DynamicTags\Module as TagsModule;
use LandkitElementor\Base\Base_Widget;
use LandkitElementor\Core\Controls_Manager AS LE_Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class Typed_Headline extends Base_Widget {

	public function get_name() {
		return 'lk-typed-headline';
	}

	public function get_title() {
		return esc_html__( 'Typed Headline', 'landkit-elementor' );
	}

	public function get_icon() {
		return 'eicon-animated-headline';
	}

	public function get_keywords() {
		return [ 'headline', 'heading', 'animation', 'typed' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'text_elements',
			[
				'label' => esc_html__( 'Headline', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'before_text',
			[
				'label'       => esc_html__( 'Before Text', 'landkit-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active'     => true,
					'categories' => [
						TagsModule::TEXT_CATEGORY,
					],
				],
				'default'     => 'The most useful resource<br>',
				'placeholder' => esc_html__( 'Enter your before text', 'landkit-elementor' ),
				'label_block' => true,
				'separator'   => 'before',
				'description' => esc_html__( 'Use <br> to break into two lines', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'typing_text_prefix',
			[
				'label'       => esc_html__( 'Typed Text Before', 'landkit-elementor' ),
				'description' => esc_html__( 'Text you enter in this field will not animate but will be highlighted', 'landkit-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active'     => true,
					'categories' => [
						TagsModule::TEXT_CATEGORY,
					],
				],
				'default'     => 'ever created for ',
				'placeholder' => esc_html__( 'Enter Typed Text Before', 'landkit-elementor' ),
				'separator'   => 'none',
				'label_block' => true,
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'typing_text',
			[
				'label'       => esc_html__( 'Typing Text', 'landkit-elementor' ),
				'description' => esc_html__( 'Enter each word in a separate line', 'landkit-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter Typing Text', 'landkit-elementor' ),
				'separator'   => 'none',
				'default'     => "designers.\ndevelopers.",
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'after_text',
			[
				'label'       => esc_html__( 'After Text', 'landkit-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active'     => true,
					'categories' => [
						TagsModule::TEXT_CATEGORY,
					],
				],
				'placeholder' => esc_html__( 'Enter after text', 'landkit-elementor' ),
				'label_block' => true,
				'separator'   => 'none',
				'description' => esc_html__( 'Use <br> to break into two lines', 'landkit-elementor' ),
			]
		);

		$this->add_responsive_control(
			'alignment',
			[
				'label' => esc_html__( 'Alignment', 'landkit-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'landkit-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'landkit-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'landkit-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'left',
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-headline' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'size',
			[
				'label'   => esc_html__( 'Size', 'landkit-elementor' ),
				'type'    => LE_Controls_Manager::FONT_SIZE,
				'default' => 'default',
			]
		);

		$this->add_control(
			'tag',
			[
				'label' => esc_html__( 'HTML Tag', 'landkit-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
					'span' => 'span',
					'p' => 'p',
				],
				'default' => 'h2',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_text',
			[
				'label' => esc_html__( 'Headline', 'landkit-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'landkit-elementor' ),
				'type'  => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-headline-plain-text' => 'color: {{VALUE}}',

				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-headline',
			]
		);

		$this->add_control(
			'text_classes',
			[
				'label' => esc_html__( 'Headline Text CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
				'title' => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);

		$this->add_control(
			'heading_words_style',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Typed Text', 'landkit-elementor' ),
				'separator' => 'before',
			]
		);

		$this->add_control(
			'words_color',
			[
				'label' => esc_html__( 'Text Color', 'landkit-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lk-elementor-headline-dynamic-text' => 'color: {{VALUE}}',
				],
				'default' => '#42BA96',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'words_typography',
				'selector' => '{{WRAPPER}} .lk-elementor-headline-dynamic-text',
				'exclude' => [ 'font_size' ],
			]
		);

		$this->add_control(
			'typing_text_classes',
			[
				'label' => esc_html__( 'Typed Text CSS Classes', 'landkit-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'title' => esc_html__( 'Add your custom class WITHOUT the dot. e.g: my-class', 'landkit-elementor' ),
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$tag = $settings['tag'];

		$animation_typed_text_array = explode( "\n", $settings[ 'typing_text' ] );

		$animation_typed_text = array(
			'strings' => $animation_typed_text_array
		);

		$this->add_render_attribute( 'headline', 'class', [ 'lk-elementor-headline', 'lk-elementor-headline-animation-type-typing', 'lk-elementor-headline-letters' ] );

		if ( $settings['size'] != 'default' ) {
			$this->add_render_attribute( 'headline', 'class', $settings['size'] );
		}

		if ( ! empty( $settings[ 'text_classes' ] ) ) {
			$this->add_render_attribute( 'headline', 'class', $settings[ 'text_classes' ] );
		}

		$this->add_render_attribute( 
			empty( $settings[ 'typing_text_prefix' ] ) ? 'typing_text' : 'highlighted_text', 'class', 
			[ 'lk-elementor-headline-dynamic-text', 'lk-elementor-headline-dynamic-wrapper', 'lk-elementor-headline-text-wrapper' ] 
		); 

		if ( ! empty( $settings[ 'typing_text_classes' ] ) ) {
			$this->add_render_attribute( 'typing_text', 'class', $settings[ 'typing_text_classes' ] );
		}

		$this->add_render_attribute( 'typing_text', [
            'data-toggle' => 'typed',
            'data-options' => htmlspecialchars( json_encode( $animation_typed_text ), ENT_QUOTES, 'UTF-8' ),
            'data-aos-id' => 'typed:in',
            'data-aos' => true,
        ] ); ?>

		<<?php echo $tag; ?> <?php echo $this->get_render_attribute_string( 'headline' ); ?>>
			<?php 
				if ( ! empty( $settings['before_text'] ) ) {
					?><span class="lk-elementor-headline-plain-text lk-elementor-headline-text-wrapper"><?php echo $settings['before_text']; ?> </span><?php
				}
			
				if ( ! empty( $settings[ 'typing_text' ] ) ) {
					if ( empty( $settings[ 'typing_text_prefix' ] ) ) {
						?><span <?php echo $this->get_render_attribute_string( 'typing_text' ); ?>></span><?php
					} else {
						?>
						<span <?php echo $this->get_render_attribute_string( 'highlighted_text' ); ?>><?php echo $settings[ 'typing_text_prefix' ] ?>
							<span <?php echo $this->get_render_attribute_string( 'typing_text' ); ?>></span>
						</span>
						<?php
					}
				}
			
				if ( ! empty( $settings['after_text'] ) ) {
					?><span class="lk-elementor-headline-plain-text lk-elementor-headline-text-wrapper"><?php echo $settings['after_text']; ?></span><?php
				}
			?>
		</<?php echo $tag; ?>>
		<?php
	}

	protected function content_template() {
		?>
		<#
			let headlineClasses = 'lk-elementor-headline lk-elementor-headline-animation-type-typing lk-elementor-headline-letters';

			if ( settings.size != 'default' ) {
				headlineClasses += ' ' + settings.size;
			}

			if ( settings.text_classes ) {
				headlineClasses += ' ' + settings.text_classes;
			}

			const tag = settings.tag;

			let strings = settings.typing_text.split( "\n" );

			view.addRenderAttribute( 
				settings.typing_text_prefix ? 'highlighted_text' : 'typing_text', 'class', 
				[ 'lk-elementor-headline-dynamic-text', 'lk-elementor-headline-dynamic-wrapper', 'lk-elementor-headline-text-wrapper' ] 
			);

			if ( settings.typing_text_classes ) {
				view.addRenderAttribute( 'typing_text', 'class', settings.typing_text_classes );
			}

			view.addRenderAttribute( 'typing_text', {
				'data-toggle': 'typed',
				'data-options': JSON.stringify( { strings } ),
				'data-aos-id': 'typed:in',
				'data-aos': '1',
			} );
		#>
			<{{{ tag }}} class="{{{ headlineClasses }}}">
				<# if ( settings.before_text ) { #>
					<span class="lk-elementor-headline-plain-text lk-elementor-headline-text-wrapper">{{{ settings.before_text }}}</span>
				<# } #>

				<# if ( settings.typing_text ) { 
					if ( settings.typing_text_prefix == '' ) { #>
						<span {{{ view.getRenderAttributeString( "typing_text" ) }}}></span>
					<# } else {#>
						<span {{{ view.getRenderAttributeString( "highlighted_text" ) }}}>{{{ settings.typing_text_prefix }}}
							<span {{{ view.getRenderAttributeString( "typing_text" ) }}}></span>
						</span>
				<# } } #>

				<# if ( settings.after_text ) { #>
					<span class="lk-elementor-headline-plain-text lk-elementor-headline-text-wrapper">{{{ settings.after_text }}}</span>
				<# } #>
			</{{{ tag }}}>
		<?php
	}
}