<?php
/**
 * Docs Icons
 *
 * Display the docs meta box.
 *
 * @author      MadrasThemes
 * @category    Admin
 * @package     Landkit/Admin/Meta Boxes
 * @version     2.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Landkit_Meta_Box_Docs Class.
 */
class Landkit_Meta_Box_Docs {

    /**
     * Output the metabox.
     *
     * @param WP_Post $post
     */
    public static function output( $post ) {
        global $thepostid;
        $thepostid      = $post->ID;

        wp_nonce_field( 'landkit_save_data', 'landkit_meta_nonce' );

        self::output_docs( $post );
    }

    private static function output_docs( $post ) {

        $wedocs = landkit_get_docs_meta();

        ?><div class="landkit-options"><?php

            landkit_wp_text_input( array(
                'id'            => '_wedocs_post_featured_icon',
                'name'          => '_wedocs[post_featured_icon]',
                'label'         => esc_html__( 'Featured Icon', 'landkit-extensions' ),
                'value'         => isset( $wedocs['post_featured_icon'] ) ? $wedocs['post_featured_icon'] : '',
            ) );

            landkit_wp_select( array(
                'label'         => esc_html__( 'Featured Icon Background', 'landkit-extensions' ),
                'name'          => '_wedocs[post_featured_icon_bg]',
                'id'            => '_wedocs_post_featured_icon_bg',
                'type'          => 'select',
                'options'       => array(
                    'primary'       => esc_html__( 'Primary', 'landkit-extensions'),
                    'secondary'     => esc_html__( 'Secondary', 'landkit-extensions'), 
                    'success'       => esc_html__( 'Success', 'landkit-extensions'),
                    'danger'        => esc_html__( 'Danger', 'landkit-extensions'),
                    'warning'       => esc_html__( 'Warning', 'landkit-extensions'),
                    'info'          => esc_html__( 'Info', 'landkit-extensions'),
                    'light'         => esc_html__( 'Light', 'landkit-extensions'),
                    'dark'          => esc_html__( 'Dark', 'landkit-extensions'),
                    'primary-desat' => esc_html__( 'Primary Desat', 'landkit-extensions'),
                ),
                'value'         => isset( $wedocs['post_featured_icon_bg'] ) ? $wedocs['post_featured_icon_bg'] : '',
            ) );

        ?></div><?php
    }
    

    /**
     * Save meta box data.
     *
     * @param int     $post_id
     * @param WP_Post $post
     */


    public static function save( $post_id, $post ) {
        if ( isset( $_POST['_wedocs'] ) ) {
            $clean_docs_options = landkit_clean( $_POST['_wedocs'] );
            update_post_meta( $post_id, '_docs_options',  serialize( $clean_docs_options ) );
        }   
    }
}
