<?php
/**
 *
 * Display the page meta box.
 *
 * @author      MadrasThemes
 * @category    Admin
 * @package     Landkit/Admin/MetaBoxes
 * @version     2.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

if ( ! class_exists( 'Landkit_Meta_Box_Page' ) ) {
    /**
     * Landkit_Meta_Box_Page Class.
     */
    class Landkit_Meta_Box_Page {
        /**
         * Render Meta Box content.
         *
         * @param WP_Post $post The post object.
         */
        public static function output( $post ) {

            $clean_meta_data = get_post_meta( $post->ID, '_lk_page_options', true );
            $lk_page_options = maybe_unserialize( $clean_meta_data );

            if( ! is_array( $lk_page_options ) ) {
                $lk_page_options  = array();
            }

            wp_nonce_field( 'landkit_save_data', 'landkit_meta_nonce' );

            ?><div class="landkit-options">
                <div class="options_group">

                    <h3 class="option-group-title general-options"><?php echo esc_html__( 'General', 'landkit-extensions' ) ?></h3>

                    <?php
                    landkit_wp_text_input( array(
                        'id'            => 'lk_page_options_general_body_classes',
                        'name'          => 'lk_page_options[general][body_classes]',
                        'label'         => esc_html__( 'Additional Body Classes', 'landkit-extensions' ),
                        'value'         => ( isset( $lk_page_options['general'] ) && isset( $lk_page_options['general']['body_classes'] ) ) ? $lk_page_options['general']['body_classes'] : '',
                    ) );

                    ?>
                </div>
                <div class="options_group">

                    <h3 class="option-group-title header-options"><?php echo esc_html__( 'Header', 'landkit-extensions' ) ?></h3>

                    <?php

                    landkit_wp_checkbox( array(
                        'id'            => 'lk_page_options_header_enable_custom_header',
                        'name'          => 'lk_page_options[header][enable_custom_header]',
                        'label'         => esc_html__( 'Enable Custom Header', 'landkit-extensions' ),
                        'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_custom_header'] ) ) ? $lk_page_options['header']['enable_custom_header'] : '',
                        'class'         => 'show_hide_checkbox',
                    ) );

                    landkit_wp_select( array(
                        'id'            => 'lk_page_options_header_skin',
                        'name'          => 'lk_page_options[header][skin]',
                        'type'          => 'select',
                        'label'         => esc_html__( 'Skin', 'landkit-extensions' ),
                        'options'       => array(
                            'light'     => esc_html__( 'Light', 'landkit-extensions'),
                            'dark'      => esc_html__( 'Dark', 'landkit-extensions'),
                        ),
                        'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['skin'] ) ) ? $lk_page_options['header']['skin'] : 'light',
                        'wrapper_class' => 'show_if_lk_page_options_header_enable_custom_header_yes hide_if_lk_page_options_header_enable_custom_header',
                        'class'         => 'show_hide_select',
                    ) );

                    landkit_wp_checkbox( array(
                        'id'            => 'lk_page_options_header_enable_bg_transparent',
                        'name'          => 'lk_page_options[header][enable_bg_transparent]',
                        'label'         => esc_html__( 'Enable Transparent Backgorund', 'landkit-extensions' ),
                        'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_bg_transparent'] ) ) ? $lk_page_options['header']['enable_bg_transparent'] : '',
                        'wrapper_class' => 'show_if_lk_page_options_header_enable_custom_header_yes hide_if_lk_page_options_header_enable_custom_header',
                    ) );

                    ?><div class="show_if_lk_page_options_header_enable_custom_header_yes hide_if_lk_page_options_header_enable_custom_header"><?php

                        landkit_wp_checkbox( array(
                            'id'            => 'lk_page_options_header_enable_border_bottom',
                            'name'          => 'lk_page_options[header][enable_border_bottom]',
                            'label'         => esc_html__( 'Enable Border Bottom', 'landkit-extensions' ),
                            'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_border_bottom'] ) ) ? $lk_page_options['header']['enable_border_bottom'] : '',
                            'wrapper_class' => 'show_if_lk_page_options_header_skin_light hide_if_lk_page_options_header_skin',
                        ) );

                        landkit_wp_checkbox( array(
                            'id'            => 'lk_page_options_header_enable_navbar_togglable',
                            'name'          => 'lk_page_options[header][enable_navbar_togglable]',
                            'label'         => esc_html__( 'Enable Navbar Toggle', 'landkit-extensions' ),
                            'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_navbar_togglable'] ) ) ? $lk_page_options['header']['enable_navbar_togglable'] : '',
                            'wrapper_class' => 'show_if_lk_page_options_header_skin_dark hide_if_lk_page_options_header_skin',
                        ) );

                    ?></div><?php

                    landkit_wp_checkbox( array(
                        'id'            => 'lk_page_options_header_enable_fixed_top',
                        'name'          => 'lk_page_options[header][enable_fixed_top]',
                        'label'         => esc_html__( 'Enable Fixed Top', 'landkit-extensions' ),
                        'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_fixed_top'] ) ) ? $lk_page_options['header']['enable_fixed_top'] : '',
                        'wrapper_class' => 'show_if_lk_page_options_header_enable_custom_header_yes hide_if_lk_page_options_header_enable_custom_header',
                    ) );

                    ?><div class="options_group options_group_sub show_if_lk_page_options_header_enable_custom_header_yes hide_if_lk_page_options_header_enable_custom_header"><?php

                        landkit_wp_checkbox( array(
                            'id'            => 'lk_page_options_header_enable_header_fullwidth',
                            'name'          => 'lk_page_options[header][enable_header_fullwidth]',
                            'label'         => esc_html__( 'Make header full-width?', 'landkit-extensions' ),
                            'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_header_fullwidth'] ) ) ? $lk_page_options['header']['enable_header_fullwidth'] : '',
                            'class'         => 'show_hide_checkbox',
                        ) );

                        landkit_wp_select( array(
                            'id'            => 'lk_page_options_header_container_layout',
                            'name'          => 'lk_page_options[header][container_layout]',
                            'type'          => 'select',
                            'label'         => esc_html__( 'Container Layout', 'landkit-extensions' ),
                            'options'       => array(
                                'container'     => esc_html__( 'Default', 'landkit-extensions' ),
                                'container-sm'  => esc_html__( 'Container Small', 'landkit-extensions' ),
                                'container-md'  => esc_html__( 'Container medium ', 'landkit-extensions' ),
                                'container-lg'  => esc_html__( 'Container Large ', 'landkit-extensions' ),
                                'container-xl'  => esc_html__( 'Container Extra Large', 'landkit-extensions' ),
                            ),
                            'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['container_layout'] ) ) ? $lk_page_options['header']['container_layout'] : 'container',
                            'wrapper_class' => 'show_if_lk_page_options_header_enable_header_fullwidth_no hide_if_lk_page_options_header_enable_header_fullwidth',
                        ) );

                    ?></div>

                    <div class="options_group show_if_lk_page_options_header_enable_custom_header_yes hide_if_lk_page_options_header_enable_custom_header">
                        <?php

                        landkit_wp_checkbox( array(
                            'id'            => 'lk_page_options_header_enable_action_button',
                            'name'          => 'lk_page_options[header][enable_action_button]',
                            'label'         => esc_html__( 'Enable Button', 'landkit-extensions' ),
                            'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['enable_action_button'] ) ) ? $lk_page_options['header']['enable_action_button'] : '',
                            'class'         => 'show_hide_checkbox',
                        ) );

                        // landkit_wp_text_input( array(
                        //     'id'            => 'lk_page_options_header_action_button_link',
                        //     'name'          => 'lk_page_options[header][action_button_link]',
                        //     'label'         => esc_html__( 'Button Link', 'landkit-extensions' ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_link'] ) ) ? $lk_page_options['header']['action_button_link'] : '#',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_text_input( array(
                        //     'id'            => 'lk_page_options_header_action_button_text',
                        //     'name'          => 'lk_page_options[header][action_button_text]',
                        //     'label'         => esc_html__( 'Button Text', 'landkit-extensions' ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_text'] ) ) ? $lk_page_options['header']['action_button_text'] : esc_html__( 'Buy now', 'landkit-extensions' ),
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_select( array(
                        //     'id'            => 'lk_page_options_header_action_button_size',
                        //     'name'          => 'lk_page_options[header][action_button_size]',
                        //     'type'          => 'select',
                        //     'label'         => esc_html__( 'Button Size', 'landkit-extensions' ),
                        //     'options'       => array(
                        //         ''          => esc_html__( 'Default', 'landkit-extensions'),
                        //         'btn-xs'    => esc_html__( 'Extra Small', 'landkit-extensions'),
                        //         'btn-sm'    => esc_html__( 'Small', 'landkit-extensions'),
                        //         'btn-lg'    => esc_html__( 'Large', 'landkit-extensions'),
                        //     ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_size'] ) ) ? $lk_page_options['header']['action_button_size'] : 'btn-sm',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_text_input( array(
                        //     'id'            => 'lk_page_options_header_action_button_background',
                        //     'name'          => 'lk_page_options[header][action_button_background]',
                        //     'label'         => esc_html__( 'Button Background', 'landkit-extensions' ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_background'] ) ) ? $lk_page_options['header']['action_button_background'] : '#335eea',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_text_input( array(
                        //     'id'            => 'lk_page_options_header_action_button_text_color',
                        //     'name'          => 'lk_page_options[header][action_button_text_color]',
                        //     'label'         => esc_html__( 'Button Text Color', 'landkit-extensions' ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_text_color'] ) ) ? $lk_page_options['header']['action_button_text_color'] : '#FFFFFF',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_text_input( array(
                        //     'id'            => 'lk_page_options_header_action_button_background_hover',
                        //     'name'          => 'lk_page_options[header][action_button_background_hover]',
                        //     'label'         => esc_html__( 'Button Background Hover', 'landkit-extensions' ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_background_hover'] ) ) ? $lk_page_options['header']['action_button_background_hover'] : '#1746e0',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_text_input( array(
                        //     'id'            => 'lk_page_options_header_action_button_text_color_hover',
                        //     'name'          => 'lk_page_options[header][action_button_text_color_hover]',
                        //     'label'         => esc_html__( 'Button Text Color Hover', 'landkit-extensions' ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_text_color_hover'] ) ) ? $lk_page_options['header']['action_button_text_color_hover'] : '#FFFFFF',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        // landkit_wp_select( array(
                        //     'id'            => 'lk_page_options_header_action_button_background',
                        //     'name'          => 'lk_page_options[header][action_button_background]',
                        //     'type'          => 'select',
                        //     'label'         => esc_html__( 'Button Background', 'landkit-extensions' ),
                        //     'options'       => array(
                        //         'btn-primary'           => esc_html__( 'Primary', 'landkit-extensions'),
                        //         'btn-secondary'         => esc_html__( 'Secondary', 'landkit-extensions'),
                        //         'btn-success'           => esc_html__( 'Success', 'landkit-extensions'),
                        //         'btn-danger'            => esc_html__( 'Danger', 'landkit-extensions'),
                        //         'btn-warning'           => esc_html__( 'Warning', 'landkit-extensions'),
                        //         'btn-info'              => esc_html__( 'Info', 'landkit-extensions'),
                        //         'btn-light'             => esc_html__( 'Light', 'landkit-extensions'),
                        //         'btn-dark'              => esc_html__( 'Dark', 'landkit-extensions'),
                        //         'btn-link'              => esc_html__( 'Link', 'landkit-extensions'),
                        //         'btn-outline-primary'   => esc_html__( 'Outline Primary', 'landkit-extensions'),
                        //         'btn-outline-secondary' => esc_html__( 'Outline Secondary', 'landkit-extensions'),
                        //         'btn-outline-success'   => esc_html__( 'Outline Success', 'landkit-extensions'),
                        //         'btn-outline-danger'    => esc_html__( 'Outline Danger', 'landkit-extensions'),
                        //         'btn-outline-warning'   => esc_html__( 'Outline Warning', 'landkit-extensions'),
                        //         'btn-outline-info'      => esc_html__( 'Outline Info', 'landkit-extensions'),
                        //         'btn-outline-light'     => esc_html__( 'Outline Light', 'landkit-extensions'),
                        //         'btn-outline-dark'      => esc_html__( 'Outline Dark', 'landkit-extensions'),
                        //         'btn-primary-soft'      => esc_html__( 'Primary Soft', 'landkit-extensions'),
                        //         'btn-secondary-soft'    => esc_html__( 'Secondary Soft', 'landkit-extensions'),
                        //         'btn-success-soft'      => esc_html__( 'Success Soft', 'landkit-extensions'),
                        //         'btn-danger-soft'       => esc_html__( 'Danger Soft', 'landkit-extensions'),
                        //         'btn-warning-soft'      => esc_html__( 'Warning Soft', 'landkit-extensions'),
                        //         'btn-info-soft'         => esc_html__( 'Info Soft', 'landkit-extensions'),
                        //     ),
                        //     'value'         => ( isset( $lk_page_options['header'] ) && isset( $lk_page_options['header']['action_button_background'] ) ) ? $lk_page_options['header']['action_button_background'] : 'btn-primary',
                        //     'wrapper_class' => 'show_if_lk_page_options_header_enable_action_button_yes hide_if_lk_page_options_header_enable_action_button',
                        // ) );

                        ?>
                    </div>
                </div>
                <div class="options_group">
                    <h3 class="option-group-title footer-options"><?php echo esc_html__( 'Footer', 'landkit-extensions' ) ?></h3>

                    <?php

                    landkit_wp_checkbox( array(
                        'id'            => 'lk_page_options_footer_disable_footer',
                        'name'          => 'lk_page_options[footer][disable_footer]',
                        'label'         => esc_html__( 'Disable Footer', 'landkit-extensions' ),
                        'value'         => ( isset( $lk_page_options['footer'] ) && isset( $lk_page_options['footer']['disable_footer'] ) ) ? $lk_page_options['footer']['disable_footer'] : '',
                        'class'         => 'show_hide_checkbox',
                    ) );

                    ?>

                    <div class="options_group show_if_lk_page_options_footer_disable_footer_no hide_if_lk_page_options_footer_disable_footer">

                        <?php

                        landkit_wp_checkbox( array(
                            'id'            => 'lk_page_options_footer_enable_custom_footer',
                            'name'          => 'lk_page_options[footer][enable_custom_footer]',
                            'label'         => esc_html__( 'Enable Custom Footer', 'landkit-extensions' ),
                            'value'         => ( isset( $lk_page_options['footer'] ) && isset( $lk_page_options['footer']['enable_custom_footer'] ) ) ? $lk_page_options['footer']['enable_custom_footer'] : '',
                            'class'         => 'show_hide_checkbox',
                        ) );

                        landkit_wp_select( array(
                            'id'            => 'lk_page_options_footer_background',
                            'name'          => 'lk_page_options[footer][background]',
                            'type'          => 'select',
                            'label'         => esc_html__( 'Background', 'landkit-extensions' ),
                            'options'       => array(
                                'bg-gray-200'   => esc_html__( 'Gray 200', 'landkit-extensions'),
                                'bg-white'      => esc_html__( 'White', 'landkit-extensions'),
                                'bg-dark'       => esc_html__( 'Dark', 'landkit-extensions'),
                                'bg-black'      => esc_html__( 'Black', 'landkit-extensions'),
                                'bg-light'      => esc_html__( 'Light', 'landkit-extensions'),
                            ),
                            'value'         => isset( $lk_page_options['footer']['background'] ) ? $lk_page_options['footer']['background'] : 'bg-gray-200',
                            'wrapper_class' => 'show_if_lk_page_options_footer_enable_custom_footer_yes hide_if_lk_page_options_footer_enable_custom_footer',
                        ) );

                        landkit_wp_checkbox( array(
                            'id'            => 'lk_page_options_footer_enable_border_top',
                            'name'          => 'lk_page_options[footer][enable_border_top]',
                            'label'         => esc_html__( 'Enable Border Top', 'landkit-extensions' ),
                            'value'         => ( isset( $lk_page_options['footer'] ) && isset( $lk_page_options['footer']['enable_border_top'] ) ) ? $lk_page_options['footer']['enable_border_top'] : '',
                            'wrapper_class' => 'show_if_lk_page_options_footer_enable_custom_footer_yes hide_if_lk_page_options_footer_enable_custom_footer',
                        ) );

                        ?>

                    </div>
                </div>
            </div><?php
        }

        public static function save( $post_id, $post ) {
            if ( isset( $_POST['lk_page_options'] ) ) {
                $clean_lk_page_options = landkit_clean( $_POST['lk_page_options'] );
                update_post_meta( $post_id, '_lk_page_options',  serialize( $clean_lk_page_options ) );
            }   
        }
    }
}
