<?php
/**
 * Plugin Name:     Landkit Extensions
 * Plugin URI:      https://themeforest.net/user/madrasthemes/portfolio
 * Description:     This selection of extensions compliment our theme Landkit. Please note: they don’t work with any WordPress theme, just Landkit.
 * Author:          MadrasThemes
 * Author URI:      https://madrasthemes.com/
 * Version:         1.0.16
 * Text Domain:     landkit-extensions
 * Domain Path:     /languages
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Define LANDKIT_PLUGIN_FILE.
if ( ! defined( 'LANDKIT_PLUGIN_FILE' ) ) {
	define( 'LANDKIT_PLUGIN_FILE', __FILE__ );
}

if ( ! class_exists( 'Landkit_Extensions' ) ) {
	/**
	 * Main Landkit_Extensions Class
	 *
	 * @class Landkit_Extensions
	 * @version 1.0.0
	 * @since 1.0.0
	 * @package Landkit
	 */
	final class Landkit_Extensions {

		/**
		 * Landkit_Extensions The single instance of Landkit_Extensions.
		 *
		 * @var     object
		 * @since   1.0.0
		 */
		private static $instance = null;

		/**
		 * The token.
		 *
		 * @var     string
		 * @since   1.0.0
		 */
		public $token;

		/**
		 * The version number.
		 *
		 * @var     string
		 * @since   1.0.0
		 */
		public $version;

		/**
		 * Constructor function.
		 *
		 * @since   1.0.0
		 * @return  void
		 */
		public function __construct() {

			$this->token   = 'landkit-extensions';
			$this->version = '1.0.4';

			add_action( 'plugins_loaded', array( $this, 'setup_constants' ), 10 );
			add_action( 'plugins_loaded', array( $this, 'includes' ), 20 );
		}

		/**
		 * Main Landkit_Extensions Instance
		 *
		 * Ensures only one instance of Landkit_Extensions is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 * @see Landkit_Extensions()
		 * @return Main Landkit instance
		 */
		public static function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Setup plugin constants
		 *
		 * @since  1.0.0
		 * @return void
		 */
		public function setup_constants() {

			// Plugin Folder Path.
			if ( ! defined( 'LANDKIT_EXTENSIONS_DIR' ) ) {
				define( 'LANDKIT_EXTENSIONS_DIR', plugin_dir_path( __FILE__ ) );
			}

			// Plugin Folder URL.
			if ( ! defined( 'LANDKIT_EXTENSIONS_URL' ) ) {
				define( 'LANDKIT_EXTENSIONS_URL', plugin_dir_url( __FILE__ ) );
			}

			// Plugin Root File.
			if ( ! defined( 'LANDKIT_EXTENSIONS_FILE' ) ) {
				define( 'LANDKIT_EXTENSIONS_FILE', __FILE__ );
			}

			// Modules File.
			if ( ! defined( 'LANDKIT_EXTENSIONS_MODULES_DIR' ) ) {
				define( 'LANDKIT_EXTENSIONS_MODULES_DIR', LANDKIT_EXTENSIONS_DIR . '/modules' );
			}

			$this->define( 'LANDKIT_ABSPATH', dirname( LANDKIT_EXTENSIONS_FILE ) . '/' );
			$this->define( 'LANDKIT_VERSION', $this->version );
		}

		/**
		 * Define constant if not already set.
		 *
		 * @param string      $name  Constant name.
		 * @param string|bool $value Constant value.
		 */
		private function define( $name, $value ) {
			if ( ! defined( $name ) ) {
				define( $name, $value );
			}
		}

		/**
		 * What type of request is this?
		 *
		 * @param  string $type admin, ajax, cron or landkitend.
		 * @return bool
		 */
		private function is_request( $type ) {
			switch ( $type ) {
				case 'admin':
					return is_admin();
				case 'ajax':
					return defined( 'DOING_AJAX' );
				case 'cron':
					return defined( 'DOING_CRON' );
				case 'landkitend':
					return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' ) && ! $this->is_rest_api_request();
			}
		}

		/**
		 * Include required files
		 *
		 * @since  1.0.0
		 * @return void
		 */
		public function includes() {
			/**
			 * Class autoloader.
			 */
			include_once LANDKIT_EXTENSIONS_DIR . '/includes/class-landkit-autoloader.php';

			/**
			 * Core classes.
			 */
			require LANDKIT_EXTENSIONS_DIR . '/includes/functions.php';
			require LANDKIT_EXTENSIONS_DIR . '/includes/landkit-core-functions.php';

			/**
			 * Custom Post Types
			 */
			require LANDKIT_EXTENSIONS_DIR . '/includes/custom-post-types/portfolios.php';

			if ( $this->is_request( 'admin' ) ) {
				include_once LANDKIT_EXTENSIONS_DIR . '/includes/admin/class-landkit-extensions-admin.php';
			}

			/**
			 * Social Share
			 */
			require LANDKIT_EXTENSIONS_MODULES_DIR . '/social-share/class-landkit-socialshare.php';
		}

		/**
		 * Get the plugin url.
		 *
		 * @return string
		 */
		public function plugin_url() {
			return untrailingslashit( plugins_url( '/', LANDKIT_PLUGIN_FILE ) );
		}

		/**
		 * Cloning is forbidden.
		 *
		 * @since 1.0.0
		 */
		public function __clone() {
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'landkit-extensions' ), '1.0.0' );
		}

		/**
		 * Unserializing instances of this class is forbidden.
		 *
		 * @since 1.0.0
		 */
		public function __wakeup() {
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'landkit-extensions' ), '1.0.0' );
		}
	}
}

/**
 * Returns the main instance of Landkit_Extensions to prevent the need to use globals.
 *
 * @since  1.0.0
 * @return object Landkit_Extensions
 */
function Landkit_Extensions() { //phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionNameInvalid
	return Landkit_Extensions::instance();
}

/**
 * Initialise the plugin
 */
Landkit_Extensions();
