<?php
namespace LandkitElementor\Core;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

use Elementor\Utils;

final class Icons_Manager {
    public function __construct() {
        add_filter( 'elementor/icons_manager/additional_tabs', [ $this, 'additional_tabs' ], 20 );
    }

    public function additional_tabs( $tabs ) {
        $new_tabs = [
            'feather-icons' => [
                'name' => 'feather-icons',
                'label' => __( 'Feather Icons', 'landkit-elementor' ),
                'url' => get_template_directory_uri() . '/assets/fonts/Feather/feather.css',
                'enqueue' => [],
                'prefix' => 'fe-',
                'displayPrefix' => 'fe',
                'labelIcon' => 'fe fe-feather',
                'ver' => '4.24.1',
                'fetchJson' => get_template_directory_uri() . '/assets/fonts/Feather/feather.js',
                'native' => false,
            ],
            'duatone-icons' => [
                'name' => 'duatone-icons',
                'label' => __( 'Duatone Icons', 'landkit-elementor' ),
                'url' => get_template_directory_uri() . '/assets/fonts/icomoon/icomoon.css',
                'prefix' => 'icon-',
                'displayPrefix' => 'icon',
                'labelIcon' => 'icon icon-Puzzle',
                'ver' => '1.0',
                'fetchJson' => get_template_directory_uri() . '/assets/fonts/icomoon/icomoon.js',
                'native' => false,
                'render_callback' => [ $this, 'render_duatone_icon_html' ],
            ],
        ];

        return array_merge( $tabs, $new_tabs );
    }

    public function render_duatone_icon_html( $icon, $attributes, $tag ) {
        if ( empty( $attributes['class'] ) ) {
            $attributes['class'] = $icon['value'];
        } else {
            if ( is_array( $attributes['class'] ) ) {
                $attributes['class'][] = $icon['value'];
            } else {
                $attributes['class'] .= ' ' . $icon['value'];
            }
        }

        $html = '<span ' . Utils::render_html_attributes( $attributes ) . '>';

        if( in_array( $icon['value'], array( 'icon icon-Celcium', 'icon icon-Cloud-fog', 'icon icon-Cloud-sun', 'icon icon-Cloud-wind', 'icon icon-Cloud1', 'icon icon-Cloudy-night', 'icon icon-Cloudy', 'icon icon-Day-rain', 'icon icon-Fahrenheit', 'icon icon-Night-fog', 'icon icon-Night-rain', 'icon icon-Rain', 'icon icon-Rain1', 'icon icon-Rain2', 'icon icon-Rainbow', 'icon icon-Snow1', 'icon icon-Snow2', 'icon icon-Snow3', 'icon icon-Storm', 'icon icon-Sun-fog', 'icon icon-Sun', 'icon icon-Suset', 'icon icon-Suset1', 'icon icon-Thunder-night', 'icon icon-Thunder', 'icon icon-Umbrella', 'icon icon-Wind', 'icon icon-Angle-Grinder', 'icon icon-Axe', 'icon icon-Brush', 'icon icon-Compass', 'icon icon-Hummer', 'icon icon-Hummer1', 'icon icon-Pantone', 'icon icon-Road-Cone', 'icon icon-Roller', 'icon icon-Roulette', 'icon icon-Screwdriver', 'icon icon-Shovel', 'icon icon-Spatula', 'icon icon-Swiss-knife', 'icon icon-Tools', 'icon icon-Align-auto', 'icon icon-Align-center', 'icon icon-Align-justify', 'icon icon-Align-left', 'icon icon-Align-right', 'icon icon-Article', 'icon icon-Bullet-list', 'icon icon-Edit-text', 'icon icon-Font', 'icon icon-H1', 'icon icon-H2', 'icon icon-Menu', 'icon icon-Quote', 'icon icon-Quote1', 'icon icon-Strikethrough', 'icon icon-Text-height', 'icon icon-Text-width', 'icon icon-Underline', 'icon icon-ATM', 'icon icon-Bag', 'icon icon-Bag1', 'icon icon-Barcode-read', 'icon icon-Barcode-scan', 'icon icon-Barcode', 'icon icon-Bitcoin', 'icon icon-Box', 'icon icon-Box1', 'icon icon-Box2', 'icon icon-Calculator', 'icon icon-Cart', 'icon icon-Cart1', 'icon icon-Cart2', 'icon icon-Chart-bar', 'icon icon-Chart-bar1', 'icon icon-Chart-bar2', 'icon icon-Chart-line', 'icon icon-Chart-line1', 'icon icon-Chart-pie', 'icon icon-Credit-card', 'icon icon-Dollar', 'icon icon-Euro', 'icon icon-Gift', 'icon icon-Loader', 'icon icon-MC', 'icon icon-Money', 'icon icon-Pound', 'icon icon-Rouble', 'icon icon-Safe', 'icon icon-Sale', 'icon icon-Sale1', 'icon icon-Settings', 'icon icon-Sort', 'icon icon-Wallet', 'icon icon-Wallet1', 'icon icon-Wallet2', 'icon icon-Angle-double-down', 'icon icon-Angle-double-left', 'icon icon-Angle-double-right', 'icon icon-Angle-double-up', 'icon icon-Arrow-down', 'icon icon-Arrow-from-bottom', 'icon icon-Arrow-from-left', 'icon icon-Arrow-from-right', 'icon icon-Arrow-from-top', 'icon icon-Arrow-left', 'icon icon-Arrow-right', 'icon icon-Arrow-to-bottom', 'icon icon-Arrow-to-left', 'icon icon-Arrow-to-right', 'icon icon-Arrow-to-up', 'icon icon-Arrow-up', 'icon icon-Arrows-h', 'icon icon-Arrows-v', 'icon icon-Close', 'icon icon-Double-check', 'icon icon-Down-2', 'icon icon-Down-left', 'icon icon-Down-right', 'icon icon-Exchange', 'icon icon-Left-3', 'icon icon-Left-2', 'icon icon-Plus', 'icon icon-Right-3', 'icon icon-Right-2', 'icon icon-Route', 'icon icon-Sign-in', 'icon icon-Sign-out', 'icon icon-Up-2', 'icon icon-Up-down', 'icon icon-Up-left', 'icon icon-Up-right', 'icon icon-Add-music', 'icon icon-Airplay-video', 'icon icon-Airplay', 'icon icon-Back', 'icon icon-Backward', 'icon icon-CD', 'icon icon-DVD', 'icon icon-Eject', 'icon icon-Equalizer', 'icon icon-Forward', 'icon icon-Media-library', 'icon icon-Media-library1', 'icon icon-Media-library2', 'icon icon-Movie-Lane', 'icon icon-Movie-lane', 'icon icon-Music-cloud', 'icon icon-Mute', 'icon icon-Next', 'icon icon-Playlist', 'icon icon-Playlist1', 'icon icon-Repeat-one', 'icon icon-Repeat', 'icon icon-Shuffle', 'icon icon-Volume-down', 'icon icon-Volume-full', 'icon icon-Volume-half', 'icon icon-Volume-up', 'icon icon-Vynil', 'icon icon-Youtube', 'icon icon-Position', 'icon icon-Layout-3d', 'icon icon-Layout-4-blocks', 'icon icon-Layout-arrange', 'icon icon-Layout-grid', 'icon icon-Layout-horizontal', 'icon icon-Layout-left-panel-1', 'icon icon-Layout-left-panel-2', 'icon icon-Layout-right-panel-1', 'icon icon-Layout-right-panel-2', 'icon icon-Layout-top-panel-1', 'icon icon-Layout-top-panel-2', 'icon icon-Layout-top-panel-3', 'icon icon-Layout-top-panel-4', 'icon icon-Layout-top-panel-5', 'icon icon-Layout-top-panel-6', 'icon icon-Layout-vertical', 'icon icon-Air-ballon', 'icon icon-Alarm-clock', 'icon icon-Armchair', 'icon icon-Bath', 'icon icon-Bed', 'icon icon-Book-open', 'icon icon-Box3', 'icon icon-Broom', 'icon icon-Building', 'icon icon-Bulb', 'icon icon-Bulb1', 'icon icon-Chair', 'icon icon-Chair1', 'icon icon-Clock', 'icon icon-Commode', 'icon icon-Commode1', 'icon icon-Couch', 'icon icon-Cupboard', 'icon icon-Curtains', 'icon icon-Deer', 'icon icon-Door-open', 'icon icon-Fireplace', 'icon icon-Flashlight', 'icon icon-Flower', 'icon icon-Globe', 'icon icon-Key', 'icon icon-Ladder', 'icon icon-Lamp', 'icon icon-Lamp1', 'icon icon-Library', 'icon icon-Mailbox', 'icon icon-Mirror', 'icon icon-Picture', 'icon icon-Timer', 'icon icon-Toilet', 'icon icon-Trash', 'icon icon-Water-mixer', 'icon icon-Weight', 'icon icon-Weight1', 'icon icon-Attachment', 'icon icon-Attachment1', 'icon icon-Clipboard', 'icon icon-Dislike', 'icon icon-Duplicate', 'icon icon-Expand-arrows', 'icon icon-Half-heart', 'icon icon-Half-star', 'icon icon-Hidden', 'icon icon-Like', 'icon icon-Notification', 'icon icon-Notifications', 'icon icon-Sad', 'icon icon-Save', 'icon icon-Scale', 'icon icon-Scissors', 'icon icon-Search', 'icon icon-Settings-1', 'icon icon-Settings1', 'icon icon-Shield-check', 'icon icon-Shield-disabled', 'icon icon-Shield-protected', 'icon icon-Size', 'icon icon-Smile', 'icon icon-Thunder-move', 'icon icon-Trash1', 'icon icon-User', 'icon icon-Beer', 'icon icon-Bottle', 'icon icon-Bottle1', 'icon icon-Bread', 'icon icon-Bucket', 'icon icon-Burger', 'icon icon-Cake', 'icon icon-Carrot', 'icon icon-Cheese', 'icon icon-Chicken', 'icon icon-Coffee', 'icon icon-Coffee1', 'icon icon-Dinner', 'icon icon-Fish', 'icon icon-Glass-martini', 'icon icon-Ice-cream', 'icon icon-Ice-cream1', 'icon icon-Miso-soup', 'icon icon-Orange', 'icon icon-Sushi', 'icon icon-Two-bottles', 'icon icon-Wine', 'icon icon-Cloud-download', 'icon icon-Cloud-upload', 'icon icon-Compilation', 'icon icon-Compiled-file', 'icon icon-Deleted-file', 'icon icon-Deleted-folder', 'icon icon-Download', 'icon icon-Downloaded-file', 'icon icon-Downloads-folder', 'icon icon-Export', 'icon icon-File-cloud', 'icon icon-File-done', 'icon icon-File-minus', 'icon icon-File-plus', 'icon icon-File', 'icon icon-Folder-check', 'icon icon-Folder-cloud', 'icon icon-Folder-error', 'icon icon-Folder-minus', 'icon icon-Folder-plus', 'icon icon-Group-folders', 'icon icon-Import', 'icon icon-Locked-folder', 'icon icon-Media-folder', 'icon icon-Media', 'icon icon-Music1', 'icon icon-Pictures', 'icon icon-Protected-file', 'icon icon-Selected-file', 'icon icon-Share', 'icon icon-Upload-folder', 'icon icon-Upload', 'icon icon-Uploaded-file', 'icon icon-Air-conditioning', 'icon icon-Blender', 'icon icon-Gas-stove', 'icon icon-Hair-dryer', 'icon icon-Iron', 'icon icon-Kettle', 'icon icon-Mixer', 'icon icon-Outlet', 'icon icon-Range-hood', 'icon icon-Shutdown', 'icon icon-Washer', 'icon icon-Battery-half', 'icon icon-Airpods', 'icon icon-Android', 'icon icon-Apple-Watch', 'icon icon-Battery-charging', 'icon icon-Battery-empty', 'icon icon-Battery-full', 'icon icon-Bluetooth', 'icon icon-Camera', 'icon icon-Cardboard-vr', 'icon icon-Cassete', 'icon icon-CPU', 'icon icon-Diagnostics', 'icon icon-Display', 'icon icon-Display1', 'icon icon-Display2', 'icon icon-Gameboy', 'icon icon-Gamepad', 'icon icon-Gamepad1', 'icon icon-Generator', 'icon icon-Hard-drive', 'icon icon-Headphones', 'icon icon-Homepod', 'icon icon-iMac', 'icon icon-iPhone-X', 'icon icon-Keyboard', 'icon icon-Laptop-macbook', 'icon icon-Laptop', 'icon icon-LTE', 'icon icon-LTE1', 'icon icon-Mic', 'icon icon-Midi', 'icon icon-Mouse', 'icon icon-Phone', 'icon icon-Printer', 'icon icon-Radio', 'icon icon-Router', 'icon icon-Router1', 'icon icon-Server', 'icon icon-Speaker', 'icon icon-Tablet', 'icon icon-TV', 'icon icon-TV1', 'icon icon-Usb-storage', 'icon icon-USB', 'icon icon-Video-camera', 'icon icon-Watch', 'icon icon-Watch1', 'icon icon-Wi-fi', 'icon icon-Anchor-center-down', 'icon icon-Anchor-center-up', 'icon icon-Anchor-center', 'icon icon-Anchor-left-down', 'icon icon-Anchor-left-up', 'icon icon-Anchor-left', 'icon icon-Anchor-right-down', 'icon icon-Anchor-right-up', 'icon icon-Anchor-right', 'icon icon-Arrows', 'icon icon-Bezier-curve', 'icon icon-Brush1', 'icon icon-Bucket1', 'icon icon-Cap-1', 'icon icon-Cap-2', 'icon icon-Cap-3', 'icon icon-Color-profile', 'icon icon-Crop', 'icon icon-Difference', 'icon icon-Edit1', 'icon icon-Flatten', 'icon icon-Flip-horizontal', 'icon icon-Flip-vertical', 'icon icon-Horizontal', 'icon icon-Interselect', 'icon icon-Join-1', 'icon icon-Join-2', 'icon icon-Join-3', 'icon icon-Layers', 'icon icon-Line', 'icon icon-Magic', 'icon icon-Mask', 'icon icon-Patch', 'icon icon-Pen-tool-vector', 'icon icon-Penruller', 'icon icon-Picker', 'icon icon-Pixels', 'icon icon-Select', 'icon icon-Sketch', 'icon icon-Stamp', 'icon icon-Substract', 'icon icon-Target', 'icon icon-Vertical', 'icon icon-Zoom-minus', 'icon icon-Zoom-plus', 'icon icon-Cooking-book', 'icon icon-Baking-glove', 'icon icon-Bowl', 'icon icon-Chef', 'icon icon-Cooking-pot', 'icon icon-Cutting-board', 'icon icon-Dinner1', 'icon icon-Dish', 'icon icon-Dishes', 'icon icon-Fork-spoon-knife', 'icon icon-Fork-spoon', 'icon icon-Fork', 'icon icon-Frying-pan', 'icon icon-Grater', 'icon icon-Kitchen-scale', 'icon icon-Knifefork', 'icon icon-Knifefork1', 'icon icon-Knife', 'icon icon-Knife1', 'icon icon-Ladle', 'icon icon-Rolling-pin', 'icon icon-Saucepan', 'icon icon-Shovel1', 'icon icon-Sieve', 'icon icon-Spoon', 'icon icon-Adress-book-1', 'icon icon-Active-call', 'icon icon-Add-user', 'icon icon-Adress-book-2', 'icon icon-Adress-book', 'icon icon-Adress-book1', 'icon icon-Chat-check', 'icon icon-Chat-error', 'icon icon-Chat-locked', 'icon icon-Chat-smile', 'icon icon-Chat', 'icon icon-Chat1', 'icon icon-Clipboard-check', 'icon icon-Clipboard-list', 'icon icon-Delete-user', 'icon icon-Dial-numbers', 'icon icon-Flag', 'icon icon-Group-chat', 'icon icon-Group', 'icon icon-Incoming-box', 'icon icon-Incoming-call', 'icon icon-Incoming-mail', 'icon icon-Mail-attachment', 'icon icon-Mail-box', 'icon icon-Mail-error', 'icon icon-Mail-heart', 'icon icon-Mail-locked', 'icon icon-Mail-notification', 'icon icon-Mail-opened', 'icon icon-Mail-unocked', 'icon icon-Missed-call', 'icon icon-Outgoing-box', 'icon icon-Outgoing-call', 'icon icon-Outgoing-mail', 'icon icon-Readed-mail', 'icon icon-Reply-all', 'icon icon-RSS', 'icon icon-Safe-chat', 'icon icon-Sending-mail', 'icon icon-Sending', 'icon icon-Share1', 'icon icon-Snoozed-mail', 'icon icon-Thumbtack', 'icon icon-Urgent-mail', 'icon icon-Write', 'icon icon-Backspace', 'icon icon-Code1', 'icon icon-Commit', 'icon icon-Compiling', 'icon icon-Done-circle', 'icon icon-Error-circle', 'icon icon-Git-1', 'icon icon-Git-2', 'icon icon-Git-3', 'icon icon-Git-4', 'icon icon-Git', 'icon icon-Git1', 'icon icon-Git2', 'icon icon-Git3', 'icon icon-Github', 'icon icon-Info-circle', 'icon icon-Left-circle', 'icon icon-Lock-circle', 'icon icon-Lock-overturning', 'icon icon-Minus1', 'icon icon-Option', 'icon icon-Plus1', 'icon icon-Question-circle', 'icon icon-Right-circle', 'icon icon-Settings-4', 'icon icon-Settings2', 'icon icon-Spy', 'icon icon-Terminal', 'icon icon-Thunder-circle', 'icon icon-Time-schedule', 'icon icon-Warning-1-circle', 'icon icon-Warning-2', 'icon icon-Briefcase', 'icon icon-Cap', 'icon icon-Crown', 'icon icon-Dress', 'icon icon-Hat', 'icon icon-Shirt', 'icon icon-Shoes', 'icon icon-Sneakers', 'icon icon-Socks', 'icon icon-Sun-glasses', 'icon icon-Tie' ) ) ) {
            $html .= '<span class="path1"></span>';
        }

        if ( in_array( $icon['value'], array( 'icon icon-Celcium', 'icon icon-Cloud-fog', 'icon icon-Cloud-sun', 'icon icon-Cloud-wind', 'icon icon-Cloud1', 'icon icon-Cloudy-night', 'icon icon-Cloudy', 'icon icon-Day-rain', 'icon icon-Fahrenheit', 'icon icon-Night-fog', 'icon icon-Night-rain', 'icon icon-Rain', 'icon icon-Rain1', 'icon icon-Rain2', 'icon icon-Rainbow', 'icon icon-Snow1', 'icon icon-Snow2', 'icon icon-Snow3', 'icon icon-Storm', 'icon icon-Sun-fog', 'icon icon-Sun', 'icon icon-Suset', 'icon icon-Suset1', 'icon icon-Thunder-night', 'icon icon-Thunder', 'icon icon-Umbrella', 'icon icon-Wind', 'icon icon-Angle-Grinder', 'icon icon-Axe', 'icon icon-Brush', 'icon icon-Compass', 'icon icon-Hummer', 'icon icon-Hummer1', 'icon icon-Pantone', 'icon icon-Road-Cone', 'icon icon-Roller', 'icon icon-Roulette', 'icon icon-Screwdriver', 'icon icon-Shovel', 'icon icon-Spatula', 'icon icon-Swiss-knife', 'icon icon-Tools', 'icon icon-Align-auto', 'icon icon-Align-center', 'icon icon-Align-justify', 'icon icon-Align-left', 'icon icon-Align-right', 'icon icon-Article', 'icon icon-Bullet-list', 'icon icon-Edit-text', 'icon icon-Font', 'icon icon-H1', 'icon icon-H2', 'icon icon-Menu', 'icon icon-Quote', 'icon icon-Quote1', 'icon icon-Strikethrough', 'icon icon-Text-height', 'icon icon-Text-width', 'icon icon-Underline', 'icon icon-ATM', 'icon icon-Bag', 'icon icon-Bag1', 'icon icon-Barcode-read', 'icon icon-Barcode-scan', 'icon icon-Barcode', 'icon icon-Bitcoin', 'icon icon-Box', 'icon icon-Box1', 'icon icon-Box2', 'icon icon-Calculator', 'icon icon-Cart', 'icon icon-Cart1', 'icon icon-Cart2', 'icon icon-Chart-bar', 'icon icon-Chart-bar1', 'icon icon-Chart-bar2', 'icon icon-Chart-line', 'icon icon-Chart-line1', 'icon icon-Chart-pie', 'icon icon-Credit-card', 'icon icon-Dollar', 'icon icon-Euro', 'icon icon-Gift', 'icon icon-Loader', 'icon icon-MC', 'icon icon-Money', 'icon icon-Pound', 'icon icon-Rouble', 'icon icon-Safe', 'icon icon-Sale', 'icon icon-Sale1', 'icon icon-Settings', 'icon icon-Sort', 'icon icon-Wallet', 'icon icon-Wallet1', 'icon icon-Wallet2', 'icon icon-Angle-double-down', 'icon icon-Angle-double-left', 'icon icon-Angle-double-right', 'icon icon-Angle-double-up', 'icon icon-Arrow-down', 'icon icon-Arrow-from-bottom', 'icon icon-Arrow-from-left', 'icon icon-Arrow-from-right', 'icon icon-Arrow-from-top', 'icon icon-Arrow-left', 'icon icon-Arrow-right', 'icon icon-Arrow-to-bottom', 'icon icon-Arrow-to-left', 'icon icon-Arrow-to-right', 'icon icon-Arrow-to-up', 'icon icon-Arrow-up', 'icon icon-Arrows-h', 'icon icon-Arrows-v', 'icon icon-Close', 'icon icon-Double-check', 'icon icon-Down-2', 'icon icon-Down-left', 'icon icon-Down-right', 'icon icon-Exchange', 'icon icon-Left-3', 'icon icon-Left-2', 'icon icon-Plus', 'icon icon-Right-3', 'icon icon-Right-2', 'icon icon-Route', 'icon icon-Sign-in', 'icon icon-Sign-out', 'icon icon-Up-2', 'icon icon-Up-down', 'icon icon-Up-left', 'icon icon-Up-right', 'icon icon-Add-music', 'icon icon-Airplay-video', 'icon icon-Airplay', 'icon icon-Back', 'icon icon-Backward', 'icon icon-CD', 'icon icon-DVD', 'icon icon-Eject', 'icon icon-Equalizer', 'icon icon-Forward', 'icon icon-Media-library', 'icon icon-Media-library1', 'icon icon-Media-library2', 'icon icon-Movie-Lane', 'icon icon-Movie-lane', 'icon icon-Music-cloud', 'icon icon-Mute', 'icon icon-Next', 'icon icon-Playlist', 'icon icon-Playlist1', 'icon icon-Repeat-one', 'icon icon-Repeat', 'icon icon-Shuffle', 'icon icon-Volume-down', 'icon icon-Volume-full', 'icon icon-Volume-half', 'icon icon-Volume-up', 'icon icon-Vynil', 'icon icon-Youtube', 'icon icon-Position', 'icon icon-Layout-3d', 'icon icon-Layout-4-blocks', 'icon icon-Layout-arrange', 'icon icon-Layout-grid', 'icon icon-Layout-horizontal', 'icon icon-Layout-left-panel-1', 'icon icon-Layout-left-panel-2', 'icon icon-Layout-right-panel-1', 'icon icon-Layout-right-panel-2', 'icon icon-Layout-top-panel-1', 'icon icon-Layout-top-panel-2', 'icon icon-Layout-top-panel-3', 'icon icon-Layout-top-panel-4', 'icon icon-Layout-top-panel-5', 'icon icon-Layout-top-panel-6', 'icon icon-Layout-vertical', 'icon icon-Air-ballon', 'icon icon-Alarm-clock', 'icon icon-Armchair', 'icon icon-Bath', 'icon icon-Bed', 'icon icon-Book-open', 'icon icon-Box3', 'icon icon-Broom', 'icon icon-Building', 'icon icon-Bulb', 'icon icon-Bulb1', 'icon icon-Chair', 'icon icon-Chair1', 'icon icon-Clock', 'icon icon-Commode', 'icon icon-Commode1', 'icon icon-Couch', 'icon icon-Cupboard', 'icon icon-Curtains', 'icon icon-Deer', 'icon icon-Door-open', 'icon icon-Fireplace', 'icon icon-Flashlight', 'icon icon-Flower', 'icon icon-Globe', 'icon icon-Key', 'icon icon-Ladder', 'icon icon-Lamp', 'icon icon-Lamp1', 'icon icon-Library', 'icon icon-Mailbox', 'icon icon-Mirror', 'icon icon-Picture', 'icon icon-Timer', 'icon icon-Toilet', 'icon icon-Trash', 'icon icon-Water-mixer', 'icon icon-Weight', 'icon icon-Weight1', 'icon icon-Attachment', 'icon icon-Attachment1', 'icon icon-Clipboard', 'icon icon-Dislike', 'icon icon-Duplicate', 'icon icon-Expand-arrows', 'icon icon-Half-heart', 'icon icon-Half-star', 'icon icon-Hidden', 'icon icon-Like', 'icon icon-Notification', 'icon icon-Notifications', 'icon icon-Sad', 'icon icon-Save', 'icon icon-Scale', 'icon icon-Scissors', 'icon icon-Search', 'icon icon-Settings-1', 'icon icon-Settings1', 'icon icon-Shield-check', 'icon icon-Shield-disabled', 'icon icon-Shield-protected', 'icon icon-Size', 'icon icon-Smile', 'icon icon-Thunder-move', 'icon icon-Trash1', 'icon icon-User', 'icon icon-Beer', 'icon icon-Bottle', 'icon icon-Bottle1', 'icon icon-Bread', 'icon icon-Bucket', 'icon icon-Burger', 'icon icon-Cake', 'icon icon-Carrot', 'icon icon-Cheese', 'icon icon-Chicken', 'icon icon-Coffee', 'icon icon-Coffee1', 'icon icon-Dinner', 'icon icon-Fish', 'icon icon-Glass-martini', 'icon icon-Ice-cream', 'icon icon-Ice-cream1', 'icon icon-Miso-soup', 'icon icon-Orange', 'icon icon-Sushi', 'icon icon-Two-bottles', 'icon icon-Wine', 'icon icon-Cloud-download', 'icon icon-Cloud-upload', 'icon icon-Compilation', 'icon icon-Compiled-file', 'icon icon-Deleted-file', 'icon icon-Deleted-folder', 'icon icon-Download', 'icon icon-Downloaded-file', 'icon icon-Downloads-folder', 'icon icon-Export', 'icon icon-File-cloud', 'icon icon-File-done', 'icon icon-File-minus', 'icon icon-File-plus', 'icon icon-File', 'icon icon-Folder-check', 'icon icon-Folder-cloud', 'icon icon-Folder-error', 'icon icon-Folder-minus', 'icon icon-Folder-plus', 'icon icon-Group-folders', 'icon icon-Import', 'icon icon-Locked-folder', 'icon icon-Media-folder', 'icon icon-Media', 'icon icon-Music1', 'icon icon-Pictures', 'icon icon-Protected-file', 'icon icon-Selected-file', 'icon icon-Share', 'icon icon-Upload-folder', 'icon icon-Upload', 'icon icon-Uploaded-file', 'icon icon-Air-conditioning', 'icon icon-Blender', 'icon icon-Gas-stove', 'icon icon-Hair-dryer', 'icon icon-Iron', 'icon icon-Kettle', 'icon icon-Mixer', 'icon icon-Outlet', 'icon icon-Range-hood', 'icon icon-Shutdown', 'icon icon-Washer', 'icon icon-Battery-half', 'icon icon-Airpods', 'icon icon-Android', 'icon icon-Apple-Watch', 'icon icon-Battery-charging', 'icon icon-Battery-empty', 'icon icon-Battery-full', 'icon icon-Bluetooth', 'icon icon-Camera', 'icon icon-Cardboard-vr', 'icon icon-Cassete', 'icon icon-CPU', 'icon icon-Diagnostics', 'icon icon-Display', 'icon icon-Display1', 'icon icon-Display2', 'icon icon-Gameboy', 'icon icon-Gamepad', 'icon icon-Gamepad1', 'icon icon-Generator', 'icon icon-Hard-drive', 'icon icon-Headphones', 'icon icon-Homepod', 'icon icon-iMac', 'icon icon-iPhone-X', 'icon icon-Keyboard', 'icon icon-Laptop-macbook', 'icon icon-Laptop', 'icon icon-LTE', 'icon icon-LTE1', 'icon icon-Mic', 'icon icon-Midi', 'icon icon-Mouse', 'icon icon-Phone', 'icon icon-Printer', 'icon icon-Radio', 'icon icon-Router', 'icon icon-Router1', 'icon icon-Server', 'icon icon-Speaker', 'icon icon-Tablet', 'icon icon-TV', 'icon icon-TV1', 'icon icon-Usb-storage', 'icon icon-USB', 'icon icon-Video-camera', 'icon icon-Watch', 'icon icon-Watch1', 'icon icon-Wi-fi', 'icon icon-Anchor-center-down', 'icon icon-Anchor-center-up', 'icon icon-Anchor-center', 'icon icon-Anchor-left-down', 'icon icon-Anchor-left-up', 'icon icon-Anchor-left', 'icon icon-Anchor-right-down', 'icon icon-Anchor-right-up', 'icon icon-Anchor-right', 'icon icon-Arrows', 'icon icon-Bezier-curve', 'icon icon-Brush1', 'icon icon-Bucket1', 'icon icon-Cap-1', 'icon icon-Cap-2', 'icon icon-Cap-3', 'icon icon-Color-profile', 'icon icon-Crop', 'icon icon-Difference', 'icon icon-Edit1', 'icon icon-Flatten', 'icon icon-Flip-horizontal', 'icon icon-Flip-vertical', 'icon icon-Horizontal', 'icon icon-Interselect', 'icon icon-Join-1', 'icon icon-Join-2', 'icon icon-Join-3', 'icon icon-Layers', 'icon icon-Line', 'icon icon-Magic', 'icon icon-Mask', 'icon icon-Patch', 'icon icon-Pen-tool-vector', 'icon icon-Penruller', 'icon icon-Picker', 'icon icon-Pixels', 'icon icon-Select', 'icon icon-Sketch', 'icon icon-Stamp', 'icon icon-Substract', 'icon icon-Target', 'icon icon-Vertical', 'icon icon-Zoom-minus', 'icon icon-Zoom-plus', 'icon icon-Cooking-book', 'icon icon-Baking-glove', 'icon icon-Bowl', 'icon icon-Chef', 'icon icon-Cooking-pot', 'icon icon-Cutting-board', 'icon icon-Dinner1', 'icon icon-Dish', 'icon icon-Dishes', 'icon icon-Fork-spoon-knife', 'icon icon-Fork-spoon', 'icon icon-Fork', 'icon icon-Frying-pan', 'icon icon-Grater', 'icon icon-Kitchen-scale', 'icon icon-Knifefork', 'icon icon-Knifefork1', 'icon icon-Knife', 'icon icon-Knife1', 'icon icon-Ladle', 'icon icon-Rolling-pin', 'icon icon-Saucepan', 'icon icon-Shovel1', 'icon icon-Sieve', 'icon icon-Spoon', 'icon icon-Adress-book-1', 'icon icon-Active-call', 'icon icon-Add-user', 'icon icon-Adress-book-2', 'icon icon-Adress-book', 'icon icon-Adress-book1', 'icon icon-Chat-check', 'icon icon-Chat-error', 'icon icon-Chat-locked', 'icon icon-Chat-smile', 'icon icon-Chat', 'icon icon-Chat1', 'icon icon-Clipboard-check', 'icon icon-Clipboard-list', 'icon icon-Delete-user', 'icon icon-Dial-numbers', 'icon icon-Flag', 'icon icon-Group-chat', 'icon icon-Group', 'icon icon-Incoming-box', 'icon icon-Incoming-call', 'icon icon-Incoming-mail', 'icon icon-Mail-attachment', 'icon icon-Mail-box', 'icon icon-Mail-error', 'icon icon-Mail-heart', 'icon icon-Mail-locked', 'icon icon-Mail-notification', 'icon icon-Mail-opened', 'icon icon-Mail-unocked', 'icon icon-Missed-call', 'icon icon-Outgoing-box', 'icon icon-Outgoing-call', 'icon icon-Outgoing-mail', 'icon icon-Readed-mail', 'icon icon-Reply-all', 'icon icon-RSS', 'icon icon-Safe-chat', 'icon icon-Sending-mail', 'icon icon-Sending', 'icon icon-Share1', 'icon icon-Snoozed-mail', 'icon icon-Thumbtack', 'icon icon-Urgent-mail', 'icon icon-Write', 'icon icon-Backspace', 'icon icon-Code1', 'icon icon-Commit', 'icon icon-Compiling', 'icon icon-Done-circle', 'icon icon-Error-circle', 'icon icon-Git-1', 'icon icon-Git-2', 'icon icon-Git-3', 'icon icon-Git-4', 'icon icon-Git', 'icon icon-Git1', 'icon icon-Git2', 'icon icon-Git3', 'icon icon-Github', 'icon icon-Info-circle', 'icon icon-Left-circle', 'icon icon-Lock-circle', 'icon icon-Lock-overturning', 'icon icon-Minus1', 'icon icon-Option', 'icon icon-Plus1', 'icon icon-Question-circle', 'icon icon-Right-circle', 'icon icon-Settings-4', 'icon icon-Settings2', 'icon icon-Spy', 'icon icon-Terminal', 'icon icon-Thunder-circle', 'icon icon-Time-schedule', 'icon icon-Warning-1-circle', 'icon icon-Warning-2', 'icon icon-Briefcase', 'icon icon-Cap', 'icon icon-Crown', 'icon icon-Dress', 'icon icon-Hat', 'icon icon-Shirt', 'icon icon-Shoes', 'icon icon-Sneakers', 'icon icon-Socks', 'icon icon-Sun-glasses', 'icon icon-Tie' ) ) ) {
            $html .= '<span class="path2"></span>';
        }

        if ( in_array( $icon['value'], array( 'icon icon-Cloud-wind', 'icon icon-Rainbow', 'icon icon-Angle-Grinder', 'icon icon-Hummer1', 'icon icon-Pantone', 'icon icon-Roller', 'icon icon-Align-left', 'icon icon-Barcode-scan', 'icon icon-Bitcoin', 'icon icon-Chart-bar', 'icon icon-Chart-bar1', 'icon icon-Chart-bar2', 'icon icon-Credit-card', 'icon icon-Dollar', 'icon icon-Loader', 'icon icon-Sale1', 'icon icon-Wallet', 'icon icon-Arrow-from-bottom', 'icon icon-Arrow-from-left', 'icon icon-Arrow-from-right', 'icon icon-Arrow-from-top', 'icon icon-Arrow-to-bottom', 'icon icon-Arrow-to-left', 'icon icon-Arrow-to-right', 'icon icon-Arrow-to-up', 'icon icon-Exchange', 'icon icon-Sign-in', 'icon icon-Sign-out', 'icon icon-Up-down', 'icon icon-Equalizer', 'icon icon-Media-library', 'icon icon-Position', 'icon icon-Alarm-clock', 'icon icon-Bed', 'icon icon-Building', 'icon icon-Bulb', 'icon icon-Bulb1', 'icon icon-Flower', 'icon icon-Lamp', 'icon icon-Picture', 'icon icon-Toilet', 'icon icon-Water-mixer', 'icon icon-Attachment1', 'icon icon-Clipboard', 'icon icon-Beer', 'icon icon-Carrot', 'icon icon-Coffee', 'icon icon-Coffee1', 'icon icon-Compilation', 'icon icon-Compiled-file', 'icon icon-Download', 'icon icon-Export', 'icon icon-File', 'icon icon-Import', 'icon icon-Pictures', 'icon icon-Share', 'icon icon-Upload', 'icon icon-Camera', 'icon icon-CPU', 'icon icon-Diagnostics', 'icon icon-Display1', 'icon icon-Display2', 'icon icon-Generator', 'icon icon-iMac', 'icon icon-Midi', 'icon icon-Mouse', 'icon icon-Phone', 'icon icon-Radio', 'icon icon-TV', 'icon icon-Flip-horizontal', 'icon icon-Flip-vertical', 'icon icon-Line', 'icon icon-Pixels', 'icon icon-Zoom-minus', 'icon icon-Zoom-plus', 'icon icon-Dinner1', 'icon icon-Fork-spoon-knife', 'icon icon-Fork-spoon', 'icon icon-Knifefork', 'icon icon-Spoon', 'icon icon-Clipboard-list', 'icon icon-Dial-numbers', 'icon icon-Incoming-box', 'icon icon-Outgoing-box', 'icon icon-RSS', 'icon icon-Git-2', 'icon icon-Git-4', 'icon icon-Git1', 'icon icon-Git3', 'icon icon-Info-circle', 'icon icon-Warning-1-circle', 'icon icon-Warning-2' ) ) ) {
            $html .= '<span class="path3"></span>';
        }

        if( in_array( $icon['value'], array( 'icon icon-Chart-bar', 'icon icon-Chart-bar1', 'icon icon-Chart-bar2', 'icon icon-Exchange', 'icon icon-Up-down', 'icon icon-Equalizer', 'icon icon-Media-library', 'icon icon-Flower', 'icon icon-Lamp', 'icon icon-Picture', 'icon icon-Clipboard', 'icon icon-Beer', 'icon icon-Carrot', 'icon icon-Compilation', 'icon icon-Compiled-file', 'icon icon-Pictures', 'icon icon-Share', 'icon icon-Radio', 'icon icon-Pixels', 'icon icon-Fork-spoon-knife', 'icon icon-Clipboard-list', 'icon icon-Dial-numbers', 'icon icon-Git-2', 'icon icon-Git1' ) ) ) {
            $html .= '<span class="path4"></span>';
        }

        if( in_array( $icon['value'], array( 'icon icon-Compilation', 'icon icon-Compiled-file', 'icon icon-Pixels', 'icon icon-Fork-spoon-knife', 'icon icon-Clipboard-list', 'icon icon-Dial-numbers' ) ) ) {
            $html .= '<span class="path5"></span>';
        }

        if( in_array( $icon['value'], array( 'icon icon-Pixels', 'icon icon-Clipboard-list', 'icon icon-Dial-numbers' ) ) ) {
            $html .= '<span class="path6"></span>';
        }

        if( in_array( $icon['value'], array( 'icon icon-Clipboard-list', 'icon icon-Dial-numbers' ) ) ) {
            $html .= '<span class="path7"></span>';
            $html .= '<span class="path8"></span>';
        }

        if( in_array( $icon['value'], array( 'icon icon-Dial-numbers' ) ) ) {
            $html .= '<span class="path9"></span>';
        }

        $html .= '</span>';

        return $html;
    }
}